import React, { useState, useEffect, useRef, useContext, useMemo, useCallback } from 'react';
import classNames from 'classnames';
import { CSSTransition, TransitionGroup } from 'react-transition-group';
import { createPopper } from '@popperjs/core';
import ReactDOM from 'react-dom';
import _ from 'lodash';
import dayjs from 'dayjs';
import isBetween from 'dayjs/plugin/isBetween';
import tinycolor from 'tinycolor2';

function styleInject(css, ref) {
  if ( ref === void 0 ) ref = {};
  var insertAt = ref.insertAt;

  if (!css || typeof document === 'undefined') { return; }

  var head = document.head || document.getElementsByTagName('head')[0];
  var style = document.createElement('style');
  style.type = 'text/css';

  if (insertAt === 'top') {
    if (head.firstChild) {
      head.insertBefore(style, head.firstChild);
    } else {
      head.appendChild(style);
    }
  } else {
    head.appendChild(style);
  }

  if (style.styleSheet) {
    style.styleSheet.cssText = css;
  } else {
    style.appendChild(document.createTextNode(css));
  }
}

var css_248z = "@charset \"UTF-8\";\n:root {\n  /**\n   * 基础颜色\n   */\n  --i-bg: #fff;\n  --i-bg-hover: #f7f8fa;\n  --i-bg-active: #f2f3f5;\n  --i-bg-back: #e5e6ea;\n  --i-bg-disabled: #f5f7fa;\n  --i-bg-mid: rgba(0, 0, 0, 0.5);\n  --i-bg-mid-hover: rgba(0, 0, 0, 0.7);\n  --i-font: #252b33;\n  --i-font-2: #343c47;\n  --i-font-3: #4e5969;\n  --i-font-4: #67758b;\n  --i-font-5: #a2a5af;\n  --i-font-disabled: #c9cdd4;\n  /**\n   * 边框\n   */\n  --i-border: #e5e7eb;\n  --i-border-hover: #c9cdd4;\n  /**\n   * 阴影\n   */\n  --i-shadow: rgba(0, 0, 0, 0.12) 0px 3px 6px -4px, rgba(0, 0, 0, 0.08) 0px 6px 16px 0px,\n    rgba(0, 0, 0, 0.05) 0px 9px 28px 8px;\n  /**\n   * 主题色\n   */\n  --i-primary: #5e62ea;\n  --i-primary-hover: #7378fa;\n  --i-primary-active: #5155d3;\n  --i-primary-disabled: #969ef6;\n  --i-primary-txt: #5e62ea;\n  --i-primary-bg: rgba(94, 98, 234, 0.08);\n  --i-primary-bg-2: rgba(94, 98, 234, 0.16);\n  /**\n   * info 主题\n   */\n  --i-info: #e7e7e7;\n  --i-info-hover: #dcdcdc;\n  --i-info-active: #c1c1c1;\n  --i-info-disabled: #ededed;\n  --i-info-txt: #e7e7e7;\n  --i-info-bg: rgba(231, 231, 231, 0.08);\n  /**\n   * success 主题\n   */\n  --i-success: #65b687;\n  --i-success-hover: #62c58b;\n  --i-success-active: #4f9b6e;\n  --i-success-disabled: #92ccaa;\n  --i-success-txt: #65b687;\n  --i-success-bg: rgba(101, 182, 135, 0.08);\n  /**\n   * warning 主题\n   */\n  --i-warning: #f1ac51;\n  --i-warning-hover: #f19e46;\n  --i-warning-active: #de8a2b;\n  --i-warning-disabled: #f3d19e;\n  --i-warning-txt: #f1ac51;\n  --i-warning-bg: rgba(241, 172, 81, 0.08);\n  /**\n   * error 主题\n   */\n  --i-error: #ec7491;\n  --i-error-hover: #f76e8e;\n  --i-error-active: #cd5571;\n  --i-error-disabled: #fab6b6;\n  --i-error-txt: #ec7491;\n  --i-error-bg: rgba(236, 116, 145, 0.08);\n}\n\nhtml.dark,\n*[data-theme=dark],\n*[data-prefers-color=dark] {\n  /**\n   * 基础颜色\n   */\n  --i-bg: #17171a;\n  --i-bg-hover: #202023;\n  --i-bg-active: #29292c;\n  --i-bg-back: #333336;\n  --i-bg-disabled: #262627;\n  --i-bg-mid: rgba(255, 255, 255, 0.1);\n  --i-bg-mid-hover: rgba(255, 255, 255, 0.2);\n  --i-font: #fff;\n  --i-font-2: #dcdcdc;\n  --i-font-3: #bababb;\n  --i-font-4: #a5a5a5;\n  --i-font-5: #8e9095;\n  --i-font-disabled: #737375;\n  /**\n   * 边框颜色\n   */\n  --i-border: #484849;\n  --i-border-hover: #737375;\n  /**\n   * 阴影\n   */\n  --i-shadow: rgba(0, 0, 0, 0.48) 0px 3px 6px -4px, rgba(0, 0, 0, 0.32) 0px 6px 16px 0px,\n    rgba(0, 0, 0, 0.2) 0px 9px 28px 8px;\n  /**\n   * 主题色\n   */\n  --i-primary: #3033ab;\n  --i-primary-hover: #484aa9;\n  --i-primary-active: #282b95;\n  --i-primary-disabled: #595d85;\n  --i-primary-txt: #8689e0;\n  --i-primary-bg: rgba(134, 137, 224, 0.08);\n  /**\n   * info 主题\n   */\n  --i-info: #29292c;\n  --i-info-hover: #333336;\n  --i-info-active: #3c3c3f;\n  --i-info-disabled: #29292c;\n  --i-info-txt: #29292c;\n  --i-info-bg: rgba(41, 41, 44, 0.08);\n  /**\n   * success 主题\n   */\n  --i-success: #5e8c3e;\n  --i-success-hover: #669843;\n  --i-success-active: #4a7130;\n  --i-success-disabled: #687a5c;\n  --i-success-txt: #91b6a0;\n  --i-success-bg: rgba(145, 182, 160, 0.08);\n  /**\n   * warning 主题\n   */\n  --i-warning: #9f7639;\n  --i-warning-hover: #a97f3f;\n  --i-warning-active: #8c6832;\n  --i-warning-disabled: #80735c;\n  --i-warning-txt: #9f7639;\n  --i-warning-bg: rgba(159, 118, 57, 0.08);\n  /**\n   * error 主题\n   */\n  --i-error: #a2514e;\n  --i-error-hover: #ab615f;\n  --i-error-active: #8f4441;\n  --i-error-disabled: #826665;\n  --i-error-txt: #a2514e;\n  --i-error-bg: rgba(162, 81, 78, 0.08);\n}";
styleInject(css_248z);

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    enumerableOnly && (symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    })), keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = null != arguments[i] ? arguments[i] : {};
    i % 2 ? ownKeys(Object(source), !0).forEach(function (key) {
      _defineProperty(target, key, source[key]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) {
      Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
    });
  }

  return target;
}

function _typeof(obj) {
  "@babel/helpers - typeof";

  return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) {
    return typeof obj;
  } : function (obj) {
    return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
  }, _typeof(obj);
}

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};

  var target = _objectWithoutPropertiesLoose(source, excluded);

  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest();
}

function _toConsumableArray(arr) {
  return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread();
}

function _arrayWithoutHoles(arr) {
  if (Array.isArray(arr)) return _arrayLikeToArray(arr);
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArray(iter) {
  if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter);
}

function _iterableToArrayLimit(arr, i) {
  var _i = arr == null ? null : typeof Symbol !== "undefined" && arr[Symbol.iterator] || arr["@@iterator"];

  if (_i == null) return;
  var _arr = [];
  var _n = true;
  var _d = false;

  var _s, _e;

  try {
    for (_i = _i.call(arr); !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _nonIterableSpread() {
  throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
}

var css_248z$1 = ".i-button {\n  position: relative;\n  z-index: 0;\n  display: inline-flex;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  height: 32px;\n  margin: 0;\n  padding: 0 12px;\n  color: var(--i-font);\n  font-size: 14px;\n  white-space: nowrap;\n  text-align: center;\n  text-transform: none;\n  vertical-align: middle;\n  -moz-tab-size: 4;\n    -o-tab-size: 4;\n       tab-size: 4;\n  border: 1px solid transparent;\n  border-radius: 4px;\n  outline: none;\n  cursor: pointer;\n  transition: all 0.2s linear;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-button .i-button-icon {\n  margin-right: 6px;\n  color: inherit;\n  font-size: inherit;\n}\n.i-button.i-button--variant-dashed {\n  border-style: dashed !important;\n}\n.i-button.i-button--variant-text {\n  border-color: transparent !important;\n}\n.i-button.i-button--size-small {\n  height: 24px;\n  padding: 0 8px;\n  font-size: 12px;\n}\n.i-button.i-button--size-small .i-button-icon {\n  margin-right: 4px;\n}\n.i-button.i-button--size-large {\n  height: 40px;\n  padding: 0 16px;\n  font-size: 16px;\n}\n.i-button.i-button--size-large .i-button-icon {\n  margin-right: 8px;\n}\n.i-button.i-button--shape-square {\n  border-radius: 0px;\n}\n.i-button.i-button--shape-circle {\n  border-radius: 20px;\n}\n.i-button.i-button-disabled {\n  cursor: not-allowed;\n}\n\n.i-button--type-info {\n  color: #fff;\n  background: var(--i-info);\n  color: var(--i-font);\n}\n.i-button--type-info:hover {\n  background: var(--i-info-hover);\n}\n.i-button--type-info:active {\n  background: var(--i-info-active);\n}\n.i-button--type-info.i-button--variant-text, .i-button--type-info.i-button--variant-outline, .i-button--type-info.i-button--variant-dashed {\n  color: var(--i-info);\n  background: transparent;\n  border: 1px solid var(--i-info);\n}\n.i-button--type-info.i-button--variant-text:hover, .i-button--type-info.i-button--variant-outline:hover, .i-button--type-info.i-button--variant-dashed:hover {\n  color: var(--i-info-hover);\n  background: transparent;\n  border-color: var(--i-info-hover);\n}\n.i-button--type-info.i-button--variant-text:active, .i-button--type-info.i-button--variant-outline:active, .i-button--type-info.i-button--variant-dashed:active {\n  color: var(--i-info-active);\n  background: transparent;\n  border-color: var(--i-info-active);\n}\n.i-button--type-info.i-button-active {\n  background: var(--i-info-active);\n}\n.i-button--type-info.i-button-active:hover {\n  background: var(--i-info-active);\n}\n.i-button--type-info.i-button-active.i-button--variant-text, .i-button--type-info.i-button-active.i-button--variant-outline, .i-button--type-info.i-button-active.i-button--variant-dashed {\n  color: var(--i-info-active);\n  background: transparent;\n  border: 1px solid var(--i-info-active);\n}\n.i-button--type-info.i-button-disabled {\n  background: var(--i-info-disabled);\n}\n.i-button--type-info.i-button-disabled:hover {\n  background: var(--i-info-disabled);\n}\n.i-button--type-info.i-button-disabled.i-button--variant-text, .i-button--type-info.i-button-disabled.i-button--variant-outline, .i-button--type-info.i-button-disabled.i-button--variant-dashed {\n  color: var(--i-info-disabled);\n  background: transparent;\n  border-color: var(--i-info-disabled);\n}\n.i-button--type-info.i-button-disabled.i-button--variant-text:hover, .i-button--type-info.i-button-disabled.i-button--variant-outline:hover, .i-button--type-info.i-button-disabled.i-button--variant-dashed:hover {\n  color: var(--i-info-disabled);\n  border-color: var(--i-info-disabled);\n}\n.i-button--type-info.i-button-disabled.i-button--variant-text:active, .i-button--type-info.i-button-disabled.i-button--variant-outline:active, .i-button--type-info.i-button-disabled.i-button--variant-dashed:active {\n  color: var(--i-info-disabled);\n  border-color: var(--i-info-disabled);\n}\n.i-button--type-info.i-button--variant-text, .i-button--type-info.i-button--variant-outline, .i-button--type-info.i-button--variant-dashed {\n  color: var(--i-font);\n}\n.i-button--type-info.i-button--variant-text:hover, .i-button--type-info.i-button--variant-outline:hover, .i-button--type-info.i-button--variant-dashed:hover {\n  color: var(--i-font);\n}\n.i-button--type-info.i-button--variant-text:active, .i-button--type-info.i-button--variant-outline:active, .i-button--type-info.i-button--variant-dashed:active {\n  color: var(--i-font);\n}\n.i-button--type-info.i-button-active {\n  color: var(--i-font);\n}\n.i-button--type-info.i-button-active.i-button--variant-text, .i-button--type-info.i-button-active.i-button--variant-outline, .i-button--type-info.i-button-active.i-button--variant-dashed {\n  color: var(--i-font);\n}\n.i-button--type-info.i-button-active.i-button--variant-text:hover, .i-button--type-info.i-button-active.i-button--variant-outline:hover, .i-button--type-info.i-button-active.i-button--variant-dashed:hover {\n  color: var(--i-font);\n}\n.i-button--type-info.i-button-disabled {\n  color: #aaaeb6;\n}\n.i-button--type-info.i-button-disabled.i-button--variant-text, .i-button--type-info.i-button-disabled.i-button--variant-outline, .i-button--type-info.i-button-disabled.i-button--variant-dashed {\n  color: #c0c4cc;\n}\n.i-button--type-info.i-button-disabled.i-button--variant-text:hover, .i-button--type-info.i-button-disabled.i-button--variant-outline:hover, .i-button--type-info.i-button-disabled.i-button--variant-dashed:hover {\n  color: #c0c4cc;\n}\n.i-button--type-info.i-button-disabled.i-button--variant-text:active, .i-button--type-info.i-button-disabled.i-button--variant-outline:active, .i-button--type-info.i-button-disabled.i-button--variant-dashed:active {\n  color: #c0c4cc;\n}\n\n.i-button--type-primary {\n  color: #fff;\n  background: var(--i-primary);\n}\n.i-button--type-primary:hover {\n  background: var(--i-primary-hover);\n}\n.i-button--type-primary:active {\n  background: var(--i-primary-active);\n}\n.i-button--type-primary.i-button--variant-text, .i-button--type-primary.i-button--variant-outline, .i-button--type-primary.i-button--variant-dashed {\n  color: var(--i-primary);\n  background: transparent;\n  border: 1px solid var(--i-primary);\n}\n.i-button--type-primary.i-button--variant-text:hover, .i-button--type-primary.i-button--variant-outline:hover, .i-button--type-primary.i-button--variant-dashed:hover {\n  color: var(--i-primary-hover);\n  background: transparent;\n  border-color: var(--i-primary-hover);\n}\n.i-button--type-primary.i-button--variant-text:active, .i-button--type-primary.i-button--variant-outline:active, .i-button--type-primary.i-button--variant-dashed:active {\n  color: var(--i-primary-active);\n  background: transparent;\n  border-color: var(--i-primary-active);\n}\n.i-button--type-primary.i-button-active {\n  background: var(--i-primary-active);\n}\n.i-button--type-primary.i-button-active:hover {\n  background: var(--i-primary-active);\n}\n.i-button--type-primary.i-button-active.i-button--variant-text, .i-button--type-primary.i-button-active.i-button--variant-outline, .i-button--type-primary.i-button-active.i-button--variant-dashed {\n  color: var(--i-primary-active);\n  background: transparent;\n  border: 1px solid var(--i-primary-active);\n}\n.i-button--type-primary.i-button-disabled {\n  background: var(--i-primary-disabled);\n}\n.i-button--type-primary.i-button-disabled:hover {\n  background: var(--i-primary-disabled);\n}\n.i-button--type-primary.i-button-disabled.i-button--variant-text, .i-button--type-primary.i-button-disabled.i-button--variant-outline, .i-button--type-primary.i-button-disabled.i-button--variant-dashed {\n  color: var(--i-primary-disabled);\n  background: transparent;\n  border-color: var(--i-primary-disabled);\n}\n.i-button--type-primary.i-button-disabled.i-button--variant-text:hover, .i-button--type-primary.i-button-disabled.i-button--variant-outline:hover, .i-button--type-primary.i-button-disabled.i-button--variant-dashed:hover {\n  color: var(--i-primary-disabled);\n  border-color: var(--i-primary-disabled);\n}\n.i-button--type-primary.i-button-disabled.i-button--variant-text:active, .i-button--type-primary.i-button-disabled.i-button--variant-outline:active, .i-button--type-primary.i-button-disabled.i-button--variant-dashed:active {\n  color: var(--i-primary-disabled);\n  border-color: var(--i-primary-disabled);\n}\n\n.i-button--type-success {\n  color: #fff;\n  background: var(--i-success);\n}\n.i-button--type-success:hover {\n  background: var(--i-success-hover);\n}\n.i-button--type-success:active {\n  background: var(--i-success-active);\n}\n.i-button--type-success.i-button--variant-text, .i-button--type-success.i-button--variant-outline, .i-button--type-success.i-button--variant-dashed {\n  color: var(--i-success);\n  background: transparent;\n  border: 1px solid var(--i-success);\n}\n.i-button--type-success.i-button--variant-text:hover, .i-button--type-success.i-button--variant-outline:hover, .i-button--type-success.i-button--variant-dashed:hover {\n  color: var(--i-success-hover);\n  background: transparent;\n  border-color: var(--i-success-hover);\n}\n.i-button--type-success.i-button--variant-text:active, .i-button--type-success.i-button--variant-outline:active, .i-button--type-success.i-button--variant-dashed:active {\n  color: var(--i-success-active);\n  background: transparent;\n  border-color: var(--i-success-active);\n}\n.i-button--type-success.i-button-active {\n  background: var(--i-success-active);\n}\n.i-button--type-success.i-button-active:hover {\n  background: var(--i-success-active);\n}\n.i-button--type-success.i-button-active.i-button--variant-text, .i-button--type-success.i-button-active.i-button--variant-outline, .i-button--type-success.i-button-active.i-button--variant-dashed {\n  color: var(--i-success-active);\n  background: transparent;\n  border: 1px solid var(--i-success-active);\n}\n.i-button--type-success.i-button-disabled {\n  background: var(--i-success-disabled);\n}\n.i-button--type-success.i-button-disabled:hover {\n  background: var(--i-success-disabled);\n}\n.i-button--type-success.i-button-disabled.i-button--variant-text, .i-button--type-success.i-button-disabled.i-button--variant-outline, .i-button--type-success.i-button-disabled.i-button--variant-dashed {\n  color: var(--i-success-disabled);\n  background: transparent;\n  border-color: var(--i-success-disabled);\n}\n.i-button--type-success.i-button-disabled.i-button--variant-text:hover, .i-button--type-success.i-button-disabled.i-button--variant-outline:hover, .i-button--type-success.i-button-disabled.i-button--variant-dashed:hover {\n  color: var(--i-success-disabled);\n  border-color: var(--i-success-disabled);\n}\n.i-button--type-success.i-button-disabled.i-button--variant-text:active, .i-button--type-success.i-button-disabled.i-button--variant-outline:active, .i-button--type-success.i-button-disabled.i-button--variant-dashed:active {\n  color: var(--i-success-disabled);\n  border-color: var(--i-success-disabled);\n}\n\n.i-button--type-warning {\n  color: #fff;\n  background: var(--i-warning);\n}\n.i-button--type-warning:hover {\n  background: var(--i-warning-hover);\n}\n.i-button--type-warning:active {\n  background: var(--i-warning-active);\n}\n.i-button--type-warning.i-button--variant-text, .i-button--type-warning.i-button--variant-outline, .i-button--type-warning.i-button--variant-dashed {\n  color: var(--i-warning);\n  background: transparent;\n  border: 1px solid var(--i-warning);\n}\n.i-button--type-warning.i-button--variant-text:hover, .i-button--type-warning.i-button--variant-outline:hover, .i-button--type-warning.i-button--variant-dashed:hover {\n  color: var(--i-warning-hover);\n  background: transparent;\n  border-color: var(--i-warning-hover);\n}\n.i-button--type-warning.i-button--variant-text:active, .i-button--type-warning.i-button--variant-outline:active, .i-button--type-warning.i-button--variant-dashed:active {\n  color: var(--i-warning-active);\n  background: transparent;\n  border-color: var(--i-warning-active);\n}\n.i-button--type-warning.i-button-active {\n  background: var(--i-warning-active);\n}\n.i-button--type-warning.i-button-active:hover {\n  background: var(--i-warning-active);\n}\n.i-button--type-warning.i-button-active.i-button--variant-text, .i-button--type-warning.i-button-active.i-button--variant-outline, .i-button--type-warning.i-button-active.i-button--variant-dashed {\n  color: var(--i-warning-active);\n  background: transparent;\n  border: 1px solid var(--i-warning-active);\n}\n.i-button--type-warning.i-button-disabled {\n  background: var(--i-warning-disabled);\n}\n.i-button--type-warning.i-button-disabled:hover {\n  background: var(--i-warning-disabled);\n}\n.i-button--type-warning.i-button-disabled.i-button--variant-text, .i-button--type-warning.i-button-disabled.i-button--variant-outline, .i-button--type-warning.i-button-disabled.i-button--variant-dashed {\n  color: var(--i-warning-disabled);\n  background: transparent;\n  border-color: var(--i-warning-disabled);\n}\n.i-button--type-warning.i-button-disabled.i-button--variant-text:hover, .i-button--type-warning.i-button-disabled.i-button--variant-outline:hover, .i-button--type-warning.i-button-disabled.i-button--variant-dashed:hover {\n  color: var(--i-warning-disabled);\n  border-color: var(--i-warning-disabled);\n}\n.i-button--type-warning.i-button-disabled.i-button--variant-text:active, .i-button--type-warning.i-button-disabled.i-button--variant-outline:active, .i-button--type-warning.i-button-disabled.i-button--variant-dashed:active {\n  color: var(--i-warning-disabled);\n  border-color: var(--i-warning-disabled);\n}\n\n.i-button--type-error {\n  color: #fff;\n  background: var(--i-error);\n}\n.i-button--type-error:hover {\n  background: var(--i-error-hover);\n}\n.i-button--type-error:active {\n  background: var(--i-error-active);\n}\n.i-button--type-error.i-button--variant-text, .i-button--type-error.i-button--variant-outline, .i-button--type-error.i-button--variant-dashed {\n  color: var(--i-error);\n  background: transparent;\n  border: 1px solid var(--i-error);\n}\n.i-button--type-error.i-button--variant-text:hover, .i-button--type-error.i-button--variant-outline:hover, .i-button--type-error.i-button--variant-dashed:hover {\n  color: var(--i-error-hover);\n  background: transparent;\n  border-color: var(--i-error-hover);\n}\n.i-button--type-error.i-button--variant-text:active, .i-button--type-error.i-button--variant-outline:active, .i-button--type-error.i-button--variant-dashed:active {\n  color: var(--i-error-active);\n  background: transparent;\n  border-color: var(--i-error-active);\n}\n.i-button--type-error.i-button-active {\n  background: var(--i-error-active);\n}\n.i-button--type-error.i-button-active:hover {\n  background: var(--i-error-active);\n}\n.i-button--type-error.i-button-active.i-button--variant-text, .i-button--type-error.i-button-active.i-button--variant-outline, .i-button--type-error.i-button-active.i-button--variant-dashed {\n  color: var(--i-error-active);\n  background: transparent;\n  border: 1px solid var(--i-error-active);\n}\n.i-button--type-error.i-button-disabled {\n  background: var(--i-error-disabled);\n}\n.i-button--type-error.i-button-disabled:hover {\n  background: var(--i-error-disabled);\n}\n.i-button--type-error.i-button-disabled.i-button--variant-text, .i-button--type-error.i-button-disabled.i-button--variant-outline, .i-button--type-error.i-button-disabled.i-button--variant-dashed {\n  color: var(--i-error-disabled);\n  background: transparent;\n  border-color: var(--i-error-disabled);\n}\n.i-button--type-error.i-button-disabled.i-button--variant-text:hover, .i-button--type-error.i-button-disabled.i-button--variant-outline:hover, .i-button--type-error.i-button-disabled.i-button--variant-dashed:hover {\n  color: var(--i-error-disabled);\n  border-color: var(--i-error-disabled);\n}\n.i-button--type-error.i-button-disabled.i-button--variant-text:active, .i-button--type-error.i-button-disabled.i-button--variant-outline:active, .i-button--type-error.i-button-disabled.i-button--variant-dashed:active {\n  color: var(--i-error-disabled);\n  border-color: var(--i-error-disabled);\n}";
styleInject(css_248z$1);

var css_248z$2 = "@font-face {\n  font-family: \"idesignicon\";\n  src: url(\"\");\n  src: url(\"?#iefix\") format(\"embedded-opentype\"), url(\"//at.alicdn.com/t/font_3161433_glke53nnqws.woff2?t=1654516269726\") format(\"woff2\"), url(\"//at.alicdn.com/t/font_3161433_glke53nnqws.woff?t=1654516269726\") format(\"woff\"), url(\"//at.alicdn.com/t/font_3161433_glke53nnqws.ttf?t=1654516269726\") format(\"truetype\"), url(\"#iconfont\") format(\"svg\");\n}\n.i-icon {\n  color: var(--i-font-3);\n  font-size: 16px;\n  font-family: \"idesignicon\" !important;\n  font-style: normal;\n  -webkit-font-smoothing: antialiased;\n  -moz-osx-font-smoothing: grayscale;\n}\n\n.icon-StarFill:before {\n  content: \"\\e690\";\n}\n\n.icon-Dropper:before {\n  content: \"\\e6bf\";\n}\n\n.icon-Clock:before {\n  content: \"\\e6be\";\n}\n\n.icon-ViewHide:before {\n  content: \"\\e6bc\";\n}\n\n.icon-View:before {\n  content: \"\\e6bd\";\n}\n\n.icon-TagPrice:before {\n  content: \"\\e6ba\";\n}\n\n.icon-TagCollection:before {\n  content: \"\\e6bb\";\n}\n\n.icon-AddFile:before {\n  content: \"\\e6b9\";\n}\n\n.icon-CheckBold:before {\n  content: \"\\e653\";\n}\n\n.icon-SearchSub:before {\n  content: \"\\e654\";\n}\n\n.icon-UserFilled:before {\n  content: \"\\e655\";\n}\n\n.icon-ChatSquare:before {\n  content: \"\\e656\";\n}\n\n.icon-ArrowLineTopLeft:before {\n  content: \"\\e657\";\n}\n\n.icon-ShoppingCart:before {\n  content: \"\\e658\";\n}\n\n.icon-RefreshLeft:before {\n  content: \"\\e659\";\n}\n\n.icon-Filter:before {\n  content: \"\\e65b\";\n}\n\n.icon-Share:before {\n  content: \"\\e65c\";\n}\n\n.icon-SearchPlus:before {\n  content: \"\\e65d\";\n}\n\n.icon-Flag:before {\n  content: \"\\e65e\";\n}\n\n.icon-LocationFill:before {\n  content: \"\\e65f\";\n}\n\n.icon-DeleteFill:before {\n  content: \"\\e660\";\n}\n\n.icon-Histogram:before {\n  content: \"\\e661\";\n}\n\n.icon-LinkDouble:before {\n  content: \"\\e662\";\n}\n\n.icon-More:before {\n  content: \"\\e663\";\n}\n\n.icon-ArrowSortBottom:before {\n  content: \"\\e664\";\n}\n\n.icon-TipPlus:before {\n  content: \"\\e665\";\n}\n\n.icon-ChatLineSquare:before {\n  content: \"\\e666\";\n}\n\n.icon-Female:before {\n  content: \"\\e667\";\n}\n\n.icon-ChatDotSquare:before {\n  content: \"\\e668\";\n}\n\n.icon-ArrowSort:before {\n  content: \"\\e669\";\n}\n\n.icon-Search:before {\n  content: \"\\e66a\";\n}\n\n.icon-Copy:before {\n  content: \"\\e66b\";\n}\n\n.icon-ArrowDoubleRight:before {\n  content: \"\\e66c\";\n}\n\n.icon-TipSubFill:before {\n  content: \"\\e66d\";\n}\n\n.icon-TheSub:before {\n  content: \"\\e66e\";\n}\n\n.icon-Loading:before {\n  content: \"\\e66f\";\n}\n\n.icon-PictureRounded:before {\n  content: \"\\e670\";\n}\n\n.icon-Edit:before {\n  content: \"\\e671\";\n}\n\n.icon-TipQuestion:before {\n  content: \"\\e672\";\n}\n\n.icon-TipPlusFill:before {\n  content: \"\\e673\";\n}\n\n.icon-ShoppingCartFull:before {\n  content: \"\\e674\";\n}\n\n.icon-TipSub:before {\n  content: \"\\e675\";\n}\n\n.icon-TipInfo:before {\n  content: \"\\e676\";\n}\n\n.icon-ArrowCaretLeft:before {\n  content: \"\\e677\";\n}\n\n.icon-Star:before {\n  content: \"\\e678\";\n}\n\n.icon-Link:before {\n  content: \"\\e679\";\n}\n\n.icon-ChatLineRound:before {\n  content: \"\\e67a\";\n}\n\n.icon-TipWarningFill:before {\n  content: \"\\e67b\";\n}\n\n.icon-TipCheckFill:before {\n  content: \"\\e67c\";\n}\n\n.icon-Delete:before {\n  content: \"\\e67d\";\n}\n\n.icon-Bell:before {\n  content: \"\\e67e\";\n}\n\n.icon-LocationArrow:before {\n  content: \"\\e67f\";\n}\n\n.icon-ArrowLineUpload:before {\n  content: \"\\e680\";\n}\n\n.icon-ArrowCaretRight:before {\n  content: \"\\e681\";\n}\n\n.icon-ArrowCaretSort:before {\n  content: \"\\e682\";\n}\n\n.icon-SettingFill:before {\n  content: \"\\e683\";\n}\n\n.icon-User:before {\n  content: \"\\e684\";\n}\n\n.icon-Location:before {\n  content: \"\\e685\";\n}\n\n.icon-MoreFilled:before {\n  content: \"\\e686\";\n}\n\n.icon-ArrowLineRight:before {\n  content: \"\\e687\";\n}\n\n.icon-ArrowLineTopRight:before {\n  content: \"\\e688\";\n}\n\n.icon-ArrowLeftBold:before {\n  content: \"\\e689\";\n}\n\n.icon-UserAvatar:before {\n  content: \"\\e68a\";\n}\n\n.icon-ArrowCaretBottom:before {\n  content: \"\\e68b\";\n}\n\n.icon-ArrowLineBottomLeft:before {\n  content: \"\\e68c\";\n}\n\n.icon-PictureFilled:before {\n  content: \"\\e68d\";\n}\n\n.icon-RefreshRight:before {\n  content: \"\\e68e\";\n}\n\n.icon-ArrowSort2:before {\n  content: \"\\e68f\";\n}\n\n.icon-Check:before {\n  content: \"\\e691\";\n}\n\n.icon-ArrowLeft:before {\n  content: \"\\e692\";\n}\n\n.icon-Menu:before {\n  content: \"\\e693\";\n}\n\n.icon-ModeLight:before {\n  content: \"\\e694\";\n}\n\n.icon-CloseBold:before {\n  content: \"\\e695\";\n}\n\n.icon-ArrowLineBottom:before {\n  content: \"\\e696\";\n}\n\n.icon-BellMute:before {\n  content: \"\\e697\";\n}\n\n.icon-TipWarning:before {\n  content: \"\\e698\";\n}\n\n.icon-BellFill:before {\n  content: \"\\e699\";\n}\n\n.icon-ArrowDown:before {\n  content: \"\\e69a\";\n}\n\n.icon-TipCheck:before {\n  content: \"\\e69b\";\n}\n\n.icon-TipClose:before {\n  content: \"\\e69c\";\n}\n\n.icon-ModeDark:before {\n  content: \"\\e69d\";\n}\n\n.icon-ArrowCaretTop:before {\n  content: \"\\e69e\";\n}\n\n.icon-TipCloseFill:before {\n  content: \"\\e69f\";\n}\n\n.icon-Email:before {\n  content: \"\\e6a0\";\n}\n\n.icon-ArrowUpBold:before {\n  content: \"\\e6a1\";\n}\n\n.icon-ArrowRight:before {\n  content: \"\\e6a2\";\n}\n\n.icon-Close:before {\n  content: \"\\e6a3\";\n}\n\n.icon-Lock:before {\n  content: \"\\e6a4\";\n}\n\n.icon-Frame:before {\n  content: \"\\e6a5\";\n}\n\n.icon-EditPen:before {\n  content: \"\\e6a6\";\n}\n\n.icon-ArrowLineLeft:before {\n  content: \"\\e6a7\";\n}\n\n.icon-ChatRound:before {\n  content: \"\\e6a8\";\n}\n\n.icon-ArrowLineBottomRight:before {\n  content: \"\\e6a9\";\n}\n\n.icon-Setting:before {\n  content: \"\\e6aa\";\n}\n\n.icon-ThePlus:before {\n  content: \"\\e6ab\";\n}\n\n.icon-FullScreen:before {\n  content: \"\\e6ac\";\n}\n\n.icon-ArrowDownBold:before {\n  content: \"\\e6ad\";\n}\n\n.icon-Male:before {\n  content: \"\\e6ae\";\n}\n\n.icon-ArrowLineDownload:before {\n  content: \"\\e6af\";\n}\n\n.icon-ArrowSortTop:before {\n  content: \"\\e6b0\";\n}\n\n.icon-ChatDotRound:before {\n  content: \"\\e6b1\";\n}\n\n.icon-Picture:before {\n  content: \"\\e6b2\";\n}\n\n.icon-Unlock:before {\n  content: \"\\e6b3\";\n}\n\n.icon-ArrowUp:before {\n  content: \"\\e6b4\";\n}\n\n.icon-ArrowDoubleLeft:before {\n  content: \"\\e6b5\";\n}\n\n.icon-Calendar:before {\n  content: \"\\e6b6\";\n}\n\n.icon-ArrowRightBold:before {\n  content: \"\\e6b7\";\n}\n\n.icon-Refresh:before {\n  content: \"\\e6b8\";\n}";
styleInject(css_248z$2);

var _excluded = ["className", "style", "name", "size", "color", "disabled", "onClick"];

var Icon = function Icon(props) {
  var className = props.className,
      style = props.style,
      _props$name = props.name,
      name = _props$name === void 0 ? 'UserAvatar' : _props$name,
      size = props.size,
      color = props.color,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      onClick = props.onClick,
      restProps = _objectWithoutProperties(props, _excluded);

  var iconStyles = _objectSpread2({
    color: color,
    fontSize: size && parseInt(size.toString())
  }, style);

  return /*#__PURE__*/React.createElement("i", _objectSpread2({
    style: iconStyles,
    className: classNames('i-icon', "icon-".concat(name), disabled && 'i-icon-is-disabled', className),
    onClick: !disabled ? onClick : function () {
      return;
    }
  }, restProps));
};

var _excluded$1 = ["active", "children", "className", "disabled", "shape", "size", "style", "type", "variant", "icon", "onClick"];
/**
 * 按钮组件
 */

var Button = function Button(props) {
  var _props$active = props.active,
      active = _props$active === void 0 ? false : _props$active,
      _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$shape = props.shape,
      shape = _props$shape === void 0 ? 'round' : _props$shape,
      _props$size = props.size,
      size = _props$size === void 0 ? 'medium' : _props$size,
      style = props.style,
      _props$type = props.type,
      type = _props$type === void 0 ? 'primary' : _props$type,
      _props$variant = props.variant,
      variant = _props$variant === void 0 ? 'base' : _props$variant,
      icon = props.icon,
      _props$onClick = props.onClick,
      onClick = _props$onClick === void 0 ? function () {} : _props$onClick,
      buttonProps = _objectWithoutProperties(props, _excluded$1);

  return /*#__PURE__*/React.createElement("button", _objectSpread2({
    className: classNames('i-button', "i-button--type-".concat(type), variant !== 'base' && "i-button--variant-".concat(variant), size !== 'medium' && "i-button--size-".concat(size), shape !== 'round' && "i-button--shape-".concat(shape), active && 'i-button-active', disabled && 'i-button-disabled', className),
    style: _objectSpread2({}, style),
    disabled: disabled,
    onClick: onClick
  }, buttonProps), icon && /*#__PURE__*/React.createElement(Icon, {
    className: 'i-button-icon',
    name: icon
  }), children);
};

Button.displayName = 'Button';

var css_248z$3 = ".i-divider {\n  box-sizing: border-box;\n  margin: 24px 0;\n  color: #303133;\n  font-size: 14px;\n  border-top: 1px solid var(--i-border);\n}\n\n.i-divider--dashed {\n  border-top-style: dashed;\n}\n\n.i-divider--with-text {\n  display: flex;\n  white-space: nowrap;\n  border-top: 0;\n}\n.i-divider--with-text::before, .i-divider--with-text::after {\n  position: relative;\n  top: 50%;\n  width: 50%;\n  border-top: 1px solid var(--i-border);\n  transform: translateY(calc(50% - 0.5px));\n  content: \"\";\n}\n\n.i-divider--with-text-left::before {\n  width: 5%;\n}\n.i-divider--with-text-left::after {\n  width: 95%;\n}\n\n.i-divider--with-text-right::after {\n  width: 5%;\n}\n.i-divider--with-text-right::before {\n  width: 95%;\n}\n\n.i-divider--text {\n  display: inline-block;\n  padding: 0 1em;\n}";
styleInject(css_248z$3);

var _excluded$2 = ["align", "children", "className", "dashed", "style"];

var Divider = function Divider(props) {
  var _props$align = props.align,
      align = _props$align === void 0 ? 'center' : _props$align,
      children = props.children,
      className = props.className,
      _props$dashed = props.dashed,
      dashed = _props$dashed === void 0 ? false : _props$dashed,
      style = props.style,
      restProps = _objectWithoutProperties(props, _excluded$2);

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-divider', dashed && 'i-divider--dashed', children && 'i-divider--with-text', children && "i-divider--with-text-".concat(align), className),
    style: _objectSpread2({}, style)
  }, restProps), children && /*#__PURE__*/React.createElement("span", {
    className: "i-divider--text"
  }, children));
};

Divider.displayName = 'Divider';

var css_248z$4 = ".i-grid {\n  width: 100%;\n  display: flex;\n  flex-flow: row wrap;\n  margin-right: 0px;\n  margin-left: 0px;\n}\n\n.i-grid--align-top {\n  align-items: flex-start;\n}\n\n.i-grid--align-middle {\n  align-items: center;\n}\n\n.i-grid--align-bottom {\n  align-items: flex-end;\n}\n\n.i-grid--justify-start {\n  justify-content: flex-start;\n}\n\n.i-grid--justify-center {\n  justify-content: center;\n}\n\n.i-grid--justify-end {\n  justify-content: flex-end;\n}\n\n.i-grid--justify-space-between {\n  justify-content: space-between;\n}\n\n.i-grid--justify-space-around {\n  justify-content: space-around;\n}\n\n.i-grid__item {\n  position: relative;\n  max-width: 100%;\n}\n\n.i-grid__item--align-top {\n  align-self: flex-start;\n}\n\n.i-grid__item--align-middle {\n  align-self: center;\n}\n\n.i-grid__item--align-bottom {\n  align-self: flex-end;\n}\n\n.i-grid__item--span-0 {\n  display: none;\n  max-width: 0%;\n  flex: 0 0 0%;\n}\n\n.i-grid__item--offset-0 {\n  margin-left: 0%;\n}\n\n.i-grid__item--order-0 {\n  order: 0;\n}\n\n.i-grid__item--span-1 {\n  display: block;\n  max-width: 4.1666666667%;\n  flex: 0 0 4.1666666667%;\n}\n\n.i-grid__item--offset-1 {\n  margin-left: 4.1666666667%;\n}\n\n.i-grid__item--order-1 {\n  order: 1;\n}\n\n.i-grid__item--span-2 {\n  display: block;\n  max-width: 8.3333333333%;\n  flex: 0 0 8.3333333333%;\n}\n\n.i-grid__item--offset-2 {\n  margin-left: 8.3333333333%;\n}\n\n.i-grid__item--order-2 {\n  order: 2;\n}\n\n.i-grid__item--span-3 {\n  display: block;\n  max-width: 12.5%;\n  flex: 0 0 12.5%;\n}\n\n.i-grid__item--offset-3 {\n  margin-left: 12.5%;\n}\n\n.i-grid__item--order-3 {\n  order: 3;\n}\n\n.i-grid__item--span-4 {\n  display: block;\n  max-width: 16.6666666667%;\n  flex: 0 0 16.6666666667%;\n}\n\n.i-grid__item--offset-4 {\n  margin-left: 16.6666666667%;\n}\n\n.i-grid__item--order-4 {\n  order: 4;\n}\n\n.i-grid__item--span-5 {\n  display: block;\n  max-width: 20.8333333333%;\n  flex: 0 0 20.8333333333%;\n}\n\n.i-grid__item--offset-5 {\n  margin-left: 20.8333333333%;\n}\n\n.i-grid__item--order-5 {\n  order: 5;\n}\n\n.i-grid__item--span-6 {\n  display: block;\n  max-width: 25%;\n  flex: 0 0 25%;\n}\n\n.i-grid__item--offset-6 {\n  margin-left: 25%;\n}\n\n.i-grid__item--order-6 {\n  order: 6;\n}\n\n.i-grid__item--span-7 {\n  display: block;\n  max-width: 29.1666666667%;\n  flex: 0 0 29.1666666667%;\n}\n\n.i-grid__item--offset-7 {\n  margin-left: 29.1666666667%;\n}\n\n.i-grid__item--order-7 {\n  order: 7;\n}\n\n.i-grid__item--span-8 {\n  display: block;\n  max-width: 33.3333333333%;\n  flex: 0 0 33.3333333333%;\n}\n\n.i-grid__item--offset-8 {\n  margin-left: 33.3333333333%;\n}\n\n.i-grid__item--order-8 {\n  order: 8;\n}\n\n.i-grid__item--span-9 {\n  display: block;\n  max-width: 37.5%;\n  flex: 0 0 37.5%;\n}\n\n.i-grid__item--offset-9 {\n  margin-left: 37.5%;\n}\n\n.i-grid__item--order-9 {\n  order: 9;\n}\n\n.i-grid__item--span-10 {\n  display: block;\n  max-width: 41.6666666667%;\n  flex: 0 0 41.6666666667%;\n}\n\n.i-grid__item--offset-10 {\n  margin-left: 41.6666666667%;\n}\n\n.i-grid__item--order-10 {\n  order: 10;\n}\n\n.i-grid__item--span-11 {\n  display: block;\n  max-width: 45.8333333333%;\n  flex: 0 0 45.8333333333%;\n}\n\n.i-grid__item--offset-11 {\n  margin-left: 45.8333333333%;\n}\n\n.i-grid__item--order-11 {\n  order: 11;\n}\n\n.i-grid__item--span-12 {\n  display: block;\n  max-width: 50%;\n  flex: 0 0 50%;\n}\n\n.i-grid__item--offset-12 {\n  margin-left: 50%;\n}\n\n.i-grid__item--order-12 {\n  order: 12;\n}\n\n.i-grid__item--span-13 {\n  display: block;\n  max-width: 54.1666666667%;\n  flex: 0 0 54.1666666667%;\n}\n\n.i-grid__item--offset-13 {\n  margin-left: 54.1666666667%;\n}\n\n.i-grid__item--order-13 {\n  order: 13;\n}\n\n.i-grid__item--span-14 {\n  display: block;\n  max-width: 58.3333333333%;\n  flex: 0 0 58.3333333333%;\n}\n\n.i-grid__item--offset-14 {\n  margin-left: 58.3333333333%;\n}\n\n.i-grid__item--order-14 {\n  order: 14;\n}\n\n.i-grid__item--span-15 {\n  display: block;\n  max-width: 62.5%;\n  flex: 0 0 62.5%;\n}\n\n.i-grid__item--offset-15 {\n  margin-left: 62.5%;\n}\n\n.i-grid__item--order-15 {\n  order: 15;\n}\n\n.i-grid__item--span-16 {\n  display: block;\n  max-width: 66.6666666667%;\n  flex: 0 0 66.6666666667%;\n}\n\n.i-grid__item--offset-16 {\n  margin-left: 66.6666666667%;\n}\n\n.i-grid__item--order-16 {\n  order: 16;\n}\n\n.i-grid__item--span-17 {\n  display: block;\n  max-width: 70.8333333333%;\n  flex: 0 0 70.8333333333%;\n}\n\n.i-grid__item--offset-17 {\n  margin-left: 70.8333333333%;\n}\n\n.i-grid__item--order-17 {\n  order: 17;\n}\n\n.i-grid__item--span-18 {\n  display: block;\n  max-width: 75%;\n  flex: 0 0 75%;\n}\n\n.i-grid__item--offset-18 {\n  margin-left: 75%;\n}\n\n.i-grid__item--order-18 {\n  order: 18;\n}\n\n.i-grid__item--span-19 {\n  display: block;\n  max-width: 79.1666666667%;\n  flex: 0 0 79.1666666667%;\n}\n\n.i-grid__item--offset-19 {\n  margin-left: 79.1666666667%;\n}\n\n.i-grid__item--order-19 {\n  order: 19;\n}\n\n.i-grid__item--span-20 {\n  display: block;\n  max-width: 83.3333333333%;\n  flex: 0 0 83.3333333333%;\n}\n\n.i-grid__item--offset-20 {\n  margin-left: 83.3333333333%;\n}\n\n.i-grid__item--order-20 {\n  order: 20;\n}\n\n.i-grid__item--span-21 {\n  display: block;\n  max-width: 87.5%;\n  flex: 0 0 87.5%;\n}\n\n.i-grid__item--offset-21 {\n  margin-left: 87.5%;\n}\n\n.i-grid__item--order-21 {\n  order: 21;\n}\n\n.i-grid__item--span-22 {\n  display: block;\n  max-width: 91.6666666667%;\n  flex: 0 0 91.6666666667%;\n}\n\n.i-grid__item--offset-22 {\n  margin-left: 91.6666666667%;\n}\n\n.i-grid__item--order-22 {\n  order: 22;\n}\n\n.i-grid__item--span-23 {\n  display: block;\n  max-width: 95.8333333333%;\n  flex: 0 0 95.8333333333%;\n}\n\n.i-grid__item--offset-23 {\n  margin-left: 95.8333333333%;\n}\n\n.i-grid__item--order-23 {\n  order: 23;\n}\n\n.i-grid__item--span-24 {\n  display: block;\n  max-width: 100%;\n  flex: 0 0 100%;\n}\n\n.i-grid__item--offset-24 {\n  margin-left: 100%;\n}\n\n.i-grid__item--order-24 {\n  order: 24;\n}";
styleInject(css_248z$4);

var _excluded$3 = ["align", "children", "className", "gutter", "order", "offset", "style", "span", "width"];

var GridItem = function GridItem(props) {
  var align = props.align,
      _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      gutter = props.gutter,
      order = props.order,
      offset = props.offset,
      style = props.style,
      _props$span = props.span,
      span = _props$span === void 0 ? 24 : _props$span,
      width = props.width,
      restProps = _objectWithoutProperties(props, _excluded$3);

  var limitNum = function limitNum(num) {
    var result = parseInt(num.toString());

    if (result > 24) {
      result = 24;
    }

    if (result < 0) {
      result = 0;
    }

    return result;
  };

  var computedWidth = function computedWidth(width) {
    if (isNaN(width)) {
      return width;
    }

    var result = width + 'px';
    return result;
  };

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-grid__item', "i-grid__item--span-".concat(limitNum(span)), offset && "i-grid__item--offset-".concat(limitNum(offset)), order && "i-grid__item--order-".concat(limitNum(order)), align && "i-grid__item--align-".concat(align), className),
    style: _objectSpread2(_objectSpread2(_objectSpread2({}, style || {}), {
      paddingLeft: gutter,
      paddingRight: gutter
    } || {}), width ? {
      flex: "0 0 ".concat(computedWidth(width)),
      maxWidth: computedWidth(width)
    } : {
      flex: '1'
    })
  }, restProps), children);
};

var _excluded$4 = ["align", "children", "className", "gutter", "justify", "style"];

var Grid = function Grid(props) {
  var align = props.align,
      _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      gutter = props.gutter,
      justify = props.justify,
      style = props.style,
      restProps = _objectWithoutProperties(props, _excluded$4);

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-grid', align && "i-grid--align-".concat(align), justify && "i-grid--justify-".concat(justify), className),
    style: _objectSpread2({}, style)
  }, restProps), React.Children.map(children, function (child) {
    if (! /*#__PURE__*/React.isValidElement(child)) {
      return null;
    }

    var childProps = {
      gutter: gutter
    };
    return /*#__PURE__*/React.cloneElement(child, childProps);
  }));
};

Grid.Item = GridItem;
Grid.displayName = 'Grid';
GridItem.displayName = 'GridItem';

var css_248z$5 = ".i-layout {\n  display: flex;\n  flex: auto;\n  flex-direction: column;\n}\n.i-layout.i-layout-has-aside {\n  flex-direction: row;\n}\n\n.i-layout--header {\n  box-sizing: border-box;\n}\n\n.i-layout--aside {\n  box-sizing: border-box;\n}\n\n.i-layout--content {\n  box-sizing: border-box;\n}\n\n.i-layout--footer {\n  box-sizing: border-box;\n}";
styleInject(css_248z$5);

var _excluded$5 = ["children", "className", "style"];

var LayoutHeader = function LayoutHeader(props) {
  var children = props.children,
      className = props.className,
      style = props.style,
      restProps = _objectWithoutProperties(props, _excluded$5);

  return /*#__PURE__*/React.createElement("header", _objectSpread2({
    className: classNames('i-layout--header', className),
    style: style
  }, restProps), children);
};

var _excluded$6 = ["width", "className", "style", "children"];

var LayoutAside = function LayoutAside(props) {
  var _props$width = props.width,
      width = _props$width === void 0 ? 240 : _props$width,
      className = props.className,
      style = props.style,
      children = props.children,
      otherAsideProps = _objectWithoutProperties(props, _excluded$6);

  var asideClassNames = classNames('i-layout--aside', className);
  var asideWidth = typeof width === 'number' ? "".concat(width, "px") : String(width);

  var asideStyle = _objectSpread2({
    width: asideWidth,
    maxWidth: asideWidth,
    minWidth: asideWidth,
    flex: "0 0 ".concat(asideWidth)
  }, style);

  return /*#__PURE__*/React.createElement("aside", _objectSpread2({
    className: asideClassNames,
    style: asideStyle
  }, otherAsideProps), children);
};

var _excluded$7 = ["children", "className", "style"];

var LayoutContent = function LayoutContent(props) {
  var children = props.children,
      className = props.className,
      style = props.style,
      restProps = _objectWithoutProperties(props, _excluded$7);

  return /*#__PURE__*/React.createElement("main", _objectSpread2({
    className: classNames('i-layout--content', className),
    style: style
  }, restProps), children);
};

var _excluded$8 = ["children", "className", "style"];

var LayoutFooter = function LayoutFooter(props) {
  var children = props.children,
      className = props.className,
      style = props.style,
      restProps = _objectWithoutProperties(props, _excluded$8);

  return /*#__PURE__*/React.createElement("footer", _objectSpread2({
    className: classNames('i-layout--footer', className),
    style: style
  }, restProps), children);
};

var _excluded$9 = ["children", "className", "style"];
/**
 * 布局组件
 */

var Layout = function Layout(props) {
  var children = props.children,
      className = props.className,
      style = props.style,
      restProps = _objectWithoutProperties(props, _excluded$9);

  var _useState = useState([]),
      _useState2 = _slicedToArray(_useState, 2),
      asides = _useState2[0],
      setAsides = _useState2[1];

  useEffect(function () {
    React.Children.forEach(children, function (child) {
      if (child.type === LayoutAside) setAsides([child]);
    });
  }, [children]);
  var layoutClassNames = classNames('i-layout', !!asides.length && 'i-layout-has-aside', className);
  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: layoutClassNames,
    style: style
  }, restProps), children);
};

Layout.Header = LayoutHeader;
Layout.Aside = LayoutAside;
Layout.Content = LayoutContent;
Layout.Footer = LayoutFooter;
LayoutHeader.displayName = 'LayoutHeader';
LayoutAside.displayName = 'LayoutAside';
LayoutContent.displayName = 'LayoutContent';
LayoutFooter.displayName = 'LayoutFooter';
Layout.displayName = 'Layout';

var css_248z$6 = ".i-scrollbar {\n  position: relative;\n}\n\n.i-scrollbar__wrap {\n  overflow: auto;\n}\n.i-scrollbar__wrap::-webkit-scrollbar {\n  display: none;\n}\n\n.i-scrollbar__barX,\n.i-scrollbar__barY {\n  position: absolute;\n  z-index: 1;\n}\n\n.i-scrollbar__barX {\n  bottom: 2px;\n  left: 2px;\n  width: 100%;\n  height: 6px;\n}\n\n.i-scrollbar__barY {\n  top: 2px;\n  right: 2px;\n  width: 6px;\n  height: 100%;\n}\n\n.i-scrollbar__thumbX,\n.i-scrollbar__thumbY {\n  position: relative;\n  background-color: rgba(144, 147, 153, 0.3);\n  border-radius: 4px;\n  cursor: pointer;\n  transition: background-color 0.2s ease-out;\n}\n.i-scrollbar__thumbX:hover,\n.i-scrollbar__thumbY:hover {\n  background-color: rgba(144, 147, 153, 0.5);\n}\n\n.i-scrollbar__thumbX {\n  width: 100px;\n  height: 100%;\n  transform: translateX(0%);\n}\n\n.i-scrollbar__thumbY {\n  width: 100%;\n  height: 100px;\n  transform: translateY(0%);\n}";
styleInject(css_248z$6);

var css_248z$7 = ".i-slide-in-top-enter {\n  transform: translateY(-100%);\n  opacity: 0;\n}\n\n.i-slide-in-top-enter-active {\n  transform: translate(0);\n  opacity: 1;\n  transition: transform 200ms ease-out, opacity 200ms ease-in-out;\n}\n\n.i-slide-in-top-exit {\n  opacity: 1;\n}\n\n.i-slide-in-top-exit-active {\n  transform: translateY(-100%);\n  opacity: 0;\n  transition: transform 300ms linear 100ms, opacity 300ms ease-in-out;\n}\n\n.i-slide-in-bottom-enter {\n  transform: translateY(100%);\n  opacity: 0;\n}\n\n.i-slide-in-bottom-enter-active {\n  transform: translate(0);\n  opacity: 1;\n  transition: transform 200ms ease-out, opacity 200ms ease-in-out;\n}\n\n.i-slide-in-bottom-exit {\n  opacity: 1;\n}\n\n.i-slide-in-bottom-exit-active {\n  transform: translateY(100%);\n  opacity: 0;\n  transition: transform 300ms linear 100ms, opacity 300ms ease-in-out;\n}\n\n.i-slide-in-left-enter {\n  transform: translateX(-100%);\n  opacity: 0;\n}\n\n.i-slide-in-left-enter-active {\n  transform: translate(0);\n  opacity: 1;\n  transition: transform 200ms ease-out, opacity 200ms ease-in-out;\n}\n\n.i-slide-in-left-exit {\n  opacity: 1;\n}\n\n.i-slide-in-left-exit-active {\n  transform: translateX(-100%);\n  opacity: 0;\n  transition: transform 300ms linear 100ms, opacity 300ms ease-in-out;\n}\n\n.i-slide-in-right-enter {\n  transform: translateX(100%);\n  opacity: 0;\n}\n\n.i-slide-in-right-enter-active {\n  transform: translate(0);\n  opacity: 1;\n  transition: transform 200ms ease-out, opacity 200ms ease-in-out;\n}\n\n.i-slide-in-right-exit {\n  opacity: 1;\n}\n\n.i-slide-in-right-exit-active {\n  transform: translateX(100%);\n  opacity: 0;\n  transition: transform 300ms linear 100ms, opacity 300ms ease-in-out;\n}\n\n.i-fade-in-enter {\n  opacity: 0;\n}\n\n.i-fade-in-enter-active {\n  opacity: 1;\n  transition: opacity 200ms ease-out;\n}\n\n.i-fade-in-exit {\n  opacity: 1;\n}\n\n.i-fade-in-exit-active {\n  opacity: 0;\n  transition: opacity 200ms ease-in;\n}";
styleInject(css_248z$7);

var _excluded$a = ["children", "animation", "nodeRef"];

var Transition = function Transition(props) {
  var children = props.children,
      animation = props.animation,
      nodeRef = props.nodeRef,
      restProps = _objectWithoutProperties(props, _excluded$a);

  return /*#__PURE__*/React.createElement(CSSTransition, _objectSpread2({
    classNames: "i-".concat(animation),
    nodeRef: nodeRef
  }, restProps), children);
};

Transition.defaultProps = {
  unmountOnExit: true,
  appear: true
};

var Scrollbar = function Scrollbar(props) {
  var children = props.children,
      height = props.height,
      width = props.width,
      onScrollX = props.onScrollX,
      onScrollY = props.onScrollY; // 滚动条显示隐藏

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      hoverShowThumb = _useState2[0],
      setHoverShowThumb = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      downShowThumb = _useState4[0],
      setDownShowThumb = _useState4[1]; // 视图实际宽高


  var _useState5 = useState(0),
      _useState6 = _slicedToArray(_useState5, 2),
      viewCurrentWidth = _useState6[0],
      setViewCurrentWidth = _useState6[1];

  var _useState7 = useState(0),
      _useState8 = _slicedToArray(_useState7, 2),
      viewCurrentHeight = _useState8[0],
      setViewCurrentHeight = _useState8[1]; // 视图总宽高


  var _useState9 = useState(0),
      _useState10 = _slicedToArray(_useState9, 2),
      viewWidth = _useState10[0],
      setViewWidth = _useState10[1];

  var _useState11 = useState(0),
      _useState12 = _slicedToArray(_useState11, 2),
      viewHeight = _useState12[0],
      setViewHeight = _useState12[1]; // 滚动条位置


  var _useState13 = useState(0),
      _useState14 = _slicedToArray(_useState13, 2),
      thumbLeft = _useState14[0],
      setThumbLeft = _useState14[1];

  var _useState15 = useState(0),
      _useState16 = _slicedToArray(_useState15, 2),
      thumbTop = _useState16[0],
      setThumbTop = _useState16[1]; // 滚动条宽高


  var _useState17 = useState(0),
      _useState18 = _slicedToArray(_useState17, 2),
      thumbWidth = _useState18[0],
      setThumbWidth = _useState18[1];

  var _useState19 = useState(0),
      _useState20 = _slicedToArray(_useState19, 2),
      thumbHeight = _useState20[0],
      setThumbHeight = _useState20[1]; // 视图宽高比滚动条宽高


  var _useState21 = useState(1),
      _useState22 = _slicedToArray(_useState21, 2),
      scaleX = _useState22[0],
      setScaleX = _useState22[1];

  var _useState23 = useState(1),
      _useState24 = _slicedToArray(_useState23, 2),
      scaleY = _useState24[0],
      setScaleY = _useState24[1]; // 是否为自动滚动状态


  var _useState25 = useState(true),
      _useState26 = _slicedToArray(_useState25, 2),
      autoScroll = _useState26[0],
      setAutoScroll = _useState26[1];

  var scrollWrap = useRef(null);
  useEffect(function () {
    var _scrollWrap$current, _scrollWrap$current2, _scrollWrap$current3, _scrollWrap$current4, _scrollWrap$current5, _scrollWrap$current6;

    // 设置视图实际宽高
    var currentWidth = ((_scrollWrap$current = scrollWrap.current) === null || _scrollWrap$current === void 0 ? void 0 : _scrollWrap$current.clientWidth) || 0;
    var currentHeight = ((_scrollWrap$current2 = scrollWrap.current) === null || _scrollWrap$current2 === void 0 ? void 0 : _scrollWrap$current2.clientHeight) || 0;
    setViewCurrentWidth(currentWidth);
    setViewCurrentHeight(currentHeight); // 设置视图总宽高

    var viewWidth = (((_scrollWrap$current3 = scrollWrap.current) === null || _scrollWrap$current3 === void 0 ? void 0 : _scrollWrap$current3.scrollWidth) || 0) - currentWidth;
    var viewHeight = (((_scrollWrap$current4 = scrollWrap.current) === null || _scrollWrap$current4 === void 0 ? void 0 : _scrollWrap$current4.scrollHeight) || 0) - currentHeight;
    setViewWidth(viewWidth);
    setViewHeight(viewHeight); // 设置滚动条宽高及视图与滚动条比值

    var currentBarWidth = Math.pow(currentWidth - 4, 2) / (((_scrollWrap$current5 = scrollWrap.current) === null || _scrollWrap$current5 === void 0 ? void 0 : _scrollWrap$current5.scrollWidth) || 1);
    setThumbWidth(currentBarWidth);
    setScaleX((currentWidth - currentBarWidth - 4) / currentBarWidth);
    var currentBarHeight = Math.pow(currentHeight - 4, 2) / (((_scrollWrap$current6 = scrollWrap.current) === null || _scrollWrap$current6 === void 0 ? void 0 : _scrollWrap$current6.scrollHeight) || 1);
    setThumbHeight(currentBarHeight);
    setScaleY((currentHeight - currentBarHeight - 4) / currentBarHeight);
  }, [width, height]); // 滚动触发事件及原比例备份

  var xProportionBackup = useRef(0);
  var yProportionBackup = useRef(0);

  var emitScrollX = function emitScrollX(xpr) {
    if (xProportionBackup.current !== Number(xpr.toFixed(4))) {
      onScrollX === null || onScrollX === void 0 ? void 0 : onScrollX(Number(xpr.toFixed(4)) || 0);
    }

    xProportionBackup.current = Number(xpr.toFixed(4));
  };

  var emitScrollY = function emitScrollY(ypr) {
    if (yProportionBackup.current !== Number(ypr.toFixed(4))) {
      onScrollY === null || onScrollY === void 0 ? void 0 : onScrollY(Number(ypr.toFixed(4)) || 0);
    }

    yProportionBackup.current = Number(ypr.toFixed(4));
  }; // 滚动事件触发


  var handleScroll = function handleScroll(e) {
    if (autoScroll) {
      e.persist(); // 滚动占比

      var scrollXProportion = e.target.scrollLeft / viewWidth || 0;
      var scrollYProportion = e.target.scrollTop / viewHeight || 0;
      emitScrollX(scrollXProportion);
      emitScrollY(scrollYProportion);
      setThumbLeft(scrollXProportion * scaleX * thumbWidth);
      setThumbTop(scrollYProportion * scaleY * thumbHeight);
    }
  }; // 滚动条初始位置


  var startX = useRef(0);
  var startY = useRef(0); // 滚动条聚焦控制

  var handleThumbMove = function handleThumbMove(e) {
    var _scrollWrap$current7, _scrollWrap$current8, _scrollWrap$current9;

    var maxX = viewCurrentWidth - thumbWidth - 4;
    startX.current += e.movementX;
    startX.current < 0 && (startX.current = 0);
    startX.current > maxX && (startX.current = maxX);
    setThumbLeft(startX.current);
    var maxY = viewCurrentHeight - thumbHeight - 4;
    startY.current += e.movementY;
    startY.current < 0 && (startY.current = 0);
    startY.current > maxY && (startY.current = maxY);
    setThumbTop(startY.current); // 滚动占比

    var scrollXProportion = (((_scrollWrap$current7 = scrollWrap.current) === null || _scrollWrap$current7 === void 0 ? void 0 : _scrollWrap$current7.scrollLeft) || 0) / viewWidth || 0;
    var scrollYProportion = (((_scrollWrap$current8 = scrollWrap.current) === null || _scrollWrap$current8 === void 0 ? void 0 : _scrollWrap$current8.scrollTop) || 0) / viewHeight || 0;
    emitScrollX(scrollXProportion);
    emitScrollY(scrollYProportion);
    (_scrollWrap$current9 = scrollWrap.current) === null || _scrollWrap$current9 === void 0 ? void 0 : _scrollWrap$current9.scrollTo({
      left: (startX.current + thumbWidth * scrollXProportion) * scaleX,
      top: (startY.current + thumbHeight * scrollYProportion) * scaleY
    });
  };

  var handleThumbUp = function handleThumbUp() {
    setDownShowThumb(false);
    setAutoScroll(true);
    window.removeEventListener('mouseup', handleThumbUp);
    window.removeEventListener('mousemove', handleThumbMove);
  };

  var handleDownThumb = function handleDownThumb(e) {
    setDownShowThumb(true);
    setAutoScroll(false);
    e.persist();
    startX.current = thumbLeft;
    startY.current = thumbTop;
    window.addEventListener('mouseup', handleThumbUp);
    window.addEventListener('mousemove', handleThumbMove);
  }; // 滚动条点击控制


  var handleClickBarX = function handleClickBarX(e) {
    var _scrollWrap$current11;

    e.persist();
    var relativeLeft = e.clientX - e.target.getBoundingClientRect().left;
    setThumbLeft(relativeLeft); // 滚动占比

    xProportionBackup.current = 0;
    setTimeout(function () {
      var _scrollWrap$current10;

      var scrollXProportion = (((_scrollWrap$current10 = scrollWrap.current) === null || _scrollWrap$current10 === void 0 ? void 0 : _scrollWrap$current10.scrollLeft) || 0) / viewWidth || 0;
      emitScrollX(scrollXProportion);
    });
    (_scrollWrap$current11 = scrollWrap.current) === null || _scrollWrap$current11 === void 0 ? void 0 : _scrollWrap$current11.scrollTo({
      left: relativeLeft * scaleX
    });
  };

  var handleClickBarY = function handleClickBarY(e) {
    var _scrollWrap$current13;

    e.persist();
    var relativeTop = e.clientY - e.target.getBoundingClientRect().top;
    setThumbTop(relativeTop); // 滚动占比

    yProportionBackup.current = 0;
    setTimeout(function () {
      var _scrollWrap$current12;

      var scrollYProportion = (((_scrollWrap$current12 = scrollWrap.current) === null || _scrollWrap$current12 === void 0 ? void 0 : _scrollWrap$current12.scrollTop) || 0) / viewHeight || 0;
      emitScrollY(scrollYProportion);
    });
    (_scrollWrap$current13 = scrollWrap.current) === null || _scrollWrap$current13 === void 0 ? void 0 : _scrollWrap$current13.scrollTo({
      top: relativeTop * scaleY
    });
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "i-scrollbar",
    onMouseEnter: function onMouseEnter() {
      return setHoverShowThumb(true);
    },
    onMouseLeave: function onMouseLeave() {
      return setHoverShowThumb(false);
    }
  }, /*#__PURE__*/React.createElement("div", {
    ref: scrollWrap,
    className: "i-scrollbar__wrap",
    style: {
      maxHeight: height ? height : 'auto',
      maxWidth: width ? width : 'auto',
      userSelect: !autoScroll ? 'none' : 'unset'
    },
    onScroll: handleScroll
  }, children), height && /*#__PURE__*/React.createElement("div", {
    className: "i-scrollbar__barY",
    onClick: handleClickBarY
  }, /*#__PURE__*/React.createElement(Transition, {
    timeout: 200,
    in: hoverShowThumb || downShowThumb,
    animation: 'fade-in',
    key: 'i-scrollbar__thumbY'
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-scrollbar__thumbY",
    style: {
      height: thumbHeight,
      transform: "translateY(".concat(thumbTop, "px)")
    },
    onMouseDown: handleDownThumb
  }))), width && /*#__PURE__*/React.createElement("div", {
    className: "i-scrollbar__barX",
    onClick: handleClickBarX
  }, /*#__PURE__*/React.createElement(Transition, {
    timeout: 200,
    in: hoverShowThumb || downShowThumb,
    animation: 'fade-in',
    key: 'i-scrollbar__thumbX'
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-scrollbar__thumbX",
    style: {
      width: thumbWidth,
      transform: "translateX(".concat(thumbLeft, "px)")
    },
    onMouseDown: handleDownThumb
  }))));
};

var css_248z$8 = ".i-dropdown__menu {\n  position: relative;\n  box-sizing: border-box;\n  margin: 0;\n  padding: 5px 0;\n  word-wrap: break-word;\n  list-style: none;\n  background-color: var(--i-bg);\n  border: none;\n  border-radius: 4px;\n  outline: none;\n}\n\n.i-dropdown__item-header {\n  margin: 0;\n  padding: 5px 16px;\n  color: var(--i-font-3);\n  font-size: 12px;\n  line-height: 22px;\n  list-style: none;\n  cursor: default;\n}\n\n.i-dropdown__item {\n  position: relative;\n  display: flex;\n  align-items: center;\n  box-sizing: border-box;\n  margin: 0;\n  padding: 5px 16px;\n  color: var(--i-font-2);\n  font-size: 14px;\n  line-height: 22px;\n  direction: ltr;\n  white-space: nowrap;\n  word-wrap: break-word;\n  list-style: none;\n  outline: none;\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\n.i-dropdown__item.i-dropdown__item--size-small {\n  padding: 1px 16px;\n  font-size: 12px;\n}\n.i-dropdown__item.i-dropdown__item--size-large {\n  padding: 7px 16px;\n}\n.i-dropdown__item[data-direction=left] .icon-ArrowLeft {\n  margin-right: 12px;\n  margin-left: -8px;\n}\n.i-dropdown__item[data-direction=left] .i-dropdown__item-txt {\n  text-align: end;\n}\n.i-dropdown__item[data-direction=right] .icon-ArrowRight {\n  margin-right: -18px;\n  margin-left: 12px;\n}\n.i-dropdown__item[data-direction=right] .i-dropdown__item-txt {\n  text-align: start;\n}\n.i-dropdown__item[data-direction=right].i-dropdown__item-cascader {\n  padding-right: 32px;\n}\n.i-dropdown__item .i-dropdown__menu {\n  position: absolute;\n  top: 0;\n  left: calc(100% - 6px);\n  z-index: 1;\n  display: none;\n  border: 1px solid var(--i-border);\n  border-radius: 4px;\n  box-shadow: var(--i-shadow);\n  cursor: default;\n}\n.i-dropdown__item .i-dropdown__menu .i-dropdown__item-txt {\n  white-space: nowrap;\n}\n.i-dropdown__item .i-dropdown__menu.i-dropdown__menu-left {\n  right: calc(100% - 6px);\n  left: unset;\n}\n.i-dropdown__item:hover {\n  background-color: var(--i-bg-active);\n}\n.i-dropdown__item:hover > .i-dropdown__menu {\n  display: block;\n}\n.i-dropdown__item[data-disabled] .i-icon {\n  color: var(--i-font-disabled) !important;\n}\n.i-dropdown__item[data-disabled]:hover > .i-dropdown__menu {\n  display: none;\n}\n.i-dropdown__item.i-dropdown__item-has-divider {\n  margin-bottom: 11px;\n}\n.i-dropdown__item.i-dropdown__item-has-divider::after {\n  position: absolute;\n  bottom: -6px;\n  left: 0px;\n  box-sizing: border-box;\n  width: 100%;\n  height: 1px;\n  margin: 0;\n  padding: 0;\n  line-height: 0;\n  list-style: none;\n  background-color: var(--i-border);\n  content: \"\";\n}\n.i-dropdown__item.i-dropdown__item-is-active {\n  background-color: var(--i-bg-active);\n}\n.i-dropdown__item.i-dropdown__item-multiple {\n  padding-right: 32px;\n}\n.i-dropdown__item.i-dropdown__item-multiple.i-dropdown__item-is-active {\n  background-color: unset;\n}\n.i-dropdown__item.i-dropdown__item-multiple:hover {\n  background-color: var(--i-bg-active);\n}\n.i-dropdown__item.i-dropdown__item-is-disabled {\n  color: var(--i-font-disabled);\n  background-color: unset;\n  cursor: not-allowed;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-dropdown__item.i-dropdown__item-is-disabled.i-dropdown__item-is-active .i-dropdown__item-txt {\n  color: var(--i-primary-disabled);\n}\n.i-dropdown__item.i-dropdown__item-is-disabled:hover {\n  background-color: unset;\n}\n\n.i-dropdown__item-txt {\n  width: 100%;\n  white-space: normal;\n}\n.i-dropdown__item-txt.i-dropdown__item-txt-is-active {\n  color: var(--i-primary-txt);\n}\n\n.i-dropdown__item-check {\n  position: absolute;\n  right: 12px;\n  display: flex;\n  align-items: center;\n  width: 14px;\n  height: 14px;\n}\n.i-dropdown__item-check .icon-Check {\n  color: var(--i-primary-txt);\n  pointer-events: none;\n}\n\n@-webkit-keyframes show {\n  0% {\n    display: none;\n  }\n  100% {\n    display: block;\n  }\n}\n\n@keyframes show {\n  0% {\n    display: none;\n  }\n  100% {\n    display: block;\n  }\n}";
styleInject(css_248z$8);

var css_248z$9 = ".i-popup {\n  z-index: 5500;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  width: -webkit-fit-content;\n  width: -moz-fit-content;\n  width: fit-content;\n  padding: 4px 8px;\n  color: var(--i-font);\n  font-size: 14px;\n  background-color: var(--i-bg);\n  border: 1px solid var(--i-border);\n  border-radius: 4px;\n  box-shadow: var(--i-shadow);\n}\n.i-popup.i-popup__no-padding {\n  padding: 0;\n}\n.i-popup[data-popper-placement^=top]::before, .i-popup[data-popper-placement^=bottom]::before, .i-popup[data-popper-placement^=left]::before, .i-popup[data-popper-placement^=right]::before {\n  position: absolute;\n  width: 100%;\n  height: 16px;\n  content: \"\";\n}\n.i-popup[data-popper-placement^=top]::before {\n  bottom: -16px;\n}\n.i-popup[data-popper-placement^=bottom]::before {\n  top: -16px;\n}\n.i-popup[data-popper-placement^=left]::before {\n  right: -16px;\n}\n.i-popup[data-popper-placement^=right]::before {\n  left: -16px;\n}\n.i-popup[data-popper-placement^=top] .i-popup__arrow {\n  bottom: -4px;\n}\n.i-popup[data-popper-placement^=top] .i-popup__arrow::before {\n  border-top-left-radius: 100%;\n  box-shadow: var(--i-border) -0.5px 0px 0px 0px inset, var(--i-border) 0px -0.5px 0px 0px inset;\n}\n.i-popup[data-popper-placement=top] .i-popup__arrow {\n  left: 50%;\n  margin-left: -4px;\n}\n.i-popup[data-popper-placement=top-start] .i-popup__arrow {\n  left: 16px;\n}\n.i-popup[data-popper-placement=top-end] .i-popup__arrow {\n  left: calc(100% - 24px);\n}\n.i-popup[data-popper-placement^=bottom] .i-popup__arrow {\n  top: -4px;\n}\n.i-popup[data-popper-placement^=bottom] .i-popup__arrow::before {\n  border-bottom-right-radius: 100%;\n  box-shadow: var(--i-border) 0px 0.5px 0px 0px inset, var(--i-border) 0.5px 0px 0px 0px inset;\n}\n.i-popup[data-popper-placement=bottom] .i-popup__arrow {\n  left: 50%;\n  margin-left: -4px;\n}\n.i-popup[data-popper-placement=bottom-start] .i-popup__arrow {\n  left: 16px;\n}\n.i-popup[data-popper-placement=bottom-end] .i-popup__arrow {\n  left: calc(100% - 24px);\n}\n.i-popup[data-popper-placement^=left] .i-popup__arrow {\n  right: -4px;\n}\n.i-popup[data-popper-placement^=left] .i-popup__arrow::before {\n  box-shadow: var(--i-border) -0.5px 0px 0px 0px inset, var(--i-border) 0px 0.5px 0px 0px inset;\n}\n.i-popup[data-popper-placement=left] .i-popup__arrow {\n  top: 50%;\n  margin-top: -4px;\n}\n.i-popup[data-popper-placement=left-start] .i-popup__arrow {\n  top: 6px;\n}\n.i-popup[data-popper-placement=left-end] .i-popup__arrow {\n  top: calc(100% - 14px);\n}\n.i-popup[data-popper-placement^=right] .i-popup__arrow {\n  left: -4px;\n}\n.i-popup[data-popper-placement^=right] .i-popup__arrow::before {\n  box-shadow: var(--i-border) 0.5px 0px 0px 0px inset, var(--i-border) 0px -0.5px 0px 0px inset;\n}\n.i-popup[data-popper-placement=end] .i-popup__arrow {\n  top: 50%;\n  margin-top: -4px;\n}\n.i-popup[data-popper-placement=right-start] .i-popup__arrow {\n  top: 6px;\n}\n.i-popup[data-popper-placement=right-end] .i-popup__arrow {\n  top: calc(100% - 14px);\n}\n\n.i-popup__arrow, .i-popup__arrow::before {\n  position: absolute;\n  width: 8px;\n  height: 8px;\n  background: var(--i-bg);\n}\n\n.i-popup__arrow {\n  visibility: hidden;\n}\n.i-popup__arrow::before {\n  transform: rotate(45deg);\n  visibility: visible;\n  content: \"\";\n}\n\n.i-popup__reference {\n  width: -webkit-fit-content;\n  width: -moz-fit-content;\n  width: fit-content;\n}";
styleInject(css_248z$9);

function useDefault(value, defaultValue, onChange) {
  // 无论是否受控，都要 useState，因为 Hooks 是无条件的
  var _useState = useState(defaultValue),
      _useState2 = _slicedToArray(_useState, 2),
      internalValue = _useState2[0],
      setInternalValue = _useState2[1];

  var defaultFn = function defaultFn() {}; // 受控模式


  if (typeof value !== 'undefined') {
    return [value, onChange || defaultFn];
  } // 非受控模式


  return [internalValue, function (newValue) {
    setInternalValue(newValue);

    if (typeof onChange === 'function') {
      for (var _len = arguments.length, args = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
        args[_key - 1] = arguments[_key];
      }

      onChange.apply(void 0, [newValue].concat(args));
    }
  }];
}

/**
 * 获取装入指定容器的 id 节点
 * @param id 标识符
 * @param container 装入的容器
 * @param className 容器类名（可选）
 */
function useContainer(id, container, className) {
  var result = document.querySelector("#".concat(id));

  if (!result) {
    result = document.createElement('div');
    result.className = className !== null && className !== void 0 ? className : id;
    result.id = id;
    container.append(result);
  }

  return result;
}

var popupWrapper = useContainer('i-popup-wrapper', document.body);

var Portal = function Portal(props) {
  var portalClassName = props.portalClassName,
      portalStyle = props.portalStyle,
      _props$noPadding = props.noPadding,
      noPadding = _props$noPadding === void 0 ? false : _props$noPadding,
      content = props.content,
      _props$visible = props.visible,
      visible = _props$visible === void 0 ? false : _props$visible,
      getRef = props.getRef;
  var portalRef = useRef(null);
  useEffect(function () {
    visible && (getRef === null || getRef === void 0 ? void 0 : getRef(portalRef));
  }, [visible]);
  var PopoverNode = /*#__PURE__*/React.createElement("div", {
    className: classNames('i-popup', noPadding && 'i-popup__no-padding', portalClassName),
    style: _objectSpread2({}, portalStyle),
    ref: portalRef
  }, content, /*#__PURE__*/React.createElement("div", {
    className: "i-popup__arrow"
  }));
  return /*#__PURE__*/ReactDOM.createPortal(PopoverNode, popupWrapper);
};

/**
 * 触发节点是否在指定包裹层中
 * @param node 要判断的节点
 * @param parent 是否在该容器中
 * @returns true 为在反之不在
 */
var useHasParent = function useHasParent(node, parent) {
  while (node) {
    if (node === parent) {
      return true;
    }

    node = node.parentNode;
  }

  return false;
};

var Popup = function Popup(props) {
  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      portalClassName = props.portalClassName,
      portalStyle = props.portalStyle,
      style = props.style,
      content = props.content,
      _props$placement = props.placement,
      placement = _props$placement === void 0 ? 'top' : _props$placement,
      _props$trigger = props.trigger,
      trigger = _props$trigger === void 0 ? 'hover' : _props$trigger,
      visible = props.visible,
      _props$defaultVisible = props.defaultVisible,
      defaultVisible = _props$defaultVisible === void 0 ? false : _props$defaultVisible,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$sameWidth = props.sameWidth,
      sameWidth = _props$sameWidth === void 0 ? false : _props$sameWidth,
      _props$noPadding = props.noPadding,
      noPadding = _props$noPadding === void 0 ? false : _props$noPadding,
      _props$onTrigger = props.onTrigger,
      onTrigger = _props$onTrigger === void 0 ? function () {} : _props$onTrigger;

  var _useDefault = useDefault(visible, defaultVisible, onTrigger),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerVisible = _useDefault2[0],
      setInnerVisible = _useDefault2[1];

  var referenceRef = useRef(null);
  var contentRef = useRef(null);

  var updateContentRef = function updateContentRef(ref) {
    contentRef.current = ref === null || ref === void 0 ? void 0 : ref.current;
  };

  var popperInstance = null; // 创建 popper 实例

  var createPopperInstance = function createPopperInstance() {
    if (contentRef.current) {
      var _referenceRef$current;

      popperInstance = createPopper((_referenceRef$current = referenceRef.current) === null || _referenceRef$current === void 0 ? void 0 : _referenceRef$current.children[0], contentRef.current, {
        placement: placement,
        modifiers: [{
          name: 'offset',
          options: {
            offset: [0, 16]
          }
        }, {
          name: 'sameWidth',
          enabled: sameWidth,
          phase: 'beforeWrite',
          requires: ['computeStyles'],
          // @ts-ignore
          fn: function fn(_ref) {
            var state = _ref.state;
            state.styles.popper.width = "".concat(state.rects.reference.width, "px");
          },
          // @ts-ignore
          effect: function effect(_ref2) {
            var state = _ref2.state;
            // @ts-ignore
            state.elements.popper.style.width = "".concat(state.elements.reference.offsetWidth, "px");
          }
        }, {
          name: "observeReferenceContent",
          enabled: true,
          phase: "main",
          fn: function fn() {},
          effect: function effect(_ref3) {
            var state = _ref3.state,
                instance = _ref3.instance;
            var reference = state.elements.reference; // 监听触发节点宽高内容变化

            var referenceObserverContent = new ResizeObserver(function (entries) {
              instance.update();
            });
            referenceObserverContent.observe(reference);
            return function () {
              referenceObserverContent.disconnect();
            };
          }
        }, {
          name: "observeReferenceLocation",
          enabled: true,
          phase: "main",
          fn: function fn() {},
          effect: function effect(_ref4) {
            var state = _ref4.state,
                instance = _ref4.instance;
            var reference = state.elements.reference; // 监听触发节点位置变化

            var referenceObserverLocation = new MutationObserver(function (entries) {
              instance.update();
            });
            referenceObserverLocation.observe(reference, {
              attributes: true,
              childList: false,
              subtree: false
            });
            return function () {
              referenceObserverLocation.disconnect();
            };
          }
        }]
      });
      popperInstance.update();
    }
  };

  useEffect(function () {
    createPopperInstance();
    return function () {
      var _popperInstance, _popperInstance$destr;

      (_popperInstance = popperInstance) === null || _popperInstance === void 0 ? void 0 : (_popperInstance$destr = _popperInstance.destroy) === null || _popperInstance$destr === void 0 ? void 0 : _popperInstance$destr.call(_popperInstance);
      popperInstance = null;
    };
  }, [visible]); // 通用方法 - 切换气泡显示隐藏

  var switchPopupShow = function switchPopupShow(show) {
    if (disabled) {
      return;
    }

    setInnerVisible(show);
    show && setTimeout(function () {
      return createPopperInstance();
    });
  }; // 通用方法 - 判断该位置是否在气泡外


  var ifOutContent = function ifOutContent(target) {
    return !useHasParent(target, contentRef.current);
  }; // 通用方法 - 判断该位置是否在触发节点外


  var ifOutReference = function ifOutReference(target) {
    return !useHasParent(target, referenceRef.current);
  };

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      listenClick = _useState2[0],
      setListenClick = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      listenContextMenu = _useState4[0],
      setListenContextMenu = _useState4[1]; // 悬浮后的操作


  var hoverHandle = function hoverHandle(e) {
    e.preventDefault(); // 悬浮位置在气泡外

    if (ifOutContent(e.target)) {
      // 悬浮位置既在气泡外 又在触发节点外
      if (ifOutReference(e.target)) {
        switchPopupShow(false);
      }

      window.removeEventListener('mouseover', hoverHandle);
    }
  }; // 鼠标点击后的操作


  var clickHandle = function clickHandle(e) {
    // 点击位置在气泡外
    if (ifOutContent(e.target)) {
      // 点击位置既在气泡外 又在触发节点外
      if (ifOutReference(e.target)) {
        switchPopupShow(false);
      }

      setListenClick(false);
      window.removeEventListener('click', clickHandle);
    }
  }; // 鼠标右键后的操作


  var rClickHandle = function rClickHandle(e) {
    e.preventDefault(); // 点击位置既在气泡外

    if (ifOutContent(e.target)) {
      switchPopupShow(false);
      setListenContextMenu(false);
      window.removeEventListener('click', rClickHandle);
      window.removeEventListener('contextmenu', rClickHandle);
    }
  };

  useEffect(function () {
    listenClick && window.addEventListener('click', clickHandle);
    return function () {
      window.removeEventListener('click', clickHandle);
    };
  }, [listenClick]);
  useEffect(function () {
    if (listenContextMenu) {
      window.addEventListener('click', rClickHandle);
      window.addEventListener('contextmenu', rClickHandle);
    }

    return function () {
      window.removeEventListener('click', rClickHandle);
      window.removeEventListener('contextmenu', rClickHandle);
    };
  }, [listenContextMenu]); // 触发节点 - 悬浮

  var handleHoverReference = function handleHoverReference() {
    if (trigger !== 'hover') {
      return;
    }

    var newVal = !innerVisible;
    switchPopupShow(newVal);
    setTimeout(function () {
      return window.addEventListener('mouseover', hoverHandle);
    });
  }; // 触发节点 - 点击


  var handleClickReference = function handleClickReference() {
    if (trigger !== 'click' || disabled) {
      return;
    }

    var newVal = !innerVisible;
    switchPopupShow(newVal); // 气泡在关闭状态下点击 则监听下一次全局点击事件

    if (newVal) {
      setTimeout(function () {
        return setListenClick(true);
      });
    }
  }; // 触发节点 - 右键


  var handleRClickReference = function handleRClickReference(e) {
    if (trigger !== 'context-menu') {
      return;
    }

    e.preventDefault();
    var newVal = !innerVisible;
    switchPopupShow(newVal); // 气泡在关闭状态下点击 则监听下一次全局点击事件

    if (newVal) {
      setTimeout(function () {
        return setListenContextMenu(true);
      });
    }
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: classNames('i-popup__reference', className),
    style: _objectSpread2({}, style),
    ref: referenceRef,
    onClick: handleClickReference,
    onMouseEnter: handleHoverReference,
    onContextMenu: handleRClickReference
  }, children), /*#__PURE__*/React.createElement(Transition, {
    timeout: 200,
    in: innerVisible && !disabled,
    animation: 'fade-in',
    key: 'i-popover'
  }, /*#__PURE__*/React.createElement(Portal, {
    portalClassName: portalClassName,
    portalStyle: _objectSpread2({}, portalStyle),
    noPadding: noPadding,
    visible: innerVisible && !disabled,
    content: content,
    getRef: updateContentRef
  })));
};

Popup.displayName = 'Popup';

var DropdownMenu = function DropdownMenu(props) {
  var _props$options = props.options,
      options = _props$options === void 0 ? [] : _props$options,
      width = props.width,
      maxHeight = props.maxHeight,
      size = props.size,
      _props$cascaderDirect = props.cascaderDirection,
      cascaderDirection = _props$cascaderDirect === void 0 ? 'right' : _props$cascaderDirect,
      _props$multiple = props.multiple,
      multiple = _props$multiple === void 0 ? false : _props$multiple,
      _props$selectedValue = props.selectedValue,
      selectedValue = _props$selectedValue === void 0 ? [] : _props$selectedValue,
      _props$clickItem = props.clickItem,
      clickItem = _props$clickItem === void 0 ? function () {} : _props$clickItem;

  var handleItemClick = function handleItemClick(item, event) {
    var _item$children, _item$onClick;

    event.stopPropagation();
    !(item.children && ((_item$children = item.children) === null || _item$children === void 0 ? void 0 : _item$children.length) > 0) && (clickItem === null || clickItem === void 0 ? void 0 : clickItem(item, event));
    (_item$onClick = item.onClick) === null || _item$onClick === void 0 ? void 0 : _item$onClick.call(item, item, event);
  };

  var clickCascaderItem = function clickCascaderItem(item, event) {
    var _item$onClick2;

    clickItem === null || clickItem === void 0 ? void 0 : clickItem(item, event);
    (_item$onClick2 = item.onClick) === null || _item$onClick2 === void 0 ? void 0 : _item$onClick2.call(item, item, event);
  };

  var ifSelected = function ifSelected(itemVal) {
    if (!_.isArray(selectedValue)) {
      if (itemVal === selectedValue) {
        return true;
      }
    } else {
      if (selectedValue.includes(itemVal)) {
        return true;
      }
    }

    return false;
  };

  var hasChildSelected = function hasChildSelected(itemContent) {
    var result = false;

    if (!_.isArray(itemContent)) {
      ifSelected(itemContent.value) && (result = true);
    } else {
      itemContent.map(function (item) {
        if (item.children && item.children.length > 0) {
          hasChildSelected(item.children) && (result = true);
        } else {
          ifSelected(item.value) && (result = true);
        }
      });
    }

    return result;
  };

  var ifItemActive = function ifItemActive(itemVal, itemContent) {
    var ifCascader = itemContent && itemContent.length > 0;

    if (ifCascader) {
      return hasChildSelected(itemContent);
    } else {
      if (!multiple) {
        // 单选 - 末选项
        return itemVal === selectedValue;
      } else {
        // 多选 - 末选项
        if (Array.isArray(selectedValue)) {
          return selectedValue.includes(itemVal);
        }
      }
    }

    return false;
  };

  return /*#__PURE__*/React.createElement("ul", {
    className: classNames('i-dropdown__menu', cascaderDirection === 'left' && 'i-dropdown__menu-left'),
    style: {
      width: width ? width : 'auto',
      maxHeight: maxHeight,
      overflowY: maxHeight ? 'auto' : 'unset'
    }
  }, options.map(function (item, index) {
    var _item$children2, _item$children3, _item$children4, _item$children5;

    return /*#__PURE__*/React.createElement("li", {
      key: "".concat(item.value).concat(index, "}")
    }, item.title && /*#__PURE__*/React.createElement("header", {
      className: "i-dropdown__item-header"
    }, item.title), /*#__PURE__*/React.createElement("div", {
      className: classNames('i-dropdown__item', size && "i-dropdown__item--size-".concat(size), item.disabled && 'i-dropdown__item-is-disabled', item.divider && 'i-dropdown__item-has-divider', item.value === selectedValue && 'i-dropdown__item-is-active', item.children && ((_item$children2 = item.children) === null || _item$children2 === void 0 ? void 0 : _item$children2.length) > 0 && 'i-dropdown__item-cascader', multiple && 'i-dropdown__item-multiple'),
      "data-direction": cascaderDirection,
      "data-disabled": item.disabled,
      onClick: !item.disabled ? function (e) {
        return handleItemClick(item, e);
      } : function () {}
    }, item.children && ((_item$children3 = item.children) === null || _item$children3 === void 0 ? void 0 : _item$children3.length) > 0 && cascaderDirection === 'left' && /*#__PURE__*/React.createElement(Icon, {
      name: "ArrowLeft",
      size: 12,
      color: ifItemActive(item.value, item.children) ? "var(--i-primary-disabled)" : "var(--i-font-2)"
    }), /*#__PURE__*/React.createElement("div", {
      className: classNames('i-dropdown__item-txt', ifItemActive(item.value, item.children) && 'i-dropdown__item-txt-is-active')
    }, item.content), item.children && ((_item$children4 = item.children) === null || _item$children4 === void 0 ? void 0 : _item$children4.length) > 0 && cascaderDirection === 'right' && /*#__PURE__*/React.createElement(Icon, {
      name: "ArrowRight",
      size: 12,
      color: ifItemActive(item.value, item.children) ? "var(--i-primary-disabled)" : "var(--i-font-2)"
    }), item.children && ((_item$children5 = item.children) === null || _item$children5 === void 0 ? void 0 : _item$children5.length) > 0 && /*#__PURE__*/React.createElement(DropdownMenu, {
      options: item.children,
      width: item.width,
      maxHeight: item.maxHeight,
      size: size,
      cascaderDirection: cascaderDirection,
      multiple: multiple,
      selectedValue: selectedValue,
      clickItem: !item.disabled ? clickCascaderItem : function () {}
    }), multiple && /*#__PURE__*/React.createElement("div", {
      className: "i-dropdown__item-check"
    }, Array.isArray(selectedValue) && selectedValue.includes(item.value) && /*#__PURE__*/React.createElement(Icon, {
      name: "Check",
      size: 12
    }))));
  }));
};

var Dropdown = function Dropdown(props) {
  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      contentClassName = props.contentClassName,
      style = props.style,
      width = props.width,
      maxHeight = props.maxHeight,
      size = props.size,
      value = props.value,
      _props$options = props.options,
      options = _props$options === void 0 ? [] : _props$options,
      _props$placement = props.placement,
      placement = _props$placement === void 0 ? 'bottom' : _props$placement,
      _props$trigger = props.trigger,
      trigger = _props$trigger === void 0 ? 'click' : _props$trigger,
      _props$cascaderDirect = props.cascaderDirection,
      cascaderDirection = _props$cascaderDirect === void 0 ? 'right' : _props$cascaderDirect,
      _props$multiple = props.multiple,
      multiple = _props$multiple === void 0 ? false : _props$multiple,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$noPadding = props.noPadding,
      noPadding = _props$noPadding === void 0 ? true : _props$noPadding,
      _props$sameWidth = props.sameWidth,
      sameWidth = _props$sameWidth === void 0 ? false : _props$sameWidth,
      _props$onClick = props.onClick,
      onClick = _props$onClick === void 0 ? function () {} : _props$onClick,
      _props$onTrigger = props.onTrigger,
      onTrigger = _props$onTrigger === void 0 ? function () {} : _props$onTrigger;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      popupVisible = _useState2[0],
      setPopupVisible = _useState2[1];

  var switchPopup = function switchPopup(visible) {
    setPopupVisible(visible);
    onTrigger === null || onTrigger === void 0 ? void 0 : onTrigger(visible);
  };

  var _useState3 = useState(options),
      _useState4 = _slicedToArray(_useState3, 2),
      dropdownOptions = _useState4[0],
      setDropdownOptions = _useState4[1];

  useEffect(function () {
    setDropdownOptions(options);
  }, [options]); // 下拉选中项

  var _useState5 = useState(value),
      _useState6 = _slicedToArray(_useState5, 2),
      innerValue = _useState6[0],
      setInnerValue = _useState6[1];

  var _useState7 = useState(0),
      _useState8 = _slicedToArray(_useState7, 2),
      updateKey = _useState8[0],
      setUpdateKey = _useState8[1];

  useEffect(function () {
    if (value !== innerValue) {
      setInnerValue(value);
    }
  }, [value]);

  var handleClickItem = function handleClickItem(item, event) {
    if (!multiple) {
      // 单选模式
      onClick === null || onClick === void 0 ? void 0 : onClick(item.value, event);
      setPopupVisible(false);
      onTrigger === null || onTrigger === void 0 ? void 0 : onTrigger(false);
    } else {
      // 多选模式
      var delIndex = 0;
      var curMultiSelected = innerValue;
      !Array.isArray(curMultiSelected) && (curMultiSelected = []);
      curMultiSelected.map(function (it, index) {
        if (it === item.value) {
          delIndex = index;
        }
      });
      curMultiSelected.includes(item.value) ? curMultiSelected.splice(delIndex, 1) : curMultiSelected.push(item.value);
      setUpdateKey(updateKey + 1);
      onClick === null || onClick === void 0 ? void 0 : onClick(curMultiSelected, event);
    }
  };

  var DropdownContent = /*#__PURE__*/React.createElement("div", {
    className: classNames('i-dropdown', contentClassName),
    style: _objectSpread2(_objectSpread2({}, style || {}), {
      width: width ? width : 'auto',
      maxHeight: maxHeight,
      overflowY: maxHeight ? 'auto' : 'unset'
    })
  }, /*#__PURE__*/React.createElement(DropdownMenu, {
    size: size,
    options: dropdownOptions,
    cascaderDirection: cascaderDirection,
    multiple: multiple,
    selectedValue: innerValue,
    clickItem: handleClickItem
  }));
  return /*#__PURE__*/React.createElement(Popup, {
    portalClassName: className,
    content: DropdownContent,
    placement: placement,
    trigger: trigger,
    visible: popupVisible,
    disabled: disabled,
    noPadding: noPadding,
    sameWidth: sameWidth,
    onTrigger: switchPopup
  }, children);
};

Dropdown.displayName = 'Dropdown';

var css_248z$a = ".i-menu {\n  position: relative;\n  display: flex;\n  align-items: center;\n  box-sizing: border-box;\n  width: 100%;\n  height: 64px;\n  padding: 0 12px;\n  color: var(--i-font-2);\n  font-size: 14px;\n  background: var(--i-bg);\n}\n.i-menu.i-menu__vertical {\n  flex-direction: column;\n  height: 100%;\n}\n.i-menu.i-menu__vertical .i-menu-item__wrapper {\n  flex-direction: column;\n  gap: 8px;\n  width: 100%;\n}\n.i-menu.i-menu__vertical .i-menu-item {\n  width: 100%;\n  padding: 0 12px;\n}\n.i-menu.i-menu__vertical .i-menu-item:not(:last-of-type) {\n  margin-right: unset;\n}\n.i-menu.i-menu__vertical .i-menu-item__txt {\n  text-align: unset;\n}\n.i-menu.i-menu__vertical .i-menu__logo,\n.i-menu.i-menu__vertical .i-menu__operations {\n  width: 100%;\n  min-height: 40px;\n  margin: 0;\n}\n.i-menu.i-menu__vertical .i-menu__logo {\n  margin-top: 16px;\n}\n\n.i-menu__logo {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  height: 40px;\n  margin-right: 20px;\n  margin-left: 8px;\n}\n.i-menu__logo img {\n  max-height: 100%;\n}\n\n.i-menu-item__wrapper {\n  display: flex;\n  flex: 1;\n  gap: 12px;\n  align-items: center;\n  padding: 0;\n}\n\n.i-menu-item,\n.i-menu-item__group-wrapper {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  min-width: 100px;\n  height: 40px;\n  border-radius: 8px;\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\n.i-menu-item.i-menu-item__group-active, .i-menu-item.i-menu-item__active,\n.i-menu-item__group-wrapper.i-menu-item__group-active,\n.i-menu-item__group-wrapper.i-menu-item__active {\n  background: var(--i-bg-active);\n}\n.i-menu-item:hover,\n.i-menu-item__group-wrapper:hover {\n  background: var(--i-bg-hover);\n}\n\n.i-menu-item__group-dropdown[data-popper-placement^=bottom]::before {\n  top: -17px;\n}\n\n.i-menu-item__group-wrapper {\n  position: relative;\n}\n.i-menu-item__group-wrapper .i-menu-item__txt {\n  padding: 0 22px;\n}\n.i-menu-item__group-wrapper .icon-ArrowUpBold {\n  position: absolute;\n  right: 8px;\n  transition: all 0.2s linear;\n}\n.i-menu-item__group-wrapper.i-menu-item__group-hover .icon-ArrowUpBold {\n  transform: rotateX(180deg);\n}\n\n.i-menu-item__txt {\n  width: 100%;\n  overflow: hidden;\n  white-space: nowrap;\n  text-align: center;\n  text-overflow: ellipsis;\n}\n\n.i-menu__operations {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  margin-right: 8px;\n  margin-left: 20px;\n}\n\n.i-menu-item__group {\n  width: 100%;\n}\n.i-menu-item__group.i-menu-item__group-active > .i-collapse-item > .i-collapse-item__header .i-collapse-item__header-txt,\n.i-menu-item__group.i-menu-item__group-active > .i-collapse-item > .i-collapse-item__header .icon-ArrowCaretRight {\n  color: var(--i-primary-txt);\n}\n.i-menu-item__group .i-collapse-item__header {\n  border-radius: 8px;\n}\n.i-menu-item__group .i-collapse-item__header:hover {\n  background: var(--i-bg-active);\n}\n.i-menu-item__group .i-collapse-item.i-collapse-item__icon-right .i-collapse-item__content {\n  padding-left: 0px;\n}\n.i-menu-item__group .i-collapse-item.i-collapse-item__icon-right .i-collapse-item__content[data-active=\"1\"] {\n  margin-bottom: -8px;\n}\n.i-menu-item__group .i-collapse-item.i-collapse-item__icon-right .i-collapse-item__content.i-collapse-item__content-unfold {\n  padding: 8px 0 0;\n  background: transparent;\n}\n.i-menu-item__group .i-collapse-item__content-inner {\n  display: flex;\n  flex-direction: column;\n  gap: 8px;\n}\n.i-menu-item__group .i-collapse-item__content-inner .i-menu-item,\n.i-menu-item__group .i-collapse-item__content-inner .i-collapse-item__header {\n  padding: 0 12px 0 24px;\n}\n.i-menu-item__group .i-collapse-item__content-inner .i-collapse-item__content-inner .i-menu-item,\n.i-menu-item__group .i-collapse-item__content-inner .i-collapse-item__content-inner .i-collapse-item__header {\n  padding: 0 12px 0 36px;\n}\n.i-menu-item__group .i-collapse-item__content-inner .i-collapse-item__content-inner .i-collapse-item__content-inner .i-menu-item,\n.i-menu-item__group .i-collapse-item__content-inner .i-collapse-item__content-inner .i-collapse-item__content-inner .i-collapse-item__header {\n  padding: 0 12px 0 48px;\n}";
styleInject(css_248z$a);

var _excluded$b = ["children", "className", "style", "value", "onClick", "active", "index", "onChange"];

var MenuItem = function MenuItem(props) {
  var children = props.children,
      className = props.className,
      style = props.style,
      _props$value = props.value,
      value = _props$value === void 0 ? '' : _props$value,
      onClick = props.onClick,
      active = props.active,
      index = props.index,
      onChange = props.onChange,
      restProps = _objectWithoutProperties(props, _excluded$b);

  var itemValue = value || String(index);

  var handleClickItem = function handleClickItem() {
    onClick === null || onClick === void 0 ? void 0 : onClick(itemValue);
    onChange === null || onChange === void 0 ? void 0 : onChange(itemValue);
  };

  return /*#__PURE__*/React.createElement("li", _objectSpread2({
    className: classNames('i-menu-item', itemValue === active && 'i-menu-item__active', className),
    style: _objectSpread2({}, style),
    onClick: handleClickItem
  }, restProps), /*#__PURE__*/React.createElement("span", {
    className: "i-menu-item__txt"
  }, children));
};

var css_248z$b = ".i-collapse {\n  box-sizing: border-box;\n  overflow: hidden;\n  color: var(--i-font-2);\n  font-size: 14px;\n  border: 1px solid var(--i-border);\n  border-radius: 6px;\n  outline: none;\n}\n.i-collapse.i-collapse__hide-border {\n  border: none;\n}\n.i-collapse.i-collapse__hide-border .i-collapse-item__active,\n.i-collapse.i-collapse__hide-border .i-collapse-item__header,\n.i-collapse.i-collapse__hide-border .i-collapse-item__header-fold,\n.i-collapse.i-collapse__hide-border .i-collapse-item__content,\n.i-collapse.i-collapse__hide-border .i-collapse-item__content-unfold {\n  border: none;\n}\n.i-collapse.i-collapse__hide-border .i-collapse-item:last-of-type .i-collapse-item__header-fold {\n  border: none;\n}\n.i-collapse.i-collapse__no-indent .i-collapse-item__content {\n  padding-left: 12px;\n}\n.i-collapse.i-collapse__no-indent .i-collapse-item__content .i-collapse-item__content {\n  padding-left: 0;\n}\n\n.i-collapse-item {\n  box-sizing: border-box;\n  border-bottom: none;\n  outline: none;\n}\n.i-collapse-item:last-of-type .i-collapse-item__content-unfold {\n  border-bottom: none;\n}\n.i-collapse-item:last-of-type .i-collapse-item__header-fold {\n  border-bottom: 1px solid transparent;\n}\n.i-collapse-item.i-collapse-item__icon-right .i-collapse-item__header {\n  flex-direction: row-reverse;\n}\n.i-collapse-item.i-collapse-item__icon-right .i-collapse-item__header-txt {\n  flex: 1;\n}\n.i-collapse-item.i-collapse-item__icon-right .i-collapse-item__content {\n  padding-left: 24px;\n}\n.i-collapse-item.i-collapse-item__active {\n  border-bottom: 1px solid var(--i-border);\n}\n.i-collapse-item.i-collapse-item__disabled .i-collapse-item__header {\n  color: var(--i-font-disabled);\n  cursor: not-allowed;\n}\n.i-collapse-item.i-collapse-item__disabled .i-collapse-item__header .icon-ArrowCaretRight {\n  color: var(--i-font-disabled);\n}\n\n.i-collapse-item__header {\n  display: flex;\n  gap: 6px;\n  align-items: center;\n  box-sizing: border-box;\n  height: 40px;\n  padding: 0 12px;\n  border-bottom: 1px solid var(--i-border);\n  cursor: pointer;\n  transition: all 0.2s ease-in;\n}\n.i-collapse-item__header .icon-ArrowCaretRight {\n  color: var(--i-font-2);\n  transition: all 0.2s ease-out;\n}\n\n.i-collapse-item__content {\n  box-sizing: border-box;\n  padding: 0 12px 0 34px;\n  overflow: hidden;\n  background: var(--i-bg);\n  visibility: hidden;\n  transition: all 0.2s ease-out;\n}\n.i-collapse-item__content.i-collapse-item__content-unfold {\n  padding: 8px 12px 8px 34px;\n  border-bottom: 1px solid var(--i-border);\n  visibility: visible;\n}\n.i-collapse-item__content .i-collapse-item__header {\n  padding: 0;\n}\n.i-collapse-item__content .i-collapse-item__content {\n  padding-left: 22px;\n}";
styleInject(css_248z$b);

var _excluded$c = ["children", "className", "style", "title", "value", "disabled", "index", "innerActive", "updateInnerActive", "iconPlacement"];

var CollapseItem = function CollapseItem(props) {
  // 从 Collapse Context 注入全局属性
  var context = useContext(CollapseContext);
  var newProps = context ? context.inject(props) : props;

  var children = newProps.children,
      className = newProps.className,
      style = newProps.style,
      title = newProps.title,
      value = newProps.value,
      _newProps$disabled = newProps.disabled,
      disabled = _newProps$disabled === void 0 ? false : _newProps$disabled,
      index = newProps.index,
      innerActive = newProps.innerActive,
      updateInnerActive = newProps.updateInnerActive,
      _newProps$iconPlaceme = newProps.iconPlacement,
      iconPlacement = _newProps$iconPlaceme === void 0 ? 'left' : _newProps$iconPlaceme,
      restProps = _objectWithoutProperties(newProps, _excluded$c);

  var itemValue = value || index;
  var isActive = Array.isArray(innerActive) ? innerActive.includes(itemValue) : innerActive === itemValue;

  var handleClickHeader = function handleClickHeader() {
    if (!disabled) {
      updateInnerActive === null || updateInnerActive === void 0 ? void 0 : updateInnerActive(itemValue);
    }
  };

  var contentInnerRef = useRef(null);

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      contentHeight = _useState2[0],
      setContentHeight = _useState2[1];

  useEffect(function () {
    var _contentInnerRef$curr;

    var height = ((_contentInnerRef$curr = contentInnerRef.current) === null || _contentInnerRef$curr === void 0 ? void 0 : _contentInnerRef$curr.getBoundingClientRect().height) || 0;
    setContentHeight(height + 16); // 加上下 padding

    var resizeObserver = new ResizeObserver(function (entries) {
      setContentHeight(entries[0].contentRect.height + 16);
    });
    resizeObserver.observe(contentInnerRef.current);
    return function () {
      return resizeObserver.disconnect();
    };
  }, []);
  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-collapse-item', disabled && 'i-collapse-item__disabled', iconPlacement === 'right' && 'i-collapse-item__icon-right', className),
    style: _objectSpread2({}, style)
  }, restProps), /*#__PURE__*/React.createElement("header", {
    className: classNames('i-collapse-item__header', !isActive && 'i-collapse-item__header-fold'),
    onClick: handleClickHeader,
    "data-active": isActive ? 1 : 0
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ArrowCaretRight",
    style: {
      transform: isActive ? 'rotate(90deg)' : 'rotate(0deg)'
    }
  }), /*#__PURE__*/React.createElement("span", {
    className: "i-collapse-item__header-txt"
  }, title)), /*#__PURE__*/React.createElement("section", {
    className: classNames('i-collapse-item__content', isActive && 'i-collapse-item__content-unfold'),
    style: {
      height: isActive ? contentHeight : 0
    },
    "data-active": isActive ? 1 : 0
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-collapse-item__content-inner",
    ref: contentInnerRef
  }, children)));
};

var _excluded$d = ["children", "className", "style", "active", "defaultActive", "accordion", "disabled", "expandAll", "iconPlacement", "hideBorder", "noIndent", "onChange"];
var CollapseContext = /*#__PURE__*/React.createContext(null);

var Collapse = function Collapse(props) {
  var defaultVal = [];
  React.Children.map(props.children, function (child, index) {
    !props.defaultActive && props.expandAll && defaultVal.push(child.props.value || index);
  });

  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      style = props.style,
      active = props.active,
      _props$defaultActive = props.defaultActive,
      defaultActive = _props$defaultActive === void 0 ? defaultVal : _props$defaultActive,
      _props$accordion = props.accordion,
      accordion = _props$accordion === void 0 ? false : _props$accordion,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$expandAll = props.expandAll,
      _props$iconPlacement = props.iconPlacement,
      iconPlacement = _props$iconPlacement === void 0 ? 'left' : _props$iconPlacement,
      _props$hideBorder = props.hideBorder,
      hideBorder = _props$hideBorder === void 0 ? false : _props$hideBorder,
      _props$noIndent = props.noIndent,
      noIndent = _props$noIndent === void 0 ? false : _props$noIndent,
      onChange = props.onChange,
      restProps = _objectWithoutProperties(props, _excluded$d);

  var _useDefault = useDefault(active, defaultActive, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerActive = _useDefault2[0],
      setInnerActive = _useDefault2[1]; // 更新展开项


  var updateInnerActive = function updateInnerActive(value) {
    var newValue = [].concat(innerActive || []);
    var index = newValue.indexOf(value);

    if (index >= 0) {
      newValue.splice(index, 1);
    } else if (accordion) {
      newValue = [value];
    } else {
      newValue.push(value);
    }

    setInnerActive(_toConsumableArray(newValue));
  }; // 注入每一项的 context


  var context = {
    // 将 props 注入每一项子节点的方法
    inject: function inject(singleCollapseProps) {
      return _objectSpread2({
        innerActive: innerActive,
        disabled: disabled,
        updateInnerActive: updateInnerActive,
        iconPlacement: iconPlacement
      }, singleCollapseProps);
    }
  };
  return /*#__PURE__*/React.createElement(CollapseContext.Provider, {
    value: context
  }, /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-collapse', hideBorder && 'i-collapse__hide-border', noIndent && 'i-collapse__no-indent', className),
    style: _objectSpread2({}, style)
  }, restProps), React.Children.map(children, function (child, index) {
    if (! /*#__PURE__*/React.isValidElement(child)) {
      return null;
    }

    var childProps = _objectSpread2({
      index: index
    }, child.props);

    return /*#__PURE__*/React.cloneElement(child, childProps);
  })));
};

Collapse.Item = CollapseItem;
CollapseItem.displayName = 'CollapseItem';
Collapse.displayName = 'Collapse';

var _excluded$e = ["children", "className", "style", "title", "index", "active", "direction", "onChange"];

var MenuGroup = function MenuGroup(props) {
  var children = props.children,
      className = props.className,
      style = props.style,
      title = props.title,
      index = props.index,
      active = props.active,
      direction = props.direction,
      onChange = props.onChange,
      restProps = _objectWithoutProperties(props, _excluded$e); // 水平 group


  var _useState = useState([]),
      _useState2 = _slicedToArray(_useState, 2),
      horizonGroupValues = _useState2[0],
      setHorizonGroupValues = _useState2[1];

  var _useState3 = useState([]),
      _useState4 = _slicedToArray(_useState3, 2),
      horizonGroupOptions = _useState4[0],
      setHorizonGroupOptions = _useState4[1];

  var valuesArr = []; // 将 Menu.Item 递归转为 Dropdown 可用的数组，同时更新组 value 集

  var mergeIndex = function mergeIndex(itemIdx, injectIdx) {
    return "".concat(injectIdx, ".").concat(itemIdx);
  };

  var getOptions = function getOptions(childList, injectIdx) {
    var result = [];
    React.Children.map(childList, function (item, itemIdx) {
      if (!_.isArray(item.props.children)) {
        var itemValue = item.props.value || mergeIndex(itemIdx, injectIdx);
        valuesArr.push(itemValue);
        result.push({
          content: item.props.children,
          value: itemValue
        });
      } else {
        // 嵌套
        var _itemValue = item.props.value || mergeIndex(itemIdx, injectIdx);

        valuesArr.push(_itemValue);
        result.push({
          content: item.props.title,
          value: _itemValue,
          children: getOptions(item.props.children, mergeIndex(itemIdx, injectIdx))
        });
      }
    });
    return result;
  };

  useEffect(function () {
    if (direction === 'horizontal') {
      setHorizonGroupOptions(_toConsumableArray(getOptions(children, String(index))));
      setHorizonGroupValues([].concat(valuesArr));
    }
  }, []);

  var handleSelectItem = function handleSelectItem(val) {
    onChange === null || onChange === void 0 ? void 0 : onChange(val);
  };

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      hover = _useState6[0],
      setHover = _useState6[1];

  var handleTrigger = function handleTrigger(trigger) {
    setHover(trigger);
  };

  var getRenderList = function getRenderList(childList, groupIdx) {
    var result = [];
    childList.map(function (item, itemIdx) {
      if (_.isArray(item.props.children)) {
        var itemProps = _objectSpread2(_objectSpread2({
          index: mergeIndex(itemIdx, groupIdx),
          key: mergeIndex(itemIdx, groupIdx),
          active: active,
          onChange: onChange
        }, item.props), {}, {
          children: getRenderList(item.props.children, mergeIndex(itemIdx, groupIdx))
        });

        result.push( /*#__PURE__*/React.cloneElement(item, itemProps));
      } else {
        var _itemProps = _objectSpread2({
          index: mergeIndex(itemIdx, groupIdx),
          key: mergeIndex(itemIdx, groupIdx),
          active: active,
          onChange: onChange
        }, item.props);

        result.push( /*#__PURE__*/React.cloneElement(item, _itemProps));
      }
    });
    return result;
  };

  var renderVertical = getRenderList(children, index);

  var ifGroupActive = function ifGroupActive(childList) {
    var result = false;
    Array.from(childList).map(function (item) {
      if (_.isArray(item.props.children)) {
        ifGroupActive(item.props.children) && (result = true);
      } else {
        if (item.props.value) {
          item.props.value === active && (result = true);
        } else {
          item.props.index === active && (result = true);
        }
      }
    });
    return result;
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, direction === 'horizontal' ? /*#__PURE__*/React.createElement(Dropdown, {
    className: 'i-menu-item__group-dropdown',
    trigger: "click",
    value: active,
    options: horizonGroupOptions,
    onClick: handleSelectItem,
    onTrigger: handleTrigger
  }, /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-menu-item__group-wrapper', horizonGroupValues.includes(active) && 'i-menu-item__group-active', hover && 'i-menu-item__group-hover')
  }, restProps), /*#__PURE__*/React.createElement("span", {
    className: "i-menu-item__txt"
  }, title), /*#__PURE__*/React.createElement(Icon, {
    name: "ArrowUpBold",
    size: 12
  }))) : /*#__PURE__*/React.createElement(Collapse, _objectSpread2({
    className: classNames('i-menu-item__group', ifGroupActive(renderVertical) && 'i-menu-item__group-active', className),
    style: style,
    hideBorder: true,
    expandAll: ifGroupActive(renderVertical),
    iconPlacement: 'right'
  }, restProps), /*#__PURE__*/React.createElement(Collapse.Item, {
    title: title
  }, renderVertical)));
};

var _excluded$f = ["children", "className", "style", "width", "active", "defaultActive", "prefixContent", "suffixContent", "direction", "onChange"];

var Menu = function Menu(props) {
  // 初始默认值（导航第一项）
  var defaultVal;
  React.Children.map(props.children, function (child, index) {
    index === 0 && (defaultVal = child.props.value || '0');
  });

  var children = props.children,
      className = props.className,
      style = props.style,
      width = props.width,
      active = props.active,
      _props$defaultActive = props.defaultActive,
      defaultActive = _props$defaultActive === void 0 ? defaultVal : _props$defaultActive,
      prefixContent = props.prefixContent,
      suffixContent = props.suffixContent,
      _props$direction = props.direction,
      direction = _props$direction === void 0 ? 'horizontal' : _props$direction,
      onChange = props.onChange,
      restProps = _objectWithoutProperties(props, _excluded$f);

  var _useDefault = useDefault(active, defaultActive, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerActive = _useDefault2[0],
      setInnerActive = _useDefault2[1];

  var handleChange = function handleChange(val) {
    setInnerActive(val);
  };

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-menu', direction === 'vertical' && 'i-menu__vertical', className),
    style: _objectSpread2(_objectSpread2({}, style), {}, {
      width: width
    })
  }, restProps), prefixContent && /*#__PURE__*/React.createElement("header", {
    className: "i-menu__logo"
  }, prefixContent), /*#__PURE__*/React.createElement("ul", {
    className: "i-menu-item__wrapper"
  }, React.Children.map(children, function (child, index) {
    if (! /*#__PURE__*/React.isValidElement(child)) {
      return null;
    }

    var childProps = _objectSpread2({
      index: index,
      direction: direction,
      active: innerActive,
      onChange: handleChange
    }, child.props);

    return /*#__PURE__*/React.cloneElement(child, childProps);
  })), suffixContent && /*#__PURE__*/React.createElement("footer", {
    className: "i-menu__operations"
  }, suffixContent));
};

Menu.Item = MenuItem;
Menu.Group = MenuGroup;
MenuItem.displayName = 'MenuItem';
MenuGroup.displayName = 'MenuGroup';
Menu.displayName = 'Menu';

var css_248z$c = ".i-tabs {\n  position: relative;\n  display: flex;\n  box-sizing: border-box;\n  font-size: 14px;\n  border-bottom: 1px solid var(--i-border);\n}\n\n.i-tabs-item {\n  position: relative;\n  display: flex;\n  align-items: center;\n  box-sizing: border-box;\n  height: 40px;\n  padding: 0 12px;\n  color: var(--i-font-2);\n  cursor: pointer;\n}\n.i-tabs-item.i-tabs-item__active {\n  color: var(--i-primary-txt);\n}\n.i-tabs-item.i-tabs-item__disabled {\n  color: var(--i-font-disabled);\n  cursor: not-allowed;\n}\n.i-tabs-item.i-tabs-item__card {\n  border-top: 1px solid var(--i-border);\n  border-left: 1px solid var(--i-border);\n}\n.i-tabs-item.i-tabs-item__card:first-of-type {\n  border-radius: 4px 0 0 0;\n}\n.i-tabs-item.i-tabs-item__card:last-of-type {\n  border-right: 1px solid var(--i-border);\n  border-radius: 0 4px 0 0;\n}\n.i-tabs-item.i-tabs-item__card.i-tabs-item__active {\n  background: var(--i-bg);\n}\n.i-tabs-item.i-tabs-item__card.i-tabs-item__active::after {\n  content: \"\";\n}\n.i-tabs-item.i-tabs-item__card::after {\n  position: absolute;\n  bottom: -1px;\n  left: 0;\n  display: block;\n  width: 100%;\n  height: 1px;\n  background: var(--i-bg);\n}\n\n.i-tabs__bar {\n  position: absolute;\n  bottom: 0px;\n  height: 2px;\n  background: var(--i-primary-txt);\n  border-radius: 1px;\n  transition: all 0.2s ease-out;\n}";
styleInject(css_248z$c);

var _excluded$g = ["children", "className", "style", "value", "onClick", "theme", "index", "active", "disabled", "onChange"];

var TabsItem = function TabsItem(props) {
  // 从 Tabs Context 注入全局属性
  var context = useContext(TabsContext);
  var newProps = context ? context.inject(props) : props;

  var children = newProps.children,
      className = newProps.className,
      style = newProps.style,
      value = newProps.value,
      onClick = newProps.onClick,
      theme = newProps.theme,
      index = newProps.index,
      active = newProps.active,
      _newProps$disabled = newProps.disabled,
      disabled = _newProps$disabled === void 0 ? false : _newProps$disabled,
      onChange = newProps.onChange,
      restProps = _objectWithoutProperties(newProps, _excluded$g);

  var itemValue = value || index;

  var handleClickTab = function handleClickTab() {
    !disabled && (onClick === null || onClick === void 0 ? void 0 : onClick(itemValue));
  };

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-tabs-item', itemValue === active && 'i-tabs-item__active', theme === 'card' && 'i-tabs-item__card', disabled && 'i-tabs-item__disabled', className),
    "data-active": itemValue === active,
    "data-disabled": disabled,
    style: _objectSpread2({}, style),
    onClick: handleClickTab
  }, restProps), children);
};

var _excluded$h = ["children", "className", "style", "active", "defaultActive", "disabled", "theme", "onChange"];
var TabsContext = /*#__PURE__*/React.createContext(null);

var Tabs = function Tabs(props) {
  var defaultVal;
  React.Children.map(props.children, function (child, index) {
    index === 0 && (defaultVal = child.props.value || 0);
  });

  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      style = props.style,
      active = props.active,
      _props$defaultActive = props.defaultActive,
      defaultActive = _props$defaultActive === void 0 ? defaultVal : _props$defaultActive,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$theme = props.theme,
      theme = _props$theme === void 0 ? 'normal' : _props$theme,
      onChange = props.onChange,
      restProps = _objectWithoutProperties(props, _excluded$h);

  var _useDefault = useDefault(active, defaultActive, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerActive = _useDefault2[0],
      setInnerActive = _useDefault2[1];

  var tabsRef = useRef(null);

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      tabsRefLeft = _useState2[0],
      setTabsRefLeft = _useState2[1];

  useEffect(function () {
    var _tabsRef$current;

    var curTabsRefLeft = ((_tabsRef$current = tabsRef.current) === null || _tabsRef$current === void 0 ? void 0 : _tabsRef$current.getBoundingClientRect().left) || 0;
    setTabsRefLeft(curTabsRefLeft);
    updateBarPosition(curTabsRefLeft);
  }, []);

  var _useState3 = useState({
    width: 0,
    left: 0
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      bar = _useState4[0],
      setBar = _useState4[1];

  var updateBarPosition = function updateBarPosition(parentLeft) {
    var _tabsRef$current2;

    (_tabsRef$current2 = tabsRef.current) === null || _tabsRef$current2 === void 0 ? void 0 : _tabsRef$current2.childNodes.forEach(function (item) {
      if (item.dataset.active === 'true' && item.dataset.disabled !== 'true') {
        var tabRect = item.getBoundingClientRect();
        bar.left = tabRect.left - parentLeft;
        bar.width = tabRect.width;
        setBar(_objectSpread2({}, bar));
      }
    });
  };

  useEffect(function () {
    tabsRefLeft !== 0 && updateBarPosition(tabsRefLeft);
  }, [innerActive]); // 注入每一项的 context

  var context = {
    // 将 props 注入每一项子节点的方法
    inject: function inject(singleTabsProps) {
      return _objectSpread2({
        theme: theme,
        active: innerActive,
        disabled: disabled,
        onClick: function onClick(value) {
          setInnerActive(value);
        }
      }, singleTabsProps);
    }
  };
  return /*#__PURE__*/React.createElement(TabsContext.Provider, {
    value: context
  }, /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-tabs', className),
    ref: tabsRef,
    style: _objectSpread2({}, style)
  }, restProps), React.Children.map(children, function (child, index) {
    if (! /*#__PURE__*/React.isValidElement(child)) {
      return null;
    }

    var childProps = _objectSpread2({
      index: index
    }, child.props);

    return /*#__PURE__*/React.cloneElement(child, childProps);
  }), theme === 'normal' && /*#__PURE__*/React.createElement("div", {
    className: "i-tabs__bar",
    style: {
      width: bar.width,
      left: bar.left
    }
  })));
};

Tabs.Item = TabsItem;
Tabs.displayName = 'Tabs';
TabsItem.displayName = 'TabsItem';

var css_248z$d = ".i-breadcrumb {\n  display: flex;\n  align-items: center;\n}\n\n.i-breadcrumb__item {\n  display: flex;\n  align-items: center;\n}\n.i-breadcrumb__item:last-of-type .i-breadcrumb__inner,\n.i-breadcrumb__item:last-of-type .i-breadcrumb__inner a {\n  color: var(--i-font2);\n}\n.i-breadcrumb__item:last-of-type .i-breadcrumb__inner:hover,\n.i-breadcrumb__item:last-of-type .i-breadcrumb__inner a:hover {\n  color: var(--i-primary-txt);\n  transition: color 0.2s ease-out;\n}\n.i-breadcrumb__item:last-of-type .i-breadcrumb__separator {\n  display: none;\n}\n\n.i-breadcrumb__inner,\n.i-breadcrumb__inner a {\n  display: inline-block;\n  overflow: hidden;\n  color: var(--i-font-4);\n  white-space: nowrap;\n  text-overflow: ellipsis;\n  word-break: break-all;\n  cursor: pointer;\n}\n.i-breadcrumb__inner:hover,\n.i-breadcrumb__inner a:hover {\n  color: var(--i-primary-txt);\n  transition: color 0.2s ease-out;\n}\n\n.i-breadcrumb__separator {\n  display: flex;\n  align-items: center;\n  margin: 0 4px;\n}\n.i-breadcrumb__separator .i-icon {\n  color: var(--i-font-4);\n}\n\n.i-breadcrumb-is-disabled .i-breadcrumb__inner,\n.i-breadcrumb-is-disabled .i-breadcrumb__inner a {\n  color: var(--i-font-disabled);\n  cursor: not-allowed;\n}\n.i-breadcrumb-is-disabled .i-breadcrumb__inner:hover,\n.i-breadcrumb-is-disabled .i-breadcrumb__inner a:hover {\n  color: var(--i-font-disabled);\n}";
styleInject(css_248z$d);

var _excluded$i = ["children", "className", "disabled", "maxItemWidth", "maxWidth", "separator", "style"];

var BreadcrumbItem = function BreadcrumbItem(props) {
  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      disabled = props.disabled,
      maxItemWidth = props.maxItemWidth,
      maxWidth = props.maxWidth,
      _props$separator = props.separator,
      separator = _props$separator === void 0 ? /*#__PURE__*/React.createElement(Icon, {
    name: "ArrowRight",
    size: 16
  }) : _props$separator,
      style = props.style,
      restProps = _objectWithoutProperties(props, _excluded$i); // 限制最大宽度


  var computedMaxWidth = useMemo(function () {
    var curMaxWidth;

    if (maxWidth) {
      curMaxWidth = typeof maxWidth === 'number' ? "".concat(maxWidth, "px") : String(maxWidth);
    }

    var curMaxItemWidth;

    if (maxItemWidth) {
      curMaxItemWidth = typeof maxItemWidth === 'number' ? "".concat(maxItemWidth, "px") : String(maxItemWidth);
    }

    return {
      maxWidth: curMaxWidth || curMaxItemWidth || '200px'
    };
  }, [maxItemWidth, maxWidth]);
  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-breadcrumb__item', disabled && 'i-breadcrumb-is-disabled', className),
    style: _objectSpread2({}, style)
  }, restProps), /*#__PURE__*/React.createElement("span", {
    className: "i-breadcrumb__inner",
    style: computedMaxWidth
  }, children), /*#__PURE__*/React.createElement("span", {
    className: "i-breadcrumb__separator"
  }, separator));
};

var _excluded$j = ["children", "className", "maxItemWidth", "separator", "style"];

var Breadcrumb = function Breadcrumb(props) {
  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      maxItemWidth = props.maxItemWidth,
      separator = props.separator,
      style = props.style,
      restProps = _objectWithoutProperties(props, _excluded$j);

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-breadcrumb', className),
    style: _objectSpread2({}, style)
  }, restProps), React.Children.map(children, function (child) {
    if (! /*#__PURE__*/React.isValidElement(child)) {
      return null;
    }

    var childProps = {
      separator: separator,
      maxItemWidth: maxItemWidth
    };
    return /*#__PURE__*/React.cloneElement(child, childProps);
  }));
};

Breadcrumb.Item = BreadcrumbItem;
BreadcrumbItem.displayName = 'BreadcrumbItem';
Breadcrumb.displayName = 'Breadcrumb';

var css_248z$e = ".i-pagination {\n  display: flex;\n  gap: 16px;\n  align-items: center;\n}\n\n.i-pagination-select {\n  width: 100px;\n}\n\n.i-pagination-control {\n  display: flex;\n  gap: 8px;\n  align-items: center;\n}\n\n.i-pagination-btn {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  width: 32px;\n  min-width: 32px;\n  height: 32px;\n  color: var(--i-font-2);\n  font-size: 14px;\n  border: 1px solid var(--i-border);\n  border-radius: 4px;\n  cursor: pointer;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-pagination-btn:hover {\n  color: var(--i-primary-txt);\n  border-color: var(--i-primary-txt);\n}\n.i-pagination-btn.i-pagination-btn__handle {\n  border: none;\n}\n.i-pagination-btn.i-pagination-btn__handle:hover {\n  background: var(--i-bg-hover);\n}\n.i-pagination-btn.i-pagination-btn__active {\n  color: var(--i-bg);\n  background: var(--i-primary-txt);\n  border-color: var(--i-primary-txt);\n}\n.i-pagination-btn.i-pagination-btn__active:hover {\n  color: var(--i-bg);\n}\n.i-pagination-btn.i-pagination-btn__disabled {\n  color: var(--i-font-disabled);\n  cursor: not-allowed;\n}\n.i-pagination-btn.i-pagination-btn__disabled:hover {\n  color: var(--i-font-disabled);\n  background: unset;\n  border-color: var(--i-border);\n}\n.i-pagination-btn.i-pagination-btn__disabled.i-pagination-btn__handle {\n  border: none;\n}\n.i-pagination-btn.i-pagination-btn__disabled.i-pagination-btn__active {\n  color: var(--i-bg);\n  background: var(--i-primary-disabled);\n  border-color: var(--i-primary-disabled);\n}\n\n.i-pagination-btn__wrapper {\n  display: flex;\n  gap: 8px;\n  align-items: center;\n  width: 192px;\n  overflow: hidden;\n}\n.i-pagination-btn__wrapper::-webkit-scrollbar {\n  display: none;\n}\n\n.i-pagination-input {\n  display: flex;\n  gap: 8px;\n  align-items: center;\n  color: var(--i-font-2);\n  font-size: 14px;\n}";
styleInject(css_248z$e);

var css_248z$f = ".i-input {\n  position: relative;\n  display: flex;\n  align-items: center;\n  box-sizing: border-box;\n  width: 100%;\n  height: 32px;\n  padding: 0 8px;\n  overflow: hidden;\n  color: var(--i-font-2);\n  font-size: 14px;\n  line-height: 32px;\n  border: 1px solid var(--i-border);\n  border-radius: 4px;\n  outline: none;\n  visibility: visible;\n  cursor: text;\n  transition: all 0.2s cubic-bezier(0.38, 0, 0.24, 1);\n}\n.i-input .i-icon {\n  margin-left: 6px;\n  color: var(--i-font-4) !important;\n  font-size: inherit !important;\n  cursor: pointer;\n  transition: all 0.1s ease-out;\n}\n.i-input .i-icon:hover {\n  color: var(--i-font-3) !important;\n}\n.i-input .icon-TipCloseFill {\n  opacity: 0;\n}\n.i-input .i-input-prefix-icon,\n.i-input .i-input-suffix-icon {\n  cursor: text;\n}\n.i-input .i-input-prefix-icon:hover,\n.i-input .i-input-suffix-icon:hover {\n  color: var(--i-font-4) !important;\n}\n.i-input .i-input-prefix-icon.i-input-icon-cursor,\n.i-input .i-input-suffix-icon.i-input-icon-cursor {\n  cursor: pointer;\n}\n.i-input .i-input-prefix-icon.i-input-icon-cursor:hover,\n.i-input .i-input-suffix-icon.i-input-icon-cursor:hover {\n  color: var(--i-font-3) !important;\n}\n.i-input .i-input-prefix-icon {\n  margin-right: 6px;\n  margin-left: 0;\n}\n.i-input.i-input--size-small {\n  height: 24px;\n  padding: 0 6px;\n  font-size: 12px;\n  line-height: 24px;\n}\n.i-input.i-input--size-small .i-input__inner {\n  height: 24px;\n}\n.i-input.i-input--size-small .i-icon {\n  margin-left: 5px;\n}\n.i-input.i-input--size-small .i-input-prefix-icon {\n  margin-right: 5px;\n  margin-left: 0;\n}\n.i-input.i-input--size-small .i-input-number-button {\n  width: 12px;\n}\n.i-input.i-input--size-small .i-input-number-button .i-icon {\n  margin-left: 6px;\n  padding-right: 3px;\n  padding-left: 3px;\n}\n.i-input.i-input--size-large {\n  height: 40px;\n  padding: 0 10px;\n  font-size: 16px;\n  line-height: 40px;\n}\n.i-input.i-input--size-large .i-input__inner {\n  height: 40px;\n}\n.i-input.i-input--size-large .i-icon {\n  margin-left: 7px;\n}\n.i-input.i-input--size-large .i-input-prefix-icon {\n  margin-right: 7px;\n  margin-left: 0;\n}\n.i-input.i-input--size-large .i-input-number-button {\n  width: 16px;\n}\n.i-input.i-input--size-large .i-input-number-button .i-icon {\n  margin-left: 10px;\n  padding-right: 5px;\n  padding-left: 5px;\n}\n.i-input:hover {\n  border-color: var(--i-border-hover);\n}\n.i-input:hover .icon-TipCloseFill {\n  opacity: 1;\n}\n.i-input:focus-within {\n  border-color: var(--i-primary);\n}\n.i-input.i-input-is-disabled {\n  background-color: var(--i-bg-disabled);\n}\n.i-input.i-input-is-disabled .i-input__inner {\n  color: var(--i-font-disabled);\n}\n.i-input.i-input-is-disabled,\n.i-input.i-input-is-disabled * {\n  cursor: not-allowed;\n}\n.i-input.i-input-is-disabled:hover {\n  border-color: var(--i-border);\n}\n.i-input.i-input-is-readonly,\n.i-input.i-input-is-readonly * {\n  cursor: default;\n}\n.i-input.i-input--status-success, .i-input.i-input--status-success:hover, .i-input.i-input--status-success:focus-within {\n  border-color: var(--i-success);\n}\n.i-input.i-input--status-warning, .i-input.i-input--status-warning:hover, .i-input.i-input--status-warning:focus-within {\n  border-color: var(--i-warning);\n}\n.i-input.i-input--status-error, .i-input.i-input--status-error:hover, .i-input.i-input--status-error:focus-within {\n  border-color: var(--i-error);\n}\n\n.i-input--type-password .i-input__inner {\n  letter-spacing: 2px;\n}\n.i-input--type-password .i-input__inner::-moz-placeholder {\n  letter-spacing: 0;\n}\n.i-input--type-password .i-input__inner:-ms-input-placeholder {\n  letter-spacing: 0;\n}\n.i-input--type-password .i-input__inner::placeholder {\n  letter-spacing: 0;\n}\n\n.i-input--type-number {\n  padding-right: 0;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-input--type-number .i-input__inner {\n  padding-right: 8px;\n}\n.i-input--type-number .i-input__inner:focus {\n  -webkit-user-select: text;\n     -moz-user-select: text;\n      -ms-user-select: text;\n          user-select: text;\n}\n.i-input--type-number .i-input-suffix-icon {\n  position: relative;\n  right: 8px;\n}\n.i-input--type-number .icon-TipCloseFill {\n  margin-right: 8px;\n}\n.i-input--type-number input::-webkit-inner-spin-button,\n.i-input--type-number input::-webkit-outer-spin-button {\n  display: none;\n  -webkit-appearance: none !important;\n}\n\n.i-input-number-button {\n  z-index: 1;\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  width: 24px;\n  height: 100%;\n  border-left: 1px solid var(--i-border);\n}\n.i-input-number-button .i-icon {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 100%;\n  height: 50%;\n  margin: 0;\n  overflow: hidden;\n}\n.i-input-number-button .i-icon:first-of-type {\n  padding-top: 2px;\n}\n.i-input-number-button .i-icon:last-of-type {\n  padding-bottom: 2px;\n  border-top: 1px solid var(--i-border);\n}\n.i-input-number-button .i-icon:hover {\n  background-color: var(--i-bg-disabled);\n}\n.i-input-number-button .i-icon:active {\n  color: var(--i-font-4) !important;\n}\n.i-input-number-button .i-icon.i-icon-is-disabled {\n  background-color: var(--i-bg-disabled);\n  cursor: not-allowed;\n  opacity: 0.5;\n}\n.i-input-number-button .i-icon.i-icon-is-disabled:hover {\n  color: var(--i-font-4) !important;\n}\n.i-input-number-button .i-icon.i-icon-is-disabled:active {\n  color: var(--i-font-4) !important;\n}\n\n.i-input-number-slider {\n  position: absolute;\n  left: 0;\n  width: 8px;\n  height: 100%;\n  cursor: url(\"./resize.svg\") 10 8, auto;\n}\n\n.i-input-number-scrubbable {\n  position: fixed;\n  top: 0;\n  left: 0;\n  z-index: 6500;\n  width: auto;\n  height: auto;\n}\n\n.i-input--limit {\n  margin-left: 8px;\n}\n\n.i-input--limit-count {\n  color: var(--i-font-5);\n  font-size: 12px;\n}\n\n.i-input__inner {\n  flex: 1;\n  box-sizing: border-box;\n  width: 100%;\n  height: 32px;\n  margin: 0;\n  padding: 0;\n  color: var(--i-font-2);\n  font-size: inherit;\n  line-height: 32px;\n  background-color: transparent;\n  border: none;\n  outline: none;\n}\n.i-input__inner::-moz-placeholder {\n  color: var(--i-font-5);\n  -moz-user-select: none;\n       user-select: none;\n}\n.i-input__inner:-ms-input-placeholder {\n  color: var(--i-font-5);\n  -ms-user-select: none;\n      user-select: none;\n}\n.i-input__inner::placeholder {\n  color: var(--i-font-5);\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n\n.i-input__group {\n  display: flex;\n  align-items: center;\n  color: var(--i-font-2);\n}\n.i-input__group .i-grid {\n  flex-wrap: nowrap;\n}\n.i-input__group .i-grid .i-grid__item .i-input {\n  border-radius: 0;\n}\n.i-input__group .i-grid .i-grid__item .i-input:hover {\n  box-shadow: -1px 0px 0 0px var(--i-font-4);\n}\n.i-input__group .i-grid .i-grid__item .i-input:focus-within {\n  box-shadow: -1px 0px 0 0px var(--i-primary);\n}\n.i-input__group .i-grid .i-grid__item:first-of-type .i-input {\n  border-radius: 4px 0 0 4px;\n}\n.i-input__group .i-grid .i-grid__item:first-of-type .i-input:hover, .i-input__group .i-grid .i-grid__item:first-of-type .i-input:focus-within {\n  box-shadow: none;\n}\n.i-input__group .i-grid .i-grid__item:last-of-type .i-input {\n  border-radius: 0 4px 4px 0;\n}\n.i-input__group .i-grid .i-grid__item:only-of-type .i-input {\n  border-radius: 4px;\n}\n.i-input__group .i-grid .i-grid__item + .i-grid__item .i-input {\n  border-left-width: 0;\n}\n.i-input__group .i-grid .i-grid__item:focus-within + .i-grid__item .i-input:hover {\n  box-shadow: none;\n}\n.i-input__group .i-input {\n  border-radius: 0;\n}\n.i-input__group .i-input:first-of-type {\n  border-radius: 4px 0 0 4px;\n}\n.i-input__group .i-input:first-of-type:hover, .i-input__group .i-input:first-of-type:focus-within {\n  box-shadow: none;\n}\n.i-input__group .i-input:last-of-type {\n  border-radius: 0 4px 4px 0;\n}\n.i-input__group .i-input:only-of-type {\n  border-radius: 4px;\n}\n.i-input__group .i-input:only-of-type:focus-within {\n  box-shadow: none;\n}\n.i-input__group .i-input + .i-input {\n  border-left-width: 0;\n}\n.i-input__group .i-input:hover {\n  box-shadow: -1px 0px 0 0px var(--i-font-4);\n}\n.i-input__group .i-input:focus-within {\n  box-shadow: -1px 0px 0 0px var(--i-primary);\n}\n.i-input__group .i-input:focus-within + .i-input:hover {\n  box-shadow: none;\n}\n.i-input__group .i-tag {\n  height: 100%;\n}\n\n.i-input__group-prefix,\n.i-input__group-suffix {\n  z-index: 1;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  width: auto;\n  height: 100%;\n  padding: 0 8px;\n  color: var(--i-font-4);\n  font-size: 14px;\n  background-color: var(--i-bg-disabled);\n  border: 1px solid var(--i-border);\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-input__group-prefix.i-input__group-cursor,\n.i-input__group-suffix.i-input__group-cursor {\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\n.i-input__group-prefix.i-input__group-cursor:hover,\n.i-input__group-suffix.i-input__group-cursor:hover {\n  background-color: var(--i-bg-active);\n}\n\n.i-input__group-prefix {\n  border-right-width: 0;\n  border-radius: 4px 0 0 4px;\n}\n\n.i-input__group-suffix {\n  border-left-width: 0;\n  border-radius: 0 4px 4px 0;\n}\n\n.i-input__tips {\n  height: auto;\n  min-height: 24px;\n  color: var(--i-font-5);\n  font-size: 12px;\n  line-height: 20px;\n}\n.i-input__tips.i-input__tips--status-success {\n  color: var(--i-success);\n}\n.i-input__tips.i-input__tips--status-warning {\n  color: var(--i-warning);\n}\n.i-input__tips.i-input__tips--status-error {\n  color: var(--i-error);\n}";
styleInject(css_248z$f);

var InputGroup = function InputGroup(props) {
  var className = props.className,
      children = props.children,
      style = props.style,
      prefixContent = props.prefixContent,
      suffixContent = props.suffixContent,
      clickPrefix = props.clickPrefix,
      clickSuffix = props.clickSuffix;

  var _useState = useState(0),
      _useState2 = _slicedToArray(_useState, 2),
      contentHeight = _useState2[0],
      setContentHeight = _useState2[1];

  var groupRef = useRef(null);
  useEffect(function () {
    var maxHeight = 0;
    var groupChild = groupRef.current && groupRef.current.childNodes;
    groupChild && Array.from(groupChild).map(function (item) {
      if (item.className !== 'i-input__group-prefix' && item.className !== 'i-input__group-suffix' && item.offsetHeight > maxHeight) {
        maxHeight = item.offsetHeight;
      }
    });
    setContentHeight(maxHeight);
  });

  var handleClickWith = function handleClickWith(location, e) {
    e.persist();
    e.stopPropagation();

    if (clickPrefix && location === 'pre') {
      clickPrefix(e);
      return;
    }

    if (clickSuffix && location === 'suf') {
      clickSuffix(e);
      return;
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classNames('i-input__group', className),
    style: _objectSpread2(_objectSpread2({}, style || {}), {
      height: contentHeight
    }),
    ref: groupRef
  }, prefixContent && /*#__PURE__*/React.createElement("div", {
    className: classNames('i-input__group-prefix', clickPrefix && 'i-input__group-cursor'),
    onClick: function onClick(e) {
      return handleClickWith('pre', e);
    }
  }, prefixContent), children, suffixContent && /*#__PURE__*/React.createElement("div", {
    className: classNames('i-input__group-suffix', clickSuffix && 'i-input__group-cursor'),
    onClick: function onClick(e) {
      return handleClickWith('suf', e);
    }
  }, suffixContent));
};

var InputSlider = function InputSlider(props) {
  var left = props.left,
      top = props.top,
      translateX = props.translateX,
      translateY = props.translateY;
  return /*#__PURE__*/React.createElement("div", {
    className: "i-input-number-scrubbable",
    style: {
      left: left,
      top: top,
      transform: "translate(".concat(translateX, "px,").concat(translateY, "px)")
    }
  }, /*#__PURE__*/React.createElement("svg", {
    width: "30",
    height: "19",
    viewBox: "0 0 30 19",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, /*#__PURE__*/React.createElement("g", {
    filter: "url(#filter0_d_7775_2255)"
  }, /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    clipRule: "evenodd",
    d: "M3 8.999V9.004L8.997 15L8.998 11.001H10.997H21V15L27 9L21 3V7.022H10.997H8.997L8.998 3L3 8.999ZM4.411 9.002L7.998 5.414L7.997 8.001H11.497H22V5.414L25.5 9L22 12.587V10L11.497 10.002L7.998 10.001L7.997 12.587L4.411 9.002Z",
    fill: "white"
  }), /*#__PURE__*/React.createElement("path", {
    fillRule: "evenodd",
    clipRule: "evenodd",
    d: "M11.4971 10.0015L22 10.0005V12.5875L25.5 9L22 5.41451V8.02151H11.4971H7.99707V5.41451L4.41107 9.0015L7.99707 12.5875V10.0005L11.4971 10.0015Z",
    fill: "black"
  })), /*#__PURE__*/React.createElement("defs", null, /*#__PURE__*/React.createElement("filter", {
    id: "filter0_d_7775_2255",
    x: "-0.6",
    y: "-1.6",
    width: "31.2",
    height: "23.2",
    filterUnits: "userSpaceOnUse",
    colorInterpolationFilters: "sRGB"
  }, /*#__PURE__*/React.createElement("feFlood", {
    floodOpacity: "0",
    result: "BackgroundImageFix"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    in: "SourceAlpha",
    type: "matrix",
    values: "0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0",
    result: "hardAlpha"
  }), /*#__PURE__*/React.createElement("feOffset", {
    dy: "1"
  }), /*#__PURE__*/React.createElement("feGaussianBlur", {
    stdDeviation: "1.3"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    type: "matrix",
    values: "0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0.32 0"
  }), /*#__PURE__*/React.createElement("feBlend", {
    mode: "normal",
    in2: "BackgroundImageFix",
    result: "effect1_dropShadow_7775_2255"
  }), /*#__PURE__*/React.createElement("feBlend", {
    mode: "normal",
    in: "SourceGraphic",
    in2: "effect1_dropShadow_7775_2255",
    result: "shape"
  })))));
};

var _excluded$k = ["className", "children", "placeholder", "style", "value", "defaultValue", "disabled", "readonly", "size", "status", "tips", "maxLength", "clearable", "hideNumberBtn", "selectAll", "type", "speed", "maxNumber", "minNumber", "minNumberLock", "precision", "step", "prefixIcon", "suffixIcon", "prefixIconClass", "suffixIconClass", "onChange", "onFocus", "onBlur", "onKeyDown", "onEnter", "onKeyUp", "onClear", "onMove", "onMoveUp", "clickPrefixIcon", "clickSuffixIcon"];

var inputSliderWrapper = useContainer('i-input-slider-wrapper', document.body);

var Input = function Input(props) {
  var className = props.className,
      children = props.children,
      _props$placeholder = props.placeholder,
      placeholder = _props$placeholder === void 0 ? '请输入' : _props$placeholder,
      style = props.style,
      value = props.value,
      _props$defaultValue = props.defaultValue,
      defaultValue = _props$defaultValue === void 0 ? '' : _props$defaultValue,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$readonly = props.readonly,
      readonly = _props$readonly === void 0 ? false : _props$readonly,
      size = props.size,
      status = props.status,
      tips = props.tips,
      maxLength = props.maxLength,
      _props$clearable = props.clearable,
      clearable = _props$clearable === void 0 ? false : _props$clearable,
      _props$hideNumberBtn = props.hideNumberBtn,
      hideNumberBtn = _props$hideNumberBtn === void 0 ? false : _props$hideNumberBtn,
      _props$selectAll = props.selectAll,
      selectAll = _props$selectAll === void 0 ? false : _props$selectAll,
      type = props.type,
      _props$speed = props.speed,
      speed = _props$speed === void 0 ? 'default' : _props$speed,
      _props$maxNumber = props.maxNumber,
      maxNumber = _props$maxNumber === void 0 ? Number.MAX_VALUE : _props$maxNumber,
      _props$minNumber = props.minNumber,
      minNumber = _props$minNumber === void 0 ? Number.MIN_SAFE_INTEGER : _props$minNumber,
      _props$minNumberLock = props.minNumberLock,
      minNumberLock = _props$minNumberLock === void 0 ? false : _props$minNumberLock,
      _props$precision = props.precision,
      precision = _props$precision === void 0 ? 0 : _props$precision,
      _props$step = props.step,
      step = _props$step === void 0 ? 1 : _props$step,
      prefixIcon = props.prefixIcon,
      suffixIcon = props.suffixIcon,
      prefixIconClass = props.prefixIconClass,
      suffixIconClass = props.suffixIconClass,
      onChange = props.onChange,
      onFocus = props.onFocus,
      onBlur = props.onBlur,
      onKeyDown = props.onKeyDown,
      onEnter = props.onEnter,
      onKeyUp = props.onKeyUp,
      onClear = props.onClear,
      onMove = props.onMove,
      onMoveUp = props.onMoveUp,
      clickPrefixIcon = props.clickPrefixIcon,
      clickSuffixIcon = props.clickSuffixIcon,
      restProps = _objectWithoutProperties(props, _excluded$k); // 聚焦 input 输入框


  var inputRef = useRef(null);

  var focusInputNode = function focusInputNode() {
    var _inputRef$current;

    (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : _inputRef$current.focus();
  };

  var _useDefault = useDefault(value, defaultValue, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerValue = _useDefault2[0],
      setInnerValue = _useDefault2[1];

  var _useState = useState((innerValue === null || innerValue === void 0 ? void 0 : innerValue.toString().length) || 0),
      _useState2 = _slicedToArray(_useState, 2),
      valueLength = _useState2[0],
      setValueLength = _useState2[1];

  var handleChange = function handleChange(e) {
    e.persist();
    maxLength && setValueLength(e.target.value.length);
    var currentValue = e.target.value;

    if (type === 'number') {
      if (currentValue !== '') {
        if (Number(currentValue) > maxNumber) {
          currentValue = maxNumber.toFixed(precision).toString();
        }

        if (Number(currentValue) < minNumber) {
          currentValue = minNumber.toFixed(precision).toString();
        }
      } else {
        if (Number(currentValue) < minNumber && minNumberLock) {
          currentValue = minNumber.toFixed(precision).toString();
        }
      }
    }

    setInnerValue(currentValue, e);
  }; // 点击清空按钮


  var handleClear = function handleClear(e) {
    setInnerValue('', e);
    onClear === null || onClear === void 0 ? void 0 : onClear(e);
  };

  var _useState3 = useState(type),
      _useState4 = _slicedToArray(_useState3, 2),
      currentType = _useState4[0],
      setCurrentType = _useState4[1]; // 密码类型切换


  var handleSwitchPassword = function handleSwitchPassword(e) {
    e.stopPropagation();
    currentType !== 'password' ? setCurrentType('password') : setCurrentType('text');
  }; // 键盘事件


  var handleKeyDown = function handleKeyDown(e) {
    e.persist();
    e.key === 'Enter' && (onEnter === null || onEnter === void 0 ? void 0 : onEnter(e.target.value, e));
    onKeyDown === null || onKeyDown === void 0 ? void 0 : onKeyDown(e.target.value, e);
  }; // 通用事件


  var handleEvent = function handleEvent(eventType, e) {
    e.persist();

    if (eventType === 'focus') {
      onFocus === null || onFocus === void 0 ? void 0 : onFocus(e.target.value, e);

      if (selectAll) {
        var _inputRef$current2;

        (_inputRef$current2 = inputRef.current) === null || _inputRef$current2 === void 0 ? void 0 : _inputRef$current2.select();
      }
    }

    if (eventType === 'blur') {
      if (type === 'number' && e.target.value) {
        var fixedValue = Number(e.target.value).toFixed(precision);
        e.target.value = fixedValue;
      }

      onBlur === null || onBlur === void 0 ? void 0 : onBlur(e.target.value, e);
    }

    if (eventType === 'up') {
      onKeyUp === null || onKeyUp === void 0 ? void 0 : onKeyUp(e.target.value, e);

      if (type === 'number') {
        var _inputRef$current3;

        // 设置最大值最小值按钮禁用状态
        var currentValue = Number((_inputRef$current3 = inputRef.current) === null || _inputRef$current3 === void 0 ? void 0 : _inputRef$current3.value);

        if (currentValue === maxNumber) {
          setIfMaximum(true);
        } else {
          setIfMaximum(false);
        }

        if (currentValue === minNumber) {
          setIfLeastValue(true);
        } else {
          setIfLeastValue(false);
        }
      }
    }
  };

  var renderInput = /*#__PURE__*/React.createElement("input", _objectSpread2({
    className: "i-input__inner",
    placeholder: placeholder,
    disabled: disabled,
    readOnly: readonly,
    ref: inputRef,
    value: innerValue,
    type: currentType,
    maxLength: maxLength,
    max: currentType === 'number' ? maxNumber : undefined,
    min: currentType === 'number' ? minNumber : undefined,
    step: currentType === 'number' ? step : undefined,
    onChange: handleChange,
    onFocus: function onFocus(e) {
      return handleEvent('focus', e);
    },
    onBlur: function onBlur(e) {
      return handleEvent('blur', e);
    },
    onKeyDown: handleKeyDown,
    onKeyUp: function onKeyUp(e) {
      return handleEvent('up', e);
    }
  }, restProps)); // 最大值 | 最小值判断

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      ifMaximum = _useState6[0],
      setIfMaximum = _useState6[1];

  var _useState7 = useState(false),
      _useState8 = _slicedToArray(_useState7, 2),
      ifLeastValue = _useState8[0],
      setIfLeastValue = _useState8[1];

  useEffect(function () {
    if (type === 'number') {
      if (Number(innerValue) <= minNumber) {
        setIfLeastValue(true);
      }

      if (Number(innerValue) >= maxNumber) {
        setIfMaximum(true);
      }
    }
  }, []); // 数字调整按钮

  var handleAdjustValue = function handleAdjustValue() {
    var handle = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;
    var e = arguments.length > 1 ? arguments[1] : undefined;
    e.stopPropagation();
    var currentValue;
    var computedValue = 0;

    if (inputRef) {
      var _inputRef$current4;

      currentValue = Number((_inputRef$current4 = inputRef.current) === null || _inputRef$current4 === void 0 ? void 0 : _inputRef$current4.value);

      if (handle) {
        computedValue = currentValue + step;
      } else {
        computedValue = currentValue - step;
      } // 设置最大值最小值按钮禁用状态


      if (computedValue >= maxNumber) {
        computedValue = maxNumber;
        setIfMaximum(true);
      } else {
        setIfMaximum(false);
      }

      if (computedValue <= minNumber) {
        computedValue = minNumber;
        setIfLeastValue(true);
      } else {
        setIfLeastValue(false);
      }
    }

    var result = computedValue.toFixed(precision);
    inputRef.current.value = result;
    setInnerValue(result, e);
  };

  var renderNumberBtn = /*#__PURE__*/React.createElement("div", {
    className: "i-input-number-button"
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ArrowCaretTop",
    disabled: ifMaximum,
    onClick: function onClick(e) {
      return handleAdjustValue(true, e);
    }
  }), /*#__PURE__*/React.createElement(Icon, {
    name: "ArrowCaretBottom",
    disabled: ifLeastValue,
    onClick: function onClick(e) {
      return handleAdjustValue(false, e);
    }
  })); // 数字调整滑块

  var _useState9 = useState({
    ifDown: false,
    left: 0,
    top: 0,
    translateX: 0,
    translateY: 0
  }),
      _useState10 = _slicedToArray(_useState9, 2),
      slider = _useState10[0],
      setSlider = _useState10[1];

  var startX = 0;
  var startY = 0;
  var countValue = 0;
  var criticalValue = 0;

  var handleSliderMove = function handleSliderMove(e) {
    startX += e.movementX;
    startY += e.movementY; // 滑块更新输入框数值

    if (inputRef) {
      var _inputRef$current5;

      countValue = Number((_inputRef$current5 = inputRef.current) === null || _inputRef$current5 === void 0 ? void 0 : _inputRef$current5.value);
      criticalValue += e.movementX;
      var changeSpeedNum = {
        slow: 30,
        default: 10,
        fast: 1
      }[speed];

      if (criticalValue > changeSpeedNum && countValue < maxNumber) {
        criticalValue = 0;
        countValue += step;
      }

      if (criticalValue < -changeSpeedNum && countValue > minNumber) {
        criticalValue = 0;
        countValue -= step;
      } // 设置最大值最小值按钮禁用状态


      countValue === maxNumber ? setIfMaximum(true) : setIfMaximum(false);
      countValue === minNumber ? setIfLeastValue(true) : setIfLeastValue(false);
      var result = countValue.toFixed(precision);
      inputRef.current.value = result;
      setInnerValue(result, e);
      onMove === null || onMove === void 0 ? void 0 : onMove(result, e);
    } // 滑块超出屏幕边界处理


    if (e.clientX + startX < 0) {
      startX += window.innerWidth;
    }

    if (e.clientX + startX > window.innerWidth) {
      startX -= window.innerWidth;
    }

    if (e.clientY + startY < 0) {
      startY += window.innerHeight;
    }

    if (e.clientY + startY > window.innerHeight) {
      startY -= window.innerHeight;
    } // 更新滑块位置


    slider.translateX = startX;
    slider.translateY = startY;
    setSlider(_objectSpread2({}, slider));
  };

  var handleSliderUp = function handleSliderUp() {
    document.exitPointerLock();
    slider.ifDown = false;
    slider.translateX = 0;
    slider.translateY = 0;
    setSlider(_objectSpread2({}, slider));
    onMoveUp === null || onMoveUp === void 0 ? void 0 : onMoveUp(inputRef.current.value);
    window.removeEventListener('mouseup', handleSliderUp);
    window.removeEventListener('mousemove', handleSliderMove);
  };

  var handleSliderDown = function handleSliderDown(e) {
    e.persist();

    if (size && size === 'small') {
      slider.top = e.clientY - 8;
    } else if (size && size === 'large') {
      slider.top = e.clientY - 15;
    } else {
      slider.top = e.clientY - 10;
    }

    slider.left = e.clientX - 14;
    e.target.requestPointerLock();
    slider.ifDown = true;
    setSlider(_objectSpread2({}, slider));
    window.addEventListener('mouseup', handleSliderUp);
    window.addEventListener('mousemove', handleSliderMove);
  };

  var renderNumberSlider = /*#__PURE__*/React.createElement("div", {
    className: "i-input-number-slider",
    onMouseDown: handleSliderDown
  }, slider.ifDown && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/ReactDOM.createPortal( /*#__PURE__*/React.createElement(InputSlider, {
    left: slider.left,
    top: slider.top,
    translateX: slider.translateX,
    translateY: slider.translateY
  }), inputSliderWrapper))); // 内置图标

  var handleClickInnerIcon = function handleClickInnerIcon(location, e) {
    e.persist();
    e.stopPropagation();

    if (clickPrefixIcon && location === 'pre') {
      clickPrefixIcon(e);
      return;
    }

    if (clickSuffixIcon && location === 'suf') {
      clickSuffixIcon(e);
      return;
    }

    focusInputNode();
  };

  var renderPrefixIcon = /*#__PURE__*/React.createElement(Icon, {
    className: classNames('i-input-prefix-icon', clickPrefixIcon && 'i-input-icon-cursor', prefixIconClass),
    name: prefixIcon,
    onClick: function onClick(e) {
      return handleClickInnerIcon('pre', e);
    }
  });
  var renderSuffixIcon = /*#__PURE__*/React.createElement(Icon, {
    className: classNames('i-input-suffix-icon', clickSuffixIcon && 'i-input-icon-cursor', suffixIconClass),
    name: suffixIcon,
    onClick: function onClick(e) {
      return handleClickInnerIcon('suf', e);
    }
  });
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: classNames('i-input', disabled && 'i-input-is-disabled', readonly && 'i-input-is-readonly', size && "i-input--size-".concat(size), status && "i-input--status-".concat(status), currentType && "i-input--type-".concat(currentType), className),
    style: _objectSpread2({}, style),
    onClick: focusInputNode
  }, prefixIcon && renderPrefixIcon, children, renderInput, maxLength && /*#__PURE__*/React.createElement("div", {
    className: "i-input--limit"
  }, /*#__PURE__*/React.createElement("span", {
    className: "i-input--limit-count"
  }, valueLength < maxLength ? valueLength : maxLength, " / ", maxLength)), !disabled && innerValue && (clearable || onClear) && /*#__PURE__*/React.createElement(Icon, {
    name: "TipCloseFill",
    onClick: handleClear
  }), !disabled && type === 'password' && /*#__PURE__*/React.createElement(Icon, {
    name: currentType === 'password' ? 'ViewHide' : 'View',
    onClick: handleSwitchPassword
  }), suffixIcon && renderSuffixIcon, !disabled && type === 'number' && !hideNumberBtn && renderNumberBtn, !disabled && type === 'number' && renderNumberSlider), tips && /*#__PURE__*/React.createElement("div", {
    className: classNames('i-input__tips', status && "i-input__tips--status-".concat(status))
  }, tips));
};

Input.displayName = 'Input';
InputGroup.displayName = 'InputGroup';
Input.Group = InputGroup;

var css_248z$g = ".i-select {\n  width: 100%;\n}\n.i-select .i-popup__reference {\n  width: 100%;\n}\n.i-select .i-popup__reference > .i-input {\n  height: auto;\n}\n.i-select .i-popup__reference > .i-input .i-input__inner::-moz-selection {\n  background: transparent;\n}\n.i-select .i-popup__reference > .i-input .i-input__inner::selection {\n  background: transparent;\n}\n.i-select[data-size=small] {\n  width: 160px;\n}\n.i-select[data-size=large] {\n  width: 240px;\n}\n.i-select .i-input__hide-clear > .icon-TipCloseFill {\n  display: none !important;\n}\n.i-select .i-input > .icon-TipCloseFill {\n  cursor: pointer;\n}\n.i-select .i-input > .icon-ArrowDown {\n  pointer-events: none;\n}\n.i-select .i-tag--close-btn .i-icon {\n  cursor: pointer;\n}\n\n.i-select-arrow__show {\n  transform: rotate(180deg);\n}\n\n.i-select__multiple-wrap {\n  display: flex;\n  flex-wrap: wrap;\n  gap: 6px;\n  align-items: center;\n  width: 100%;\n  margin: 6px 0;\n  overflow: hidden;\n}\n.i-select__multiple-wrap .i-tag {\n  border-radius: 2px;\n}";
styleInject(css_248z$g);

var css_248z$h = ".i-tag {\n  display: inline-flex;\n  flex-direction: row;\n  align-items: center;\n  box-sizing: border-box;\n  height: 24px;\n  padding: 0 8px;\n  font-size: 14px;\n  line-height: 1;\n  white-space: nowrap;\n  border: 1px solid transparent;\n  border-radius: 4px;\n  cursor: default;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n\na {\n  text-decoration: none;\n}\n\na .i-tag {\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\na .i-tag:hover {\n  color: var(--i-primary);\n  border-color: var(--i-primary);\n}\n\n.i-tag--type-default {\n  color: var(--i-font-5);\n  border-color: var(--i-font-5);\n}\n.i-tag--type-default .i-icon {\n  margin-right: 4px;\n  color: var(--i-font-5) !important;\n}\n.i-tag--type-default.i-tag--theme-dark {\n  color: #fff;\n  background-color: var(--i-font-5);\n  border-color: var(--i-font-5);\n}\n.i-tag--type-default.i-tag--theme-dark .i-icon {\n  color: #fff !important;\n}\n.i-tag--type-default.i-tag--theme-dark.i-tag--add-btn:hover {\n  background-color: var(--i-font-5);\n  opacity: 0.8;\n}\n.i-tag--type-default.i-tag--add-btn {\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\n.i-tag--type-default.i-tag--add-btn:hover {\n  background-color: var(--i-bg-active);\n}\n.i-tag--type-default .i-tag--close-btn {\n  position: relative;\n  width: 12px;\n  height: 12px;\n  margin-right: -2px;\n  margin-left: 4px;\n  cursor: pointer;\n}\n.i-tag--type-default .i-tag--close-btn .icon-Close {\n  position: absolute;\n  z-index: 1;\n  margin: 0;\n  transition: all 0.2s ease-out;\n}\n.i-tag--type-default .i-tag--close-btn::after {\n  position: absolute;\n  top: -1px;\n  left: -1px;\n  z-index: 0;\n  width: calc(100% + 2px);\n  height: calc(100% + 2px);\n  border-radius: 50%;\n  transition: all 0.2s ease-out;\n  content: \"\";\n}\n.i-tag--type-default .i-tag--close-btn:hover {\n  opacity: 0.8;\n}\n\n.i-tag--type-primary {\n  color: var(--i-primary);\n  border-color: var(--i-primary);\n}\n.i-tag--type-primary .i-icon {\n  margin-right: 4px;\n  color: var(--i-primary) !important;\n}\n.i-tag--type-primary.i-tag--theme-dark {\n  color: #fff;\n  background-color: var(--i-primary);\n  border-color: var(--i-primary);\n}\n.i-tag--type-primary.i-tag--theme-dark .i-icon {\n  color: #fff !important;\n}\n.i-tag--type-primary.i-tag--theme-dark.i-tag--add-btn:hover {\n  background-color: var(--i-primary);\n  opacity: 0.8;\n}\n.i-tag--type-primary.i-tag--add-btn {\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\n.i-tag--type-primary.i-tag--add-btn:hover {\n  background-color: var(--i-primary-bg);\n}\n.i-tag--type-primary .i-tag--close-btn {\n  position: relative;\n  width: 12px;\n  height: 12px;\n  margin-right: -2px;\n  margin-left: 4px;\n  cursor: pointer;\n}\n.i-tag--type-primary .i-tag--close-btn .icon-Close {\n  position: absolute;\n  z-index: 1;\n  margin: 0;\n  transition: all 0.2s ease-out;\n}\n.i-tag--type-primary .i-tag--close-btn::after {\n  position: absolute;\n  top: -1px;\n  left: -1px;\n  z-index: 0;\n  width: calc(100% + 2px);\n  height: calc(100% + 2px);\n  border-radius: 50%;\n  transition: all 0.2s ease-out;\n  content: \"\";\n}\n.i-tag--type-primary .i-tag--close-btn:hover {\n  opacity: 0.8;\n}\n\n.i-tag--type-success {\n  color: var(--i-success);\n  border-color: var(--i-success);\n}\n.i-tag--type-success .i-icon {\n  margin-right: 4px;\n  color: var(--i-success) !important;\n}\n.i-tag--type-success.i-tag--theme-dark {\n  color: #fff;\n  background-color: var(--i-success);\n  border-color: var(--i-success);\n}\n.i-tag--type-success.i-tag--theme-dark .i-icon {\n  color: #fff !important;\n}\n.i-tag--type-success.i-tag--theme-dark.i-tag--add-btn:hover {\n  background-color: var(--i-success);\n  opacity: 0.8;\n}\n.i-tag--type-success.i-tag--add-btn {\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\n.i-tag--type-success.i-tag--add-btn:hover {\n  background-color: var(--i-success-bg);\n}\n.i-tag--type-success .i-tag--close-btn {\n  position: relative;\n  width: 12px;\n  height: 12px;\n  margin-right: -2px;\n  margin-left: 4px;\n  cursor: pointer;\n}\n.i-tag--type-success .i-tag--close-btn .icon-Close {\n  position: absolute;\n  z-index: 1;\n  margin: 0;\n  transition: all 0.2s ease-out;\n}\n.i-tag--type-success .i-tag--close-btn::after {\n  position: absolute;\n  top: -1px;\n  left: -1px;\n  z-index: 0;\n  width: calc(100% + 2px);\n  height: calc(100% + 2px);\n  border-radius: 50%;\n  transition: all 0.2s ease-out;\n  content: \"\";\n}\n.i-tag--type-success .i-tag--close-btn:hover {\n  opacity: 0.8;\n}\n\n.i-tag--type-warning {\n  color: var(--i-warning);\n  border-color: var(--i-warning);\n}\n.i-tag--type-warning .i-icon {\n  margin-right: 4px;\n  color: var(--i-warning) !important;\n}\n.i-tag--type-warning.i-tag--theme-dark {\n  color: #fff;\n  background-color: var(--i-warning);\n  border-color: var(--i-warning);\n}\n.i-tag--type-warning.i-tag--theme-dark .i-icon {\n  color: #fff !important;\n}\n.i-tag--type-warning.i-tag--theme-dark.i-tag--add-btn:hover {\n  background-color: var(--i-warning);\n  opacity: 0.8;\n}\n.i-tag--type-warning.i-tag--add-btn {\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\n.i-tag--type-warning.i-tag--add-btn:hover {\n  background-color: var(--i-warning-bg);\n}\n.i-tag--type-warning .i-tag--close-btn {\n  position: relative;\n  width: 12px;\n  height: 12px;\n  margin-right: -2px;\n  margin-left: 4px;\n  cursor: pointer;\n}\n.i-tag--type-warning .i-tag--close-btn .icon-Close {\n  position: absolute;\n  z-index: 1;\n  margin: 0;\n  transition: all 0.2s ease-out;\n}\n.i-tag--type-warning .i-tag--close-btn::after {\n  position: absolute;\n  top: -1px;\n  left: -1px;\n  z-index: 0;\n  width: calc(100% + 2px);\n  height: calc(100% + 2px);\n  border-radius: 50%;\n  transition: all 0.2s ease-out;\n  content: \"\";\n}\n.i-tag--type-warning .i-tag--close-btn:hover {\n  opacity: 0.8;\n}\n\n.i-tag--type-error {\n  color: var(--i-error);\n  border-color: var(--i-error);\n}\n.i-tag--type-error .i-icon {\n  margin-right: 4px;\n  color: var(--i-error) !important;\n}\n.i-tag--type-error.i-tag--theme-dark {\n  color: #fff;\n  background-color: var(--i-error);\n  border-color: var(--i-error);\n}\n.i-tag--type-error.i-tag--theme-dark .i-icon {\n  color: #fff !important;\n}\n.i-tag--type-error.i-tag--theme-dark.i-tag--add-btn:hover {\n  background-color: var(--i-error);\n  opacity: 0.8;\n}\n.i-tag--type-error.i-tag--add-btn {\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\n.i-tag--type-error.i-tag--add-btn:hover {\n  background-color: var(--i-error-bg);\n}\n.i-tag--type-error .i-tag--close-btn {\n  position: relative;\n  width: 12px;\n  height: 12px;\n  margin-right: -2px;\n  margin-left: 4px;\n  cursor: pointer;\n}\n.i-tag--type-error .i-tag--close-btn .icon-Close {\n  position: absolute;\n  z-index: 1;\n  margin: 0;\n  transition: all 0.2s ease-out;\n}\n.i-tag--type-error .i-tag--close-btn::after {\n  position: absolute;\n  top: -1px;\n  left: -1px;\n  z-index: 0;\n  width: calc(100% + 2px);\n  height: calc(100% + 2px);\n  border-radius: 50%;\n  transition: all 0.2s ease-out;\n  content: \"\";\n}\n.i-tag--type-error .i-tag--close-btn:hover {\n  opacity: 0.8;\n}\n\n.i-tag--ellipsis {\n  position: relative;\n  overflow: hidden;\n  text-overflow: ellipsis;\n}\n.i-tag--ellipsis::after {\n  position: absolute;\n  right: 0;\n  display: flex;\n  align-items: center;\n  justify-content: flex-end;\n  width: 24px;\n  height: 100%;\n  background: linear-gradient(270deg, var(--i-bg) 20%, rgba(255, 255, 255, 0) 100%);\n  content: \"\";\n}\n\n.i-tag--size-small {\n  height: 20px;\n  padding: 0 6px;\n  font-size: 12px;\n}\n.i-tag--size-small .i-icon {\n  margin-right: 2px;\n}\n.i-tag--size-small.i-tag--ellipsis::after {\n  width: 16px;\n}\n\n.i-tag--size-large {\n  height: 32px;\n  padding: 0 12px;\n  font-size: 16px;\n}\n.i-tag--size-large .i-icon {\n  margin-right: 6px;\n}\n.i-tag--size-large .i-tag--close-btn {\n  width: 16px;\n  height: 16px;\n}\n.i-tag--size-large.i-tag--ellipsis::after {\n  width: 32px;\n}";
styleInject(css_248z$h);

var _excluded$l = ["children", "className", "icon", "maxWidth", "size", "style", "theme", "type", "onAdd", "onClick", "onClose"];

var Tag = function Tag(props) {
  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      icon = props.icon,
      maxWidth = props.maxWidth,
      size = props.size,
      style = props.style,
      theme = props.theme,
      _props$type = props.type,
      type = _props$type === void 0 ? 'default' : _props$type,
      onAdd = props.onAdd,
      _props$onClick = props.onClick,
      onClick = _props$onClick === void 0 ? function () {} : _props$onClick,
      onClose = props.onClose,
      restProps = _objectWithoutProperties(props, _excluded$l);

  var handleClick = function handleClick(e) {
    if (onAdd) {
      onAdd(e);
    }

    onClick(e);
  };

  var handleClose = function handleClose(e) {
    e.stopPropagation();
    onClose === null || onClose === void 0 ? void 0 : onClose(e);
  };

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-tag', size && "i-tag--size-".concat(size), type && "i-tag--type-".concat(type), theme && "i-tag--theme-".concat(theme), onAdd && 'i-tag--add-btn', maxWidth && 'i-tag--ellipsis', className),
    style: _objectSpread2(_objectSpread2({}, style || {}), {
      maxWidth: maxWidth
    }),
    onClick: handleClick
  }, restProps), onAdd && /*#__PURE__*/React.createElement(Icon, {
    name: "ThePlus",
    size: size === 'large' ? 16 : 12
  }), icon && /*#__PURE__*/React.createElement(Icon, {
    name: icon,
    size: size && {
      small: 12,
      medium: 14,
      large: 16
    }[size]
  }), children, onClose && /*#__PURE__*/React.createElement("div", {
    className: "i-tag--close-btn",
    onClick: handleClose
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "Close",
    size: size === 'large' ? 16 : 12
  })));
};

Tag.displayName = 'Tag';

var _excluded$m = ["children", "className", "style", "width", "value", "defaultValue", "placeholder", "options", "size", "clearable", "prefixIcon", "suffixIcon", "prefixIconClass", "suffixIconClass", "cascaderDirection", "multiple", "disabled", "onChange"];

var SelectItem = function SelectItem(props) {
  var children = props.children;
  return /*#__PURE__*/React.createElement(React.Fragment, null, children);
};

var Select = function Select(props) {
  var children = props.children,
      className = props.className,
      style = props.style,
      width = props.width,
      value = props.value,
      _props$defaultValue = props.defaultValue,
      defaultValue = _props$defaultValue === void 0 ? [] : _props$defaultValue,
      _props$placeholder = props.placeholder,
      placeholder = _props$placeholder === void 0 ? '请选择' : _props$placeholder,
      _props$options = props.options,
      options = _props$options === void 0 ? [] : _props$options,
      size = props.size,
      _props$clearable = props.clearable,
      clearable = _props$clearable === void 0 ? true : _props$clearable,
      prefixIcon = props.prefixIcon,
      suffixIcon = props.suffixIcon,
      _props$prefixIconClas = props.prefixIconClass,
      prefixIconClass = _props$prefixIconClas === void 0 ? '' : _props$prefixIconClas,
      _props$suffixIconClas = props.suffixIconClass,
      suffixIconClass = _props$suffixIconClas === void 0 ? '' : _props$suffixIconClas,
      _props$cascaderDirect = props.cascaderDirection,
      cascaderDirection = _props$cascaderDirect === void 0 ? 'right' : _props$cascaderDirect,
      _props$multiple = props.multiple,
      multiple = _props$multiple === void 0 ? false : _props$multiple,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$onChange = props.onChange,
      onChange = _props$onChange === void 0 ? function () {} : _props$onChange,
      restProps = _objectWithoutProperties(props, _excluded$m); // 转换下拉数据及更新下拉框宽度


  var selectNode = useRef(null);

  var _useState = useState(options),
      _useState2 = _slicedToArray(_useState, 2),
      innerOptions = _useState2[0],
      setInnerOptions = _useState2[1];

  var _useState3 = useState(0),
      _useState4 = _slicedToArray(_useState3, 2),
      dropdownWidth = _useState4[0],
      setDropdownWidth = _useState4[1];

  useEffect(function () {
    var _selectNode$current;

    // Select.Item 模式 -> 更新下拉数据
    if (children) {
      var selectData = [];
      React.Children.map(children, function (child) {
        if (! /*#__PURE__*/React.isValidElement(child)) {
          return null;
        }

        selectData.push({
          content: child.props.children,
          value: child.props.value,
          disabled: child.props.disabled,
          divider: child.props.divider,
          title: child.props.title,
          onClick: child.props.onClick
        });
      });
      setInnerOptions(selectData);
    } // 更新下拉宽度


    var currentWidth = ((_selectNode$current = selectNode.current) === null || _selectNode$current === void 0 ? void 0 : _selectNode$current.getBoundingClientRect().width) || 0;
    setDropdownWidth(currentWidth);
  }, []); // 更新下拉数据

  var _useDefault = useDefault(value, defaultValue, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerValue = _useDefault2[0],
      setInnerValue = _useDefault2[1];

  var updateValue = function updateValue(val) {
    var newVal = _.cloneDeep(val);

    setInnerValue(newVal);
  }; // 根据 options 的 value 获得对应的 content


  var valToContent = function valToContent(options, val) {
    var content = '';
    options.map(function (item) {
      if (item.children && item.children.length > 0) {
        // 级联项
        if (content === '') {
          content = valToContent(item.children, val);
        }
      } else {
        // 单项
        if (item.value === val && item.content && content === '') {
          content = item.content;
        }
      }
    });
    return content;
  }; // 选择器输入框文本内容


  var getInputValue = function getInputValue(val) {
    if (!multiple) {
      // 单选
      if (!Array.isArray(val)) {
        var content = valToContent(innerOptions, val);

        if (typeof content === 'string' || typeof content === 'number') {
          return content;
        } else {
          return '';
        }
      } else {
        return '';
      }
    } else {
      // 多选
      if (Array.isArray(innerValue)) {
        if (innerValue.length > 0) {
          return 'i';
        } else {
          return '';
        }
      } else {
        return '';
      }
    }
  }; // 选择器显示隐藏操作


  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      dropdownShow = _useState6[0],
      setDropdownShow = _useState6[1];

  var handleTrigger = function handleTrigger(visible) {
    !disabled && setDropdownShow(visible);
  }; // 删除多选项


  var handleDelItem = function handleDelItem(e, val) {
    e.stopPropagation();

    if (Array.isArray(innerValue)) {
      var curInnerValue = _.pull(innerValue, val);

      setInnerValue(_.cloneDeep(curInnerValue));
    }
  };

  var handleClear = function handleClear(e) {
    !dropdownShow && e.stopPropagation();
    var nullVal = '';

    if (multiple) {
      nullVal = [];
    }

    setInnerValue(nullVal);
  };

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    ref: selectNode,
    className: classNames('i-select', className),
    style: _objectSpread2(_objectSpread2({}, style || {}), {
      width: width,
      minWidth: width
    }),
    "data-size": size
  }, restProps), /*#__PURE__*/React.createElement(Dropdown, {
    width: dropdownWidth,
    options: innerOptions,
    onClick: updateValue,
    onTrigger: handleTrigger,
    value: innerValue,
    cascaderDirection: cascaderDirection,
    multiple: multiple,
    disabled: disabled,
    size: size
  }, /*#__PURE__*/React.createElement(Input, {
    className: classNames(!clearable && 'i-input__hide-clear'),
    value: getInputValue(innerValue),
    placeholder: placeholder,
    readonly: !disabled,
    disabled: disabled,
    size: size,
    prefixIcon: prefixIcon,
    prefixIconClass: prefixIconClass,
    suffixIcon: suffixIcon ? suffixIcon : "ArrowDown",
    suffixIconClass: dropdownShow && !suffixIcon ? "i-select-arrow__show" : suffixIconClass,
    clearable: true,
    onClear: handleClear
  }, multiple && Array.isArray(innerValue) && innerValue.length > 0 && /*#__PURE__*/React.createElement("div", {
    className: 'i-select__multiple-wrap'
  }, innerValue.map(function (val) {
    return /*#__PURE__*/React.createElement(Tag, {
      theme: "dark",
      size: "small",
      onClose: function onClose(e) {
        return handleDelItem(e, val);
      },
      key: val
    }, valToContent(innerOptions, val));
  })))));
};

Select.Item = SelectItem;
SelectItem.displayName = 'SelectItem';
Select.displayName = 'Select';

var PaginationSelect = function PaginationSelect(props) {
  var _props$value = props.value,
      value = _props$value === void 0 ? 10 : _props$value,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      onSelect = props.onSelect;
  var options = [{
    content: '10 条/页',
    value: 10
  }, {
    content: '20 条/页',
    value: 20
  }, {
    content: '30 条/页',
    value: 30
  }, {
    content: '40 条/页',
    value: 40
  }, {
    content: '50 条/页',
    value: 50
  }];

  var handleChange = function handleChange(val) {
    onSelect === null || onSelect === void 0 ? void 0 : onSelect(val);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "i-pagination-select"
  }, /*#__PURE__*/React.createElement(Select, {
    value: value,
    disabled: disabled,
    options: options,
    clearable: false,
    onChange: handleChange
  }));
};

var PaginationList = function PaginationList(props) {
  var _props$current = props.current,
      current = _props$current === void 0 ? 1 : _props$current,
      _props$total = props.total,
      total = _props$total === void 0 ? 0 : _props$total,
      _props$pageSize = props.pageSize,
      pageSize = _props$pageSize === void 0 ? 10 : _props$pageSize,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      onChoose = props.onChoose;

  var _useState = useState(_.range(1, _.ceil(total / pageSize) + 1)),
      _useState2 = _slicedToArray(_useState, 2),
      pageArr = _useState2[0],
      setPageArr = _useState2[1];

  var handleChooseNum = function handleChooseNum(item) {
    if (!disabled) {
      var result = item;
      result < 1 && (result = 1);
      result > pageArr.length && (result = pageArr.length);
      onChoose === null || onChoose === void 0 ? void 0 : onChoose(result);
    }
  };

  var shortItems = pageArr.map(function (item) {
    return /*#__PURE__*/React.createElement("div", {
      className: classNames('i-pagination-btn', current === item && 'i-pagination-btn__active', disabled && 'i-pagination-btn__disabled'),
      key: "item".concat(item),
      onClick: function onClick() {
        return handleChooseNum(item);
      }
    }, item);
  });

  var updateArrowShow = function updateArrowShow() {
    var lShow = true;
    var rShow = true;

    if (_.indexOf(pageArr, current) < 4) {
      lShow = false;
    } else if (_.indexOf(pageArr, current) > pageArr.length - 5) {
      rShow = false;
    }

    setLeftShow(lShow);
    setRightShow(rShow);
  };

  var pagesRef = useRef(null);
  useEffect(function () {
    updateArrowShow();
    pagesRef.current && pagesRef.current.scrollTo({
      left: 32 * (current - 3) + 8 * (current - 3),
      behavior: 'smooth'
    });

    var newCountArr = _.range(1, _.ceil(total / pageSize) + 1);

    setPageArr(newCountArr);
  }, [current, total, pageSize]);

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      leftShow = _useState4[0],
      setLeftShow = _useState4[1];

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      rightShow = _useState6[0],
      setRightShow = _useState6[1];

  var _useState7 = useState(false),
      _useState8 = _slicedToArray(_useState7, 2),
      leftHover = _useState8[0],
      setLeftHover = _useState8[1];

  var _useState9 = useState(false),
      _useState10 = _slicedToArray(_useState9, 2),
      rightHover = _useState10[0],
      setRightHover = _useState10[1];

  var longItems = /*#__PURE__*/React.createElement(React.Fragment, null, leftShow && /*#__PURE__*/React.createElement("div", {
    className: classNames('i-pagination-btn', '-handle', disabled && 'i-pagination-btn__disabled'),
    onMouseEnter: function onMouseEnter() {
      return setLeftHover(true);
    },
    onMouseLeave: function onMouseLeave() {
      return setLeftHover(false);
    },
    onClick: disabled ? function () {} : function () {
      return handleChooseNum(current - 5);
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    name: leftHover ? "ArrowDoubleLeft" : "MoreFilled",
    size: 12
  })), /*#__PURE__*/React.createElement("section", {
    className: "i-pagination-btn__wrapper",
    ref: pagesRef
  }, pageArr.map(function (item) {
    return /*#__PURE__*/React.createElement("div", {
      className: classNames('i-pagination-btn', current === item && 'i-pagination-btn__active', disabled && 'i-pagination-btn__disabled'),
      key: "item".concat(item),
      onClick: function onClick() {
        return handleChooseNum(item);
      }
    }, item);
  })), rightShow && /*#__PURE__*/React.createElement("div", {
    className: classNames('i-pagination-btn', '-handle', disabled && 'i-pagination-btn__disabled'),
    onMouseEnter: function onMouseEnter() {
      return setRightHover(true);
    },
    onMouseLeave: function onMouseLeave() {
      return setRightHover(false);
    },
    onClick: disabled ? function () {} : function () {
      return handleChooseNum(current + 5);
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    name: rightHover ? "ArrowDoubleRight" : "MoreFilled",
    size: 12
  })));
  return /*#__PURE__*/React.createElement("div", {
    className: "i-pagination-control"
  }, /*#__PURE__*/React.createElement("div", {
    className: classNames('i-pagination-btn', 'i-pagination-btn__handle', (current === 1 || disabled) && 'i-pagination-btn__disabled'),
    onClick: function onClick() {
      return current !== 1 && !disabled && (onChoose === null || onChoose === void 0 ? void 0 : onChoose(current - 1));
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ArrowLeft",
    size: 12
  })), pageArr.length <= 10 ? shortItems : longItems, /*#__PURE__*/React.createElement("div", {
    className: classNames('i-pagination-btn', 'i-pagination-btn__handle', (current === pageArr.length || disabled) && 'i-pagination-btn__disabled'),
    onClick: function onClick() {
      return current !== pageArr.length && !disabled && (onChoose === null || onChoose === void 0 ? void 0 : onChoose(current + 1));
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ArrowRight",
    size: 12
  })));
};

var _excluded$n = ["className", "style", "current", "total", "pageSize", "disabled", "hideSelect", "hideInput", "onChange"];

var Pagination = function Pagination(props) {
  var className = props.className,
      style = props.style,
      _props$current = props.current,
      current = _props$current === void 0 ? 1 : _props$current,
      _props$total = props.total,
      total = _props$total === void 0 ? 0 : _props$total,
      _props$pageSize = props.pageSize,
      pageSize = _props$pageSize === void 0 ? 10 : _props$pageSize,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$hideSelect = props.hideSelect,
      hideSelect = _props$hideSelect === void 0 ? false : _props$hideSelect,
      _props$hideInput = props.hideInput,
      hideInput = _props$hideInput === void 0 ? false : _props$hideInput,
      onChange = props.onChange,
      restProps = _objectWithoutProperties(props, _excluded$n);

  var _useState = useState({
    current: current,
    total: total,
    pageSize: pageSize
  }),
      _useState2 = _slicedToArray(_useState, 2),
      pageData = _useState2[0],
      setPageData = _useState2[1];

  var switchPageSize = function switchPageSize(pageSize) {
    pageData.current = 1;
    pageData.pageSize = pageSize;
    setPageData(_objectSpread2({}, pageData));
    onChange === null || onChange === void 0 ? void 0 : onChange(pageData);
  };

  var clickPageNum = function clickPageNum(page) {
    pageData.current = page;
    setPageData(_objectSpread2({}, pageData));
    onChange === null || onChange === void 0 ? void 0 : onChange(pageData);
  };

  var _useState3 = useState(String(pageData.current)),
      _useState4 = _slicedToArray(_useState3, 2),
      inputVal = _useState4[0],
      setInputVal = _useState4[1];

  useEffect(function () {
    setInputVal(String(pageData.current));
  }, [pageData.current]);

  var handleInputEnter = function handleInputEnter(val) {
    if (val !== '') {
      clickPageNum(Number(val));
    } else {
      clickPageNum(1);
    }
  };

  var handleInputChange = function handleInputChange(val) {
    setInputVal(val);
  };

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-pagination', className),
    style: _objectSpread2({}, style)
  }, restProps), !hideSelect && /*#__PURE__*/React.createElement(PaginationSelect, {
    value: pageData.pageSize,
    disabled: disabled,
    onSelect: switchPageSize
  }), /*#__PURE__*/React.createElement(PaginationList, {
    current: pageData.current,
    total: pageData.total,
    pageSize: pageData.pageSize,
    disabled: disabled,
    onChoose: clickPageNum
  }), !hideInput && /*#__PURE__*/React.createElement("section", {
    className: 'i-pagination-input'
  }, /*#__PURE__*/React.createElement("span", null, "\u524D\u5F80"), /*#__PURE__*/React.createElement(Input, {
    style: {
      width: String(_.ceil(pageData.total / pageData.pageSize)).length * 8 + 20
    },
    placeholder: '',
    type: 'number',
    speed: 'slow',
    hideNumberBtn: true,
    value: inputVal,
    disabled: disabled,
    maxNumber: _.ceil(pageData.total / pageData.pageSize),
    minNumber: 1,
    onChange: handleInputChange,
    onEnter: handleInputEnter,
    onBlur: handleInputEnter,
    onMoveUp: handleInputEnter
  }), /*#__PURE__*/React.createElement("span", null, "\u9875")));
};

Pagination.displayName = 'Pagination';

var css_248z$i = ".i-back-top--button {\n  width: 32px;\n  padding: 0;\n}\n.i-back-top--button .i-icon {\n  color: #fff;\n}";
styleInject(css_248z$i);

var _excluded$o = ["className", "children", "style", "target", "visibleHeight", "smooth", "onClick", "onScroll"];

var BackTop = function BackTop(props) {
  var className = props.className,
      children = props.children,
      style = props.style,
      _props$target = props.target,
      target = _props$target === void 0 ? function () {
    return window;
  } : _props$target,
      _props$visibleHeight = props.visibleHeight,
      visibleHeight = _props$visibleHeight === void 0 ? 0 : _props$visibleHeight,
      _props$smooth = props.smooth,
      smooth = _props$smooth === void 0 ? true : _props$smooth,
      _props$onClick = props.onClick,
      onClick = _props$onClick === void 0 ? function () {} : _props$onClick,
      _props$onScroll = props.onScroll,
      onScroll = _props$onScroll === void 0 ? function () {} : _props$onScroll,
      restProps = _objectWithoutProperties(props, _excluded$o);

  var _useState = useState(visibleHeight > 0 ? false : true),
      _useState2 = _slicedToArray(_useState, 2),
      visible = _useState2[0],
      setVisible = _useState2[1]; // 获取滚动层节点 t


  var getTarget = function getTarget(target) {
    return target === window ? document.documentElement : target;
  };

  var handleScroll = _.throttle(function (e) {
    var top = e.target.scrollTop;
    top >= visibleHeight ? setVisible(true) : setVisible(false);
    onScroll === null || onScroll === void 0 ? void 0 : onScroll();
  }, 16);

  useEffect(function () {
    var t = getTarget(target === null || target === void 0 ? void 0 : target());
    t === null || t === void 0 ? void 0 : t.addEventListener('scroll', handleScroll);
  }, []);

  var scrollToTop = function scrollToTop() {
    var t = getTarget(target === null || target === void 0 ? void 0 : target());
    t === null || t === void 0 ? void 0 : t.scrollTo({
      top: 0,
      behavior: smooth ? 'smooth' : 'auto'
    });
    onClick === null || onClick === void 0 ? void 0 : onClick();
  };

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-back-top', className),
    style: _objectSpread2({}, style),
    onClick: scrollToTop
  }, restProps), /*#__PURE__*/React.createElement(Transition, {
    timeout: 200,
    in: visible,
    animation: 'fade-in'
  }, children || /*#__PURE__*/React.createElement(Button, {
    shape: "circle",
    className: 'i-back-top--button'
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ArrowUpBold"
  }))));
};

BackTop.displayName = 'BackTop';

var css_248z$j = "@-webkit-keyframes checked {\n  0% {\n    transform: scale(0);\n  }\n  50% {\n    transform: scale(1.2);\n  }\n  100% {\n    transform: scale(1);\n  }\n}\n@keyframes checked {\n  0% {\n    transform: scale(0);\n  }\n  50% {\n    transform: scale(1.2);\n  }\n  100% {\n    transform: scale(1);\n  }\n}\n.i-radio {\n  position: relative;\n  cursor: pointer;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-radio.i-radio-is-checked .i-radio__input {\n  border-color: var(--i-primary);\n}\n.i-radio.i-radio-is-checked .i-radio__input::after {\n  transform: scale(1);\n  -webkit-animation: checked 0.2s cubic-bezier(0, 0, 0.15, 1);\n          animation: checked 0.2s cubic-bezier(0, 0, 0.15, 1);\n}\n.i-radio:hover .i-radio__input {\n  border-color: var(--i-primary);\n}\n.i-radio:active.i-radio-is-checked .i-radio__input::after {\n  transform: scale(1.1);\n}\n.i-radio.i-radio-is-disabled {\n  cursor: not-allowed;\n}\n.i-radio.i-radio-is-disabled .i-radio__input {\n  background-color: var(--i-bg-disabled);\n}\n.i-radio.i-radio-is-disabled .i-radio__input::after {\n  background-color: var(--i-border-hover);\n}\n.i-radio.i-radio-is-disabled.i-radio-is-checked .i-radio__input {\n  border-color: var(--i-border);\n}\n.i-radio.i-radio-is-disabled.i-radio-is-checked:hover .i-radio__input {\n  border-color: var(--i-border);\n}\n.i-radio.i-radio-is-disabled:hover .i-radio__input {\n  border-color: var(--i-border);\n}\n\n.i-radio__input {\n  position: relative;\n  display: inline-block;\n  box-sizing: border-box;\n  width: 16px;\n  height: 16px;\n  vertical-align: middle;\n  background-color: var(--i-bg);\n  border: 1px solid var(--i-border);\n  border-radius: 50%;\n  transition: border 0.2s cubic-bezier(0, 0, 0.15, 1);\n}\n.i-radio__input::after {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  box-sizing: border-box;\n  width: 8px;\n  height: 8px;\n  margin-top: -4px;\n  margin-left: -4px;\n  background-color: var(--i-primary);\n  border-radius: 50%;\n  transform: scale(0);\n  transition: all 0.2s cubic-bezier(0, 0, 0.15, 1);\n  content: \"\";\n}\n\n.i-radio__label {\n  display: inline-block;\n  margin-left: 8px;\n  color: var(--i-font);\n  font-size: 14px;\n  white-space: nowrap;\n  vertical-align: middle;\n}\n\n.i-radio-button {\n  position: relative;\n  padding: 4px 16px;\n  color: var(--i-font);\n  font-size: 14px;\n  white-space: nowrap;\n  border: 1px solid var(--i-border);\n  border-radius: 4px;\n  cursor: pointer;\n  transition: color 0.2s cubic-bezier(0, 0, 0.15, 1);\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-radio-button.i-radio-button-is-checked {\n  color: var(--i-primary);\n  border-color: var(--i-primary);\n}\n.i-radio-button.i-radio-button-is-checked:active {\n  color: var(--i-primary-active);\n  border-color: var(--i-primary-active);\n}\n.i-radio-button.i-radio-button--size-small {\n  padding: 2px 8px;\n  font-size: 12px;\n}\n.i-radio-button.i-radio-button--size-large {\n  padding: 8px 24px;\n  font-size: 16px;\n}\n.i-radio-button:hover {\n  color: var(--i-primary-hover);\n}\n.i-radio-button:active {\n  color: var(--i-primary);\n}\n.i-radio-button.i-radio-button-is-disabled {\n  color: var(--i-font-disabled);\n  background-color: var(--i-bg-disabled);\n  border-color: var(--i-border) !important;\n  cursor: not-allowed;\n}\n.i-radio-button.i-radio-button-is-disabled.i-radio-button-is-checked {\n  color: var(--i-font-5);\n  background-color: var(--i-bg-active);\n  border-color: var(--i-border);\n}\n.i-radio-button.i-radio-button-is-disabled.i-radio-button-is-checked:hover {\n  color: var(--i-font-5);\n}\n.i-radio-button.i-radio-button-is-disabled:hover {\n  color: var(--i-font-disabled);\n}\n.i-radio-button.i-radio-button-is-disabled:active {\n  color: var(--i-font-disabled);\n}\n\n.i-radio__former,\n.i-radio-button__former {\n  position: absolute;\n  width: 0;\n  height: 0;\n  opacity: 0;\n}\n\n.i-radio-group {\n  display: inline-flex;\n  align-items: center;\n}\n.i-radio-group .i-radio {\n  margin-right: 24px;\n}\n.i-radio-group .i-radio-button {\n  border-right: 0;\n  border-radius: 0;\n}\n.i-radio-group .i-radio-button:first-of-type {\n  border-radius: 4px 0 0 4px;\n}\n.i-radio-group .i-radio-button:last-of-type {\n  border-right: 1px solid var(--i-border);\n  border-radius: 0 4px 4px 0;\n}\n.i-radio-group .i-radio-button.i-radio-button-is-checked {\n  border-top-color: var(--i-primary);\n  border-right: 1px solid;\n  border-right-color: var(--i-primary);\n  border-bottom-color: var(--i-primary);\n  border-left-color: var(--i-primary);\n  transition: border-color 0.2s cubic-bezier(0, 0, 0.15, 1);\n}\n.i-radio-group .i-radio-button.i-radio-button-is-checked + .i-radio-button {\n  border-left: 0;\n}";
styleInject(css_248z$j);

var RadioContext = /*#__PURE__*/React.createContext(null); // 单选框组

var RadioGroup = function RadioGroup(props) {
  var initSelectedValue = function initSelectedValue() {
    var result = props.defaultSelected;

    if (!result) {
      React.Children.map(props.children, function (child, index) {
        index === 0 && (result = child === null || child === void 0 ? void 0 : child.props.value);
      });
    }

    return result;
  };

  initSelectedValue();
  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      style = props.style,
      selected = props.selected,
      _props$defaultSelecte = props.defaultSelected,
      defaultSelected = _props$defaultSelecte === void 0 ? initSelectedValue() : _props$defaultSelecte,
      _props$type = props.type,
      type = _props$type === void 0 ? 'radio' : _props$type,
      size = props.size,
      disabled = props.disabled,
      onChange = props.onChange;

  var _useDefault = useDefault(selected, defaultSelected, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      groupValue = _useDefault2[0],
      setGroupValue = _useDefault2[1]; // 注入每一项单选框的 context


  var context = {
    // 将单选框组的 props 注入单项单选框的方法
    inject: function inject(itemProps) {
      // 拿到单项单选框的 value，方便与单选框组的 groupValue 做比较
      var itemVal = itemProps.value;
      return _objectSpread2(_objectSpread2({}, itemProps), {}, {
        type: type,
        size: size,
        disabled: disabled,
        checked: groupValue === itemVal,
        onChange: function onChange(checked, e) {
          e.persist(); // 触发单选框组传入的 onChange

          itemVal && setGroupValue(itemVal, e);
        }
      });
    }
  };
  return /*#__PURE__*/React.createElement(RadioContext.Provider, {
    value: context
  }, /*#__PURE__*/React.createElement("div", {
    className: classNames('i-radio-group', className),
    style: _objectSpread2({}, style)
  }, children));
};

var _excluded$p = ["children", "className", "style", "checked", "defaultChecked", "value", "onChange"];

var Radio = function Radio(props) {
  // 存在单选框组时从 Context 注入 checked 覆盖原 checked
  var context = useContext(RadioContext);
  var newProps = context ? context.inject(props) : props;

  var _newProps$children = newProps.children,
      children = _newProps$children === void 0 ? '' : _newProps$children,
      className = newProps.className,
      style = newProps.style,
      checked = newProps.checked,
      _newProps$defaultChec = newProps.defaultChecked,
      defaultChecked = _newProps$defaultChec === void 0 ? false : _newProps$defaultChec,
      value = newProps.value,
      onChange = newProps.onChange,
      restProps = _objectWithoutProperties(newProps, _excluded$p);

  var type = newProps.type || props.type || 'radio';
  var size = newProps.size || props.size;
  var disabled = newProps.disabled || props.disabled || false;

  var _useDefault = useDefault(checked, defaultChecked, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerChecked = _useDefault2[0],
      setInnerChecked = _useDefault2[1];

  var handleCheck = function handleCheck(e) {
    if (disabled) return;
    var checkedValue = e.currentTarget.checked;
    setInnerChecked(checkedValue, e);
  };

  return /*#__PURE__*/React.createElement("label", _objectSpread2({
    className: classNames("i-".concat(type), innerChecked && "i-".concat(type, "-is-checked"), disabled && "i-".concat(type, "-is-disabled"), size && "i-".concat(type, "--size-").concat(size), className),
    style: _objectSpread2({}, style)
  }, restProps), /*#__PURE__*/React.createElement("input", {
    readOnly: true,
    type: "radio",
    className: "i-".concat(type, "__former"),
    checked: innerChecked,
    disabled: disabled,
    value: value,
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    onChange: handleCheck
  }), /*#__PURE__*/React.createElement("span", {
    className: "i-".concat(type, "__input")
  }), /*#__PURE__*/React.createElement("span", {
    className: "i-".concat(type, "__label")
  }, children));
};

Radio.Group = RadioGroup;
Radio.displayName = 'Radio';
RadioGroup.displayName = 'RadioGroup';

var css_248z$k = ".i-checkbox {\n  position: relative;\n  display: inline-flex;\n  align-items: center;\n  color: var(--i-font-2);\n  cursor: pointer;\n}\n.i-checkbox.i-checkbox--size-small .i-checkbox__input {\n  transform: scale(0.8);\n  transform-origin: left;\n}\n.i-checkbox.i-checkbox--size-small .i-checkbox__label {\n  margin: 0 4px;\n}\n.i-checkbox.i-checkbox--size-large .i-checkbox__input {\n  transform: scale(1.2);\n  transform-origin: left;\n}\n.i-checkbox.i-checkbox--size-large .i-checkbox__label {\n  margin: 0 12px;\n}\n.i-checkbox:hover .i-checkbox__input {\n  border-color: var(--i-primary-hover);\n}\n.i-checkbox.i-checkbox-is-checked {\n  margin-left: inherit;\n}\n.i-checkbox.i-checkbox-is-checked .i-checkbox__input {\n  background-color: var(--i-primary);\n  border-color: var(--i-primary);\n  transition: background-color 0.1s cubic-bezier(0.82, 0, 1, 0.9);\n}\n.i-checkbox.i-checkbox-is-checked .i-checkbox__input::after {\n  opacity: 1;\n}\n.i-checkbox.i-checkbox-is-disabled {\n  cursor: not-allowed;\n}\n.i-checkbox.i-checkbox-is-disabled:hover .i-checkbox__input, .i-checkbox.i-checkbox-is-disabled.i-checkbox-is-checked .i-checkbox__input {\n  border-color: var(--i-border);\n}\n.i-checkbox.i-checkbox-is-disabled .i-checkbox__input {\n  background-color: var(--i-bg-disabled);\n}\n.i-checkbox.i-checkbox-is-disabled .i-checkbox__input::after {\n  border-color: var(--i-border);\n}\n.i-checkbox.i-checkbox-is-disabled .i-checkbox__label {\n  color: var(--i-font-disabled);\n}\n\n.i-checkbox__former {\n  position: absolute;\n  box-sizing: border-box;\n  width: 1px;\n  height: 1px;\n  margin: -1px;\n  padding: 0;\n  overflow: hidden;\n  border: 0;\n  outline: 0;\n  -webkit-appearance: none;\n     -moz-appearance: none;\n          appearance: none;\n  clip: rect(0 0 0 0);\n}\n\n.i-checkbox__input {\n  position: relative;\n  display: inline-block;\n  box-sizing: border-box;\n  width: 16px;\n  height: 16px;\n  vertical-align: middle;\n  background-color: var(--i-bg);\n  border: 1px solid var(--i-border);\n  border-radius: 4px;\n  transition: all 0.2s ease-out;\n}\n.i-checkbox__input::after {\n  position: absolute;\n  top: 7px;\n  left: 3px;\n  width: 4px;\n  height: 8px;\n  background: transparent;\n  border: 2px solid #fff;\n  border-top: 0;\n  border-left: 0;\n  border-radius: 0 0 1px;\n  transform: rotate(45deg) scale(1) translate(-60%, -50%);\n  opacity: 0;\n  content: \"\";\n}\n\n.i-checkbox__label {\n  display: inline-block;\n  margin: 0 8px;\n  font-size: 14px;\n  vertical-align: middle;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n\n.i-checkbox-group .i-checkbox {\n  margin-right: 16px;\n}";
styleInject(css_248z$k);

var CheckboxContext = /*#__PURE__*/React.createContext(null); // 多选框组

var CheckboxGroup = function CheckboxGroup(props) {
  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      style = props.style,
      selected = props.selected,
      _props$defaultSelecte = props.defaultSelected,
      defaultSelected = _props$defaultSelecte === void 0 ? [] : _props$defaultSelecte,
      size = props.size,
      disabled = props.disabled,
      onChange = props.onChange;

  var _useDefault = useDefault(selected, defaultSelected, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      groupValue = _useDefault2[0],
      setGroupValue = _useDefault2[1];

  var groupCheckedArr = new Set([].concat(groupValue));
  useEffect(function () {
    groupCheckedArr = new Set([].concat(groupValue));
  }, [groupValue]); // 注入每一项多选框的 context

  var context = {
    // 将多选框组的 props 注入单项多选框的方法
    inject: function inject(itemProps) {
      // 拿到单项多选框的 value，方便与多选框组的 groupValue 做比较
      var itemVal = itemProps.value;
      return _objectSpread2(_objectSpread2({}, itemProps), {}, {
        size: size,
        disabled: disabled,
        checked: groupCheckedArr.has(itemVal),
        onChange: function onChange(checked, e) {
          e.persist(); // 触发单项多选框传入的 onChange

          if (typeof itemProps.onChange === 'function') {
            itemProps.onChange(checked, e);
          } // 设置多选框组的 groupCheckedArr


          if (checked) {
            groupCheckedArr.add(itemVal);
          } else {
            groupCheckedArr.delete(itemVal);
          } // 触发多选框组传入的 onChange


          itemVal && setGroupValue(Array.from(groupCheckedArr), e);
        }
      });
    }
  };
  return /*#__PURE__*/React.createElement(CheckboxContext.Provider, {
    value: context
  }, /*#__PURE__*/React.createElement("div", {
    className: classNames('i-checkbox-group', className),
    style: _objectSpread2({}, style)
  }, children));
};

var _excluded$q = ["children", "className", "style", "checked", "defaultChecked", "value", "onChange"];

var Checkbox = function Checkbox(props) {
  // 存在多选框组时从 Context 注入 checked 覆盖原 checked
  var context = useContext(CheckboxContext);
  var newProps = context ? context.inject(props) : props;

  var _newProps$children = newProps.children,
      children = _newProps$children === void 0 ? '' : _newProps$children,
      className = newProps.className,
      style = newProps.style,
      checked = newProps.checked,
      _newProps$defaultChec = newProps.defaultChecked,
      defaultChecked = _newProps$defaultChec === void 0 ? false : _newProps$defaultChec,
      value = newProps.value,
      onChange = newProps.onChange,
      restProps = _objectWithoutProperties(newProps, _excluded$q);

  var size = newProps.size || props.size;
  var disabled = newProps.disabled || props.disabled || false;

  var _useDefault = useDefault(checked, defaultChecked, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerChecked = _useDefault2[0],
      setInnerChecked = _useDefault2[1];

  var handleCheck = function handleCheck(e) {
    if (disabled) return;
    var checkedValue = e.currentTarget.checked;
    setInnerChecked(checkedValue, e);
  };

  return /*#__PURE__*/React.createElement("label", _objectSpread2({
    className: classNames('i-checkbox', innerChecked && 'i-checkbox-is-checked', disabled && 'i-checkbox-is-disabled', size && "i-checkbox--size-".concat(size), className),
    style: _objectSpread2({}, style)
  }, restProps), /*#__PURE__*/React.createElement("input", {
    readOnly: true,
    type: "checkbox",
    className: 'i-checkbox__former',
    checked: innerChecked,
    disabled: disabled,
    value: value,
    onClick: function onClick(e) {
      return e.stopPropagation();
    },
    onChange: function onChange(e) {
      return handleCheck(e);
    }
  }), /*#__PURE__*/React.createElement("span", {
    className: 'i-checkbox__input'
  }), /*#__PURE__*/React.createElement("span", {
    className: 'i-checkbox__label'
  }, children));
};

Checkbox.Group = CheckboxGroup;
Checkbox.displayName = 'Checkbox';
CheckboxGroup.displayName = 'CheckboxGroup';

var css_248z$l = ".i-switch {\n  position: relative;\n  display: inline-flex;\n  align-items: center;\n  min-width: 40px;\n  height: 20px;\n  margin: 0;\n  padding: 0;\n  line-height: 20px;\n  vertical-align: middle;\n  background-color: var(--i-info-active);\n  border: 0;\n  border-radius: 10px;\n  outline: none;\n  cursor: pointer;\n  transition: all 0.2s cubic-bezier(0, 0, 0.15, 1);\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-switch:hover .i-switch__handle::before {\n  box-shadow: 0 0 3px 1px rgba(0, 0, 0, 0.2);\n}\n.i-switch:active:not(.i-switch-is-disabled) .i-switch__handle::before {\n  right: -8px;\n  left: 0;\n}\n.i-switch.i-switch-is-checked {\n  background-color: var(--i-primary);\n}\n.i-switch.i-switch-is-checked .i-switch__handle {\n  left: calc(100% - 2px);\n  transform: translate(-100%);\n}\n.i-switch.i-switch-is-checked .i-switch__handle .icon-Loading {\n  color: var(--i-primary-disabled) !important;\n}\n.i-switch.i-switch-is-checked:active:not(.i-switch-is-disabled) .i-switch__handle::before {\n  right: 0;\n  left: -8px;\n}\n.i-switch.i-switch-is-disabled {\n  background-color: var(--i-info-hover);\n  cursor: not-allowed;\n}\n.i-switch.i-switch-is-disabled.i-switch-is-checked {\n  background-color: var(--i-primary-disabled);\n}\n.i-switch.i-switch-is-disabled .i-switch__handle {\n  cursor: not-allowed;\n}\n\n@-webkit-keyframes rotating {\n  from {\n    transform: rotate(0deg);\n  }\n  to {\n    transform: rotate(360deg);\n  }\n}\n\n@keyframes rotating {\n  from {\n    transform: rotate(0deg);\n  }\n  to {\n    transform: rotate(360deg);\n  }\n}\n.i-switch__handle {\n  position: absolute;\n  top: 2px;\n  left: 2px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  width: 16px;\n  height: 16px;\n  border-radius: 12px;\n  transform: translate(0%);\n  visibility: visible;\n  cursor: pointer;\n  transition: all 0.2s cubic-bezier(0.38, 0, 0.24, 1);\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-switch__handle .icon-Loading {\n  z-index: 1;\n  color: var(--i-info) !important;\n  transform: scale(0.8);\n  -webkit-animation: rotating 2s linear infinite;\n          animation: rotating 2s linear infinite;\n}\n.i-switch__handle::before {\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  background-color: #fff;\n  border-radius: 12px;\n  box-shadow: 0 0 3px 1px rgba(0, 0, 0, 0.1);\n  transition: all 0.2s cubic-bezier(0.38, 0, 0.24, 1);\n  content: \"\";\n}\n\n.i-switch__content {\n  display: inline-flex;\n  align-items: center;\n  box-sizing: border-box;\n  min-width: 36px;\n  padding-left: 22px;\n  color: #fff;\n  font-size: 12px;\n  transition: padding 0.2s cubic-bezier(0.38, 0, 0.24, 1), opacity 0.2s linear;\n}\n.i-switch__content .i-icon {\n  margin-left: -1px;\n  color: #fff !important;\n  font-size: 14px !important;\n}\n\n.i-switch.i-switch-is-checked .i-switch__content {\n  padding-left: 6px;\n}\n\n.i-switch--size-small {\n  min-width: 32px;\n  height: 16px;\n  border-radius: 8px;\n}\n.i-switch--size-small .i-switch__handle {\n  width: 12px;\n  height: 12px;\n}\n.i-switch--size-small:active:not(.i-switch-is-disabled) .i-switch__handle::before {\n  right: -6.4px;\n}\n.i-switch--size-small.i-switch-is-checked:active:not(.i-switch-is-disabled) .i-switch__handle::before {\n  left: -6.4px;\n}\n.i-switch--size-small .i-switch__content {\n  padding-left: 20px;\n  transform: scale(0.9);\n}\n.i-switch--size-small.i-switch-is-checked .i-switch__content {\n  padding-left: 4px;\n}\n\n.i-switch--size-large {\n  min-width: 48px;\n  height: 24px;\n  border-radius: 12px;\n}\n.i-switch--size-large .i-switch__handle {\n  width: 20px;\n  height: 20px;\n}\n.i-switch--size-large:active:not(.i-switch-is-disabled) .i-switch__handle::before {\n  right: -9.6px;\n}\n.i-switch--size-large.i-switch-is-checked:active:not(.i-switch-is-disabled) .i-switch__handle::before {\n  left: -9.6px;\n}\n.i-switch--size-large .i-switch__content {\n  padding-left: 26px;\n  transform: scale(1.1);\n}\n.i-switch--size-large.i-switch-is-checked .i-switch__content {\n  padding-left: 8px;\n}";
styleInject(css_248z$l);

var _excluded$r = ["className", "style", "size", "disabled", "loading", "inactiveColor", "activeColor", "inactiveLabel", "activeLabel", "value", "defaultValue", "onChange"];

var Switch = function Switch(props) {
  var className = props.className,
      style = props.style,
      _props$size = props.size,
      size = _props$size === void 0 ? 'medium' : _props$size,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$loading = props.loading,
      loading = _props$loading === void 0 ? false : _props$loading,
      inactiveColor = props.inactiveColor,
      activeColor = props.activeColor,
      inactiveLabel = props.inactiveLabel,
      activeLabel = props.activeLabel,
      value = props.value,
      _props$defaultValue = props.defaultValue,
      defaultValue = _props$defaultValue === void 0 ? false : _props$defaultValue,
      _props$onChange = props.onChange,
      onChange = _props$onChange === void 0 ? function () {} : _props$onChange,
      restProps = _objectWithoutProperties(props, _excluded$r);

  var _useDefault = useDefault(value, defaultValue, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerChecked = _useDefault2[0],
      setInnerChecked = _useDefault2[1];

  var handleSwitch = function handleSwitch() {
    if (disabled || loading) return;
    var changedValue = !innerChecked;
    setInnerChecked(changedValue);
  };

  var renderContent = function renderContent(value) {
    if (!!value && activeLabel) {
      return activeLabel;
    }

    if (!value && inactiveLabel) {
      return inactiveLabel;
    }

    return null;
  };

  return /*#__PURE__*/React.createElement("button", _objectSpread2({
    type: "button",
    role: "switch",
    disabled: disabled,
    className: classNames('i-switch', innerChecked && 'i-switch-is-checked', (disabled || loading) && 'i-switch-is-disabled', size === 'small' && 'i-switch--size-small', size === 'large' && 'i-switch--size-large', className),
    style: _objectSpread2(_objectSpread2({}, style || {}), {
      backgroundColor: innerChecked ? activeColor : inactiveColor
    } || {}),
    onClick: handleSwitch
  }, restProps), /*#__PURE__*/React.createElement("span", {
    className: 'i-switch__handle'
  }, loading && /*#__PURE__*/React.createElement(Icon, {
    name: "Loading",
    size: {
      small: 12,
      medium: 16,
      large: 20
    }[size]
  })), renderContent(innerChecked) && /*#__PURE__*/React.createElement("div", {
    className: "i-switch__content"
  }, renderContent(innerChecked)));
};

Switch.displayName = 'Switch';

var css_248z$m = ".i-textarea {\n  position: relative;\n  width: 100%;\n}\n\n.i-textarea__inner {\n  display: flex;\n  width: 100%;\n  height: 56px;\n  min-height: 56px;\n  padding: 5px 8px;\n  color: inherit;\n  color: var(--i-font-2);\n  font-size: 14px;\n  font-family: auto;\n  line-height: 22px;\n  background-color: var(--i-bg);\n  border: 1px solid var(--i-border);\n  border-radius: 4px;\n  outline: none;\n  transition: all 0.2s cubic-bezier(0.38, 0, 0.24, 1), height 0s;\n  resize: vertical;\n}\n.i-textarea__inner::-moz-placeholder {\n  color: var(--i-font-5);\n  -moz-user-select: none;\n       user-select: none;\n}\n.i-textarea__inner:-ms-input-placeholder {\n  color: var(--i-font-5);\n  -ms-user-select: none;\n      user-select: none;\n}\n.i-textarea__inner::placeholder {\n  color: var(--i-font-5);\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-textarea__inner:hover {\n  border-color: var(--i-border-hover);\n}\n.i-textarea__inner:focus {\n  border-color: var(--i-primary);\n}\n.i-textarea__inner.i-textarea__inner-is-disabled {\n  background-color: var(--i-bg-disabled);\n}\n.i-textarea__inner.i-textarea__inner-is-disabled,\n.i-textarea__inner.i-textarea__inner-is-disabled * {\n  cursor: not-allowed;\n}\n.i-textarea__inner.i-textarea__inner-is-disabled:hover {\n  border-color: var(--i-border);\n}\n.i-textarea__inner.i-textarea__inner-is-readonly,\n.i-textarea__inner.i-textarea__inner-is-readonly * {\n  cursor: default;\n}\n.i-textarea__inner.i-textarea__inner--status-success, .i-textarea__inner.i-textarea__inner--status-success:hover, .i-textarea__inner.i-textarea__inner--status-success:focus-within {\n  border-color: var(--i-success);\n}\n.i-textarea__inner.i-textarea__inner--status-warning, .i-textarea__inner.i-textarea__inner--status-warning:hover, .i-textarea__inner.i-textarea__inner--status-warning:focus-within {\n  border-color: var(--i-warning);\n}\n.i-textarea__inner.i-textarea__inner--status-error, .i-textarea__inner.i-textarea__inner--status-error:hover, .i-textarea__inner.i-textarea__inner--status-error:focus-within {\n  border-color: var(--i-error);\n}\n\n.i-textarea--limit {\n  position: absolute;\n  right: 0px;\n  bottom: 8px;\n  margin-left: 8px;\n}\n\n.i-textarea--limit-count {\n  color: var(--i-font-5);\n  font-size: 12px;\n}\n\n.i-textarea__tips {\n  height: auto;\n  min-height: 24px;\n  color: var(--i-font-5);\n  font-size: 12px;\n  line-height: 20px;\n}\n.i-textarea__tips.i-textarea__tips--status-success {\n  color: var(--i-success);\n}\n.i-textarea__tips.i-textarea__tips--status-warning {\n  color: var(--i-warning);\n}\n.i-textarea__tips.i-textarea__tips--status-error {\n  color: var(--i-error);\n}";
styleInject(css_248z$m);

var _excluded$s = ["className", "style", "placeholder", "disabled", "readonly", "status", "tips", "maxLength", "autofocus", "autoSize", "noResize", "minRows", "maxRows", "value", "defaultValue", "onChange", "onFocus", "onBlur"];

var Textarea = function Textarea(props) {
  var className = props.className,
      style = props.style,
      _props$placeholder = props.placeholder,
      placeholder = _props$placeholder === void 0 ? "请输入" : _props$placeholder,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$readonly = props.readonly,
      readonly = _props$readonly === void 0 ? false : _props$readonly,
      status = props.status,
      tips = props.tips,
      maxLength = props.maxLength,
      _props$autofocus = props.autofocus,
      autofocus = _props$autofocus === void 0 ? false : _props$autofocus,
      _props$autoSize = props.autoSize,
      autoSize = _props$autoSize === void 0 ? false : _props$autoSize,
      _props$noResize = props.noResize,
      noResize = _props$noResize === void 0 ? false : _props$noResize,
      minRows = props.minRows,
      maxRows = props.maxRows,
      value = props.value,
      _props$defaultValue = props.defaultValue,
      defaultValue = _props$defaultValue === void 0 ? '' : _props$defaultValue,
      onChange = props.onChange,
      onFocus = props.onFocus,
      onBlur = props.onBlur,
      restProps = _objectWithoutProperties(props, _excluded$s);

  var _useDefault = useDefault(value, defaultValue, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerValue = _useDefault2[0],
      setInnerValue = _useDefault2[1];

  var _useState = useState((innerValue === null || innerValue === void 0 ? void 0 : innerValue.toString().length) || 0),
      _useState2 = _slicedToArray(_useState, 2),
      valueLength = _useState2[0],
      setValueLength = _useState2[1];

  var handleChange = function handleChange(e) {
    e.persist();
    maxLength && setValueLength(e.target.value.length);
    setInnerValue(e.target.value, e);
    resize();
  }; // 高度自适应


  useEffect(function () {
    autoSize ? resize() : '';
  }, [autoSize]);
  var textareaRef = useRef(null);

  var resize = function resize() {
    if (autoSize && textareaRef.current) {
      // 如果字数减少，重设高度
      textareaRef.current.style.height = 'auto'; // 如果高度不够，重新设置

      if (textareaRef.current.scrollHeight >= textareaRef.current.offsetHeight) {
        var val;
        textareaRef.current.scrollHeight > 32 ? val = textareaRef.current.scrollHeight - 10 : val = textareaRef.current.scrollHeight;
        textareaRef.current.style.height = val + 'px';
      }
    }
  }; // 通用事件


  var handleEvent = function handleEvent(eventType, e) {
    e.persist();

    if (eventType === 'focus') {
      onFocus === null || onFocus === void 0 ? void 0 : onFocus(e.target.value, e);
    }

    if (eventType === 'blur') {
      onBlur === null || onBlur === void 0 ? void 0 : onBlur(e.target.value, e);
    }
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-textarea', className),
    style: _objectSpread2({}, style)
  }, restProps), /*#__PURE__*/React.createElement("textarea", {
    className: classNames('i-textarea__inner', disabled && 'i-textarea__inner-is-disabled', readonly && 'i-textarea__inner-is-readonly', status && "i-textarea__inner--status-".concat(status)),
    style: {
      minHeight: autoSize ? minRows && 22 * minRows || 22 : minRows && 22 * minRows,
      maxHeight: maxRows && 22 * maxRows,
      resize: noResize ? 'none' : undefined
    },
    placeholder: placeholder,
    disabled: disabled,
    readOnly: readonly,
    ref: textareaRef,
    rows: autoSize ? 1 : undefined,
    maxLength: maxLength,
    autoFocus: autofocus,
    value: innerValue,
    onChange: handleChange,
    onFocus: function onFocus(e) {
      return handleEvent('focus', e);
    },
    onBlur: function onBlur(e) {
      return handleEvent('blur', e);
    }
  }), maxLength && /*#__PURE__*/React.createElement("div", {
    className: "i-textarea--limit"
  }, /*#__PURE__*/React.createElement("span", {
    className: "i-textarea--limit-count"
  }, valueLength < maxLength ? valueLength : maxLength, " / ", maxLength))), tips && /*#__PURE__*/React.createElement("div", {
    className: classNames('i-textarea__tips', status && "i-textarea__tips--status-".concat(status))
  }, tips));
};

Textarea.displayName = 'Textarea';

var css_248z$n = ".i-time-popup > .i-input > .i-input {\n  width: 20px;\n  padding: 0;\n  border: none;\n}\n.i-time-popup > .i-input > .i-input .i-input__inner {\n  padding-right: 0;\n  text-align: center;\n}\n.i-time-popup > .i-input > .i-input__inner,\n.i-time-popup > .i-input .i-input-number-slider {\n  display: none;\n}\n.i-time-popup > .i-input > .i-input-suffix-icon {\n  pointer-events: none;\n}\n\n.i-time-colon {\n  margin-bottom: 2px;\n  color: var(--i-font-2);\n}\n.i-time-colon.i-time-colon__disabled {\n  color: var(--i-font-disabled);\n}\n\n.i-time-panel {\n  width: 200px;\n}\n\n.i-time-panel-content {\n  display: flex;\n  align-items: center;\n  height: 200px;\n}\n\n.i-time-panel-item {\n  flex: 1;\n  height: 100%;\n  margin: 0;\n  padding: 0;\n  overflow: auto;\n  overflow: overlay;\n}\n.i-time-panel-item::-webkit-scrollbar {\n  display: none;\n}\n.i-time-panel-item::after {\n  display: list-item;\n  width: 100%;\n  height: 168px;\n  content: \"\";\n}\n\n.i-time-spinner-item {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 100%;\n  height: 32px;\n  font-size: 12px;\n  line-height: 32px;\n  list-style: none;\n  cursor: default;\n}\n.i-time-spinner-item:hover {\n  background: var(--i-bg-hover);\n}\n.i-time-spinner-item.i-time-spinner-item__selected {\n  font-weight: bold;\n  background: var(--i-bg-active);\n}\n.i-time-spinner-item.i-time-spinner-item__selected:hover {\n  background: var(--i-bg-active);\n}\n\n.i-time-panel-footer {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  box-sizing: border-box;\n  width: 100%;\n  padding: 12px;\n  border-top: 1px solid var(--i-border);\n}\n\n.i-time-panel-footer__handle {\n  display: flex;\n  gap: 8px;\n  align-items: center;\n  margin-left: auto;\n}";
styleInject(css_248z$n);

var EPickerCols;

(function (EPickerCols) {
  EPickerCols["hour"] = "hour";
  EPickerCols["minute"] = "minute";
  EPickerCols["second"] = "second";
  EPickerCols["meridiem"] = "meridiem";
})(EPickerCols || (EPickerCols = {}));

var TimePanel = function TimePanel(props) {
  var _props$value = props.value,
      value = _props$value === void 0 ? {
    hour: '00',
    minute: '00',
    second: '00',
    meridiem: ''
  } : _props$value,
      _props$format = props.format,
      format = _props$format === void 0 ? DEFAULT_FORMAT : _props$format,
      _props$steps = props.steps,
      steps = _props$steps === void 0 ? DEFAULT_STEPS : _props$steps,
      _props$hideDisabledTi = props.hideDisabledTime,
      hideDisabledTime = _props$hideDisabledTi === void 0 ? true : _props$hideDisabledTi,
      disableTime = props.disableTime,
      _props$onNow = props.onNow,
      onNow = _props$onNow === void 0 ? function () {} : _props$onNow,
      _props$onChange = props.onChange,
      onChange = _props$onChange === void 0 ? function () {} : _props$onChange,
      _props$onClose = props.onClose,
      onClose = _props$onClose === void 0 ? function () {} : _props$onClose,
      _props$onConfirm = props.onConfirm,
      onConfirm = _props$onConfirm === void 0 ? function () {} : _props$onConfirm;

  var _useState = useState([]),
      _useState2 = _slicedToArray(_useState, 2),
      cols = _useState2[0],
      setCols = _useState2[1]; // 初始化 -> 渲染时间数据


  useEffect(function () {
    var match = format.match(/(a\s+|A\s+)?(h+|H+)?:?(m+)?:?(s+)?(\s+a|\s+A)?/);

    var _match = _slicedToArray(match, 6),
        startCol = _match[1],
        hourCol = _match[2],
        minuteCol = _match[3],
        secondCol = _match[4],
        endCol = _match[5];

    var meridiem = EPickerCols.meridiem,
        hour = EPickerCols.hour,
        minute = EPickerCols.minute,
        second = EPickerCols.second;
    var renderCol = [startCol && meridiem, hourCol && hour, minuteCol && minute, secondCol && second, endCol && meridiem].filter(function (v) {
      return !!v;
    });
    setCols(renderCol);
  }, [format]);
  var dayjsValue = useMemo(function () {
    var isStepsSet = !!steps.filter(function (v) {
      return v > 1;
    }).length;

    if (value) {
      return dayjs("".concat(value.hour, "-").concat(value.minute, "-").concat(value.second), format);
    }

    if (isStepsSet) {
      return dayjs().hour(Number(steps[0]) - 1).minute(Number(steps[1]) - 1).second(Number(steps[2]) - 1);
    }

    return dayjs();
  }, [value.hour, value.minute, value.second, format, steps]);
  var getColList = useCallback(function (col) {
    var count = 0;

    if (timeArr.includes(col)) {
      // hour/minute/second column scroll render
      var colIdx = timeArr.indexOf(col);
      var colStep = steps[colIdx];

      if (col === EPickerCols.hour) {
        count = /[h]{1}/.test(format) ? 11 : 23;
      } else {
        count = 59;
      }

      var colList = _.range(0, count + 1, Number(colStep)).map(function (v) {
        return _.padStart(String(v), 2, '0');
      }) || [];
      return hideDisabledTime && !!disableTime ? colList.filter(function (t) {
        var params = [dayjsValue.hour(), dayjsValue.minute(), dayjsValue.second()];
        params[colIdx] = Number(t);
        return !(disableTime === null || disableTime === void 0 ? void 0 : disableTime.apply(void 0, params));
      }) : colList;
    } // meridiem column scroll render


    return MERIDIEM_LIST;
  }, [steps, format, hideDisabledTime, dayjsValue, disableTime]); // 同步滚动

  var hourPanelRef = useRef(null);
  var minutePanelRef = useRef(null);
  var secondPanelRef = useRef(null);
  var meridiemPanelRef = useRef(null);

  var getRef = function getRef(type) {
    var ref = meridiemPanelRef;
    type === 'hour' && (ref = hourPanelRef);
    type === 'minute' && (ref = minutePanelRef);
    type === 'second' && (ref = secondPanelRef);
    return ref;
  };

  var updateScroll = function updateScroll(mode) {
    hourPanelRef.current && hourPanelRef.current.scrollTo({
      top: 32 * (Number(value.hour) / Number(steps[0])),
      behavior: mode
    });
    minutePanelRef.current && minutePanelRef.current.scrollTo({
      top: 32 * (Number(value.minute) / Number(steps[1])),
      behavior: mode
    });
    secondPanelRef.current && secondPanelRef.current.scrollTo({
      top: 32 * (Number(value.second) / Number(steps[2])),
      behavior: mode
    });
  };

  useEffect(function () {
    setTimeout(function () {
      updateScroll();
    });
  }, []);
  useEffect(function () {
    updateScroll('smooth');
  }, [value]);

  var clickItem = function clickItem(type, val) {
    onChange === null || onChange === void 0 ? void 0 : onChange(type, val);
  };

  var handleNow = function handleNow() {
    onNow === null || onNow === void 0 ? void 0 : onNow();
  };

  var closePanel = function closePanel() {
    onClose === null || onClose === void 0 ? void 0 : onClose(false);
  };

  var handleConfirm = function handleConfirm() {
    closePanel();
    onConfirm === null || onConfirm === void 0 ? void 0 : onConfirm();
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "i-time-panel"
  }, /*#__PURE__*/React.createElement("section", {
    className: "i-time-panel-content"
  }, cols.map(function (col, index) {
    return /*#__PURE__*/React.createElement("ul", {
      className: "i-time-panel-item",
      key: col + index,
      ref: getRef(col)
    }, getColList(col).map(function (item) {
      return /*#__PURE__*/React.createElement("li", {
        className: classNames('i-time-spinner-item', value[col] === item && 'i-time-spinner-item__selected'),
        key: item,
        onClick: function onClick() {
          return clickItem(col, item);
        }
      }, item);
    }));
  })), /*#__PURE__*/React.createElement("footer", {
    className: "i-time-panel-footer"
  }, !steps.filter(function (v) {
    return v > 1;
  }).length && /*#__PURE__*/React.createElement(Button, {
    size: "small",
    variant: "text",
    onClick: handleNow
  }, "\u6B64\u523B"), /*#__PURE__*/React.createElement("div", {
    className: "i-time-panel-footer__handle"
  }, /*#__PURE__*/React.createElement(Button, {
    size: "small",
    variant: "outline",
    onClick: closePanel
  }, "\u53D6\u6D88"), /*#__PURE__*/React.createElement(Button, {
    size: "small",
    onClick: handleConfirm
  }, "\u786E\u8BA4"))));
};

var TimeInput = function TimeInput(props) {
  var _props$value = props.value,
      value = _props$value === void 0 ? {
    hour: '00',
    minute: '00',
    second: '00',
    meridiem: 'AM'
  } : _props$value,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$format = props.format,
      format = _props$format === void 0 ? DEFAULT_FORMAT : _props$format,
      _props$onChange = props.onChange,
      onChange = _props$onChange === void 0 ? function () {} : _props$onChange;

  var _useState = useState(value),
      _useState2 = _slicedToArray(_useState, 2),
      innerValue = _useState2[0],
      setInnerValue = _useState2[1];

  var _useState3 = useState({
    hour: false,
    minute: false,
    second: false
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      show = _useState4[0],
      setShow = _useState4[1];

  useEffect(function () {
    /H|h/.test(format) && (show.hour = true);
    /m/.test(format) && (show.minute = true);
    /s/.test(format) && (show.second = true);
    setShow(_objectSpread2({}, show));
    var newHour = /^[H]/.test(format) ? value.hour : Number(value.hour) % 12;
    newHour = _.padStart(String(newHour), 2, '0');
    value.hour = newHour;
    setInnerValue(_objectSpread2({}, value));
  }, [value, format]);

  var inputChangeHour = function inputChangeHour(val) {
    val = _.padStart(String(val), 2, '0');
    innerValue.hour = val;
    setInnerValue(_objectSpread2({}, innerValue));
    onChange === null || onChange === void 0 ? void 0 : onChange(innerValue);
  };

  var inputChangeMinute = function inputChangeMinute(val) {
    val = _.padStart(String(val), 2, '0');
    innerValue.minute = val;
    setInnerValue(_objectSpread2({}, innerValue));
    onChange === null || onChange === void 0 ? void 0 : onChange(innerValue);
  };

  var inputChangeSecond = function inputChangeSecond(val) {
    val = _.padStart(String(val), 2, '0');
    innerValue.second = val;
    setInnerValue(_objectSpread2({}, innerValue));
    onChange === null || onChange === void 0 ? void 0 : onChange(innerValue);
  };

  var handleUsualBlur = function handleUsualBlur() {
    innerValue.hour = _.padStart(String(innerValue.hour), 2, '0');
    innerValue.minute = _.padStart(String(innerValue.minute), 2, '0');
    innerValue.second = _.padStart(String(innerValue.second), 2, '0');
    setInnerValue(_objectSpread2({}, value));
  };

  var timeColon = /*#__PURE__*/React.createElement("div", {
    className: classNames('i-time-colon', disabled && 'i-time-colon__disabled')
  }, ":");
  return /*#__PURE__*/React.createElement(Input, {
    placeholder: "",
    readonly: !disabled,
    disabled: disabled,
    suffixIcon: "Clock"
  }, show.hour && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Input, {
    size: "small",
    type: "number",
    hideNumberBtn: true,
    minNumber: 0,
    maxNumber: /^[H]/.test(format) ? 23 : 11,
    placeholder: '',
    disabled: disabled,
    value: (innerValue === null || innerValue === void 0 ? void 0 : innerValue.hour) || '',
    onChange: inputChangeHour,
    onBlur: handleUsualBlur
  }), timeColon), show.minute && /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Input, {
    size: "small",
    type: "number",
    hideNumberBtn: true,
    minNumber: 0,
    maxNumber: 59,
    placeholder: '',
    disabled: disabled,
    value: (innerValue === null || innerValue === void 0 ? void 0 : innerValue.minute) || '',
    onChange: inputChangeMinute,
    onBlur: handleUsualBlur
  })), show.second && /*#__PURE__*/React.createElement(React.Fragment, null, timeColon, /*#__PURE__*/React.createElement(Input, {
    size: "small",
    type: "number",
    hideNumberBtn: true,
    minNumber: 0,
    maxNumber: 59,
    placeholder: '',
    disabled: disabled,
    value: (innerValue === null || innerValue === void 0 ? void 0 : innerValue.second) || '',
    onChange: inputChangeSecond,
    onBlur: handleUsualBlur
  })));
};

var MERIDIEM_LIST = ['AM', 'PM'];
var DEFAULT_STEPS = [1, 1, 1];
var DEFAULT_FORMAT = 'HH:mm:ss';
var timeArr = [EPickerCols.hour, EPickerCols.minute, EPickerCols.second];

var TimePicker = function TimePicker(props) {
  var className = props.className,
      style = props.style,
      value = props.value,
      _props$defaultValue = props.defaultValue,
      defaultValue = _props$defaultValue === void 0 ? dayjs().format(props.format || DEFAULT_FORMAT) : _props$defaultValue,
      _props$trigger = props.trigger,
      trigger = _props$trigger === void 0 ? "click" : _props$trigger,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$format = props.format,
      format = _props$format === void 0 ? DEFAULT_FORMAT : _props$format,
      _props$steps = props.steps,
      steps = _props$steps === void 0 ? DEFAULT_STEPS : _props$steps,
      _props$onChange = props.onChange,
      onChange = _props$onChange === void 0 ? function () {} : _props$onChange,
      _props$onTrigger = props.onTrigger,
      onTrigger = _props$onTrigger === void 0 ? function () {} : _props$onTrigger;

  var getCurrentTime = function getCurrentTime(type) {
    var currentVal = new Date().getHours().toString();

    if (type === 'meridiem') {
      /H|h/.test(format) && (currentVal = innerValue.split(':')[0]);
      Number(currentVal) >= 12 ? currentVal = 'PM' : currentVal = 'AM';
    } else {
      type === 'minute' && (currentVal = new Date().getMinutes().toString());
      type === 'second' && (currentVal = new Date().getSeconds().toString());
      currentVal.length === 1 && (currentVal = '0' + currentVal);
    }

    return currentVal;
  };

  var _useDefault = useDefault(value, defaultValue, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerValue = _useDefault2[0],
      setInnerValue = _useDefault2[1];

  var _useState = useState({
    hour: '00',
    minute: '00',
    second: '00',
    meridiem: ''
  }),
      _useState2 = _slicedToArray(_useState, 2),
      timeValue = _useState2[0],
      setTimeValue = _useState2[1];

  var valueToObj = function valueToObj(val) {
    var result = {
      hour: '00',
      minute: '00',
      second: '00',
      meridiem: ''
    };
    var ifMeridiem = false;
    /A/.test(format) && (ifMeridiem = true);
    var timeArr = val.split(':');

    if (!/H|h/.test(format) && timeArr.length === 2) {
      timeArr.unshift('00');
    }

    result.hour = timeArr[0];
    result.minute = timeArr[1];
    result.second = String(timeArr[2]).split(' ')[0];
    ifMeridiem && (result.meridiem = val.split(' ')[1] || getCurrentTime('meridiem'));
    return result;
  };

  var objToValue = function objToValue(obj) {
    var hourVal = "".concat(obj.hour, ":");
    var minuteVal = "".concat(obj.minute);
    var secondVal = ":".concat(obj.second);
    var meridiemVal = "";
    !/H|h/.test(format) && (hourVal = "");
    !/s/.test(format) && (secondVal = "");
    /A/.test(format) && (meridiemVal = " ".concat(timeValue.meridiem));
    var result = "".concat(hourVal).concat(minuteVal).concat(secondVal).concat(meridiemVal);
    return result;
  };

  useEffect(function () {
    var newTimeVal = valueToObj(innerValue);
    setTimeValue(_objectSpread2({}, newTimeVal));
  }, [innerValue]);

  var updateValue = function updateValue(val) {
    var currentTime;
    val ? currentTime = objToValue(val) : currentTime = objToValue(timeValue);
    setInnerValue(currentTime);
  };

  var selectTime = function selectTime(type, val) {
    timeValue[type] = val;
    updateValue();
  };

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      popupVisible = _useState4[0],
      setPopupVisible = _useState4[1];

  var switchPopup = function switchPopup(visible) {
    setPopupVisible(visible);
    onTrigger === null || onTrigger === void 0 ? void 0 : onTrigger(visible);
  };

  var handleNow = function handleNow() {
    var currentTime = dayjs().format(format);
    setInnerValue(currentTime);
  };

  var handleConfirm = function handleConfirm() {
    switchPopup(false);
    updateValue();
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classNames('i-time-picker', className),
    style: _objectSpread2({}, style)
  }, /*#__PURE__*/React.createElement(Popup, {
    content: /*#__PURE__*/React.createElement(TimePanel, {
      value: timeValue,
      format: format,
      steps: steps,
      onNow: handleNow,
      onClose: switchPopup,
      onChange: selectTime,
      onConfirm: handleConfirm
    }),
    placement: "bottom",
    trigger: trigger,
    className: "i-time-popup",
    visible: popupVisible,
    disabled: disabled,
    noPadding: true,
    onTrigger: switchPopup
  }, /*#__PURE__*/React.createElement(TimeInput, {
    value: timeValue,
    format: format,
    disabled: disabled,
    onChange: updateValue
  })));
};

TimePicker.displayName = 'TimePicker';

var css_248z$o = ".i-date-picker[data-type=range] .i-input {\n  min-width: 196px;\n}\n\n.i-date-panel {\n  box-sizing: border-box;\n  width: auto;\n}\n\n.i-date-panel__header {\n  position: relative;\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  box-sizing: border-box;\n  width: 100%;\n  height: 50px;\n  padding: 12px 16px 12px 20px;\n}\n\n.i-date-panel__header-today {\n  box-sizing: border-box;\n  width: 12px;\n  height: 12px;\n  margin: 0 6px;\n  border: 1px solid var(--i-font-2);\n  border-radius: 50%;\n  cursor: pointer;\n  transition: all 0.1s ease-out;\n}\n.i-date-panel__header-today:hover {\n  border-color: var(--i-primary-txt);\n}\n\n.i-date-panel__header-handle {\n  display: flex;\n  gap: 2px;\n  align-items: center;\n}\n\n.i-date-panel__header-icon {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 24px;\n  height: 24px;\n  border-radius: 50%;\n  cursor: pointer;\n  transition: all 0.1s ease-out;\n}\n.i-date-panel__header-icon .i-icon {\n  margin: 0;\n}\n.i-date-panel__header-icon:hover {\n  background: var(--i-bg-hover);\n}\n.i-date-panel__header-icon.i-date-panel__header-icon__disabled {\n  cursor: not-allowed;\n}\n.i-date-panel__header-icon.i-date-panel__header-icon__disabled .i-icon {\n  color: var(--i-font-disabled);\n}\n.i-date-panel__header-icon.i-date-panel__header-icon__disabled:hover {\n  background: unset;\n}\n\n.i-date-panel__header-title-wrapper {\n  display: flex;\n  gap: 2px;\n  align-items: center;\n}\n\n.i-date-panel__header-title {\n  cursor: pointer;\n  transition: all 0.1s ease-out;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-date-panel__header-title:hover {\n  color: var(--i-primary-txt);\n}\n\n.i-date__year-select-panel,\n.i-date__month-select-panel {\n  box-sizing: border-box;\n  width: auto;\n  padding: 8px 12px 16px;\n}\n\n.i-date__year-select-title,\n.i-date__month-select-title {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  box-sizing: border-box;\n  width: 100%;\n  padding-bottom: 8px;\n  border-bottom: 1px solid var(--i-border);\n}\n\n.i-date__year-select-list,\n.i-date__month-select-list {\n  display: grid;\n  grid-template-columns: 1fr 1fr 1fr 1fr;\n  gap: 8px;\n  padding-top: 16px;\n}\n\n.i-date__year-select-item,\n.i-date__month-select-item {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  width: 42px;\n  height: 26px;\n  font-size: 12px;\n  border-radius: 16px;\n  cursor: pointer;\n  transition: all 0.1s ease-out;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-date__year-select-item.i-date__year-select-item__current, .i-date__year-select-item.i-date__month-select-item__current,\n.i-date__month-select-item.i-date__year-select-item__current,\n.i-date__month-select-item.i-date__month-select-item__current {\n  color: var(--i-primary-txt);\n  background: var(--i-primary-bg);\n}\n.i-date__year-select-item.i-date__year-select-item__current:hover, .i-date__year-select-item.i-date__month-select-item__current:hover,\n.i-date__month-select-item.i-date__year-select-item__current:hover,\n.i-date__month-select-item.i-date__month-select-item__current:hover {\n  color: var(--i-primary-txt);\n}\n.i-date__year-select-item.i-date__year-select-item__selected, .i-date__year-select-item.i-date__month-select-item__selected,\n.i-date__month-select-item.i-date__year-select-item__selected,\n.i-date__month-select-item.i-date__month-select-item__selected {\n  color: #fff;\n  background: var(--i-primary);\n}\n.i-date__year-select-item.i-date__year-select-item__selected:hover, .i-date__year-select-item.i-date__month-select-item__selected:hover,\n.i-date__month-select-item.i-date__year-select-item__selected:hover,\n.i-date__month-select-item.i-date__month-select-item__selected:hover {\n  color: #fff;\n}\n.i-date__year-select-item:hover,\n.i-date__month-select-item:hover {\n  color: var(--i-primary-txt);\n}\n\n.i-date-panel__content {\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  justify-content: center;\n  padding: 0 12px 12px;\n}\n\n.i-date-panel__week-wrapper,\n.i-date-panel__day-wrapper {\n  display: flex;\n  flex-wrap: wrap;\n  width: 252px;\n  row-gap: 4px;\n}\n\n.i-date-panel__week-item,\n.i-date-panel__day-item {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 36px;\n  height: 36px;\n}\n\n.i-date-panel__day-item {\n  position: relative;\n  cursor: pointer;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-date-panel__day-item.i-date-panel__day-item__current {\n  color: var(--i-primary-txt);\n}\n.i-date-panel__day-item.i-date-panel__day-item__current .i-date-panel__day-item-txt {\n  background: var(--i-primary-bg);\n}\n.i-date-panel__day-item.i-date-panel__day-item__current:hover {\n  color: var(--i-primary-txt);\n}\n.i-date-panel__day-item.i-date-panel__day-item__in-range {\n  color: #fff;\n  background: var(--i-primary-disabled);\n}\n.i-date-panel__day-item.i-date-panel__day-item__in-range .i-date-panel__day-item-txt {\n  background: unset;\n}\n.i-date-panel__day-item.i-date-panel__day-item__in-range.-range__start {\n  border-radius: 50% 0 0 50%;\n}\n.i-date-panel__day-item.i-date-panel__day-item__in-range.-range__end {\n  border-radius: 0 50% 50% 0;\n}\n.i-date-panel__day-item.i-date-panel__day-item__in-range.-range__same {\n  border-radius: 50%;\n}\n.i-date-panel__day-item.i-date-panel__day-item__selected {\n  color: #fff;\n}\n.i-date-panel__day-item.i-date-panel__day-item__selected .i-date-panel__day-item-txt {\n  background: var(--i-primary);\n}\n.i-date-panel__day-item.i-date-panel__day-item__selected:hover {\n  color: #fff;\n}\n.i-date-panel__day-item.i-date-panel__day-item__blur {\n  color: var(--i-font-5);\n}\n.i-date-panel__day-item.i-date-panel__day-item__blur .i-date-panel__day-item-txt {\n  background: unset;\n}\n.i-date-panel__day-item.i-date-panel__day-item__blur:hover {\n  color: var(--i-font-5);\n}\n.i-date-panel__day-item:hover {\n  color: var(--i-primary-txt);\n}\n\n.i-date-panel__day-item-txt {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 30px;\n  height: 30px;\n  color: inherit;\n  border-radius: 50%;\n}\n\n.i-date-panel__range {\n  display: flex;\n  align-items: center;\n}\n.i-date-panel__range .i-date-panel:last-of-type {\n  border-left: 1px solid var(--i-border);\n}";
styleInject(css_248z$o);

var YearSelectPanel = function YearSelectPanel(props) {
  var _props$year = props.year,
      year = _props$year === void 0 ? 2022 : _props$year,
      onChange = props.onChange;

  var _useState = useState(year),
      _useState2 = _slicedToArray(_useState, 2),
      innerYear = _useState2[0],
      setInnerYear = _useState2[1];

  useEffect(function () {
    setInnerYear(year);
  }, [year]);

  var _useState3 = useState(_.range(2020, 2030)),
      _useState4 = _slicedToArray(_useState3, 2),
      yearList = _useState4[0],
      setYearList = _useState4[1];

  var yearToRangeList = function yearToRangeList(curYear) {
    var year = String(curYear);
    var startNum = Number("".concat(year.substring(0, 3), "0"));
    var endNum = Number("".concat(Number(year.substring(0, 3)) + 1, "0"));

    var list = _.range(startNum, endNum);

    setYearList(list);
  };

  useEffect(function () {
    yearToRangeList(year);
  }, []);

  var handleLastTenYears = function handleLastTenYears(e) {
    e.stopPropagation();
    var subTenYear = yearList[0] - 10;
    yearToRangeList(subTenYear);
  };

  var handleNextTenYears = function handleNextTenYears(e) {
    e.stopPropagation();
    var subTenYear = yearList[0] + 10;
    yearToRangeList(subTenYear);
  };

  var handleClickItem = function handleClickItem(e, item) {
    e.stopPropagation();
    onChange === null || onChange === void 0 ? void 0 : onChange(item);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "i-date__year-select-panel",
    onClick: function onClick(e) {
      return e.stopPropagation();
    }
  }, /*#__PURE__*/React.createElement("header", {
    className: "i-date__year-select-title"
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-date-panel__header-icon",
    onClick: handleLastTenYears
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ArrowDoubleLeft"
  })), /*#__PURE__*/React.createElement("div", {
    className: "i-date-panel__header-title"
  }, yearList[0], " - ", yearList[yearList.length - 1]), /*#__PURE__*/React.createElement("div", {
    className: "i-date-panel__header-icon",
    onClick: handleNextTenYears
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ArrowDoubleRight"
  }))), /*#__PURE__*/React.createElement("section", {
    className: "i-date__year-select-list"
  }, yearList.map(function (item) {
    return /*#__PURE__*/React.createElement("div", {
      className: classNames('i-date__year-select-item', innerYear === item && 'i-date__year-select-item__selected', new Date().getFullYear() === item && 'i-date__year-select-item__current'),
      key: item,
      onClick: function onClick(e) {
        return handleClickItem(e, item);
      }
    }, item);
  })));
};

var MonthSelectPanel = function MonthSelectPanel(props) {
  var _props$month = props.month,
      month = _props$month === void 0 ? 6 : _props$month,
      onChange = props.onChange;

  var _useState = useState(month),
      _useState2 = _slicedToArray(_useState, 2),
      innerMonth = _useState2[0],
      setInnerMonth = _useState2[1];

  useEffect(function () {
    setInnerMonth(month);
  }, [month]);

  var handleLastMonth = function handleLastMonth(e) {
    e.stopPropagation();
    innerMonth > 0 && setInnerMonth(innerMonth - 1);
  };

  var handleNextMonth = function handleNextMonth(e) {
    e.stopPropagation();
    innerMonth < 11 && setInnerMonth(innerMonth + 1);
  };

  var handleClickItem = function handleClickItem(e, item) {
    e.stopPropagation();
    onChange === null || onChange === void 0 ? void 0 : onChange(item);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "i-date__month-select-panel",
    onClick: function onClick(e) {
      return e.stopPropagation();
    }
  }, /*#__PURE__*/React.createElement("header", {
    className: "i-date__month-select-title"
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-date-panel__header-icon",
    onClick: handleLastMonth
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ArrowLeft"
  })), /*#__PURE__*/React.createElement("div", {
    className: "i-date-panel__header-title"
  }, innerMonth + 1, " \u6708"), /*#__PURE__*/React.createElement("div", {
    className: "i-date-panel__header-icon",
    onClick: handleNextMonth
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "ArrowRight"
  }))), /*#__PURE__*/React.createElement("section", {
    className: "i-date__month-select-list"
  }, _.range(0, 12).map(function (item) {
    return /*#__PURE__*/React.createElement("div", {
      className: classNames('i-date__month-select-item', innerMonth === item && 'i-date__month-select-item__selected', new Date().getMonth() === item && 'i-date__month-select-item__current'),
      key: item,
      onClick: function onClick(e) {
        return handleClickItem(e, item);
      }
    }, item + 1);
  })));
};

var DateHeaderBtn = function DateHeaderBtn(props) {
  var _props$icon = props.icon,
      icon = _props$icon === void 0 ? "ArrowDoubleLeft" : _props$icon,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$onClick = props.onClick,
      onClick = _props$onClick === void 0 ? function () {} : _props$onClick;

  var handleClickBtn = function handleClickBtn() {
    !disabled && (onClick === null || onClick === void 0 ? void 0 : onClick());
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classNames('i-date-panel__header-icon', disabled && 'i-date-panel__header-icon__disabled'),
    onClick: handleClickBtn
  }, /*#__PURE__*/React.createElement(Icon, {
    name: icon
  }));
};

dayjs.extend(isBetween);

var DatePanel = function DatePanel(props) {
  var firstDayOfWeek = props.firstDayOfWeek,
      value = props.value,
      rangeValue = props.rangeValue,
      defaultDisplayVal = props.defaultDisplayVal,
      onChange = props.onChange,
      onHover = props.onHover,
      onClose = props.onClose;

  var _useState = useState(value),
      _useState2 = _slicedToArray(_useState, 2),
      dateVal = _useState2[0],
      setDateVal = _useState2[1];

  var _useState3 = useState(value),
      _useState4 = _slicedToArray(_useState3, 2),
      displayVal = _useState4[0],
      setDisplayVal = _useState4[1];

  useEffect(function () {
    if (defaultDisplayVal) {
      setDisplayVal(defaultDisplayVal);
    } else {
      setDisplayVal(value);
    }
  }, [value]);

  var handleSwitchDate = function handleSwitchDate(mode, type) {
    var step = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 1;
    var newDateVal;

    if (mode === 'add') {
      newDateVal = dayjs(displayVal).add(step, type).format(DATE_FORMAT);
    } else {
      newDateVal = dayjs(displayVal).subtract(step, type).format(DATE_FORMAT);
    }

    setDisplayVal(newDateVal);
  };

  var handleToday = function handleToday() {
    setDisplayVal(dayjs().format(DATE_FORMAT));
  };

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      yearPanelVisible = _useState6[0],
      setYearPanelVisible = _useState6[1];

  var _useState7 = useState(false),
      _useState8 = _slicedToArray(_useState7, 2),
      monthPanelVisible = _useState8[0],
      setMonthPanelVisible = _useState8[1];

  var handleSelectYear = function handleSelectYear(val) {
    var newDateVal = dayjs(displayVal).year(val).format(DATE_FORMAT);
    setDisplayVal(newDateVal);
    setYearPanelVisible(false);
  };

  var handleSelectMonth = function handleSelectMonth(val) {
    var newDateVal = dayjs(displayVal).month(val).format(DATE_FORMAT);
    setDisplayVal(newDateVal);
    setMonthPanelVisible(false);
  };

  var handleSelectDay = function handleSelectDay(type, val) {
    value && type !== 'current' && setDisplayVal(val);
    value && setDateVal(val);
    onChange === null || onChange === void 0 ? void 0 : onChange(val);
    onClose === null || onClose === void 0 ? void 0 : onClose();
  };

  var handleEnterMonth = function handleEnterMonth(val) {
    onHover === null || onHover === void 0 ? void 0 : onHover(val);
  };

  var getMonthPanelDays = function getMonthPanelDays() {
    var currentMonthStart = dayjs(displayVal).startOf('month').day();
    var startIndex = 0; // 每周第一天

    if (firstDayOfWeek === 1) {
      currentMonthStart === 0 ? startIndex = 6 : startIndex = currentMonthStart - 1;
    } else {
      startIndex = currentMonthStart;
    }

    var panelDays = [];
    var lastMonthDays = dayjs(displayVal).subtract(1, 'month').daysInMonth();

    for (var i = lastMonthDays - startIndex + 1; i < lastMonthDays + 1; i++) {
      panelDays.push({
        label: i,
        type: 'last',
        value: dayjs(displayVal).subtract(1, 'month').set('date', i).format(DATE_FORMAT)
      });
    }

    var currentMonthDays = dayjs(displayVal).daysInMonth();

    var currentDayVal = function currentDayVal(index) {
      return dayjs(displayVal).set('date', index).format(DATE_FORMAT);
    };

    var rangeValid = (rangeValue === null || rangeValue === void 0 ? void 0 : rangeValue.length) === 2;

    for (var _i = 1; _i < currentMonthDays + 1; _i++) {
      panelDays.push({
        label: _i,
        type: 'current',
        range: rangeValid && (dayjs(currentDayVal(_i)).isBetween(dayjs(rangeValue[0]), dayjs(rangeValue[1]), "day") || currentDayVal(_i) === rangeValue[0] || currentDayVal(_i) === rangeValue[1]),
        rangeStart: rangeValid && currentDayVal(_i) === rangeValue[0],
        rangeSame: rangeValid && rangeValue[0] === rangeValue[1],
        rangeEnd: rangeValid && currentDayVal(_i) === rangeValue[1],
        value: currentDayVal(_i)
      });
    }

    var remainLen = 42 - startIndex + 1 - currentMonthDays;

    for (var _i2 = 1; _i2 < remainLen; _i2++) {
      panelDays.push({
        label: _i2,
        type: 'next',
        value: dayjs(displayVal).add(1, 'month').set('date', _i2).format(DATE_FORMAT)
      });
    }

    return panelDays;
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "i-date-panel"
  }, /*#__PURE__*/React.createElement("header", {
    className: "i-date-panel__header"
  }, /*#__PURE__*/React.createElement("section", {
    className: "i-date-panel__header-title-wrapper"
  }, /*#__PURE__*/React.createElement(Popup, {
    visible: yearPanelVisible,
    content: /*#__PURE__*/React.createElement(YearSelectPanel, {
      year: dayjs(displayVal).year(),
      onChange: handleSelectYear
    }),
    trigger: "click",
    onTrigger: function onTrigger(visible) {
      return setYearPanelVisible(visible);
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-date-panel__header-title"
  }, "".concat(dayjs(displayVal).year(), "\u5E74"))), /*#__PURE__*/React.createElement(Popup, {
    visible: monthPanelVisible,
    content: /*#__PURE__*/React.createElement(MonthSelectPanel, {
      month: dayjs(displayVal).month(),
      onChange: handleSelectMonth
    }),
    trigger: "click",
    onTrigger: function onTrigger(visible) {
      return setMonthPanelVisible(visible);
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-date-panel__header-title"
  }, "".concat(dayjs(displayVal).month() + 1, "\u6708")))), /*#__PURE__*/React.createElement("section", {
    className: "i-date-panel__header-handle"
  }, /*#__PURE__*/React.createElement(DateHeaderBtn, {
    icon: "ArrowDoubleLeft",
    disabled: false,
    onClick: function onClick() {
      return handleSwitchDate('sub', "year");
    }
  }), /*#__PURE__*/React.createElement(DateHeaderBtn, {
    icon: "ArrowLeft",
    disabled: false,
    onClick: function onClick() {
      return handleSwitchDate('sub', "month");
    }
  }), /*#__PURE__*/React.createElement("div", {
    className: "i-date-panel__header-today",
    onClick: handleToday
  }), /*#__PURE__*/React.createElement(DateHeaderBtn, {
    icon: "ArrowRight",
    disabled: false,
    onClick: function onClick() {
      return handleSwitchDate('add', "month");
    }
  }), /*#__PURE__*/React.createElement(DateHeaderBtn, {
    icon: "ArrowDoubleRight",
    disabled: false,
    onClick: function onClick() {
      return handleSwitchDate('add', "year");
    }
  }))), /*#__PURE__*/React.createElement("div", {
    className: "i-date-panel__content"
  }, /*#__PURE__*/React.createElement("header", {
    className: "i-date-panel__week-wrapper"
  }, firstDayOfWeek === 0 ? WEEK_HEAD_0.map(function (item) {
    return /*#__PURE__*/React.createElement("div", {
      className: "i-date-panel__week-item",
      key: item
    }, item);
  }) : WEEK_HEAD_1.map(function (item) {
    return /*#__PURE__*/React.createElement("div", {
      className: "i-date-panel__week-item",
      key: item
    }, item);
  })), /*#__PURE__*/React.createElement("section", {
    className: "i-date-panel__day-wrapper"
  }, getMonthPanelDays().map(function (item) {
    return /*#__PURE__*/React.createElement("div", {
      className: classNames('i-date-panel__day-item', item.range && 'i-date-panel__day-item__in-range', item.rangeStart && '-range__start', item.rangeSame && '-range__same', item.rangeEnd && '-range__end', item.type !== 'current' && 'i-date-panel__day-item__blur', (item.value === dateVal || (rangeValue === null || rangeValue === void 0 ? void 0 : rangeValue.includes(item.value))) && 'i-date-panel__day-item__selected', item.value === dayjs().format(DATE_FORMAT) && 'i-date-panel__day-item__current'),
      key: item.value,
      onClick: function onClick() {
        return handleSelectDay(item.type, item.value);
      },
      onMouseEnter: function onMouseEnter() {
        return handleEnterMonth(item.value);
      }
    }, /*#__PURE__*/React.createElement("div", {
      className: 'i-date-panel__day-item-txt'
    }, item.label));
  }))));
};

dayjs.extend(isBetween);

var DateRangePanel = function DateRangePanel(props) {
  var _props$rangeValue = props.rangeValue,
      rangeValue = _props$rangeValue === void 0 ? [dayjs().format(DATE_FORMAT), dayjs().add(1, 'month').format(DATE_FORMAT)] : _props$rangeValue,
      firstDayOfWeek = props.firstDayOfWeek,
      onChange = props.onChange,
      onClose = props.onClose;

  var _useState = useState(rangeValue),
      _useState2 = _slicedToArray(_useState, 2),
      innerRangeValue = _useState2[0],
      setInnerRangeValue = _useState2[1];

  var _useState3 = useState(true),
      _useState4 = _slicedToArray(_useState3, 2),
      rangeLock = _useState4[0],
      setRangeLock = _useState4[1];

  var handleSelect = function handleSelect(val) {
    if (rangeLock) {
      // 滑选未解锁 -> 解锁
      if (innerRangeValue.length === 2) {
        hoverStartVal.current = val;
        var newRangeValue = [val, val];
        setInnerRangeValue([].concat(newRangeValue));
        setRangeLock(false);
      }
    } else {
      // 滑选已解锁 -> 锁定
      onChange === null || onChange === void 0 ? void 0 : onChange(innerRangeValue);
      onClose === null || onClose === void 0 ? void 0 : onClose();
      setRangeLock(true);
    }
  };

  var valToNum = function valToNum(val) {
    return Number(val.replaceAll('-', ''));
  };

  var hoverStartVal = useRef('');

  var handleHover = function handleHover(val) {
    if (!rangeLock) {
      var newRangeValue = innerRangeValue;

      if (valToNum(val) > valToNum(hoverStartVal.current)) {
        newRangeValue[0] = hoverStartVal.current;
        newRangeValue[1] = val;
      } else if (valToNum(val) === valToNum(hoverStartVal.current)) {
        newRangeValue[0] = val;
        newRangeValue[1] = val;
      } else {
        newRangeValue[0] = val;
        newRangeValue[1] = hoverStartVal.current;
      }

      setInnerRangeValue(_toConsumableArray(newRangeValue));
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "i-date-panel__range"
  }, /*#__PURE__*/React.createElement(DatePanel, {
    firstDayOfWeek: firstDayOfWeek,
    rangeValue: innerRangeValue,
    defaultDisplayVal: innerRangeValue[0],
    onChange: handleSelect,
    onHover: handleHover
  }), /*#__PURE__*/React.createElement(DatePanel, {
    firstDayOfWeek: firstDayOfWeek,
    rangeValue: innerRangeValue,
    defaultDisplayVal: innerRangeValue[1],
    onChange: handleSelect,
    onHover: handleHover
  }));
};

dayjs.extend(isBetween);
var DATE_FORMAT = 'YYYY-MM-DD';
var WEEK_HEAD_0 = ['日', '一', '二', '三', '四', '五', '六'];
var WEEK_HEAD_1 = ['一', '二', '三', '四', '五', '六', '日'];

var getDefaultVal = function getDefaultVal(type) {
  if (type === 'range') {
    return [dayjs().format(DATE_FORMAT), dayjs().add(1, 'month').format(DATE_FORMAT)];
  } else {
    return dayjs().format(DATE_FORMAT);
  }
};

var DatePicker = function DatePicker(props) {
  var className = props.className,
      style = props.style,
      value = props.value,
      _props$defaultValue = props.defaultValue,
      defaultValue = _props$defaultValue === void 0 ? getDefaultVal(props.type || 'date') : _props$defaultValue,
      _props$trigger = props.trigger,
      trigger = _props$trigger === void 0 ? "click" : _props$trigger,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$type = props.type,
      type = _props$type === void 0 ? 'date' : _props$type,
      _props$rangeSeparator = props.rangeSeparator,
      rangeSeparator = _props$rangeSeparator === void 0 ? '~' : _props$rangeSeparator,
      _props$firstDayOfWeek = props.firstDayOfWeek,
      firstDayOfWeek = _props$firstDayOfWeek === void 0 ? 1 : _props$firstDayOfWeek,
      onChange = props.onChange;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      popupVisible = _useState2[0],
      setPopupVisible = _useState2[1];

  var switchPopup = function switchPopup(visible) {
    setPopupVisible(visible);
  };

  var _useDefault = useDefault(value, defaultValue, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerValue = _useDefault2[0],
      setInnerValue = _useDefault2[1];

  var handleChange = function handleChange(val) {
    setInnerValue(val);
  };

  var handleClose = function handleClose() {
    setPopupVisible(false);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: classNames('i-date-picker', className),
    "data-type": type,
    style: _objectSpread2({}, style)
  }, /*#__PURE__*/React.createElement(Popup, {
    content: type === 'date' ? /*#__PURE__*/React.createElement(DatePanel, {
      value: innerValue,
      firstDayOfWeek: firstDayOfWeek,
      onChange: handleChange,
      onClose: handleClose
    }) : /*#__PURE__*/React.createElement(DateRangePanel, {
      rangeValue: innerValue,
      firstDayOfWeek: firstDayOfWeek,
      onChange: handleChange,
      onClose: handleClose
    }),
    placement: "bottom",
    trigger: trigger,
    className: "i-date-popup",
    visible: popupVisible,
    disabled: disabled,
    onTrigger: switchPopup
  }, /*#__PURE__*/React.createElement(Input, {
    readonly: true,
    disabled: disabled,
    value: !_.isArray(innerValue) ? innerValue : "".concat(innerValue[0], " ").concat(rangeSeparator, " ").concat(innerValue[1]),
    placeholder: "\u8BF7\u9009\u62E9\u65E5\u671F",
    suffixIcon: "Calendar"
  })));
};

DatePicker.displayName = 'DatePicker';

var css_248z$p = ".i-color {\n  box-sizing: border-box;\n  width: 32px;\n  height: 32px;\n  border: 1px solid var(--i-border);\n  border-radius: 6px;\n  cursor: pointer;\n}\n.i-color.i-color__disabled {\n  cursor: not-allowed;\n}\n.i-color.i-color--size-small {\n  width: 24px;\n  height: 24px;\n}\n.i-color.i-color--size-large {\n  width: 40px;\n  height: 40px;\n}\n\n.i-color-panel {\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  width: 240px;\n}\n.i-color-panel.i-color-panel__disabled .i-color-panel-block,\n.i-color-panel.i-color-panel__disabled .i-color-panel-bar__rgb,\n.i-color-panel.i-color-panel__disabled .i-color-panel-bar__a,\n.i-color-panel.i-color-panel__disabled .i-color-panel-controls__dropper,\n.i-color-panel.i-color-panel__disabled .i-color-panel-color {\n  cursor: not-allowed;\n}\n.i-color-panel.i-color-panel__disabled .i-color-panel-controls__dropper {\n  background: var(--i-bg-disabled);\n}\n\n.i-color-panel-header {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  box-sizing: border-box;\n  width: 100%;\n  height: 40px;\n  padding: 0 16px;\n  color: var(--i-font-2);\n}\n\n.i-color-panel-header-txt {\n  cursor: default;\n}\n\n.i-color-panel-header-icon {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 24px;\n  height: 24px;\n  margin-right: -8px;\n  border-radius: 50%;\n  cursor: pointer;\n  transition: all 0.1s ease-out;\n}\n.i-color-panel-header-icon .i-icon {\n  margin: 0;\n}\n.i-color-panel-header-icon:hover {\n  background: var(--i-bg-hover);\n}\n\n.i-color-panel-block {\n  position: relative;\n  width: 240px;\n  height: 240px;\n}\n\n.i-color-panel-block__white,\n.i-color-panel-block__black {\n  position: absolute;\n  top: 0;\n  right: 0;\n  bottom: 0;\n  left: 0;\n  width: 100%;\n  height: 100%;\n}\n\n.i-color-panel-block__white {\n  background: linear-gradient(90deg, #fff, rgba(255, 255, 255, 0));\n}\n\n.i-color-panel-block__black {\n  background: linear-gradient(0deg, #000, transparent);\n}\n\n.i-color-picker__cursor {\n  position: absolute;\n  z-index: 3;\n  box-sizing: border-box;\n  width: 12px;\n  height: 12px;\n  border: 2px solid #fff;\n  border-radius: 6px;\n  box-shadow: rgba(0, 0, 0, 0.2) 0px 0px 0px 0.6px;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n  pointer-events: none;\n  -webkit-user-drag: none;\n}\n\n.i-color-panel-controls {\n  display: flex;\n  gap: 8px;\n  align-items: center;\n  box-sizing: border-box;\n  width: 100%;\n  padding: 16px;\n}\n\n.i-color-panel-controls__dropper,\n.i-color-panel-controls__bar {\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n  justify-content: center;\n}\n\n.i-color-panel-controls__dropper {\n  width: 32px;\n  height: 32px;\n  border: 1px solid var(--i-border);\n  border-radius: 16px;\n  cursor: pointer;\n  transition: all 0.2s cubic-bezier(0.38, 0, 0.24, 1);\n}\n.i-color-panel-controls__dropper .icon-Dropper {\n  color: var(--i-font-4);\n}\n.i-color-panel-controls__dropper:hover {\n  background: var(--i-bg-hover);\n}\n\n.i-color-panel-controls__bar {\n  flex: 1;\n}\n\n.i-color-panel-bar__rgb,\n.i-color-panel-bar__a {\n  position: relative;\n  box-sizing: border-box;\n  width: 100%;\n  height: 12px;\n  border-radius: 6px;\n  box-shadow: rgba(0, 0, 0, 0.2) 0px 0px 0px 0.6px inset;\n}\n\n.i-color-panel-bar__rgb {\n  margin-bottom: 8px;\n  background: linear-gradient(90deg, #f00 0, #ff0 17%, #0f0 33%, #0ff 50%, #00f 67%, #f0f 83%, #f00);\n}\n\n.i-color-panel-bar__a {\n  position: relative;\n  overflow: hidden;\n}\n\n.i-color-panel-bar__a-color,\n.i-color-panel-bar__a-bg {\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 100%;\n  height: 100%;\n}\n\n.i-color-panel-bar__a-color {\n  z-index: 2;\n  border-radius: 6px;\n  box-shadow: rgba(0, 0, 0, 0.2) 0px 0px 0px 0.6px inset;\n}\n\n.i-color-panel-bar__a-bg {\n  z-index: 1;\n  background: url(\"data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAwAAAAMCAIAAADZF8uwAAAAGUlEQVQYV2M4gwH+YwCGIasIUwhT25BVBADtzYNYrHvv4gAAAABJRU5ErkJggg==\");\n}\n\n.i-color-panel-values {\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  box-sizing: border-box;\n  width: 100%;\n  padding: 0px 16px 16px;\n}\n\n.i-color-panel-input__wrapper {\n  display: flex;\n  align-items: center;\n  box-sizing: border-box;\n  width: 66%;\n  overflow: hidden;\n  border: 1px solid var(--i-border);\n  border-radius: 4px;\n  transition: all 0.2s cubic-bezier(0.38, 0, 0.24, 1);\n}\n.i-color-panel-input__wrapper:focus-within {\n  border-color: var(--i-primary);\n}\n.i-color-panel-input__wrapper .i-input {\n  border: none;\n  border-right: 1px solid var(--i-border);\n  border-radius: 0;\n}\n.i-color-panel-input__wrapper .i-input:hover, .i-color-panel-input__wrapper .i-input:focus-within {\n  background-color: var(--i-bg-hover);\n}\n.i-color-panel-input__wrapper .i-input__inner {\n  padding-right: 0;\n}\n.i-color-panel-input__wrapper .i-input__inner::-moz-selection {\n  background: transparent;\n}\n.i-color-panel-input__wrapper .i-input__inner::selection {\n  background: transparent;\n}\n.i-color-panel-input__wrapper .i-input__inner:focus::-moz-selection {\n  background: var(--i-primary-bg-2);\n}\n.i-color-panel-input__wrapper .i-input__inner:focus::selection {\n  background: var(--i-primary-bg-2);\n}\n\n.i-color-panel-input__class {\n  display: flex;\n  flex: 75%;\n  align-items: center;\n}\n\n.i-color-panel-input__alpha {\n  flex: 25%;\n}\n.i-color-panel-input__alpha .i-input {\n  border-right: none;\n}\n.i-color-panel-input__alpha .i-input--type-number .i-input__inner {\n  padding-right: 0;\n}\n\n.i-color-panel-footer {\n  display: flex;\n  flex-wrap: wrap;\n  gap: 8px;\n  box-sizing: border-box;\n  width: 100%;\n  padding: 16px;\n  border-top: 1px solid var(--i-border);\n}\n\n.i-color-panel-color {\n  width: 16px;\n  height: 16px;\n  background-color: #fff;\n  border-radius: 4px;\n  box-shadow: rgba(0, 0, 0, 0.2) 0px 0px 0px 0.6px inset;\n  cursor: pointer;\n}";
styleInject(css_248z$p);

var ColorCursor = function ColorCursor(props) {
  var _props$x = props.x,
      x = _props$x === void 0 ? 0 : _props$x,
      _props$y = props.y,
      y = _props$y === void 0 ? 0 : _props$y,
      _props$mode = props.mode,
      mode = _props$mode === void 0 ? 'xy' : _props$mode,
      color = props.color,
      style = props.style;
  var cursorRef = useRef(null);

  var _useState = useState({
    x: 0,
    y: 0
  }),
      _useState2 = _slicedToArray(_useState, 2),
      translate = _useState2[0],
      setTranslate = _useState2[1];

  var _useState3 = useState({
    width: 0,
    height: 0
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      parent = _useState4[0],
      setParent = _useState4[1];

  useEffect(function () {
    var _cursorRef$current, _cursorRef$current2;

    parent.width = (_cursorRef$current = cursorRef.current) === null || _cursorRef$current === void 0 ? void 0 : _cursorRef$current.parentNode.clientWidth;
    parent.height = (_cursorRef$current2 = cursorRef.current) === null || _cursorRef$current2 === void 0 ? void 0 : _cursorRef$current2.parentNode.clientHeight;
    setParent(_objectSpread2({}, parent));
  }, []);
  useEffect(function () {
    if (mode === 'x') {
      translate.x = x * (parent.width - 12);
    } else if (mode === 'y') {
      translate.y = y * (parent.height - 12);
    } else {
      translate.x = x * parent.width - 6;
      translate.y = y * parent.height - 6;
    }

    setTranslate(_objectSpread2({}, translate));
  }, [x, y]);
  return /*#__PURE__*/React.createElement("div", {
    className: "i-color-picker__cursor",
    ref: cursorRef,
    style: _objectSpread2(_objectSpread2({}, style || {}), {
      transform: "translate(".concat(translate.x, "px, ").concat(translate.y, "px)"),
      background: color
    })
  });
};

var ColorItem = function ColorItem(props) {
  var _props$color = props.color,
      color = _props$color === void 0 ? '#5e62ea' : _props$color,
      onClick = props.onClick;

  var handleClick = function handleClick() {
    onClick === null || onClick === void 0 ? void 0 : onClick(color);
  };

  return /*#__PURE__*/React.createElement("div", {
    className: "i-color-panel-color",
    style: {
      background: color
    },
    onClick: handleClick
  });
};

var _excluded$t = ["className", "style", "value", "defaultValue", "colorList", "disabled", "onChange", "onClose"];

var ColorPanel = function ColorPanel(props) {
  var className = props.className,
      style = props.style,
      value = props.value,
      _props$defaultValue = props.defaultValue,
      defaultValue = _props$defaultValue === void 0 ? '#5e62ea' : _props$defaultValue,
      _props$colorList = props.colorList,
      colorList = _props$colorList === void 0 ? defaultColor : _props$colorList,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      onChange = props.onChange,
      onClose = props.onClose,
      restProps = _objectWithoutProperties(props, _excluded$t);

  var _useDefault = useDefault(value, defaultValue, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerValue = _useDefault2[0],
      setInnerValue = _useDefault2[1]; // 颜色值


  var _useState = useState({
    rgbVal: tinycolor(innerValue).toRgbString(),
    hexVal: tinycolor(innerValue).toHexString(),
    r: tinycolor(innerValue).toRgb().r,
    g: tinycolor(innerValue).toRgb().g,
    b: tinycolor(innerValue).toRgb().b,
    h: tinycolor(innerValue).toHsv().h,
    s: tinycolor(innerValue).toHsv().s,
    v: tinycolor(innerValue).toHsv().v,
    a: tinycolor(innerValue).getAlpha()
  }),
      _useState2 = _slicedToArray(_useState, 2),
      colors = _useState2[0],
      setColors = _useState2[1]; // 是否为移动状态


  var handleMoving = function handleMoving(ifMoving) {
    if (ifMoving) {
      document.body.style.userSelect = 'none';
    } else {
      document.body.style.userSelect = '';
    }
  }; // 调色板、色阶柱、透明度柱 节点宽高位置


  var _useState3 = useState({
    panel: {
      width: 0,
      height: 0,
      left: 0,
      top: 0
    },
    rgb: {
      width: 0,
      left: 0
    },
    a: {
      width: 0,
      left: 0
    }
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      rect = _useState4[0],
      setRect = _useState4[1];

  var panelNode = useRef(null);
  var rgbBarNode = useRef(null);
  var aBarNode = useRef(null);

  var updateLocation = function updateLocation() {
    // 初始化给各节点宽高及位置参数赋值（popup 打开后再执行）
    setTimeout(function () {
      var _panelNode$current, _rgbBarNode$current, _aBarNode$current;

      var panelRect = (_panelNode$current = panelNode.current) === null || _panelNode$current === void 0 ? void 0 : _panelNode$current.getBoundingClientRect();
      rect.panel.width = (panelRect === null || panelRect === void 0 ? void 0 : panelRect.width) || 0;
      rect.panel.height = (panelRect === null || panelRect === void 0 ? void 0 : panelRect.height) || 0;
      rect.panel.left = (panelRect === null || panelRect === void 0 ? void 0 : panelRect.left) || 0;
      rect.panel.top = (panelRect === null || panelRect === void 0 ? void 0 : panelRect.top) || 0;
      var rgbRect = (_rgbBarNode$current = rgbBarNode.current) === null || _rgbBarNode$current === void 0 ? void 0 : _rgbBarNode$current.getBoundingClientRect();
      rect.rgb.width = (rgbRect === null || rgbRect === void 0 ? void 0 : rgbRect.width) || 0;
      rect.rgb.left = (rgbRect === null || rgbRect === void 0 ? void 0 : rgbRect.left) || 0;
      var aRect = (_aBarNode$current = aBarNode.current) === null || _aBarNode$current === void 0 ? void 0 : _aBarNode$current.getBoundingClientRect();
      rect.a.width = (aRect === null || aRect === void 0 ? void 0 : aRect.width) || 0;
      rect.a.left = (aRect === null || aRect === void 0 ? void 0 : aRect.left) || 0;
      setRect(_objectSpread2({}, rect));
    }, 100);
  };

  useEffect(function () {
    updateLocation(); // 设置初始滑块位置

    var currentColor = tinycolor(colors.rgbVal);
    location.panel.x = currentColor.toHsv().s;
    location.panel.y = 1 - currentColor.toHsv().v;
    location.rgb.x = currentColor.toHsv().h / 360;
    location.a.x = currentColor.getAlpha();
    setLocation(_objectSpread2({}, location));
    document.addEventListener('scroll', updateLocation);
    return function () {
      document.removeEventListener('scroll', updateLocation);
    };
  }, []); // 调色板、色阶柱、透明度柱 坐标值

  var _useState5 = useState({
    panel: {
      x: 0,
      y: 0
    },
    rgb: {
      x: 0
    },
    a: {
      x: 0
    }
  }),
      _useState6 = _slicedToArray(_useState5, 2),
      location = _useState6[0],
      setLocation = _useState6[1];

  var emitColor = function emitColor(tinyObj) {
    if (colorType === 'hex') {
      setInnerValue(tinyObj.toHex8String());
    } else {
      setInnerValue(tinyObj.toRgbString());
    }
  }; // 通用更新滑块位置函数


  var updateCursorLocation = function updateCursorLocation(tinyObj) {
    location.panel.x = tinyObj.toHsv().s;
    location.panel.y = 1 - tinyObj.toHsv().v;
    location.rgb.x = tinyObj.toHsv().h / 360;
    location.a.x = tinyObj.getAlpha();
    setLocation(_objectSpread2({}, location));
  }; // 传入一种颜色值 -> 更新全部颜色值


  var updateColor = function updateColor(color, alpha) {
    var tinyObj = tinycolor(color);
    tinyObj.setAlpha(alpha);
    colors.rgbVal = tinyObj.toRgbString();
    colors.hexVal = tinyObj.toHexString();
    colors.r = tinyObj.toRgb().r;
    colors.g = tinyObj.toRgb().g;
    colors.b = tinyObj.toRgb().b;
    colors.s = tinyObj.toHsv().s;
    colors.v = tinyObj.toHsv().v;
    colors.a = alpha;
    setColors(_objectSpread2({}, colors));
    emitColor(tinyObj);
  }; // 传入调色板坐标 -> 更新颜色


  var updatePanelColor = function updatePanelColor(x, y) {
    var hsv = "hsv(".concat(colors.h.toFixed(0), ", ").concat((x * 100).toFixed(0), "%, ").concat(((1 - y) * 100).toFixed(0), "%)");
    updateColor(hsv, colors.a); // 更新滑块位置

    location.panel.x = x;
    location.panel.y = y;
    setLocation(_objectSpread2({}, location));
  }; // 传入色阶柱坐标 -> 更新颜色


  var updateRgbColor = function updateRgbColor(x) {
    var currentX = x;
    currentX === 1 && (currentX = 0); // 左右极限值去重

    var currentHue = Math.round(currentX * 360 * 100) / 100; // 单独更新色阶

    colors.h = currentHue;
    setColors(_objectSpread2({}, colors)); // 更新全部颜色

    var hsv = "hsv(".concat(currentHue, ", ").concat(colors.s, ", ").concat(colors.v, ")");
    updateColor(hsv, colors.a); // 更新滑块位置

    location.rgb.x = x;
    setLocation(_objectSpread2({}, location));
  }; // 传入透明度柱坐标 -> 更新颜色


  var updateAColor = function updateAColor(x) {
    var currentX = Number(x.toFixed(2));
    updateColor(colors.rgbVal, currentX); // 更新滑块位置

    location.a.x = x;
    setLocation(_objectSpread2({}, location));
  }; // 移动调色板


  var handlePanelMove = function handlePanelMove(e) {
    var moveX = e.clientX - rect.panel.left;
    var moveY = e.clientY - rect.panel.top;
    var maxX = rect.panel.width;
    var maxY = rect.panel.height;
    var minX = 0;
    var minY = 0;
    moveX < minX && (moveX = minX);
    moveX > maxX && (moveX = maxX);
    moveY < minY && (moveY = minY);
    moveY > maxY && (moveY = maxY);
    updatePanelColor(moveX / maxX, moveY / maxY);
  };

  var handlePanelUp = function handlePanelUp() {
    handleMoving(false);
    window.removeEventListener('mousemove', handlePanelMove);
    window.removeEventListener('mouseup', handlePanelUp);
  }; // 移动色阶柱


  var handleRgbMove = function handleRgbMove(e) {
    var moveX = e.clientX - rect.rgb.left;
    var maxX = rect.rgb.width;
    var minX = 0;
    moveX < minX && (moveX = minX);
    moveX > maxX && (moveX = maxX);
    updateRgbColor(moveX / maxX);
  };

  var handleRgbUp = function handleRgbUp() {
    handleMoving(false);
    window.removeEventListener('mousemove', handleRgbMove);
    window.removeEventListener('mouseup', handleRgbUp);
  }; // 移动透明度柱


  var handleAMove = function handleAMove(e) {
    var moveX = e.clientX - rect.a.left;
    var maxX = rect.a.width;
    var minX = 0;
    moveX < minX && (moveX = minX);
    moveX > maxX && (moveX = maxX);
    updateAColor(moveX / maxX);
  };

  var handleAUp = function handleAUp() {
    handleMoving(false);
    window.removeEventListener('mousemove', handleAMove);
    window.removeEventListener('mouseup', handleAUp);
  };

  var handleUsualDown = function handleUsualDown(e, type) {
    e.persist();
    var downX = 0;
    var downY = 0;
    handleMoving(true);

    if (type === 'panel') {
      // 点击调色板 -> 更新颜色
      downX = e.clientX - rect.panel.left;
      downY = e.clientY - rect.panel.top;
      updatePanelColor(downX / rect.panel.width, downY / rect.panel.height); // 移动调色板 -> 更新颜色

      window.addEventListener('mousemove', handlePanelMove);
      window.addEventListener('mouseup', handlePanelUp);
    } else if (type === 'rgb') {
      // 点击色阶柱 -> 更新颜色
      downX = e.clientX - rect.rgb.left;
      updateRgbColor(downX / rect.rgb.width); // 移动色阶柱 -> 更新颜色

      window.addEventListener('mousemove', handleRgbMove);
      window.addEventListener('mouseup', handleRgbUp);
    } else {
      // 点击透明度柱 -> 更新颜色
      downX = e.clientX - rect.a.left;
      updateAColor(downX / rect.a.width); // 移动透明度柱 -> 更新颜色

      window.addEventListener('mousemove', handleAMove);
      window.addEventListener('mouseup', handleAUp);
    }
  }; // 通过更新颜色函数


  var handleUsualUpdate = function handleUsualUpdate(val) {
    var currentColor = tinycolor(val);
    updateColor(val, currentColor.getAlpha()); // 单独更新色阶

    colors.h = currentColor.toHsv().h;
    setColors(_objectSpread2({}, colors)); // 更新滑块位置

    updateCursorLocation(currentColor);
  }; // 选择颜色值类型


  var _useState7 = useState('hex'),
      _useState8 = _slicedToArray(_useState7, 2),
      colorType = _useState8[0],
      setColorType = _useState8[1];

  var handleSelect = function handleSelect(val) {
    if (disabled) return;
    setColorType(val);
  }; // RGBA 输入框变化时触发


  var inputChange = function inputChange(val, type) {
    var currentVal = Number(val);
    var color = '';

    if (type === 'r') {
      colors.r = currentVal;
      color = "rgba(".concat(val, ", ").concat(colors.g, ", ").concat(colors.b, ", ").concat(colors.a, ")");
    } else if (type === 'g') {
      colors.g = currentVal;
      color = "rgba(".concat(colors.r, ", ").concat(val, ", ").concat(colors.b, ", ").concat(colors.a, ")");
    } else {
      colors.b = currentVal;
      color = "rgba(".concat(colors.r, ", ").concat(colors.g, ", ").concat(val, ", ").concat(colors.a, ")");
    }

    setColors(_objectSpread2({}, colors));
    handleUsualUpdate(color);
  };

  var inputChangeR = function inputChangeR(val) {
    inputChange(val, 'r');
  };

  var inputChangeG = function inputChangeG(val) {
    inputChange(val, 'g');
  };

  var inputChangeB = function inputChangeB(val) {
    inputChange(val, 'b');
  };

  var inputChangeA = function inputChangeA(val) {
    var currentVal = Number(val) / 100;
    colors.a = currentVal;
    setColors(_objectSpread2({}, colors));
    updateAColor(currentVal);
  };

  var hexBackup = useRef('');

  var inputFocusHex = function inputFocusHex(val) {
    hexBackup.current = val;
  };

  var inputChangeHex = function inputChangeHex(val) {
    colors.hexVal = val;
    setColors(_objectSpread2({}, colors));
  };

  var inputBlurHex = function inputBlurHex(val) {
    var currentColor = tinycolor(val);
    currentColor.setAlpha(colors.a);

    if (currentColor.isValid()) {
      updateColor(val, colors.a); // 单独更新色阶

      colors.h = currentColor.toHsv().h;
      setColors(_objectSpread2({}, colors)); // 更新滑块位置

      updateCursorLocation(currentColor);
    } else {
      colors.hexVal = hexBackup.current;
      setColors(_objectSpread2({}, colors));
    }
  }; // 取色


  var handleClickDropper = /*#__PURE__*/function () {
    var _ref = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
      var eyeDropper, result, color;
      return regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              if (!disabled) {
                _context.next = 2;
                break;
              }

              return _context.abrupt("return");

            case 2:
              // @ts-ignore
              eyeDropper = new EyeDropper();
              _context.next = 5;
              return eyeDropper.open();

            case 5:
              result = _context.sent;
              color = result.sRGBHex;
              handleUsualUpdate(color);

            case 8:
            case "end":
              return _context.stop();
          }
        }
      }, _callee);
    }));

    return function handleClickDropper() {
      return _ref.apply(this, arguments);
    };
  }();

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-color-panel', disabled && 'i-color-panel__disabled', className),
    style: _objectSpread2({}, style)
  }, restProps), /*#__PURE__*/React.createElement("header", {
    className: "i-color-panel-header"
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-color-panel-header-txt"
  }, "\u989C\u8272\u9009\u62E9\u5668"), /*#__PURE__*/React.createElement("div", {
    className: "i-color-panel-header-icon",
    onClick: function onClick() {
      onClose === null || onClose === void 0 ? void 0 : onClose();
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "Close"
  }))), /*#__PURE__*/React.createElement("section", {
    className: "i-color-panel-block",
    style: {
      background: "hsl(".concat(colors.h, ", 100%, 50%)")
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-color-panel-block__white"
  }), /*#__PURE__*/React.createElement("div", {
    className: "i-color-panel-block__black",
    ref: panelNode,
    onMouseDown: function onMouseDown(e) {
      if (disabled) return;
      handleUsualDown(e, 'panel');
    }
  }), /*#__PURE__*/React.createElement(ColorCursor, {
    x: location.panel.x,
    y: location.panel.y,
    color: colors.rgbVal
  })), /*#__PURE__*/React.createElement("section", {
    className: "i-color-panel-controls"
  }, !!window.EyeDropper && /*#__PURE__*/React.createElement("div", {
    className: "i-color-panel-controls__dropper",
    onClick: handleClickDropper
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "Dropper"
  })), /*#__PURE__*/React.createElement("div", {
    className: "i-color-panel-controls__bar"
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-color-panel-bar__rgb",
    ref: rgbBarNode,
    onMouseDown: function onMouseDown(e) {
      if (disabled) return;
      handleUsualDown(e, 'rgb');
    }
  }, /*#__PURE__*/React.createElement(ColorCursor, {
    x: location.rgb.x,
    mode: "x"
  })), /*#__PURE__*/React.createElement("div", {
    className: "i-color-panel-bar__a",
    ref: aBarNode,
    onMouseDown: function onMouseDown(e) {
      if (disabled) return;
      handleUsualDown(e, 'a');
    }
  }, /*#__PURE__*/React.createElement(ColorCursor, {
    mode: "x",
    x: location.a.x,
    style: {
      background: 'rgba(0, 0, 0, 0.4)'
    }
  }), /*#__PURE__*/React.createElement("section", {
    className: "i-color-panel-bar__a-color",
    style: {
      background: "linear-gradient(90deg, rgba(255, 0, 0, 0) 0%, hsl(".concat(colors.h, ", 100%, 50%) 100%)")
    }
  }), /*#__PURE__*/React.createElement("section", {
    className: "i-color-panel-bar__a-bg"
  })))), /*#__PURE__*/React.createElement("section", {
    className: "i-color-panel-values"
  }, /*#__PURE__*/React.createElement(Select, {
    width: 60,
    value: colorType,
    size: "small",
    disabled: disabled,
    clearable: false,
    onChange: handleSelect
  }, /*#__PURE__*/React.createElement(Select.Item, {
    value: "hex"
  }, "Hex"), /*#__PURE__*/React.createElement(Select.Item, {
    value: "rgb"
  }, "RGB")), /*#__PURE__*/React.createElement("div", {
    className: "i-color-panel-input__wrapper"
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-color-panel-input__class"
  }, colorType === 'hex' ? /*#__PURE__*/React.createElement(Input, {
    value: colors.hexVal,
    size: "small",
    disabled: disabled,
    onFocus: inputFocusHex,
    onChange: inputChangeHex,
    onBlur: inputBlurHex
  }) : /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Input, {
    value: colors.r.toFixed(0),
    type: "number",
    size: "small",
    maxNumber: 255,
    minNumber: 0,
    selectAll: true,
    hideNumberBtn: true,
    onChange: inputChangeR
  }), /*#__PURE__*/React.createElement(Input, {
    value: colors.g.toFixed(0),
    type: "number",
    size: "small",
    maxNumber: 255,
    minNumber: 0,
    selectAll: true,
    hideNumberBtn: true,
    onChange: inputChangeG
  }), /*#__PURE__*/React.createElement(Input, {
    value: colors.b.toFixed(0),
    type: "number",
    size: "small",
    maxNumber: 255,
    minNumber: 0,
    selectAll: true,
    hideNumberBtn: true,
    onChange: inputChangeB
  }))), /*#__PURE__*/React.createElement("div", {
    className: "i-color-panel-input__alpha"
  }, /*#__PURE__*/React.createElement(Input, {
    value: (colors.a * 100).toFixed(0),
    type: "number",
    size: "small",
    disabled: disabled,
    maxNumber: 100,
    minNumber: 0,
    selectAll: true,
    hideNumberBtn: true,
    onChange: inputChangeA
  })))), /*#__PURE__*/React.createElement("footer", {
    className: "i-color-panel-footer"
  }, colorList.map(function (item) {
    return /*#__PURE__*/React.createElement(ColorItem, {
      color: item === null || item === void 0 ? void 0 : item.value,
      key: item === null || item === void 0 ? void 0 : item.value,
      onClick: function onClick() {
        if (disabled) return;
        handleUsualUpdate(item === null || item === void 0 ? void 0 : item.value);
      }
    });
  })));
};

var _excluded$u = ["className", "style", "triggerClassName", "triggerStyle", "size", "value", "defaultValue", "colorList", "disabled", "onChange", "onTrigger"];
var defaultColor = [{
  value: 'rgb(206, 55, 46)'
}, {
  value: 'rgb(237, 149, 160)'
}, {
  value: 'rgb(252, 238, 239)'
}, {
  value: 'rgb(232, 109, 44)'
}, {
  value: 'rgb(245, 192, 66)'
}, {
  value: 'rgb(238, 209, 103)'
}, {
  value: 'rgb(127, 225, 89)'
}, {
  value: 'rgb(114, 212, 183)'
}, {
  value: 'rgb(135, 214, 230)'
}, {
  value: 'rgb(216, 238, 242)'
}, {
  value: 'rgb(86, 116, 245)'
}, {
  value: 'rgb(103, 98, 192)'
}, {
  value: 'rgb(223, 221, 252)'
}, {
  value: 'rgb(92, 192, 131)'
}, {
  value: 'rgb(210, 90, 182)'
}];

var ColorPicker = function ColorPicker(props) {
  var className = props.className,
      style = props.style,
      triggerClassName = props.triggerClassName,
      triggerStyle = props.triggerStyle,
      size = props.size,
      value = props.value,
      _props$defaultValue = props.defaultValue,
      defaultValue = _props$defaultValue === void 0 ? '#5e62ea' : _props$defaultValue,
      _props$colorList = props.colorList,
      colorList = _props$colorList === void 0 ? defaultColor : _props$colorList,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      onChange = props.onChange,
      onTrigger = props.onTrigger,
      restProps = _objectWithoutProperties(props, _excluded$u);

  var _useDefault = useDefault(value, defaultValue, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerValue = _useDefault2[0],
      setInnerValue = _useDefault2[1];

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      visible = _useState2[0],
      setVisible = _useState2[1];

  var currentColor = useRef(innerValue);

  var handleChange = function handleChange(val) {
    if (currentColor.current !== val) {
      setInnerValue(val);
      currentColor.current = val;
    }
  };

  var popupChange = function popupChange(val) {
    setVisible(val);
    onTrigger === null || onTrigger === void 0 ? void 0 : onTrigger(currentColor.current, val);
  };

  var handleClose = function handleClose() {
    setVisible(false);
    onTrigger === null || onTrigger === void 0 ? void 0 : onTrigger(currentColor.current, false);
  };

  var colorPanel = useMemo(function () {
    return /*#__PURE__*/React.createElement(ColorPanel, {
      value: innerValue,
      colorList: colorList,
      onChange: handleChange,
      onClose: handleClose
    });
  }, [visible]);
  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-color-picker', className),
    style: _objectSpread2({}, style)
  }, restProps), /*#__PURE__*/React.createElement(Popup, {
    visible: visible,
    content: colorPanel,
    disabled: disabled,
    trigger: "click",
    placement: 'bottom-start',
    noPadding: true,
    onTrigger: popupChange
  }, /*#__PURE__*/React.createElement("div", {
    className: classNames('i-color', disabled && 'i-color__disabled', size && "i-color--size-".concat(size), triggerClassName),
    style: _objectSpread2(_objectSpread2({}, triggerStyle), {}, {
      background: innerValue
    })
  })));
};

ColorPicker.Panel = ColorPanel;
ColorPanel.displayName = 'ColorPanel';
ColorPicker.displayName = 'ColorPicker';

var css_248z$q = ".i-table {\n  width: 100%;\n  color: var(--i-font-2);\n  font-size: 14px;\n}\n\n.i-table-thead__wrapper,\n.i-table-tbody__wrapper {\n  display: table;\n  width: 100%;\n  min-width: 100%;\n  margin: 0;\n  table-layout: fixed;\n  border-collapse: separate;\n  border-spacing: 0;\n}\n\n.i-table-tbody__box {\n  box-sizing: border-box;\n  overflow: auto;\n  overflow: overlay;\n  border: 1px solid var(--i-border);\n  border-radius: 0 0 8px 8px;\n}\n.i-table-tbody__box::-webkit-scrollbar-button {\n  display: none;\n}\n\n.i-table-thead {\n  background: var(--i-bg-hover);\n}\n.i-table-thead .i-table-th {\n  border-top: 1px solid var(--i-border);\n}\n.i-table-thead .i-table-th:first-of-type {\n  border-left: 1px solid var(--i-border);\n  border-radius: 8px 0 0 0;\n}\n.i-table-thead .i-table-th:last-of-type {\n  border-right: 1px solid var(--i-border);\n  border-radius: 0 8px 0 0;\n}\n\n.i-table-th,\n.i-table-td {\n  box-sizing: border-box;\n  padding: 9px 16px;\n  text-align: left;\n  border: unset;\n}\n.i-table-th:first-of-type,\n.i-table-td:first-of-type {\n  border-left: none;\n}\n.i-table-th:last-of-type,\n.i-table-td:last-of-type {\n  border-right: none;\n}\n\n.i-table-td {\n  border-bottom: 1px solid var(--i-border);\n}\n\n.i-table-tbody {\n  overflow: auto;\n  overflow: overlay;\n  background: var(--i-bg);\n}\n.i-table-tbody .i-table-tr {\n  background: unset;\n}\n.i-table-tbody .i-table-tr:last-of-type .i-table-td {\n  border-bottom: none;\n}\n.i-table-tbody .i-table-tr:last-of-type .i-table-td:first-of-type {\n  border-radius: 0 0 0 8px;\n}\n.i-table-tbody .i-table-tr:last-of-type .i-table-td:last-of-type {\n  border-radius: 0 0 8px 0;\n}\n.i-table-tbody.i-table-tbody__stripe .i-table-tr:nth-of-type(even) {\n  background: var(--i-bg-hover);\n}";
styleInject(css_248z$q);

var ColumnGroup = function ColumnGroup(props) {
  var _props$columns = props.columns,
      columns = _props$columns === void 0 ? [] : _props$columns;
  var columnWidths = columns.map(function (ele) {
    return ele.width;
  }).join("-");
  var cols = useMemo(function () {
    var cols = [];
    var mustInsert = false;

    for (var i = columns.length; i >= 0; i--) {
      var width = columns[i] && columns[i].width;

      if (width || mustInsert) {
        cols.unshift( /*#__PURE__*/React.createElement("col", {
          key: i,
          width: width,
          style: {
            width: width,
            minWidth: width,
            textAlign: columns[i].align
          }
        }));
        mustInsert = true;
      }
    }

    return cols;
  }, [columnWidths]);
  return /*#__PURE__*/React.createElement("colgroup", null, cols);
};

var TableHead = function TableHead(props) {
  var _props$columns = props.columns,
      columns = _props$columns === void 0 ? [] : _props$columns;
  return /*#__PURE__*/React.createElement("table", {
    className: "i-table-thead__wrapper"
  }, /*#__PURE__*/React.createElement(ColumnGroup, {
    columns: columns
  }), /*#__PURE__*/React.createElement("thead", {
    className: 'i-table-thead'
  }, /*#__PURE__*/React.createElement("tr", {
    className: 'i-table-tr'
  }, columns.map(function (column) {
    return /*#__PURE__*/React.createElement("th", {
      className: "i-table-th",
      key: column.key
    }, column.title);
  }))));
};

var TableBody = function TableBody(props) {
  var _props$data = props.data,
      data = _props$data === void 0 ? [] : _props$data,
      _props$columns = props.columns,
      columns = _props$columns === void 0 ? [] : _props$columns,
      maxHeight = props.maxHeight,
      _props$stripe = props.stripe,
      stripe = _props$stripe === void 0 ? false : _props$stripe;
  return /*#__PURE__*/React.createElement("div", {
    className: "i-table-tbody__box",
    style: {
      maxHeight: maxHeight
    }
  }, /*#__PURE__*/React.createElement("table", {
    className: "i-table-tbody__wrapper"
  }, /*#__PURE__*/React.createElement(ColumnGroup, {
    columns: columns
  }), /*#__PURE__*/React.createElement("tbody", {
    className: classNames('i-table-tbody', stripe && 'i-table-tbody__stripe')
  }, data.map(function (item) {
    return /*#__PURE__*/React.createElement("tr", {
      className: 'i-table-tr',
      key: item.key
    }, columns.map(function (cell) {
      return /*#__PURE__*/React.createElement("td", {
        className: "i-table-td",
        key: cell.key
      }, item[cell.key]);
    }));
  }))));
};

var _excluded$v = ["className", "style", "columns", "data", "maxHeight", "stripe"];

var Table = function Table(props) {
  var className = props.className,
      style = props.style,
      _props$columns = props.columns,
      columns = _props$columns === void 0 ? [] : _props$columns,
      _props$data = props.data,
      data = _props$data === void 0 ? [] : _props$data,
      maxHeight = props.maxHeight,
      _props$stripe = props.stripe,
      stripe = _props$stripe === void 0 ? false : _props$stripe,
      restProps = _objectWithoutProperties(props, _excluded$v);

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-table', className),
    style: _objectSpread2({}, style)
  }, restProps), /*#__PURE__*/React.createElement(TableHead, {
    columns: columns
  }), /*#__PURE__*/React.createElement(TableBody, {
    columns: columns,
    data: data,
    maxHeight: maxHeight,
    stripe: stripe
  }));
};

Table.displayName = 'Table';

var css_248z$r = ".i-upload {\n  color: var(--i-font-2);\n  font-size: 14px;\n}\n\n.i-upload__block {\n  display: flex;\n  flex-direction: column;\n  gap: 8px;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  width: 100px;\n  height: 100px;\n  border: 1px dashed var(--i-border);\n  border-radius: 8px;\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\n.i-upload__block:hover {\n  border-color: var(--i-border-hover);\n}\n\n.i-upload__drag {\n  display: flex;\n  flex-direction: column;\n  gap: 6px;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  width: 320px;\n  padding: 12px 0;\n  background: var(--i-bg-hover);\n  border: 1px dashed var(--i-border);\n  border-radius: 8px;\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\n.i-upload__drag:hover {\n  border-color: var(--i-border-hover);\n}\n.i-upload__drag.i-upload__dragging {\n  border-color: var(--i-primary);\n}\n\n.i-upload-placeholder {\n  color: var(--i-font-4);\n}\n\n.i-upload-tip {\n  color: var(--i-font-5);\n  font-size: 12px;\n}";
styleInject(css_248z$r);

var css_248z$s = ".i-message {\n  display: flex;\n  align-items: center;\n  box-sizing: border-box;\n  width: -webkit-fit-content;\n  width: -moz-fit-content;\n  width: fit-content;\n  padding: 10px 16px;\n  overflow: hidden;\n  color: var(--i-font-2);\n  font-size: 14px;\n  background-color: var(--i-bg);\n  border-radius: 6px;\n  outline: 0;\n  box-shadow: var(--i-shadow);\n}\n.i-message .i-icon {\n  margin-right: 8px;\n}\n.i-message .icon-TipInfo {\n  color: var(--i-primary);\n}\n.i-message .icon-TipCheckFill {\n  color: var(--i-success);\n}\n.i-message .icon-TipWarningFill {\n  color: var(--i-warning);\n}\n.i-message .icon-TipCloseFill {\n  color: var(--i-error);\n}\n\n.i-message-wrapper {\n  position: fixed;\n  top: 20px;\n  left: 50%;\n  z-index: 5000;\n  transform: translateX(-50%);\n}\n.i-message-wrapper > div {\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n}\n.i-message-wrapper.i-message-wrapper__bottom {\n  top: unset;\n  bottom: 20px;\n}\n\n.i-message-wrapper__top .i-message:not(:last-of-type) {\n  margin-bottom: 16px;\n}\n\n.i-message-wrapper__bottom .i-message:not(:first-of-type) {\n  margin-top: 16px;\n}\n\n.i-message-top-enter {\n  transform: translateY(-100%);\n  opacity: 0;\n}\n\n.i-message-top-enter-active {\n  transform: translate(0);\n  opacity: 1;\n  transition: all 300ms ease-out;\n}\n\n.i-message-top-exit {\n  opacity: 1;\n}\n\n.i-message-top-exit-active {\n  height: 0 !important;\n  margin-bottom: 0 !important;\n  padding: 0 16px !important;\n  transform: translateY(-100%);\n  opacity: 0;\n  transition: all 300ms ease-out;\n}\n\n.i-message-bottom-enter {\n  transform: translateY(100%);\n  opacity: 0;\n}\n\n.i-message-bottom-enter-active {\n  transform: translate(0);\n  opacity: 1;\n  transition: all 300ms ease-out;\n}\n\n.i-message-bottom-exit {\n  opacity: 1;\n}\n\n.i-message-bottom-exit-active {\n  height: 0 !important;\n  margin-top: 0 !important;\n  padding: 0 16px !important;\n  transform: translateY(100%);\n  opacity: 0;\n  transition: all 300ms ease-out;\n}";
styleInject(css_248z$s);

var _excluded$w = ["type", "content", "entered"];

var Message = function Message(props) {
  var _props$type = props.type,
      type = _props$type === void 0 ? 'info' : _props$type,
      content = props.content,
      _props$entered = props.entered,
      entered = _props$entered === void 0 ? false : _props$entered,
      restProps = _objectWithoutProperties(props, _excluded$w);

  var msgRef = useRef(null);

  var _useState = useState(undefined),
      _useState2 = _slicedToArray(_useState, 2),
      msgHeight = _useState2[0],
      setMsgHeight = _useState2[1];

  useEffect(function () {
    if (entered) {
      var _msgRef$current$getBo = msgRef.current.getBoundingClientRect(),
          height = _msgRef$current$getBo.height;

      setMsgHeight(height);
    }
  }, [entered]);
  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: "i-message",
    style: {
      height: msgHeight
    },
    ref: msgRef
  }, restProps), /*#__PURE__*/React.createElement(Icon, {
    name: {
      info: 'TipInfo',
      success: 'TipCheckFill',
      warning: 'TipWarningFill',
      error: 'TipCloseFill'
    }[type],
    size: 20
  }), content);
};

Message.displayName = 'Message';

var MessageList = function MessageList(props) {
  var listData = props.listData,
      _props$position = props.position,
      position = _props$position === void 0 ? 'top' : _props$position;

  var _useState = useState([]),
      _useState2 = _slicedToArray(_useState, 2),
      enteredIds = _useState2[0],
      setEnteredIds = _useState2[1];

  var handleEntered = function handleEntered(id) {
    enteredIds.push(id);
    setEnteredIds(_toConsumableArray(enteredIds));
  };

  return /*#__PURE__*/React.createElement(TransitionGroup, null, listData.map(function (_ref) {
    var id = _ref.id,
        type = _ref.type,
        content = _ref.content;
    return /*#__PURE__*/React.createElement(Transition, {
      timeout: 300,
      in: true,
      animation: "message-".concat(position),
      key: id,
      onEntered: function onEntered() {
        return handleEntered(id);
      }
    }, /*#__PURE__*/React.createElement(Message, {
      type: type,
      content: content,
      entered: enteredIds.includes(id)
    }));
  }));
};

MessageList.displayName = 'MessageList';

var popupWrapper$1 = useContainer('i-popup-wrapper', document.body);
var messageWrapper = useContainer('i-message-container', popupWrapper$1);
var messageList = {
  top: [],
  bottom: []
};

var createMessageWrapper = function createMessageWrapper(position) {
  var idName = "i-message-wrapper__".concat(position);
  var container = useContainer(idName, messageWrapper, "i-message-wrapper ".concat(idName));
  ReactDOM.render( /*#__PURE__*/React.createElement(MessageList, {
    position: position,
    listData: messageList[position]
  }), container);
};

createMessageWrapper('top');
createMessageWrapper('bottom');

var getWrapper = function getWrapper(position) {
  return document.querySelector("#i-message-wrapper__".concat(position));
};

var updateMessageWrapper = function updateMessageWrapper(config) {
  var _config$id = config.id,
      id = _config$id === void 0 ? 0 : _config$id,
      _config$position = config.position,
      position = _config$position === void 0 ? 'top' : _config$position,
      _config$duration = config.duration,
      duration = _config$duration === void 0 ? 3 : _config$duration;
  position === 'top' ? messageList[position].push(config) : messageList[position].unshift(config);
  var renderContainer = getWrapper(position); // 延迟消除

  if (duration > 0) {
    setTimeout(function () {
      messageList[position].map(function (item, index) {
        if (item.id === id) {
          messageList[position].splice(index, 1);
        }
      });
      ReactDOM.render( /*#__PURE__*/React.createElement(MessageList, {
        position: position,
        listData: messageList[position]
      }), renderContainer);
    }, duration * 1000);
  } // 此刻更新


  ReactDOM.render( /*#__PURE__*/React.createElement(MessageList, {
    position: position,
    listData: messageList[position]
  }), renderContainer);
};

var openMessage = function openMessage(type, messageConfig) {
  var _messageConfig$durati, _messageConfig$positi;

  var duration = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 3;
  var position = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'top';
  var isConfigMode = _typeof(messageConfig) === 'object' && ! /*#__PURE__*/React.isValidElement(messageConfig);
  var mergeConfig = {
    id: Date.now(),
    type: type,
    content: isConfigMode ? messageConfig === null || messageConfig === void 0 ? void 0 : messageConfig.content : messageConfig,
    duration: isConfigMode ? (_messageConfig$durati = messageConfig === null || messageConfig === void 0 ? void 0 : messageConfig.duration) !== null && _messageConfig$durati !== void 0 ? _messageConfig$durati : 3 : duration,
    position: isConfigMode ? (_messageConfig$positi = messageConfig === null || messageConfig === void 0 ? void 0 : messageConfig.position) !== null && _messageConfig$positi !== void 0 ? _messageConfig$positi : 'top' : position
  };
  updateMessageWrapper(mergeConfig);
};

var clearMessage = function clearMessage(position) {
  var positionArr = ['top', 'bottom'];

  if (position) {
    messageList[position] = [];
    ReactDOM.render( /*#__PURE__*/React.createElement(MessageList, {
      position: position,
      listData: []
    }), getWrapper(position));
  } else {
    positionArr.forEach(function (item) {
      messageList[item] = [];
      ReactDOM.render( /*#__PURE__*/React.createElement(MessageList, {
        position: item,
        listData: []
      }), getWrapper(item));
    });
  }
};

Message.info = function (messageConfig, duration, position) {
  return openMessage('info', messageConfig, duration, position);
};

Message.success = function (messageConfig, duration, position) {
  return openMessage('success', messageConfig, duration, position);
};

Message.warning = function (messageConfig, duration, position) {
  return openMessage('warning', messageConfig, duration, position);
};

Message.error = function (messageConfig, duration, position) {
  return openMessage('error', messageConfig, duration, position);
};

Message.clear = function (position) {
  return clearMessage(position);
};

Message.displayName = 'Message';

var _excluded$x = ["children", "className", "style", "placeholder", "theme", "maxSize", "onChange"];

var Upload = function Upload(props) {
  var defaultPlaceHolder = props.theme === 'drag' ? '点击或拖动到框内上传' : '点击上传';

  var children = props.children,
      className = props.className,
      style = props.style,
      _props$placeholder = props.placeholder,
      placeholder = _props$placeholder === void 0 ? defaultPlaceHolder : _props$placeholder,
      _props$theme = props.theme,
      theme = _props$theme === void 0 ? 'button' : _props$theme,
      _props$maxSize = props.maxSize,
      maxSize = _props$maxSize === void 0 ? 10 : _props$maxSize,
      onChange = props.onChange,
      restProps = _objectWithoutProperties(props, _excluded$x);

  var MAX_SIZE = useMemo(function () {
    return maxSize * 1024 * 1024;
  }, [maxSize]);
  var inputRef = useRef(null);

  var handleClickInput = function handleClickInput() {
    var _inputRef$current;

    (_inputRef$current = inputRef.current) === null || _inputRef$current === void 0 ? void 0 : _inputRef$current.click();
  };

  var uploadFile = function uploadFile(file) {
    if (file) {
      if (file.size > MAX_SIZE) {
        var unit = MAX_SIZE > 1 * 1024 ? 'M' : 'kb';
        var size = MAX_SIZE > 1 * 1024 ? maxSize : maxSize * 1024;
        Message.error("\u6587\u4EF6\u5927\u5C0F\u4E0D\u5F97\u8D85\u8FC7 ".concat(size, " ").concat(unit));
      } else {
        onChange === null || onChange === void 0 ? void 0 : onChange(file);
      }
    }
  };

  var handleUpload = function handleUpload(e) {
    e.persist();
    var file = (e.target.files || [])[0];
    uploadFile(file);
  };

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      ifDragIn = _useState2[0],
      setIfDragIn = _useState2[1];

  var handleDragOver = function handleDragOver(e) {
    e.preventDefault();
    setIfDragIn(true);
  };

  var handleDragLeave = function handleDragLeave(e) {
    setIfDragIn(false);
  };

  var handleDragDrop = function handleDragDrop(e) {
    e.preventDefault();
    var file = e.dataTransfer.files[0];
    uploadFile(file);
    setIfDragIn(false);
  };

  var renderUpload = function renderUpload() {
    if (theme === 'button') {
      return /*#__PURE__*/React.createElement(Button, {
        type: "info",
        variant: "outline",
        icon: "ArrowLineUpload"
      }, placeholder);
    } else if (theme === 'block') {
      return /*#__PURE__*/React.createElement("div", {
        className: "i-upload__block"
      }, /*#__PURE__*/React.createElement(Icon, {
        name: "ThePlus",
        size: 20
      }), placeholder);
    } else if (theme === 'drag') {
      return /*#__PURE__*/React.createElement("div", {
        className: classNames('i-upload__drag', ifDragIn && 'i-upload__dragging'),
        draggable: true,
        onDragOver: handleDragOver,
        onDragLeave: handleDragLeave,
        onDrop: handleDragDrop
      }, /*#__PURE__*/React.createElement(Icon, {
        name: "ArrowLineUpload",
        size: 20
      }), /*#__PURE__*/React.createElement("span", {
        className: 'i-upload-placeholder'
      }, placeholder), /*#__PURE__*/React.createElement("span", {
        className: 'i-upload-tip'
      }, "\u652F\u6301\u4E0D\u8D85\u8FC7 10M \u7684 excel \u7C7B\u578B\u6587\u4EF6"));
    }
  };

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-upload', className),
    style: _objectSpread2({}, style),
    onClick: handleClickInput
  }, restProps), /*#__PURE__*/React.createElement("input", {
    type: "file",
    style: {
      display: 'none'
    },
    ref: inputRef,
    onChange: handleUpload
  }), children ? children : renderUpload());
};

Upload.displayName = 'Upload';

var css_248z$t = ".i-slider {\n  position: relative;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  width: 100%;\n  height: 20px;\n  cursor: pointer;\n}\n.i-slider.i-slider__layout-vertical {\n  width: 20px;\n  height: 100%;\n}\n.i-slider.i-slider__layout-vertical .i-slider__bar {\n  width: 6px;\n  height: 100%;\n}\n.i-slider.i-slider__layout-vertical .i-slider__button {\n  top: 0;\n  left: 50%;\n  transform: translateX(-50%);\n}\n.i-slider.i-slider__disabled {\n  cursor: not-allowed;\n}\n.i-slider.i-slider__disabled .i-slider__bar {\n  background-color: var(--i-primary-disabled);\n}\n.i-slider.i-slider__disabled .i-slider__button {\n  border-color: var(--i-primary-disabled);\n}\n\n.i-slider__bar {\n  position: relative;\n  width: 100%;\n  height: 6px;\n  overflow: hidden;\n  background-color: var(--i-primary);\n  border-radius: 3px;\n}\n\n.i-slider__bar-active {\n  position: absolute;\n  width: 100%;\n  height: 100%;\n  background-color: var(--i-bg-active);\n}\n\n.i-slider__button {\n  position: absolute;\n  top: 50%;\n  left: 0;\n  box-sizing: border-box;\n  width: 20px;\n  height: 20px;\n  background: #fff;\n  border: 2px solid var(--i-primary);\n  border-radius: 50%;\n  transform: translateY(-50%);\n}";
styleInject(css_248z$t);

var SliderBtn = function SliderBtn(props) {
  var _props$layout = props.layout,
      layout = _props$layout === void 0 ? 'horizontal' : _props$layout,
      _props$currentVal = props.currentVal,
      currentVal = _props$currentVal === void 0 ? 0 : _props$currentVal,
      _props$max = props.max,
      max = _props$max === void 0 ? 100 : _props$max,
      _props$min = props.min,
      min = _props$min === void 0 ? 0 : _props$min,
      _props$downSlider = props.downSlider,
      downSlider = _props$downSlider === void 0 ? false : _props$downSlider,
      _props$hideTip = props.hideTip,
      hideTip = _props$hideTip === void 0 ? false : _props$hideTip,
      _props$placement = props.placement,
      placement = _props$placement === void 0 ? 'top' : _props$placement;

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      enterShowTip = _useState2[0],
      setEnterShowTip = _useState2[1];

  var btnRef = useRef(null);

  var _useState3 = useState({
    width: 0,
    height: 0
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      rect = _useState4[0],
      setRect = _useState4[1];

  useEffect(function () {
    var _btnRef$current, _btnRef$current2;

    rect.width = ((_btnRef$current = btnRef.current) === null || _btnRef$current === void 0 ? void 0 : _btnRef$current.getBoundingClientRect().width) || 0;
    rect.height = ((_btnRef$current2 = btnRef.current) === null || _btnRef$current2 === void 0 ? void 0 : _btnRef$current2.getBoundingClientRect().height) || 0;
    setRect(_objectSpread2({}, rect));
  }, []);

  var getBtnStyle = function getBtnStyle() {
    if (layout === 'horizontal') {
      return {
        left: "calc(".concat((currentVal - min) / (max - min) * 100, "% - ").concat(rect.width / 2, "px)")
      };
    } else {
      return {
        top: "calc(".concat((currentVal - min) / (max - min) * 100, "% - ").concat(rect.height / 2, "px)")
      };
    }
  };

  return /*#__PURE__*/React.createElement(Popup, {
    content: currentVal,
    trigger: "hover",
    visible: !hideTip && (downSlider || enterShowTip),
    placement: placement
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-slider__button",
    ref: btnRef,
    style: getBtnStyle(),
    onMouseEnter: function onMouseEnter() {
      return setEnterShowTip(true);
    },
    onMouseLeave: function onMouseLeave() {
      return setEnterShowTip(false);
    }
  }));
};

var getNearNum = function getNearNum(numArr, num) {
  var newArr = _.cloneDeep(numArr);

  newArr.push(num);
  newArr.sort();
  var nearNum = 0;

  for (var i = 0, len = newArr.length; i < len; i++) {
    if (newArr[i] === num) {
      if (i === 0) {
        nearNum = numArr[0];
      } else if (i === len - 1) {
        nearNum = numArr[numArr.length - 1];
      } else {
        if (Math.abs(newArr[i - 1] - num) < Math.abs(newArr[i + 1] - num)) {
          nearNum = newArr[i - 1];
        } else {
          nearNum = newArr[i + 1];
        }
      }
    }
  }

  return nearNum;
};

var Slider = function Slider(props) {
  var className = props.className,
      style = props.style,
      _props$layout = props.layout,
      layout = _props$layout === void 0 ? 'horizontal' : _props$layout,
      value = props.value,
      _props$defaultValue = props.defaultValue,
      defaultValue = _props$defaultValue === void 0 ? !props.range ? props.min || 0 : [props.min || 0, props.max || 0] : _props$defaultValue,
      _props$disabled = props.disabled,
      disabled = _props$disabled === void 0 ? false : _props$disabled,
      _props$max = props.max,
      max = _props$max === void 0 ? 100 : _props$max,
      _props$min = props.min,
      min = _props$min === void 0 ? 0 : _props$min,
      _props$step = props.step,
      step = _props$step === void 0 ? 1 : _props$step,
      _props$range = props.range,
      range = _props$range === void 0 ? false : _props$range,
      _props$hideTip = props.hideTip,
      _props$placement = props.placement,
      onChange = props.onChange;

  var _useDefault = useDefault(value, defaultValue, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerValue = _useDefault2[0],
      setInnerValue = _useDefault2[1];

  var slider = useRef(null);

  var _useState = useState({
    left: 0,
    top: 0,
    width: 0,
    height: 0
  }),
      _useState2 = _slicedToArray(_useState, 2),
      rect = _useState2[0],
      setRect = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      downStatus = _useState4[0],
      setDownStatus = _useState4[1]; // 是否为移动状态


  var setMoving = function setMoving(ifMoving) {
    setDownStatus(ifMoving);

    if (ifMoving) {
      document.body.style.userSelect = 'none';
    } else {
      document.body.style.userSelect = '';
    }
  }; // 精度


  var _useState5 = useState(0),
      _useState6 = _slicedToArray(_useState5, 2),
      stepPrecision = _useState6[0],
      setStepPrecision = _useState6[1];

  useEffect(function () {
    var _String$split$;

    setStepPrecision((_String$split$ = String(step).split('.')[1]) === null || _String$split$ === void 0 ? void 0 : _String$split$.length);
  }, []); // 所有可取值的位置

  var positionArr = useMemo(function () {
    var result = [];

    for (var i = min; i <= max; i = _.add(i, step)) {
      result.push((i - min) / (max - min));
    }

    return result;
  }, [max, min, step]);

  var positTurnVal = function positTurnVal(movePercent) {
    return min + _.round((max - min) * getNearNum(positionArr, movePercent), stepPrecision);
  };

  var lastVal = useRef(0);

  var handleSliderMove = _.throttle(function (e) {
    var move = 0;
    var minMove = 0;
    var maxMove = 0;

    if (layout === 'horizontal') {
      move = e.clientX - rect.left;
      maxMove = rect.width;
    } else {
      move = e.clientY - rect.top;
      maxMove = rect.height;
    }

    move < minMove && (move = minMove);
    move > maxMove && (move = maxMove);
    var movePercent = move / maxMove;
    var newVal = positTurnVal(movePercent);
    if (newVal === lastVal.current) return;
    updateInnerValue(newVal);
    lastVal.current = newVal;
  }, 16);

  var handleSliderUp = function handleSliderUp() {
    setMoving(false);
    window.removeEventListener('mousemove', handleSliderMove);
    window.removeEventListener('mouseup', handleSliderUp);
  };

  var getBtnRect = function getBtnRect() {
    var _slider$current;

    var curRect = (_slider$current = slider.current) === null || _slider$current === void 0 ? void 0 : _slider$current.getBoundingClientRect();
    rect.left = (curRect === null || curRect === void 0 ? void 0 : curRect.left) || 0;
    rect.top = (curRect === null || curRect === void 0 ? void 0 : curRect.top) || 0;
    rect.width = (curRect === null || curRect === void 0 ? void 0 : curRect.width) || 0;
    rect.height = (curRect === null || curRect === void 0 ? void 0 : curRect.height) || 0;
    setRect(_objectSpread2({}, rect));
  };

  var updateInnerValue = function updateInnerValue(val) {
    if (!range) {
      setInnerValue(val);
    } else {
      if (Math.abs(val - innerValue[0]) < Math.abs(val - innerValue[1])) {
        innerValue[0] = val;
      } else {
        innerValue[1] = val;
      }

      setInnerValue(_toConsumableArray(innerValue));
    }
  };

  var handleSliderDown = function handleSliderDown(e) {
    if (!disabled) {
      e.persist();
      setMoving(true);
      getBtnRect();
      var movePercent = 0;

      if (layout === 'horizontal') {
        movePercent = (e.clientX - rect.left) / rect.width;
      } else {
        movePercent = (e.clientY - rect.top) / rect.height;
      }

      var newVal = positTurnVal(movePercent);
      lastVal.current = newVal;
      updateInnerValue(newVal);
      window.addEventListener('mousemove', handleSliderMove);
      window.addEventListener('mouseup', handleSliderUp);
    }
  };

  var singleSlider = /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: "i-slider__bar"
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-slider__bar-active",
    style: {
      left: layout === 'horizontal' ? "".concat((innerValue - min) / (max - min) * 100, "%") : 0,
      top: layout === 'vertical' ? "".concat((innerValue - min) / (max - min) * 100, "%") : 0
    }
  })), /*#__PURE__*/React.createElement(SliderBtn, _objectSpread2({
    currentVal: innerValue,
    downSlider: downStatus
  }, props)));
  var rangeSlider = /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: "i-slider__bar"
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-slider__bar-active",
    style: {
      left: 0,
      top: 0,
      width: layout === 'horizontal' ? "".concat((innerValue[0] - min) / (max - min) * 100, "%") : 6,
      height: layout === 'vertical' ? "".concat((innerValue[0] - min) / (max - min) * 100, "%") : 6
    }
  }), /*#__PURE__*/React.createElement("div", {
    className: "i-slider__bar-active",
    style: {
      left: layout === 'horizontal' ? "".concat((innerValue[1] - min) / (max - min) * 100, "%") : 0,
      top: layout === 'vertical' ? "".concat((innerValue[1] - min) / (max - min) * 100, "%") : 0
    }
  })), /*#__PURE__*/React.createElement(SliderBtn, _objectSpread2({
    currentVal: innerValue[0],
    downSlider: downStatus
  }, props)), /*#__PURE__*/React.createElement(SliderBtn, _objectSpread2({
    currentVal: innerValue[1],
    downSlider: downStatus
  }, props)));
  return /*#__PURE__*/React.createElement("div", {
    className: classNames('i-slider', layout === 'vertical' && "i-slider__layout-".concat(layout), disabled && 'i-slider__disabled', className),
    style: _objectSpread2({}, style),
    ref: slider,
    onMouseDown: handleSliderDown
  }, !range && !_.isArray(innerValue) && singleSlider, range && _.isArray(innerValue) && rangeSlider);
};

Slider.displayName = 'Slider';

var css_248z$u = ".i-progress {\n  display: flex;\n  align-items: center;\n}\n\n@-webkit-keyframes indeterminate_bar {\n  0% {\n    left: -100%;\n  }\n  to {\n    left: 100%;\n  }\n}\n\n@keyframes indeterminate_bar {\n  0% {\n    left: -100%;\n  }\n  to {\n    left: 100%;\n  }\n}\n.i-progress-bar {\n  position: relative;\n  overflow: hidden;\n  background: var(--i-bg-back);\n  border-radius: 100px;\n}\n.i-progress-bar .i-progress__info {\n  position: absolute;\n  top: 50%;\n  right: 6px;\n  transform: translateY(-50%);\n}\n.i-progress-bar.i-progress-bar__has-label {\n  min-height: 20px;\n}\n\n.i-progress-circle__bg {\n  stroke: var(--i-bg-back);\n}\n\n.i-progress-bar__inner {\n  position: absolute;\n  top: 0;\n  left: 0;\n  height: 100%;\n  background: var(--i-primary);\n  border-radius: 100px;\n}\n\n.i-progress-circle__inner {\n  stroke: var(--i-primary);\n}\n\n.i-progress__info {\n  margin-left: 8px;\n  color: var(--i-font-2);\n  font-size: 14px;\n}\n\n@-webkit-keyframes indeterminate_circle {\n  to {\n    stroke-dashoffset: 0;\n  }\n}\n\n@keyframes indeterminate_circle {\n  to {\n    stroke-dashoffset: 0;\n  }\n}\n.i-progress-circle {\n  position: relative;\n}\n.i-progress-circle svg {\n  transform: rotate(-90deg);\n}\n.i-progress-circle .i-progress__info {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  margin: 0;\n  transform: translate(-50%, -50%);\n}";
styleInject(css_248z$u);

var _excluded$y = ["className", "style", "percentage", "type", "labelTxt", "innerLabel", "label", "color", "backColor", "width", "strokeWidth", "indeterminate", "duration"];

var Progress = function Progress(props) {
  var className = props.className,
      style = props.style,
      _props$percentage = props.percentage,
      percentage = _props$percentage === void 0 ? 0 : _props$percentage,
      _props$type = props.type,
      type = _props$type === void 0 ? 'bar' : _props$type,
      _props$labelTxt = props.labelTxt,
      labelTxt = _props$labelTxt === void 0 ? true : _props$labelTxt,
      _props$innerLabel = props.innerLabel,
      innerLabel = _props$innerLabel === void 0 ? false : _props$innerLabel,
      label = props.label,
      color = props.color,
      backColor = props.backColor,
      _props$width = props.width,
      width = _props$width === void 0 ? 200 : _props$width,
      _props$strokeWidth = props.strokeWidth,
      strokeWidth = _props$strokeWidth === void 0 ? 6 : _props$strokeWidth,
      _props$indeterminate = props.indeterminate,
      indeterminate = _props$indeterminate === void 0 ? false : _props$indeterminate,
      _props$duration = props.duration,
      duration = _props$duration === void 0 ? 3 : _props$duration,
      restProps = _objectWithoutProperties(props, _excluded$y);

  var animateBar = "indeterminate_bar ".concat(duration, "s infinite ease-in-out");
  var progressBar = /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    className: classNames('i-progress-bar', innerLabel && 'i-progress-bar__has-label'),
    style: {
      width: width,
      height: strokeWidth,
      background: backColor
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-progress-bar__inner",
    style: {
      width: "".concat(percentage, "%"),
      background: color,
      animation: indeterminate ? animateBar : 'unset'
    }
  }), innerLabel && (labelTxt || label) && /*#__PURE__*/React.createElement("div", {
    className: "i-progress__info"
  }, !label ? "".concat(percentage, "%") : label)), !innerLabel && (labelTxt || label) && /*#__PURE__*/React.createElement("div", {
    className: "i-progress__info"
  }, !label ? "".concat(percentage, "%") : label));

  var getStyleNum = function getStyleNum(val) {
    return parseInt(String(width));
  };

  var circle = {
    d: getStyleNum(),
    r: getStyleNum() / 2 - strokeWidth / 2,
    l: getStyleNum() * Math.PI
  };
  var animateCircle = "indeterminate_circle ".concat(duration, "s infinite linear");
  var progressCircle = /*#__PURE__*/React.createElement("div", {
    className: classNames('i-progress-circle', innerLabel && 'i-progress-circle__has-label'),
    style: {
      width: width,
      height: width
    }
  }, /*#__PURE__*/React.createElement("svg", {
    width: circle.d,
    height: circle.d
  }, /*#__PURE__*/React.createElement("circle", {
    cx: circle.d / 2,
    cy: circle.d / 2,
    r: circle.r,
    fill: "none",
    className: "i-progress-circle__bg",
    style: {
      stroke: backColor,
      strokeWidth: strokeWidth
    }
  }), /*#__PURE__*/React.createElement("circle", {
    cx: circle.d / 2,
    cy: circle.d / 2,
    r: circle.r,
    fill: "none",
    className: "i-progress-circle__inner",
    style: {
      stroke: color,
      strokeWidth: strokeWidth,
      strokeLinecap: 'round',
      strokeDasharray: circle.l,
      strokeDashoffset: !indeterminate ? circle.l - circle.l * percentage / 100 : circle.l * 2,
      animation: indeterminate ? animateCircle : 'unset'
    }
  })), (labelTxt || label) && /*#__PURE__*/React.createElement("div", {
    className: "i-progress__info"
  }, !label ? "".concat(percentage, "%") : label));
  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-progress', className),
    style: _objectSpread2({}, style)
  }, restProps), type !== 'bar' ? progressCircle : progressBar);
};

Progress.displayName = 'Progress';

var css_248z$v = ".i-steps {\n  display: flex;\n}\n.i-steps.i-steps__layout-vertical {\n  flex-direction: column;\n}\n.i-steps.i-steps__layout-vertical .i-steps-item__title::after {\n  display: none;\n}\n.i-steps.i-steps__layout-vertical .i-steps-item {\n  padding-bottom: 20px;\n}\n.i-steps.i-steps__layout-vertical .i-steps-item:not(:last-of-type) .i-steps-item__icon::after {\n  content: \"\";\n}\n.i-steps.i-steps__layout-vertical .i-steps-item__icon::after {\n  position: absolute;\n  top: calc(100% + 1px);\n  left: 50%;\n  display: block;\n  width: 2px;\n  height: 999px;\n  background: var(--i-bg-back);\n  transform: translateX(-50%);\n}\n.i-steps.i-steps__dot .i-steps-item__content {\n  margin-left: 20px;\n}\n.i-steps.i-steps__dot .i-steps-item__icon {\n  left: -20px;\n  width: 12px;\n  min-width: 12px;\n  height: 12px;\n  min-height: 12px;\n  border-width: 2px;\n}\n.i-steps.i-steps__dot .i-steps-item__icon .i-icon,\n.i-steps.i-steps__dot .i-steps-item__icon span {\n  display: none;\n}\n.i-steps.i-steps__dot .i-steps-item__icon::after {\n  top: calc(100% + 6px);\n}\n\n.i-steps-item {\n  display: flex;\n  overflow: hidden;\n}\n.i-steps-item:not(:last-of-type) {\n  flex: 1;\n  margin-right: 8px;\n}\n.i-steps-item:not(:last-of-type) .i-steps-item__title::after {\n  content: \"\";\n}\n.i-steps-item.i-steps-item__finish,\n.i-steps-item.i-steps-item__finish .i-icon,\n.i-steps-item.i-steps-item__finish .i-steps-item__icon {\n  color: var(--i-primary-txt);\n}\n.i-steps-item.i-steps-item__finish .i-steps-item__icon {\n  border-color: var(--i-primary);\n}\n.i-steps-item.i-steps-item__finish .i-steps-item__title {\n  color: var(--i-font-2);\n}\n.i-steps-item.i-steps-item__finish .i-steps-item__title::after {\n  background: var(--i-primary);\n}\n.i-steps-item.i-steps-item__current,\n.i-steps-item.i-steps-item__current .i-icon,\n.i-steps-item.i-steps-item__current .i-steps-item__icon {\n  color: #fff;\n}\n.i-steps-item.i-steps-item__current .i-steps-item__icon {\n  background: var(--i-primary);\n  border-color: var(--i-primary);\n}\n.i-steps-item.i-steps-item__current .i-steps-item__title {\n  color: var(--i-primary);\n}\n\n.i-steps-item__icon {\n  position: absolute;\n  top: 50%;\n  left: -28px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  width: 20px;\n  min-width: 20px;\n  height: 20px;\n  min-height: 20px;\n  margin-right: 8px;\n  color: var(--i-font-5);\n  font-size: 12px;\n  border: 1px solid var(--i-font-5);\n  border-radius: 50%;\n  transform: translateY(-50%);\n}\n.i-steps-item__icon .i-icon {\n  color: var(--i-font-5);\n}\n\n.i-steps-item__content {\n  margin-left: 28px;\n}\n\n.i-steps-item__title {\n  position: relative;\n  width: -webkit-fit-content;\n  width: -moz-fit-content;\n  width: fit-content;\n  color: var(--i-font-5);\n  font-size: 14px;\n}\n.i-steps-item__title::after {\n  position: absolute;\n  top: 50%;\n  left: calc(100% + 6px);\n  display: block;\n  width: 999px;\n  height: 2px;\n  background: var(--i-bg-back);\n  transform: translateY(-50%);\n}\n\n.i-steps-item__description {\n  margin-top: 8px;\n  color: var(--i-font-5);\n  font-size: 13px;\n}";
styleInject(css_248z$v);

var _excluded$z = ["className", "style", "title", "description", "index", "current"];

var StepsItem = function StepsItem(props) {
  var context = useContext(StepsContext);
  var newProps = context ? context.inject(props) : props;

  var className = newProps.className,
      style = newProps.style,
      _newProps$title = newProps.title,
      title = _newProps$title === void 0 ? '' : _newProps$title,
      _newProps$description = newProps.description,
      description = _newProps$description === void 0 ? '' : _newProps$description,
      _newProps$index = newProps.index,
      index = _newProps$index === void 0 ? 0 : _newProps$index,
      _newProps$current = newProps.current,
      current = _newProps$current === void 0 ? 0 : _newProps$current,
      restProps = _objectWithoutProperties(newProps, _excluded$z);

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-steps-item', current > index + 1 && 'i-steps-item__finish', current === index + 1 && 'i-steps-item__current', className),
    style: _objectSpread2({}, style)
  }, restProps), /*#__PURE__*/React.createElement("div", {
    className: "i-steps-item__content"
  }, /*#__PURE__*/React.createElement("header", {
    className: "i-steps-item__title"
  }, title, /*#__PURE__*/React.createElement("div", {
    className: "i-steps-item__icon"
  }, current > index + 1 ? /*#__PURE__*/React.createElement(Icon, {
    name: "Check",
    size: 13
  }) : /*#__PURE__*/React.createElement("span", null, index + 1))), /*#__PURE__*/React.createElement("article", {
    className: "i-steps-item__description"
  }, description)));
};

var StepsContext = /*#__PURE__*/React.createContext(null);

var Steps = function Steps(props) {
  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      style = props.style,
      _props$current = props.current,
      current = _props$current === void 0 ? 0 : _props$current,
      _props$layout = props.layout,
      layout = _props$layout === void 0 ? 'horizontal' : _props$layout,
      reverse = props.reverse,
      _props$dot = props.dot,
      dot = _props$dot === void 0 ? false : _props$dot; // 注入每一项的 context

  var context = {
    // 将 props 注入每一项子节点的方法
    inject: function inject(stepsItemProps) {
      return _objectSpread2({
        current: current
      }, stepsItemProps);
    }
  };
  var stepItemList = useMemo(function () {
    var childrenList = React.Children.toArray(children);
    var childrenDisplayList = reverse ? childrenList.reverse() : childrenList;
    return childrenList.map(function (child, index) {
      var stepIndex = reverse ? childrenDisplayList.length - index - 1 : index;
      return /*#__PURE__*/React.cloneElement(child, _objectSpread2(_objectSpread2({}, child.props), {}, {
        index: stepIndex
      }));
    });
  }, [children, reverse]);
  return /*#__PURE__*/React.createElement(StepsContext.Provider, {
    value: context
  }, /*#__PURE__*/React.createElement("div", {
    className: classNames('i-steps', layout && "i-steps__layout-".concat(layout), dot && 'i-steps__dot', className),
    style: _objectSpread2({}, style)
  }, stepItemList));
};

Steps.Item = StepsItem;
StepsItem.displayName = 'StepsItem';
Steps.displayName = 'Steps';

var css_248z$w = ".i-rate {\n  display: flex;\n  align-items: center;\n}\n.i-rate.i-rate__readonly .i-rate-star {\n  cursor: default;\n}\n.i-rate.i-rate__readonly .i-rate-star:active {\n  transform: unset;\n}\n\n.i-rate-star {\n  position: relative;\n  cursor: pointer;\n  transition: all 0.1s ease-out;\n}\n.i-rate-star:active {\n  transform: scale(1.2);\n}\n.i-rate-star:not(:last-of-type) {\n  padding-right: 8px;\n}\n\n.i-rate-star__first {\n  position: absolute;\n  top: 0;\n  left: 0;\n  width: 10px;\n  overflow: hidden;\n}";
styleInject(css_248z$w);

var _excluded$A = ["className", "style", "value", "defaultValue", "readonly", "allowClear", "allowHalf", "count", "activeColor", "voidColor", "activeIcon", "voidIcon", "onChange"];

var Rate = function Rate(props) {
  var className = props.className,
      style = props.style,
      value = props.value,
      _props$defaultValue = props.defaultValue,
      defaultValue = _props$defaultValue === void 0 ? 0 : _props$defaultValue,
      _props$readonly = props.readonly,
      readonly = _props$readonly === void 0 ? false : _props$readonly,
      _props$allowClear = props.allowClear,
      allowClear = _props$allowClear === void 0 ? false : _props$allowClear,
      _props$allowHalf = props.allowHalf,
      allowHalf = _props$allowHalf === void 0 ? false : _props$allowHalf,
      _props$count = props.count,
      count = _props$count === void 0 ? 5 : _props$count,
      _props$activeColor = props.activeColor,
      activeColor = _props$activeColor === void 0 ? '#f5db4d' : _props$activeColor,
      _props$voidColor = props.voidColor,
      voidColor = _props$voidColor === void 0 ? 'var(--i-bg-back)' : _props$voidColor,
      _props$activeIcon = props.activeIcon,
      activeIcon = _props$activeIcon === void 0 ? 'StarFill' : _props$activeIcon,
      _props$voidIcon = props.voidIcon,
      voidIcon = _props$voidIcon === void 0 ? 'StarFill' : _props$voidIcon,
      _props$onChange = props.onChange,
      onChange = _props$onChange === void 0 ? function () {} : _props$onChange,
      restProps = _objectWithoutProperties(props, _excluded$A);

  var _useDefault = useDefault(value, defaultValue, onChange),
      _useDefault2 = _slicedToArray(_useDefault, 2),
      innerValue = _useDefault2[0],
      setInnerValue = _useDefault2[1];

  var _useState = useState(value || defaultValue),
      _useState2 = _slicedToArray(_useState, 2),
      hoverValue = _useState2[0],
      setHoverValue = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      ifHover = _useState4[0],
      setIfHover = _useState4[1];

  var handleEnterRate = function handleEnterRate() {
    !readonly && setIfHover(true);
  };

  var handleLeaveRate = function handleLeaveRate() {
    !readonly && setIfHover(false);
  };

  var handleEnterRateItem = function handleEnterRateItem(index) {
    var step = !allowHalf ? 1 : 0.5;
    !readonly && setHoverValue(index + step);
  };

  var handleDownRateItem = function handleDownRateItem(index) {
    var step = !allowHalf ? 1 : 0.5;

    if (!readonly) {
      if (innerValue !== index + step) {
        setInnerValue(index + step);
      } else {
        allowClear && setInnerValue(0);
      }
    }
  };

  var getStar = function getStar(index, type) {
    var result = type === 'name' ? voidIcon : voidColor;
    var compareValue = ifHover ? hoverValue : innerValue;

    if (compareValue > index) {
      result = type === 'name' ? activeIcon : activeColor;
    }

    return result;
  };

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-rate', readonly && 'i-rate__readonly', className),
    style: _objectSpread2({}, style),
    onMouseEnter: handleEnterRate,
    onMouseLeave: handleLeaveRate
  }, restProps), Array(count).fill('star').map(function (item, index) {
    return !allowHalf ? /*#__PURE__*/React.createElement("div", {
      className: "i-rate-star",
      onMouseEnter: function onMouseEnter() {
        return handleEnterRateItem(index);
      },
      onMouseDown: function onMouseDown() {
        return handleDownRateItem(index);
      },
      key: "".concat(item).concat(index)
    }, /*#__PURE__*/React.createElement(Icon, {
      name: getStar(index, 'name'),
      color: getStar(index, 'color'),
      size: 20
    })) : /*#__PURE__*/React.createElement("div", {
      className: 'i-rate-star',
      key: "".concat(item).concat(index)
    }, /*#__PURE__*/React.createElement("div", {
      className: "i-rate-star__first",
      onMouseEnter: function onMouseEnter() {
        return handleEnterRateItem(index);
      },
      onMouseDown: function onMouseDown() {
        return handleDownRateItem(index);
      }
    }, /*#__PURE__*/React.createElement(Icon, {
      name: getStar(index, 'name'),
      color: getStar(index, 'color'),
      size: 20
    })), /*#__PURE__*/React.createElement("div", {
      className: "i-rate-star__second",
      onMouseEnter: function onMouseEnter() {
        return handleEnterRateItem(index + 0.5);
      },
      onMouseDown: function onMouseDown() {
        return handleDownRateItem(index + 0.5);
      }
    }, /*#__PURE__*/React.createElement(Icon, {
      name: getStar(index + 0.5, 'name'),
      color: getStar(index + 0.5, 'color'),
      size: 20
    })));
  }));
};

Rate.displayName = 'Rate';

var css_248z$x = ".i-empty {\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n}\n.i-empty.i-empty--size-small .i-empty-image {\n  width: 160px;\n}\n.i-empty.i-empty--size-small .i-empty-description {\n  font-size: 14px;\n}\n.i-empty.i-empty--size-large .i-empty-image {\n  width: 240px;\n}\n.i-empty.i-empty--size-large .i-empty-description {\n  font-size: 18px;\n}\n\n.i-empty-image {\n  display: flex;\n  align-items: flex-end;\n  justify-content: center;\n  width: 200px;\n  height: auto;\n}\n.i-empty-image svg {\n  width: 100%;\n  height: auto;\n}\n\nhtml.dark .i-empty-image svg,\n*[data-theme=dark] .i-empty-image svg,\n*[data-prefers-color=dark] .i-empty-image svg {\n  filter: invert(1) contrast(0.9) brightness(1.5) hue-rotate(180deg);\n}\n\n.i-empty-description {\n  margin-top: 20px;\n  color: #888;\n  font-size: 16px;\n}";
styleInject(css_248z$x);

var _excluded$B = ["children", "className", "image", "size", "style", "type"];

var Empty = function Empty(props) {
  var _props$children = props.children,
      children = _props$children === void 0 ? '暂无数据' : _props$children,
      className = props.className,
      image = props.image,
      size = props.size,
      style = props.style,
      _props$type = props.type,
      type = _props$type === void 0 ? 'default' : _props$type,
      restProps = _objectWithoutProperties(props, _excluded$B);

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-empty', size === 'small' && 'i-empty--size-small', size === 'large' && 'i-empty--size-large', className),
    style: _objectSpread2({}, style)
  }, restProps), /*#__PURE__*/React.createElement("div", {
    className: "i-empty-image"
  }, !image && type === 'default' && /*#__PURE__*/React.createElement("svg", {
    width: "640",
    height: "420",
    viewBox: "0 0 640 420",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, /*#__PURE__*/React.createElement("g", {
    clipPath: "url(#clip0_44_427)"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M321.95 420.27C484.62 420.27 616.49 386.772 616.49 345.45C616.49 304.128 484.62 270.63 321.95 270.63C159.28 270.63 27.4102 304.128 27.4102 345.45C27.4102 386.772 159.28 420.27 321.95 420.27Z",
    fill: "url(#paint0_linear_44_427)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M153.05 91.3007L315.55 39V183.15L178.98 133.141L153.05 91.3007Z",
    fill: "url(#paint1_linear_44_427)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M315.55 39L516.65 87.3753L484.95 269.441L315.55 217.469V39Z",
    fill: "url(#paint2_linear_44_427)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M153.05 91.3008L332.83 144.259V384.82L153.05 321.413V91.3008Z",
    fill: "url(#paint3_linear_44_427)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M516.65 87.3755V325.338L332.83 384.82V144.26L516.65 87.3755Z",
    fill: "url(#paint4_linear_44_427)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M268.01 238.06L107.24 170.399L153.05 91.3008L332.83 144.259L268.01 238.06Z",
    fill: "url(#paint5_linear_44_427)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M516.65 87.3755L582.62 159.621L401.98 238.061L332.83 144.26L516.65 87.3755Z",
    fill: "url(#paint6_linear_44_427)"
  })), /*#__PURE__*/React.createElement("defs", null, /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint0_linear_44_427",
    x1: "321.954",
    y1: "270.635",
    x2: "321.954",
    y2: "420.274",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#EAEAEA"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#FCFCFC"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint1_linear_44_427",
    x1: "234.299",
    y1: "183.151",
    x2: "234.299",
    y2: "39.0045",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.1119",
    stopColor: "#DADCE1"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "0.9205",
    stopColor: "#DFE1E4"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint2_linear_44_427",
    x1: "416.096",
    y1: "269.442",
    x2: "416.096",
    y2: "39.0045",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.0884",
    stopColor: "#EBEEF2"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#E8EAEE"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint3_linear_44_427",
    x1: "332.832",
    y1: "238.064",
    x2: "153.052",
    y2: "238.064",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.0884",
    stopColor: "#E7E8EC"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#F9F9FA"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint4_linear_44_427",
    x1: "344.5",
    y1: "392.467",
    x2: "536.021",
    y2: "100.071",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.1119",
    stopColor: "#DADCE2"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "0.9205",
    stopColor: "#DADCE2"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint5_linear_44_427",
    x1: "332.832",
    y1: "164.683",
    x2: "107.242",
    y2: "164.683",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.0884",
    stopColor: "#F6F7FA"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#F6F7FA"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint6_linear_44_427",
    x1: "582.624",
    y1: "162.722",
    x2: "332.832",
    y2: "162.722",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.0884",
    stopColor: "#F6F7FA"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#F6F7FA"
  })), /*#__PURE__*/React.createElement("clipPath", {
    id: "clip0_44_427"
  }, /*#__PURE__*/React.createElement("rect", {
    width: "640",
    height: "420",
    fill: "white"
  })))), !image && type === 'shoppingTrolley' && /*#__PURE__*/React.createElement("svg", {
    width: "640",
    height: "420",
    viewBox: "0 0 640 420",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M319.54 419.64C482.21 419.64 614.08 386.142 614.08 344.82C614.08 303.498 482.21 270 319.54 270C156.87 270 25 303.498 25 344.82C25 386.142 156.87 419.64 319.54 419.64Z",
    fill: "url(#paint0_linear_45_498)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M351.625 324.404C360.825 324.523 368.491 317.05 368.748 307.713C369.005 298.376 361.755 290.709 352.555 290.59C343.355 290.471 335.689 297.944 335.432 307.281C335.176 316.618 342.426 324.285 351.625 324.404Z",
    fill: "url(#paint1_linear_45_498)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M162.524 356.454C171.724 356.574 179.39 349.101 179.647 339.763C179.904 330.426 172.654 322.76 163.454 322.641C154.254 322.521 146.588 329.994 146.331 339.332C146.075 348.669 153.324 356.335 162.524 356.454Z",
    fill: "url(#paint2_linear_45_498)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M179.019 325.468L290.819 349.376L307.209 345.137L195.805 321.454L179.019 325.468Z",
    fill: "#DADCE2"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M363.5 295L474.121 307.028L471.446 299.271L361.5 287.5L363.5 295Z",
    fill: "#DADCE2"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M272.67 243.621L245.86 307.608L253.778 306.247L280.332 242.794L272.67 243.621Z",
    fill: "#DADCE2"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M391.152 234.045L362.078 332.639L369.786 330.849L398.327 233.73L391.152 234.045Z",
    fill: "#DADCE2"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M342.377 237.328L353.925 288.288L160.622 323.776L168.777 329.729L364 295L350.023 236.014L342.377 237.328Z",
    fill: "#DADCE2"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M442.396 228.376L472.01 305.108L252.407 357.548L264.933 362.947L484.845 311.341L451.925 227.041L442.396 228.376Z",
    fill: "#DADCE2"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M254.526 390.045C263.725 390.164 271.392 382.692 271.648 373.354C271.905 364.017 264.655 356.351 255.455 356.232C246.255 356.112 238.589 363.585 238.332 372.922C238.076 382.26 245.326 389.926 254.526 390.045Z",
    fill: "url(#paint3_linear_45_498)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M472.034 339.254C481.233 339.373 488.9 331.9 489.156 322.563C489.413 313.226 482.163 305.56 472.963 305.44C463.763 305.321 456.097 312.794 455.84 322.131C455.584 331.469 462.834 339.135 472.034 339.254Z",
    fill: "url(#paint4_linear_45_498)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M499.374 83.6828L512.771 66.5601L543.616 62.3094C549.18 57.3794 548.749 53.5105 542.322 50.7027C533.22 51.8835 521.193 53.5577 506.24 55.7253L487.084 80.4781L499.374 83.6828Z",
    fill: "url(#paint5_linear_45_498)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M397.717 62.3359L411.114 45.2132L441.959 40.9626C447.523 36.0326 447.091 32.1636 440.664 29.3559C431.563 30.5367 419.536 32.2109 404.583 34.3785L385.426 59.1313L397.717 62.3359Z",
    fill: "url(#paint6_linear_45_498)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M153.81 119.701L389 55L385.217 180.046L169 215.811L153.81 119.701Z",
    fill: "url(#paint7_linear_45_498)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M389 55L384.963 183.544L445.269 229.54L499.972 83.065L389 55Z",
    fill: "url(#paint8_linear_45_498)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M153.9 120.275L161.761 222.009L236.833 248.571L239.839 138.915L153.9 120.275Z",
    fill: "url(#paint9_linear_45_498)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M239.832 139.51L500 82.9999L456.662 229.533L236.833 248.574L239.832 139.51Z",
    fill: "url(#paint10_linear_45_498)"
  }), /*#__PURE__*/React.createElement("defs", null, /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint0_linear_45_498",
    x1: "319.544",
    y1: "270.005",
    x2: "319.544",
    y2: "419.644",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#EAEAEA"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#FCFCFC"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint1_linear_45_498",
    x1: "352.555",
    y1: "290.591",
    x2: "352.117",
    y2: "324.411",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#DADCE2"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#DBDDE2"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint2_linear_45_498",
    x1: "163.454",
    y1: "322.642",
    x2: "163.016",
    y2: "356.462",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#DADCE2"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#DBDDE2"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint3_linear_45_498",
    x1: "255.455",
    y1: "356.233",
    x2: "255.017",
    y2: "390.052",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#DADCE2"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#DBDDE2"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint4_linear_45_498",
    x1: "472.963",
    y1: "305.441",
    x2: "472.525",
    y2: "339.261",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#DADCE2"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#DBDDE2"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint5_linear_45_498",
    x1: "527.514",
    y1: "73.132",
    x2: "501.218",
    y2: "46.8594",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#DBDDE2"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#E7EAF0"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint6_linear_45_498",
    x1: "425.857",
    y1: "51.7852",
    x2: "399.561",
    y2: "25.5126",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#DBDDE3"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#E7EAF0"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint7_linear_45_498",
    x1: "309.095",
    y1: "182.086",
    x2: "201.899",
    y2: "44.2478",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#DADCE1"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#E7EAF0"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#DFE1E4"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint8_linear_45_498",
    x1: "447.955",
    y1: "241.645",
    x2: "378.49",
    y2: "51.4148",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#EBEEF2"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#E8EAEE"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint9_linear_45_498",
    x1: "200.472",
    y1: "256.949",
    x2: "147.529",
    y2: "117.292",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#E8E9ED"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#F9F9FA"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint10_linear_45_498",
    x1: "412.293",
    y1: "206.408",
    x2: "296.778",
    y2: "71.826",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#DADCE2"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#E7EAF0"
  })))), !image && type === 'favorite' && /*#__PURE__*/React.createElement("svg", {
    width: "640",
    height: "420",
    viewBox: "0 0 640 420",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, /*#__PURE__*/React.createElement("g", {
    clipPath: "url(#clip0_45_535)"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M321.64 420.29C484.31 420.29 616.18 386.792 616.18 345.47C616.18 304.148 484.31 270.65 321.64 270.65C158.97 270.65 27.1 304.148 27.1 345.47C27.1 386.792 158.97 420.29 321.64 420.29Z",
    fill: "url(#paint0_linear_45_535)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M449.878 85.48H317.528V63.01C317.528 51.96 308.568 43 297.518 43H183.768C172.718 43 163.758 51.96 163.758 63.01V317.18H317.518V278.91H469.878V105.49C469.888 94.43 460.928 85.48 449.878 85.48Z",
    fill: "url(#paint1_linear_45_535)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M489.008 132.64H219.238C208.668 132.64 199.548 140.39 197.358 151.22L163.918 316.61C160.968 331.19 171.578 344.91 185.798 344.91H451.848C462.228 344.91 471.238 337.43 473.618 326.84L510.768 161.45C514.088 146.73 503.438 132.64 489.008 132.64Z",
    fill: "url(#paint2_linear_45_535)"
  }), /*#__PURE__*/React.createElement("g", {
    filter: "url(#filter0_ii_45_535)"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M346.438 181.2L360.638 209.98C361.728 212.18 363.828 213.71 366.258 214.06L398.018 218.68C404.138 219.57 406.588 227.09 402.158 231.41L379.178 253.81C377.418 255.52 376.618 257.99 377.028 260.42L382.458 292.05C383.508 298.15 377.108 302.8 371.628 299.92L343.218 284.98C341.048 283.84 338.448 283.84 336.268 284.98L307.858 299.92C302.378 302.8 295.988 298.15 297.028 292.05L302.458 260.42C302.878 258 302.068 255.53 300.308 253.81L277.328 231.41C272.898 227.09 275.338 219.57 281.468 218.68L313.228 214.06C315.658 213.71 317.758 212.18 318.848 209.98L333.048 181.2C335.788 175.66 343.698 175.66 346.438 181.2Z",
    fill: "url(#paint3_linear_45_535)"
  }))), /*#__PURE__*/React.createElement("defs", null, /*#__PURE__*/React.createElement("filter", {
    id: "filter0_ii_45_535",
    x: "265.065",
    y: "167.045",
    width: "149.354",
    height: "143.75",
    filterUnits: "userSpaceOnUse",
    colorInterpolationFilters: "sRGB"
  }, /*#__PURE__*/React.createElement("feFlood", {
    floodOpacity: "0",
    result: "BackgroundImageFix"
  }), /*#__PURE__*/React.createElement("feBlend", {
    mode: "normal",
    in: "SourceGraphic",
    in2: "BackgroundImageFix",
    result: "shape"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    in: "SourceAlpha",
    type: "matrix",
    values: "0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0",
    result: "hardAlpha"
  }), /*#__PURE__*/React.createElement("feOffset", {
    dx: "-10",
    dy: "-10"
  }), /*#__PURE__*/React.createElement("feGaussianBlur", {
    stdDeviation: "15"
  }), /*#__PURE__*/React.createElement("feComposite", {
    in2: "hardAlpha",
    operator: "arithmetic",
    k2: "-1",
    k3: "1"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    type: "matrix",
    values: "0 0 0 0 1 0 0 0 0 1 0 0 0 0 1 0 0 0 1 0"
  }), /*#__PURE__*/React.createElement("feBlend", {
    mode: "normal",
    in2: "shape",
    result: "effect1_innerShadow_45_535"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    in: "SourceAlpha",
    type: "matrix",
    values: "0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0",
    result: "hardAlpha"
  }), /*#__PURE__*/React.createElement("feOffset", {
    dx: "10",
    dy: "10"
  }), /*#__PURE__*/React.createElement("feGaussianBlur", {
    stdDeviation: "15"
  }), /*#__PURE__*/React.createElement("feComposite", {
    in2: "hardAlpha",
    operator: "arithmetic",
    k2: "-1",
    k3: "1"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    type: "matrix",
    values: "0 0 0 0 0.0941176 0 0 0 0 0.152941 0 0 0 0 0.294118 0 0 0 0.12 0"
  }), /*#__PURE__*/React.createElement("feBlend", {
    mode: "normal",
    in2: "effect1_innerShadow_45_535",
    result: "effect2_innerShadow_45_535"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint0_linear_45_535",
    x1: "321.644",
    y1: "270.655",
    x2: "321.644",
    y2: "420.294",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#EAEAEA"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#FCFCFC"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint1_linear_45_535",
    x1: "316.823",
    y1: "317.176",
    x2: "316.823",
    y2: "42.9974",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.1119",
    stopColor: "#DADCE2"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "0.9205",
    stopColor: "#E9ECF0"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint2_linear_45_535",
    x1: "260.466",
    y1: "105.51",
    x2: "413.415",
    y2: "370.427",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.0884",
    stopColor: "#F6F7F8"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "0.7879",
    stopColor: "#DFE1E7"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint3_linear_45_535",
    x1: "311.792",
    y1: "192.347",
    x2: "375.325",
    y2: "302.214",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.0884",
    stopColor: "#E1E6EC"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#E1E5EB"
  })), /*#__PURE__*/React.createElement("clipPath", {
    id: "clip0_45_535"
  }, /*#__PURE__*/React.createElement("rect", {
    width: "640",
    height: "420",
    fill: "white"
  })))), !image && type === 'gold' && /*#__PURE__*/React.createElement("svg", {
    width: "640",
    height: "420",
    viewBox: "0 0 640 420",
    fill: "none",
    xmlns: "http://www.w3.org/2000/svg"
  }, /*#__PURE__*/React.createElement("g", {
    clipPath: "url(#clip0_45_549)"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M321.74 420.12C484.41 420.12 616.28 386.622 616.28 345.3C616.28 303.978 484.41 270.48 321.74 270.48C159.07 270.48 27.2 303.978 27.2 345.3C27.2 386.622 159.07 420.12 321.74 420.12Z",
    fill: "url(#paint0_linear_45_549)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M500.13 335.43C506.895 335.43 512.38 329.945 512.38 323.18C512.38 316.414 506.895 310.93 500.13 310.93C493.364 310.93 487.88 316.414 487.88 323.18C487.88 329.945 493.364 335.43 500.13 335.43Z",
    fill: "url(#paint1_linear_45_549)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M307.56 365.08C404.508 365.08 483.1 286.488 483.1 189.54C483.1 92.5919 404.508 14 307.56 14C210.612 14 132.02 92.5919 132.02 189.54C132.02 286.488 210.612 365.08 307.56 365.08Z",
    fill: "url(#paint2_linear_45_549)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M315.75 365.08C408.175 365.08 483.1 290.155 483.1 197.73C483.1 105.305 408.175 30.38 315.75 30.38C223.325 30.38 148.4 105.305 148.4 197.73C148.4 290.155 223.325 365.08 315.75 365.08Z",
    fill: "url(#paint3_linear_45_549)"
  }), /*#__PURE__*/React.createElement("g", {
    filter: "url(#filter0_ii_45_549)"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M315.75 324.28C385.642 324.28 442.3 267.622 442.3 197.73C442.3 127.838 385.642 71.1799 315.75 71.1799C245.858 71.1799 189.2 127.838 189.2 197.73C189.2 267.622 245.858 324.28 315.75 324.28Z",
    fill: "url(#paint4_linear_45_549)"
  })), /*#__PURE__*/React.createElement("g", {
    filter: "url(#filter1_dd_45_549)"
  }, /*#__PURE__*/React.createElement("path", {
    d: "M321.45 127.93L339.74 164.98C340.67 166.86 342.45 168.16 344.52 168.46L385.41 174.4C390.62 175.16 392.7 181.56 388.93 185.24L359.34 214.08C357.84 215.54 357.16 217.64 357.51 219.7L364.49 260.43C365.38 265.62 359.93 269.58 355.27 267.13L318.7 247.9C316.85 246.93 314.64 246.93 312.79 247.9L276.22 267.13C271.56 269.58 266.11 265.62 267 260.43L273.98 219.7C274.33 217.64 273.65 215.54 272.15 214.08L242.56 185.24C238.79 181.56 240.87 175.16 246.08 174.4L286.97 168.46C289.04 168.16 290.83 166.86 291.75 164.98L310.04 127.93C312.38 123.21 319.12 123.21 321.45 127.93Z",
    fill: "url(#paint5_linear_45_549)"
  })), /*#__PURE__*/React.createElement("path", {
    d: "M427.41 396.12C469.163 396.12 503.01 382.899 503.01 366.59C503.01 350.281 469.163 337.06 427.41 337.06C385.657 337.06 351.81 350.281 351.81 366.59C351.81 382.899 385.657 396.12 427.41 396.12Z",
    fill: "url(#paint6_linear_45_549)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M427.41 373.55C469.163 373.55 503.01 360.329 503.01 344.02C503.01 327.711 469.163 314.49 427.41 314.49C385.657 314.49 351.81 327.711 351.81 344.02C351.81 360.329 385.657 373.55 427.41 373.55Z",
    fill: "url(#paint7_linear_45_549)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M427.41 350.99C469.163 350.99 503.01 337.769 503.01 321.46C503.01 305.151 469.163 291.93 427.41 291.93C385.657 291.93 351.81 305.151 351.81 321.46C351.81 337.769 385.657 350.99 427.41 350.99Z",
    fill: "url(#paint8_linear_45_549)"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M427.41 328.43C469.163 328.43 503.01 315.209 503.01 298.9C503.01 282.591 469.163 269.37 427.41 269.37C385.657 269.37 351.81 282.591 351.81 298.9C351.81 315.209 385.657 328.43 427.41 328.43Z",
    fill: "url(#paint9_linear_45_549)"
  })), /*#__PURE__*/React.createElement("defs", null, /*#__PURE__*/React.createElement("filter", {
    id: "filter0_ii_45_549",
    x: "184.2",
    y: "66.1799",
    width: "263.1",
    height: "263.1",
    filterUnits: "userSpaceOnUse",
    colorInterpolationFilters: "sRGB"
  }, /*#__PURE__*/React.createElement("feFlood", {
    floodOpacity: "0",
    result: "BackgroundImageFix"
  }), /*#__PURE__*/React.createElement("feBlend", {
    mode: "normal",
    in: "SourceGraphic",
    in2: "BackgroundImageFix",
    result: "shape"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    in: "SourceAlpha",
    type: "matrix",
    values: "0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0",
    result: "hardAlpha"
  }), /*#__PURE__*/React.createElement("feOffset", {
    dx: "-5",
    dy: "-5"
  }), /*#__PURE__*/React.createElement("feGaussianBlur", {
    stdDeviation: "7.5"
  }), /*#__PURE__*/React.createElement("feComposite", {
    in2: "hardAlpha",
    operator: "arithmetic",
    k2: "-1",
    k3: "1"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    type: "matrix",
    values: "0 0 0 0 1 0 0 0 0 1 0 0 0 0 1 0 0 0 1 0"
  }), /*#__PURE__*/React.createElement("feBlend", {
    mode: "normal",
    in2: "shape",
    result: "effect1_innerShadow_45_549"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    in: "SourceAlpha",
    type: "matrix",
    values: "0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0",
    result: "hardAlpha"
  }), /*#__PURE__*/React.createElement("feOffset", {
    dx: "5",
    dy: "5"
  }), /*#__PURE__*/React.createElement("feGaussianBlur", {
    stdDeviation: "7.5"
  }), /*#__PURE__*/React.createElement("feComposite", {
    in2: "hardAlpha",
    operator: "arithmetic",
    k2: "-1",
    k3: "1"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    type: "matrix",
    values: "0 0 0 0 0.0941176 0 0 0 0 0.152941 0 0 0 0 0.294118 0 0 0 0.06 0"
  }), /*#__PURE__*/React.createElement("feBlend", {
    mode: "normal",
    in2: "effect1_innerShadow_45_549",
    result: "effect2_innerShadow_45_549"
  })), /*#__PURE__*/React.createElement("filter", {
    id: "filter1_dd_45_549",
    x: "160.635",
    y: "44.3901",
    width: "310.22",
    height: "303.483",
    filterUnits: "userSpaceOnUse",
    colorInterpolationFilters: "sRGB"
  }, /*#__PURE__*/React.createElement("feFlood", {
    floodOpacity: "0",
    result: "BackgroundImageFix"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    in: "SourceAlpha",
    type: "matrix",
    values: "0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0",
    result: "hardAlpha"
  }), /*#__PURE__*/React.createElement("feOffset", {
    dx: "-20",
    dy: "-20"
  }), /*#__PURE__*/React.createElement("feGaussianBlur", {
    stdDeviation: "30"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    type: "matrix",
    values: "0 0 0 0 1 0 0 0 0 1 0 0 0 0 1 0 0 0 1 0"
  }), /*#__PURE__*/React.createElement("feBlend", {
    mode: "normal",
    in2: "BackgroundImageFix",
    result: "effect1_dropShadow_45_549"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    in: "SourceAlpha",
    type: "matrix",
    values: "0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0",
    result: "hardAlpha"
  }), /*#__PURE__*/React.createElement("feOffset", {
    dx: "20",
    dy: "20"
  }), /*#__PURE__*/React.createElement("feGaussianBlur", {
    stdDeviation: "30"
  }), /*#__PURE__*/React.createElement("feColorMatrix", {
    type: "matrix",
    values: "0 0 0 0 0.803922 0 0 0 0 0.803922 0 0 0 0 0.811765 0 0 0 1 0"
  }), /*#__PURE__*/React.createElement("feBlend", {
    mode: "normal",
    in2: "effect1_dropShadow_45_549",
    result: "effect2_dropShadow_45_549"
  }), /*#__PURE__*/React.createElement("feBlend", {
    mode: "normal",
    in: "SourceGraphic",
    in2: "effect2_dropShadow_45_549",
    result: "shape"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint0_linear_45_549",
    x1: "321.744",
    y1: "270.485",
    x2: "321.744",
    y2: "420.124",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    stopColor: "#EAEAEA"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#FCFCFC"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint1_linear_45_549",
    x1: "512.383",
    y1: "323.181",
    x2: "487.879",
    y2: "323.181",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.1119",
    stopColor: "#F1F3F6"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "0.9205",
    stopColor: "#D2D9E3"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint2_linear_45_549",
    x1: "395.347",
    y1: "341.584",
    x2: "219.78",
    y2: "37.4937",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.1119",
    stopColor: "#E9E9E9"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "0.9205",
    stopColor: "#F8F8F8"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint3_linear_45_549",
    x1: "232.063",
    y1: "52.7741",
    x2: "399.44",
    y2: "342.68",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.0884",
    stopColor: "#FBFBFC"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#E5E6EA"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint4_linear_45_549",
    x1: "425.368",
    y1: "261.014",
    x2: "206.135",
    y2: "134.44",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.1119",
    stopColor: "#FBFBFC"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "0.9205",
    stopColor: "#DADCE2"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint5_linear_45_549",
    x1: "283.287",
    y1: "142.132",
    x2: "356.892",
    y2: "269.621",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.0884",
    stopColor: "white"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#DADCE2"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint6_linear_45_549",
    x1: "427.415",
    y1: "337.058",
    x2: "427.415",
    y2: "396.115",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.1119",
    stopColor: "#DADCE2"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "0.9205",
    stopColor: "#DADCE2"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint7_linear_45_549",
    x1: "351.814",
    y1: "344.023",
    x2: "503.015",
    y2: "344.023",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.0884",
    stopColor: "white"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#DADCE2"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint8_linear_45_549",
    x1: "427.415",
    y1: "291.931",
    x2: "427.415",
    y2: "350.988",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.1119",
    stopColor: "#DADCE2"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "0.9205",
    stopColor: "#DADCE2"
  })), /*#__PURE__*/React.createElement("linearGradient", {
    id: "paint9_linear_45_549",
    x1: "351.814",
    y1: "298.897",
    x2: "503.015",
    y2: "298.897",
    gradientUnits: "userSpaceOnUse"
  }, /*#__PURE__*/React.createElement("stop", {
    offset: "0.0884",
    stopColor: "white"
  }), /*#__PURE__*/React.createElement("stop", {
    offset: "1",
    stopColor: "#DADCE2"
  })), /*#__PURE__*/React.createElement("clipPath", {
    id: "clip0_45_549"
  }, /*#__PURE__*/React.createElement("rect", {
    width: "640",
    height: "420",
    fill: "white"
  })))), image && /*#__PURE__*/React.createElement("img", {
    src: image
  })), /*#__PURE__*/React.createElement("div", {
    className: "i-empty-description"
  }, children));
};

Empty.displayName = 'Empty';

var css_248z$y = "@-webkit-keyframes loading-rotate {\n  to {\n    transform: rotate(360deg);\n  }\n}\n@keyframes loading-rotate {\n  to {\n    transform: rotate(360deg);\n  }\n}\n.i-loading {\n  display: flex;\n  align-items: center;\n}\n\n.i-loading-spinner {\n  -webkit-animation: loading-rotate 2s linear infinite;\n          animation: loading-rotate 2s linear infinite;\n}\n.i-loading-spinner .i-icon {\n  color: var(--i-primary-txt);\n}\n\n.i-loading-info {\n  margin-left: 8px;\n  color: var(--i-primary-txt);\n}";
styleInject(css_248z$y);

var _excluded$C = ["className", "style", "icon", "size", "color", "info", "spinner"];

var Loading = function Loading(props) {
  var className = props.className,
      style = props.style,
      _props$icon = props.icon,
      icon = _props$icon === void 0 ? "Loading" : _props$icon,
      _props$size = props.size,
      size = _props$size === void 0 ? 36 : _props$size,
      color = props.color,
      _props$info = props.info,
      info = _props$info === void 0 ? '' : _props$info,
      spinner = props.spinner,
      restProps = _objectWithoutProperties(props, _excluded$C);

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-loading', className),
    style: _objectSpread2({}, style)
  }, restProps), /*#__PURE__*/React.createElement("div", {
    className: "i-loading-spinner"
  }, spinner || /*#__PURE__*/React.createElement(Icon, {
    name: icon,
    size: size,
    color: color
  })), /*#__PURE__*/React.createElement("div", {
    className: "i-loading-info",
    style: {
      color: color
    }
  }, info));
};

Loading.displayName = 'Loading';

var css_248z$z = ".i-avatar {\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  overflow: hidden;\n  color: #fff;\n  background: var(--i-font-5);\n  border-radius: 50%;\n}\n.i-avatar.i-avatar__shape-round {\n  border-radius: 6px;\n}\n\n.i-avatar__image {\n  width: 100%;\n  height: 100%;\n}\n\n.i-avatar-group {\n  display: flex;\n  align-items: center;\n  box-sizing: border-box;\n}\n.i-avatar-group .i-avatar {\n  border: 2px solid var(--i-bg);\n}\n.i-avatar-group.i-avatar__offset-right .i-avatar:not(:last-child) {\n  margin-right: -6px;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:first-child {\n  z-index: 49;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(2) {\n  z-index: 48;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(3) {\n  z-index: 47;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(4) {\n  z-index: 46;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(5) {\n  z-index: 45;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(6) {\n  z-index: 44;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(7) {\n  z-index: 43;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(8) {\n  z-index: 42;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(9) {\n  z-index: 41;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(10) {\n  z-index: 40;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(11) {\n  z-index: 39;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(12) {\n  z-index: 38;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(13) {\n  z-index: 37;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(14) {\n  z-index: 36;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(15) {\n  z-index: 35;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(16) {\n  z-index: 34;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(17) {\n  z-index: 33;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(18) {\n  z-index: 32;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(19) {\n  z-index: 31;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(20) {\n  z-index: 30;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(21) {\n  z-index: 29;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(22) {\n  z-index: 28;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(23) {\n  z-index: 27;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(24) {\n  z-index: 26;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(25) {\n  z-index: 25;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(26) {\n  z-index: 24;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(27) {\n  z-index: 23;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(28) {\n  z-index: 22;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(29) {\n  z-index: 21;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(30) {\n  z-index: 20;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(31) {\n  z-index: 19;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(32) {\n  z-index: 18;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(33) {\n  z-index: 17;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(34) {\n  z-index: 16;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(35) {\n  z-index: 15;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(36) {\n  z-index: 14;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(37) {\n  z-index: 13;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(38) {\n  z-index: 12;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(39) {\n  z-index: 11;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(40) {\n  z-index: 10;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(41) {\n  z-index: 9;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(42) {\n  z-index: 8;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(43) {\n  z-index: 7;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(44) {\n  z-index: 6;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(45) {\n  z-index: 5;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(46) {\n  z-index: 4;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(47) {\n  z-index: 3;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(48) {\n  z-index: 2;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(49) {\n  z-index: 1;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:nth-child(50) {\n  z-index: 0;\n}\n.i-avatar-group.i-avatar__offset-left .i-avatar:not(:first-child) {\n  margin-left: -6px;\n}";
styleInject(css_248z$z);

var AvatarContext = /*#__PURE__*/React.createContext(null);

var AvatarGroup = function AvatarGroup(props) {
  var children = props.children,
      className = props.className,
      style = props.style,
      _props$size = props.size,
      size = _props$size === void 0 ? 32 : _props$size,
      _props$shape = props.shape,
      shape = _props$shape === void 0 ? "circle" : _props$shape,
      color = props.color,
      _props$cascading = props.cascading,
      cascading = _props$cascading === void 0 ? "right" : _props$cascading; // 注入每一项的 context

  var context = {
    // 将头像组的 props 注入单个头像的方法
    inject: function inject(singleAvatarProps) {
      return _objectSpread2({
        size: size,
        shape: shape,
        color: color
      }, singleAvatarProps);
    }
  };
  return /*#__PURE__*/React.createElement(AvatarContext.Provider, {
    value: context
  }, /*#__PURE__*/React.createElement("div", {
    className: classNames('i-avatar-group', "i-avatar__offset-".concat(cascading), className),
    style: _objectSpread2({}, style)
  }, children));
};

var _excluded$D = ["children", "className", "style", "image", "size", "shape", "color"];

var Avatar = function Avatar(props) {
  // 存在头像组时从 Context 注入全局属性
  var context = useContext(AvatarContext);
  var newProps = context ? context.inject(props) : props;

  var children = newProps.children,
      className = newProps.className,
      style = newProps.style,
      image = newProps.image,
      _newProps$size = newProps.size,
      size = _newProps$size === void 0 ? 32 : _newProps$size,
      _newProps$shape = newProps.shape,
      shape = _newProps$shape === void 0 ? "circle" : _newProps$shape,
      color = newProps.color,
      restProps = _objectWithoutProperties(newProps, _excluded$D);

  var _useState = useState(true),
      _useState2 = _slicedToArray(_useState, 2),
      imgLoad = _useState2[0],
      setImgLoad = _useState2[1];

  var handleImgLoadError = function handleImgLoadError() {
    setImgLoad(false);
  };

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-avatar', shape === 'round' && "i-avatar__shape-".concat(shape), className),
    style: _objectSpread2(_objectSpread2({}, style), {}, {
      width: size,
      height: size,
      background: color
    })
  }, restProps), image && imgLoad ? /*#__PURE__*/React.createElement("img", {
    className: 'i-avatar__image',
    src: image,
    onError: handleImgLoadError,
    referrerPolicy: "no-referrer"
  }) : children ? children : /*#__PURE__*/React.createElement(Icon, {
    name: "User",
    color: "#fff"
  }));
};

Avatar.Group = AvatarGroup;
AvatarGroup.displayName = 'AvatarGroup';
Avatar.displayName = 'Avatar';

var css_248z$A = ".i-badge {\n  position: relative;\n  display: inline-block;\n  vertical-align: middle;\n}\n\n.i-badge__content {\n  position: absolute;\n  top: 0;\n  right: 0;\n  display: inline-flex;\n  align-items: center;\n  justify-content: center;\n  box-sizing: border-box;\n  color: #fff;\n  font-size: 12px;\n  white-space: nowrap;\n  text-align: center;\n  background-color: var(--i-error);\n  transform: translate(50%, -50%);\n  transform-origin: 100% 0;\n}\n.i-badge__content.i-badge--circle, .i-badge__content.i-badge--round {\n  min-width: 20px;\n  height: 20px;\n  padding: 0 6px;\n  line-height: 20px;\n}\n.i-badge__content.i-badge--circle {\n  border-radius: 10px;\n}\n.i-badge__content.i-badge--round {\n  border-radius: 6px;\n}\n.i-badge__content.i-badge__size-small.i-badge--circle, .i-badge__content.i-badge__size-small.i-badge--round {\n  min-width: 16px;\n  height: 16px;\n  padding: 0 4px;\n  line-height: 16px;\n}\n.i-badge__content.i-badge--dot {\n  right: 1px;\n  width: 6px;\n  height: 6px;\n  margin-top: 1px;\n  border-radius: 50%;\n}";
styleInject(css_248z$A);

var _excluded$E = ["children", "className", "style", "count", "maxCount", "color", "dot", "size", "shape", "showZero", "offset"];

var Badge = function Badge(props) {
  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      style = props.style,
      _props$count = props.count,
      count = _props$count === void 0 ? 0 : _props$count,
      _props$maxCount = props.maxCount,
      maxCount = _props$maxCount === void 0 ? 99 : _props$maxCount,
      color = props.color,
      _props$dot = props.dot,
      dot = _props$dot === void 0 ? false : _props$dot,
      _props$size = props.size,
      size = _props$size === void 0 ? "medium" : _props$size,
      _props$shape = props.shape,
      shape = _props$shape === void 0 ? "circle" : _props$shape,
      _props$showZero = props.showZero,
      showZero = _props$showZero === void 0 ? true : _props$showZero,
      offset = props.offset,
      restProps = _objectWithoutProperties(props, _excluded$E);

  var getDisplayCount = function getDisplayCount() {
    if (typeof count === 'number' && count > maxCount) {
      return "".concat(maxCount, "+");
    }

    return count;
  };

  var isHidden = !count;

  if (typeof count === 'number') {
    isHidden = count < 1 && !showZero;
  }

  var getOffset = function getOffset() {
    var result = {};

    if (offset) {
      offset[0] && (result.right = +offset[0]);
      offset[1] && (result.marginTop = +offset[1]);
    }

    return result;
  };

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-badge', className)
  }, restProps), children, !isHidden && /*#__PURE__*/React.createElement("sup", {
    className: classNames('i-badge__content', dot ? "i-badge--dot" : shape && "i-badge--".concat(shape), size === 'small' && "i-badge__size-".concat(size)),
    style: _objectSpread2(_objectSpread2({}, style), {}, {
      background: color
    }, getOffset())
  }, !dot ? getDisplayCount() : null));
};

Badge.displayName = 'Badge';

var css_248z$B = ".i-image {\n  position: relative;\n  width: 200px;\n}\n\n.i-image-img {\n  width: 100%;\n  height: auto;\n  vertical-align: middle;\n}\n\n.i-image-mask {\n  position: absolute;\n  display: flex;\n  gap: 8px;\n  align-items: center;\n  justify-content: center;\n  color: #fff;\n  font-size: 14px;\n  background: rgba(0, 0, 0, 0.5);\n  cursor: pointer;\n  opacity: 0;\n  transition: opacity 0.3s;\n  inset: 0;\n}\n.i-image-mask:hover {\n  opacity: 1;\n}\n\n.i-preview-dialog-wrapper {\n  position: fixed;\n  top: 0;\n  left: 0;\n  z-index: 2500;\n  width: 100vw;\n  height: 100vh;\n  pointer-events: none;\n}\n\n.i-preview-dialog__mask {\n  position: absolute;\n  top: 0;\n  left: 0;\n  z-index: 2500;\n  width: 100%;\n  height: 100%;\n  background: rgba(0, 0, 0, 0.6);\n  pointer-events: auto;\n}\n\n.i-preview-dialog__close {\n  position: absolute;\n  top: 40px;\n  right: 40px;\n  z-index: 2501;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 45px;\n  height: 45px;\n  background: var(--i-bg-mid);\n  border-radius: 50%;\n  cursor: pointer;\n  transition: all 0.1s ease-out;\n}\n.i-preview-dialog__close .i-icon {\n  margin: 0;\n}\n.i-preview-dialog__close:hover {\n  background: var(--i-bg-mid-hover);\n}\n\n.i-preview-dialog__handle {\n  position: absolute;\n  bottom: 30px;\n  left: 50%;\n  z-index: 2502;\n  display: flex;\n  align-items: center;\n  justify-content: space-between;\n  box-sizing: border-box;\n  width: 360px;\n  height: 45px;\n  padding: 0 20px;\n  background: var(--i-bg-mid);\n  border-radius: 20px;\n  box-shadow: var(--i-shadow);\n  transform: translate(-50%);\n  -webkit-backdrop-filter: blur(4px);\n          backdrop-filter: blur(4px);\n}\n.i-preview-dialog__handle .i-icon {\n  cursor: pointer;\n  opacity: 0.8;\n  transition: all 0.1s ease-out;\n}\n.i-preview-dialog__handle .i-icon:hover {\n  opacity: 1;\n}\n.i-preview-dialog__handle section {\n  display: flex;\n  gap: 16px;\n  align-items: center;\n}\n\n@-webkit-keyframes iDialogOpen {\n  0% {\n    transform: scale(0.2) translate(-50%, -50%);\n  }\n  100% {\n    transform: scale(1) translate(-50%, -50%);\n  }\n}\n\n@keyframes iDialogOpen {\n  0% {\n    transform: scale(0.2) translate(-50%, -50%);\n  }\n  100% {\n    transform: scale(1) translate(-50%, -50%);\n  }\n}\n.i-preview-img {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  z-index: 2501;\n  box-sizing: border-box;\n  width: -webkit-fill-available;\n  max-width: 100%;\n  max-height: 100%;\n  box-shadow: var(--i-shadow);\n  cursor: -webkit-grab;\n  cursor: grab;\n  -webkit-animation: iDialogOpen 0.2s ease-out;\n          animation: iDialogOpen 0.2s ease-out;\n  pointer-events: auto;\n}";
styleInject(css_248z$B);

var PreviewDialog = function PreviewDialog(props) {
  var _props$visible = props.visible,
      visible = _props$visible === void 0 ? false : _props$visible,
      _props$closeOnEsc = props.closeOnEsc,
      closeOnEsc = _props$closeOnEsc === void 0 ? true : _props$closeOnEsc,
      image = props.image,
      _props$x = props.x,
      x = _props$x === void 0 ? 0 : _props$x,
      _props$y = props.y,
      y = _props$y === void 0 ? 0 : _props$y,
      _props$onClose = props.onClose,
      onClose = _props$onClose === void 0 ? function () {} : _props$onClose;
  var dialogRef = useRef(null);

  var _useState = useState({
    x: "0px",
    y: "0px"
  }),
      _useState2 = _slicedToArray(_useState, 2),
      origin = _useState2[0],
      setOrigin = _useState2[1];

  var handleKeyDown = function handleKeyDown(e) {
    if (e.key === 'Escape') {
      onClose === null || onClose === void 0 ? void 0 : onClose();
    }
  };

  var closePreviewDialog = function closePreviewDialog(e) {
    e.stopPropagation();
    onClose === null || onClose === void 0 ? void 0 : onClose();
    closeOnEsc && document.removeEventListener('keydown', handleKeyDown);
  };

  var _useState3 = useState(1),
      _useState4 = _slicedToArray(_useState3, 2),
      scale = _useState4[0],
      setScale = _useState4[1];

  var handleWheel = function handleWheel(e) {
    e.persist();
    origin.x = "".concat(e.clientX - dialogRef.current.offsetLeft, "px");
    origin.y = "".concat(e.clientY - dialogRef.current.offsetTop, "px");
    setOrigin(_objectSpread2({}, origin));
    var newScale = scale;

    if (e.deltaY > 0) {
      newScale > 0.4 && (newScale -= 0.1);
    } else {
      newScale < 3 && (newScale += 0.1);
    }

    setScale(newScale);
  };

  var _useState5 = useState({
    x: '-50%',
    y: '-50%'
  }),
      _useState6 = _slicedToArray(_useState5, 2),
      position = _useState6[0],
      setPosition = _useState6[1];

  var start = useRef({
    x: 0,
    y: 0
  });

  var handleDown = function handleDown(e) {
    e.stopPropagation();
    start.current.x = e.clientX;
    start.current.y = e.clientY;
    window.addEventListener('mousemove', handleMove);
  };

  var handleMove = function handleMove(e) {
    position.x = "calc(-50% + ".concat(e.clientX - start.current.x, "px)");
    position.y = "calc(-50% + ".concat(e.clientY - start.current.y, "px)");
    setPosition(_objectSpread2({}, position));
    window.addEventListener('mouseup', handleUp);
  };

  var handleUp = function handleUp() {
    position.x = "-50%";
    position.y = "-50%";
    setPosition(_objectSpread2({}, position));
    window.removeEventListener('mousemove', handleMove);
    window.removeEventListener('mouseup', handleUp);
  }; // 打开对话框时禁止背景滚动，对原 overflow 进行备份


  var bodyOverflow = useRef(document.body.style.overflow);
  useEffect(function () {
    if (visible) {
      // 退出键功能
      closeOnEsc && document.addEventListener('keydown', handleKeyDown); // 初始缩放位置

      origin.x = "".concat(x - dialogRef.current.offsetLeft, "px");
      origin.y = "".concat(y - dialogRef.current.offsetTop, "px");
      setOrigin(_objectSpread2({}, origin));
      setScale(1); // 打开对话框时禁止背景滚动

      document.body.style.overflow = 'hidden';
    }

    return function () {
      closeOnEsc && window.removeEventListener('keydown', handleKeyDown); // 关闭对话框时恢复背景滚动

      document.body.style.overflow = bodyOverflow.current;
    };
  }, [visible]);

  var clickHandleBar = function clickHandleBar(e) {
    e.stopPropagation();
  };

  var _useState7 = useState(0),
      _useState8 = _slicedToArray(_useState7, 2),
      rotate = _useState8[0],
      setRotate = _useState8[1];

  var clickHandle = function clickHandle(type) {
    if (type === 'reScale') {
      var newScale = scale;
      newScale > 0.4 && (newScale -= 0.1);
      setScale(newScale);
      origin.x = "0px";
      origin.y = "0px";
      setOrigin(_objectSpread2({}, origin));
    }

    if (type === 'scale') {
      var _newScale = scale;
      _newScale < 3 && (_newScale += 0.1);
      setScale(_newScale);
      origin.x = "0px";
      origin.y = "0px";
      setOrigin(_objectSpread2({}, origin));
    }

    if (type === 'full') {
      var _newScale2 = 1;
      setScale(_newScale2);
    }

    if (type === 'reRotate') {
      var newRotate = rotate - 90;
      setRotate(newRotate);
      origin.x = "center";
      origin.y = "center";
      setOrigin(_objectSpread2({}, origin));
    }

    if (type === 'rotate') {
      var _newRotate = rotate + 90;

      setRotate(_newRotate);
      origin.x = "center";
      origin.y = "center";
      setOrigin(_objectSpread2({}, origin));
    }
  };

  return /*#__PURE__*/React.createElement("div", {
    className: 'i-preview-dialog-wrapper'
  }, /*#__PURE__*/React.createElement(Transition, {
    timeout: 200,
    in: visible,
    animation: 'fade-in',
    key: 'i-preview-dialog__mask'
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-preview-dialog__mask",
    onMouseDown: closePreviewDialog,
    onScroll: function onScroll() {
      return;
    }
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-preview-dialog__close",
    onMouseDown: closePreviewDialog
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "Close",
    size: 20,
    color: "#fff"
  })), /*#__PURE__*/React.createElement("div", {
    className: "i-preview-dialog__handle",
    onMouseDown: clickHandleBar
  }, /*#__PURE__*/React.createElement("section", null, /*#__PURE__*/React.createElement(Icon, {
    name: "SearchSub",
    size: 24,
    color: "#fff",
    onClick: function onClick() {
      return clickHandle('reScale');
    }
  }), /*#__PURE__*/React.createElement(Icon, {
    name: "SearchPlus",
    size: 24,
    color: "#fff",
    onClick: function onClick() {
      return clickHandle('scale');
    }
  })), /*#__PURE__*/React.createElement(Icon, {
    name: "FullScreen",
    size: 24,
    color: "#fff",
    onClick: function onClick() {
      return clickHandle('full');
    }
  }), /*#__PURE__*/React.createElement("section", null, /*#__PURE__*/React.createElement(Icon, {
    name: "RefreshLeft",
    size: 24,
    color: "#fff",
    onClick: function onClick() {
      return clickHandle('reRotate');
    }
  }), /*#__PURE__*/React.createElement(Icon, {
    name: "RefreshRight",
    size: 24,
    color: "#fff",
    onClick: function onClick() {
      return clickHandle('rotate');
    }
  }))), /*#__PURE__*/React.createElement("img", {
    style: {
      transform: "scale(".concat(scale, ") translate(").concat(position.x, ", ").concat(position.y, ") rotate(").concat(rotate, "deg)"),
      transformOrigin: "".concat(origin.x, " ").concat(origin.y)
    },
    className: 'i-preview-img',
    draggable: false,
    src: image,
    ref: dialogRef,
    onWheel: handleWheel,
    onMouseDown: handleDown,
    onMouseUp: handleUp
  }))));
};

var _excluded$F = ["className", "style", "src", "width"];

var IImage = function IImage(props) {
  var className = props.className,
      style = props.style,
      src = props.src,
      width = props.width,
      restProps = _objectWithoutProperties(props, _excluded$F);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      previewShow = _useState2[0],
      setPreviewShow = _useState2[1];

  var iImageRef = useRef(null);

  var _useState3 = useState({
    x: 0,
    y: 0
  }),
      _useState4 = _slicedToArray(_useState3, 2),
      dialogPosition = _useState4[0],
      setDialogPosition = _useState4[1];

  var _useState5 = useState(''),
      _useState6 = _slicedToArray(_useState5, 2),
      url = _useState6[0],
      setUrl = _useState6[1];

  var urlToBase64 = function urlToBase64(url) {
    var Img = new Image();
    Img.src = url + '?v=' + Math.random();
    Img.setAttribute('crossOrigin', 'Anonymous');

    Img.onload = function () {
      var _canvas$getContext;

      var canvas = document.createElement('canvas'),
          width = Img.width,
          height = Img.height;
      canvas.width = width;
      canvas.height = height;
      (_canvas$getContext = canvas.getContext('2d')) === null || _canvas$getContext === void 0 ? void 0 : _canvas$getContext.drawImage(Img, 0, 0, width, height);
      var dataURL = canvas.toDataURL('image/jpeg');
      setUrl(dataURL);
    };
  };

  useEffect(function () {
    src && urlToBase64(src);
    var rect = iImageRef.current.getBoundingClientRect();
    dialogPosition.x = rect.left;
    dialogPosition.y = rect.top;
    setDialogPosition(_objectSpread2({}, dialogPosition));
  }, []);
  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-image', className),
    style: _objectSpread2(_objectSpread2({}, style), {}, {
      width: width
    }),
    ref: iImageRef
  }, restProps), url === '' ? /*#__PURE__*/React.createElement(Loading, null) : /*#__PURE__*/React.createElement("img", {
    className: 'i-image-img',
    src: url
  }), /*#__PURE__*/React.createElement("div", {
    className: "i-image-mask",
    onClick: function onClick() {
      return setPreviewShow(true);
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "View",
    color: "#fff"
  }), "\u9884\u89C8"), /*#__PURE__*/React.createElement(PreviewDialog, {
    visible: previewShow,
    image: url,
    x: dialogPosition.x,
    y: dialogPosition.y,
    onClose: function onClose() {
      return setPreviewShow(false);
    }
  }));
};

IImage.displayName = 'Image';

var css_248z$C = ".i-carousel {\n  position: relative;\n  min-height: 60px;\n}\n.i-carousel.i-carousel__vertical .i-carousel__wrapper {\n  flex-direction: column;\n}\n.i-carousel.i-carousel__vertical .i-carousel__navigation {\n  right: 16px;\n  bottom: 50%;\n  left: unset;\n  flex-direction: column;\n  transform: translateY(50%);\n}\n.i-carousel.i-carousel__vertical .i-carousel__navigation .i-carousel__navigation-item {\n  width: 6px;\n  height: 26px;\n}\n.i-carousel.i-carousel__vertical .i-carousel__arrow-last,\n.i-carousel.i-carousel__vertical .i-carousel__arrow-next {\n  top: unset;\n  right: unset;\n  left: 50%;\n  transform: translateX(-50%) rotate(90deg);\n}\n.i-carousel.i-carousel__vertical .i-carousel__arrow-last {\n  top: 16px;\n}\n.i-carousel.i-carousel__vertical .i-carousel__arrow-next {\n  bottom: 16px;\n}\n.i-carousel.i-carousel__card .i-carousel__wrapper {\n  display: block;\n}\n.i-carousel.i-carousel__card .i-carousel-item {\n  position: absolute;\n  top: 0;\n  left: 0;\n  z-index: 0;\n  width: 41.5%;\n  height: 100%;\n}\n.i-carousel.i-carousel__card .i-carousel-item.i-carousel-item__active {\n  z-index: 2;\n}\n\n.i-carousel__content {\n  position: relative;\n  width: 100%;\n  height: 100%;\n  overflow: hidden;\n}\n\n.i-carousel__wrapper {\n  position: relative;\n  display: flex;\n  width: 100%;\n  height: 100%;\n  margin: 0;\n  padding: 0;\n}\n\n.i-carousel-item {\n  display: inline-block;\n  flex: 0 0 auto;\n  width: 100%;\n  height: 100%;\n  list-style: none;\n}\n\n.i-carousel__navigation {\n  position: absolute;\n  bottom: 16px;\n  left: 50%;\n  z-index: 3;\n  display: flex;\n  gap: 10px;\n  align-items: center;\n  margin: 0;\n  padding: 0;\n  transform: translateX(-50%);\n}\n\n.i-carousel__navigation-item {\n  width: 26px;\n  height: 6px;\n  list-style: none;\n  background: rgba(0, 0, 0, 0.1);\n  border-radius: 3px;\n  box-shadow: inset 0 1px 6px rgba(0, 0, 0, 0.12);\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\n.i-carousel__navigation-item.i-carousel__navigation-item__active {\n  background: #fff;\n}\n\n.i-carousel__arrow-last,\n.i-carousel__arrow-next {\n  position: absolute;\n  top: 50%;\n  z-index: 2;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 24px;\n  height: 24px;\n  background: rgba(0, 0, 0, 0.1);\n  border-radius: 50%;\n  box-shadow: inset 0 1px 6px rgba(0, 0, 0, 0.12);\n  transform: translateY(-50%);\n  cursor: pointer;\n  transition: all 0.2s ease-out;\n}\n.i-carousel__arrow-last:hover,\n.i-carousel__arrow-next:hover {\n  background: rgba(0, 0, 0, 0.2);\n}\n\n.i-carousel__arrow-last {\n  left: 16px;\n}\n\n.i-carousel__arrow-next {\n  right: 16px;\n}";
styleInject(css_248z$C);

var _excluded$G = ["children", "className", "style", "index", "innerCurrent", "type", "ifAnimation", "childrenLength", "duration", "wrapWidth", "clickItem"];

var CarouselItem = function CarouselItem(props) {
  var children = props.children,
      className = props.className,
      style = props.style,
      _props$index = props.index,
      index = _props$index === void 0 ? 0 : _props$index,
      _props$innerCurrent = props.innerCurrent,
      innerCurrent = _props$innerCurrent === void 0 ? 0 : _props$innerCurrent,
      _props$type = props.type,
      type = _props$type === void 0 ? 'default' : _props$type,
      _props$ifAnimation = props.ifAnimation,
      _props$childrenLength = props.childrenLength,
      childrenLength = _props$childrenLength === void 0 ? 1 : _props$childrenLength,
      _props$duration = props.duration,
      duration = _props$duration === void 0 ? 300 : _props$duration,
      _props$wrapWidth = props.wrapWidth,
      wrapWidth = _props$wrapWidth === void 0 ? 0 : _props$wrapWidth,
      clickItem = props.clickItem,
      restProps = _objectWithoutProperties(props, _excluded$G);

  var disposeIndex = function disposeIndex(index, innerCurrent, childrenLength) {
    if (innerCurrent === 0 && index === childrenLength - 1) {
      return -1;
    }

    if (innerCurrent === childrenLength - 1 && index === 0) {
      return childrenLength;
    }

    if (index < innerCurrent - 1 && innerCurrent - index >= childrenLength / 2) {
      return childrenLength + 1;
    }

    if (index > innerCurrent + 1 && index - innerCurrent >= childrenLength / 2) {
      return -2;
    }

    return index;
  };

  var CARD_SCALE = 210 / 332; // 缩放比例

  var itemWidth = 0.415; // 宽度比例

  var calculateTranslate = function calculateTranslate(index, innerCurrent, parentWidth, inStage) {
    if (inStage) {
      return parentWidth * ((index - innerCurrent) * (1 - itemWidth * CARD_SCALE) - itemWidth + 1) / 2;
    }

    if (index < innerCurrent) {
      return -itemWidth * (1 + CARD_SCALE) * parentWidth / 2;
    }

    return (2 + itemWidth * (CARD_SCALE - 1)) * parentWidth / 2;
  };

  var getZIndex = function getZIndex(isActivity, inStage) {
    if (isActivity) {
      return 2;
    }

    if (inStage) {
      return 1;
    }

    return 0;
  };

  var getItemStyle = function getItemStyle() {
    if (type === 'card') {
      var translateIndex = index !== innerCurrent && childrenLength > 2 ? disposeIndex(index, innerCurrent, childrenLength) : index;
      var inStage = Math.round(Math.abs(translateIndex - innerCurrent)) <= 1;
      var translate = calculateTranslate(translateIndex, innerCurrent, wrapWidth, inStage).toFixed(2);
      var isActivity = translateIndex === innerCurrent;
      var zIndex = getZIndex(isActivity, inStage);
      return _objectSpread2({
        msTransform: "translateX(".concat(translate, "px) scale(").concat(isActivity ? 1 : CARD_SCALE, ")"),
        WebkitTransform: "translateX(".concat(translate, "px) scale(").concat(isActivity ? 1 : CARD_SCALE, ")"),
        transform: "translateX(".concat(translate, "px) scale(").concat(isActivity ? 1 : CARD_SCALE, ")"),
        transition: "transform ".concat(duration / 1000, "s ease"),
        zIndex: zIndex
      }, style);
    }

    return _objectSpread2({}, style);
  };

  return /*#__PURE__*/React.createElement("li", _objectSpread2({
    className: classNames('i-carousel-item', className),
    style: getItemStyle(),
    onClick: function onClick() {
      return clickItem === null || clickItem === void 0 ? void 0 : clickItem(index);
    }
  }, restProps), children);
};

var CarouselNavigation = function CarouselNavigation(props) {
  var _props$itemNum = props.itemNum,
      itemNum = _props$itemNum === void 0 ? 0 : _props$itemNum,
      _props$current = props.current,
      current = _props$current === void 0 ? 0 : _props$current,
      onEnter = props.onEnter;

  var lists = _.range(0, itemNum);

  var handleEnterItem = function handleEnterItem(index) {
    onEnter === null || onEnter === void 0 ? void 0 : onEnter(index);
  };

  return /*#__PURE__*/React.createElement("ul", {
    className: 'i-carousel__navigation'
  }, lists.map(function (item) {
    return /*#__PURE__*/React.createElement("li", {
      className: classNames('i-carousel__navigation-item', current - 1 === item && 'i-carousel__navigation-item__active'),
      onMouseEnter: function onMouseEnter() {
        return handleEnterItem(item);
      },
      key: item
    });
  }));
};

var _excluded$H = ["children", "className", "style", "defaultCurrent", "width", "height", "autoPlay", "interval", "stopOnHover", "type", "direction", "duration", "onChange"];

var Carousel = function Carousel(props) {
  var children = props.children,
      className = props.className,
      style = props.style,
      _props$defaultCurrent = props.defaultCurrent,
      defaultCurrent = _props$defaultCurrent === void 0 ? 0 : _props$defaultCurrent,
      _props$width = props.width,
      width = _props$width === void 0 ? '100%' : _props$width,
      _props$height = props.height,
      height = _props$height === void 0 ? 300 : _props$height,
      _props$autoPlay = props.autoPlay,
      autoPlay = _props$autoPlay === void 0 ? false : _props$autoPlay,
      _props$interval = props.interval,
      interval = _props$interval === void 0 ? 3 : _props$interval,
      _props$stopOnHover = props.stopOnHover,
      stopOnHover = _props$stopOnHover === void 0 ? true : _props$stopOnHover,
      _props$type = props.type,
      type = _props$type === void 0 ? 'default' : _props$type,
      _props$direction = props.direction,
      direction = _props$direction === void 0 ? 'horizontal' : _props$direction,
      _props$duration = props.duration,
      duration = _props$duration === void 0 ? 300 : _props$duration,
      onChange = props.onChange,
      restProps = _objectWithoutProperties(props, _excluded$H);

  var resetDefaultCurrent = function resetDefaultCurrent(index) {
    if (type === 'default') {
      if (index >= childrenLength) {
        return 0;
      } else if (index <= -1) {
        return childrenLength - 1;
      } else {
        return index + 1;
      }
    } else {
      return index;
    }
  };

  var _useState = useState(resetDefaultCurrent(defaultCurrent)),
      _useState2 = _slicedToArray(_useState, 2),
      innerCurrent = _useState2[0],
      setInnerCurrent = _useState2[1]; // 进行子组件筛选，创建子节点列表


  var childrenList = useMemo(function () {
    return React.Children.toArray(children).filter(function (child) {
      return child.type.displayName === CarouselItem.displayName;
    });
  }, [children]);
  var childrenLength = childrenList.length;
  var carouselRef = useRef(null);

  var _useState3 = useState(0),
      _useState4 = _slicedToArray(_useState3, 2),
      wrapWidth = _useState4[0],
      setWrapWidth = _useState4[1];

  useEffect(function () {
    carouselRef.current && setWrapWidth(carouselRef.current.getBoundingClientRect().width);
  }, []); // 创建渲染用的节点列表

  var carouselItemList = childrenList.map(function (child, index) {
    return /*#__PURE__*/React.cloneElement(child, _objectSpread2({
      key: index,
      index: index,
      innerCurrent: innerCurrent,
      ifAnimation: ifAnimation,
      childrenLength: childrenLength,
      wrapWidth: wrapWidth,
      type: type,
      duration: duration,
      clickItem: function clickItem(index) {
        if (type === 'card') {
          setInnerCurrent(index);
          onChange === null || onChange === void 0 ? void 0 : onChange(index);
        }
      }
    }, child.props));
  }); // 列表头尾补一项（衔接轮播滑动）

  if (childrenLength > 0 && type === 'default') {
    var firstEle = carouselItemList[0];
    var lastEle = carouselItemList[carouselItemList.length - 1];
    carouselItemList.push( /*#__PURE__*/React.cloneElement(firstEle, _objectSpread2(_objectSpread2({}, firstEle.props), {}, {
      key: childrenLength
    })));
    carouselItemList.unshift( /*#__PURE__*/React.cloneElement(lastEle, _objectSpread2(_objectSpread2({}, lastEle.props), {}, {
      key: -1
    })));
  }

  var carouselItemLength = carouselItemList.length;

  var _useState5 = useState(false),
      _useState6 = _slicedToArray(_useState5, 2),
      ifAnimation = _useState6[0],
      setIfAnimation = _useState6[1];

  var animationTimer = useRef(null); // 计时器指针
  // 轮播图通用跳转函数

  var handleTo = useCallback(function (index, handle) {
    setIfAnimation(true);
    setInnerCurrent(index);

    if (handle === 'last') {
      if (index > 0) {
        onChange === null || onChange === void 0 ? void 0 : onChange(index - 1);
      } else {
        onChange === null || onChange === void 0 ? void 0 : onChange(childrenLength - 1);
      }
    } else {
      if (index <= childrenLength) {
        onChange === null || onChange === void 0 ? void 0 : onChange(index - 1);
      } else {
        onChange === null || onChange === void 0 ? void 0 : onChange(0);
      }
    }
  }, [childrenLength, onChange]); // 监听每次轮播结束

  useEffect(function () {
    if (animationTimer.current) {
      clearTimeout(animationTimer.current);
      animationTimer.current = null;
    }

    animationTimer.current = setTimeout(function () {
      setIfAnimation(false);

      if (type !== 'card') {
        if (innerCurrent + 1 >= carouselItemLength) {
          setInnerCurrent(1);
        }

        if (innerCurrent <= 0) {
          setInnerCurrent(carouselItemLength - 2);
        }
      }
    }, duration + 50);
  }, [innerCurrent, carouselItemLength, duration, type]);

  var _useState7 = useState(false),
      _useState8 = _slicedToArray(_useState7, 2),
      ifHoverContent = _useState8[0],
      setIfHoverContent = _useState8[1];

  var handleEnterContent = function handleEnterContent() {
    stopOnHover && setIfHoverContent(true);
  };

  var handleLeaveContent = function handleLeaveContent() {
    stopOnHover && setIfHoverContent(false);
  }; // 自动轮播


  var loopTimer = useRef(null); // 自动轮播指针

  var setLoopTimer = useCallback(function () {
    if (!ifHoverContent && autoPlay && interval > 0) {
      loopTimer.current = setTimeout(function () {
        handleTo(innerCurrent + 1);
      }, innerCurrent === 0 ? interval * 1000 - (duration + 50) : interval * 1000);
    }
  }, [autoPlay, ifHoverContent, innerCurrent, duration, interval, handleTo]);
  var clearLoopTimer = useCallback(function () {
    if (loopTimer.current) {
      clearTimeout(loopTimer.current);
      loopTimer.current = null;
    }
  }, []);
  useEffect(function () {
    setLoopTimer();
    return function () {
      return clearLoopTimer();
    };
  }, [setLoopTimer]);

  var handleClickArrow = function handleClickArrow(handle) {
    if (ifAnimation) {
      return false;
    } else {
      if (handle === 'last') {
        if (innerCurrent - 1 < 0) {
          return handleTo(childrenLength - 1, 'last');
        } else {
          return handleTo(innerCurrent - 1, 'last');
        }
      }

      if (handle === 'next') {
        if (type === 'card') {
          return handleTo(innerCurrent + 1 >= carouselItemLength ? 0 : innerCurrent + 1, 'next');
        } else {
          return handleTo(innerCurrent + 1, 'next');
        }
      }
    }
  }; // Item 包裹层样式


  var getWrapperStyle = function getWrapperStyle() {
    if (type === 'card') ; else {
      // 默认样式轮播
      if (direction === 'vertical') {
        return {
          transform: "translate3d(0, -".concat(innerCurrent * 100, "%, 0px)"),
          transition: ifAnimation ? "transform ".concat(duration / 1000, "s ease") : ''
        };
      } else {
        return {
          transform: "translate3d(-".concat(innerCurrent * 100, "%, 0px, 0px)"),
          transition: ifAnimation ? "transform ".concat(duration / 1000, "s ease") : ''
        };
      }
    }
  };

  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-carousel', direction === 'vertical' && 'i-carousel__vertical', type === 'card' && 'i-carousel__card', className),
    style: _objectSpread2(_objectSpread2({}, style), {}, {
      width: width,
      height: height
    }),
    ref: carouselRef
  }, restProps), /*#__PURE__*/React.createElement("div", {
    className: "i-carousel__content",
    onMouseEnter: handleEnterContent,
    onMouseLeave: handleLeaveContent
  }, /*#__PURE__*/React.createElement("ul", {
    className: 'i-carousel__wrapper',
    style: getWrapperStyle()
  }, carouselItemList)), /*#__PURE__*/React.createElement(CarouselNavigation, {
    itemNum: childrenLength,
    current: type === 'default' ? innerCurrent : innerCurrent + 1,
    onEnter: function onEnter(current) {
      return handleTo(type === 'default' ? current + 1 : current);
    }
  }), /*#__PURE__*/React.createElement("div", {
    className: "i-carousel__arrow-last",
    onClick: function onClick() {
      return handleClickArrow('last');
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    color: "#fff",
    name: "ArrowLeft"
  })), /*#__PURE__*/React.createElement("div", {
    className: "i-carousel__arrow-next",
    onClick: function onClick() {
      return handleClickArrow('next');
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    color: "#fff",
    name: "ArrowRight"
  })));
};

Carousel.Item = CarouselItem;
CarouselItem.displayName = 'CarouselItem';
Carousel.displayName = 'Carousel';

var css_248z$D = ".i-alert {\n  position: relative;\n  display: flex;\n  align-items: center;\n  box-sizing: border-box;\n  width: 100%;\n  margin: 0;\n  padding: 12px 20px;\n  overflow: hidden;\n  border-radius: 4px;\n  opacity: 1;\n  transition: opacity 0.2s ease-out;\n}\n\n.i-alert--content {\n  padding-right: 26px;\n}\n\n.i-alert--title {\n  margin-bottom: 6px;\n  font-weight: bold;\n  font-size: 14px;\n}\n\n.i-alert--description {\n  box-sizing: border-box;\n  margin: 0;\n  font-size: 14px;\n  word-break: break-all;\n}\n\n.i-alert--operation {\n  display: inline-block;\n  box-sizing: border-box;\n  margin-left: 8px;\n  color: var(--i-primary-txt);\n  cursor: pointer;\n  -webkit-user-select: none;\n     -moz-user-select: none;\n      -ms-user-select: none;\n          user-select: none;\n}\n.i-alert--operation:hover {\n  color: var(--i-primary-hover);\n}\n.i-alert--operation:active {\n  color: var(--i-primary-active);\n}\n\n.i-alert--close-btn {\n  position: absolute;\n  right: 16px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  padding: 4px;\n  cursor: pointer;\n}\n.i-alert--close-btn:hover .icon-Close {\n  color: var(--i-font-3) !important;\n  transition: color 0.2s ease-out;\n}\n\n.i-alert--type-info {\n  color: var(--i-font-5);\n  background-color: var(--i-bg-hover);\n}\n.i-alert--type-info .i-icon {\n  align-self: flex-start;\n  margin-top: 2px;\n  margin-right: 8px;\n  color: var(--i-font-5) !important;\n}\n.i-alert--type-info .icon-Close {\n  margin-right: 0;\n  color: var(--i-font-5) !important;\n}\n\n.i-alert--type-success {\n  color: var(--i-success);\n  background-color: var(--i-success-bg);\n}\n.i-alert--type-success .i-icon {\n  align-self: flex-start;\n  margin-top: 2px;\n  margin-right: 8px;\n  color: var(--i-success) !important;\n}\n.i-alert--type-success .icon-Close {\n  margin-right: 0;\n  color: var(--i-font-5) !important;\n}\n\n.i-alert--type-warning {\n  color: var(--i-warning);\n  background-color: var(--i-warning-bg);\n}\n.i-alert--type-warning .i-icon {\n  align-self: flex-start;\n  margin-top: 2px;\n  margin-right: 8px;\n  color: var(--i-warning) !important;\n}\n.i-alert--type-warning .icon-Close {\n  margin-right: 0;\n  color: var(--i-font-5) !important;\n}\n\n.i-alert--type-error {\n  color: var(--i-error);\n  background-color: var(--i-error-bg);\n}\n.i-alert--type-error .i-icon {\n  align-self: flex-start;\n  margin-top: 2px;\n  margin-right: 8px;\n  color: var(--i-error) !important;\n}\n.i-alert--type-error .icon-Close {\n  margin-right: 0;\n  color: var(--i-font-5) !important;\n}";
styleInject(css_248z$D);

var _excluded$I = ["className", "closable", "message", "operation", "style", "title", "type"];

var Alert = function Alert(props) {
  var className = props.className,
      _props$closable = props.closable,
      closable = _props$closable === void 0 ? false : _props$closable,
      _props$message = props.message,
      message = _props$message === void 0 ? '' : _props$message,
      operation = props.operation,
      style = props.style,
      title = props.title,
      _props$type = props.type,
      type = _props$type === void 0 ? 'info' : _props$type,
      restProps = _objectWithoutProperties(props, _excluded$I);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      closed = _useState2[0],
      setClosed = _useState2[1];

  var handleCloseAlert = function handleCloseAlert() {
    setClosed(true);
  };

  return closed ? null : /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: classNames('i-alert', "i-alert--type-".concat(type), className),
    style: _objectSpread2({}, style)
  }, restProps), /*#__PURE__*/React.createElement(Icon, {
    name: {
      info: 'TipInfo',
      success: 'TipCheckFill',
      warning: 'TipWarningFill',
      error: 'TipCloseFill'
    }[type],
    size: 16
  }), /*#__PURE__*/React.createElement("div", {
    className: "i-alert--content"
  }, title && /*#__PURE__*/React.createElement("div", {
    className: "i-alert--title"
  }, title), /*#__PURE__*/React.createElement("div", {
    className: "i-alert--description"
  }, message, operation && /*#__PURE__*/React.createElement("div", {
    className: "i-alert--operation"
  }, operation))), closable && /*#__PURE__*/React.createElement("div", {
    className: "i-alert--close-btn",
    onClick: handleCloseAlert
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "Close",
    size: 16
  })));
};

Alert.displayName = 'Alert';

var css_248z$E = ".i-notification {\n  position: relative;\n  display: flex;\n  box-sizing: border-box;\n  width: 400px;\n  padding: 16px;\n  color: var(--i-font-2);\n  font-size: 14px;\n  background-color: var(--i-bg);\n  border-radius: 6px;\n  outline: 0;\n  box-shadow: var(--i-shadow);\n}\n.i-notification .i-icon {\n  margin-right: 8px;\n}\n.i-notification .icon-TipInfo {\n  color: var(--i-primary);\n}\n.i-notification .icon-TipCheckFill {\n  color: var(--i-success);\n}\n.i-notification .icon-TipWarningFill {\n  color: var(--i-warning);\n}\n.i-notification .icon-TipCloseFill {\n  color: var(--i-error);\n}\n\n.i-notification__close {\n  position: absolute;\n  top: 14px;\n  right: 14px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 24px;\n  height: 24px;\n  border-radius: 50%;\n  cursor: pointer;\n  transition: all 0.1s ease-out;\n}\n.i-notification__close .i-icon {\n  margin: 0;\n}\n.i-notification__close:hover {\n  background: var(--i-bg-hover);\n}\n\n.i-notification__main-closeable {\n  padding-right: 24px;\n}\n\n.i-notification__title {\n  margin-bottom: 8px;\n  color: var(--i-font-2);\n  font-size: 16px;\n  line-height: 24px;\n  word-break: break-all;\n}\n\n.i-notification__content {\n  color: var(--i-font-5);\n  line-height: 22px;\n  word-break: break-all;\n}\n\n.i-notification-wrapper {\n  position: fixed;\n  top: 24px;\n  right: 24px;\n  z-index: 5000;\n  display: flex;\n  flex-direction: column;\n  align-items: center;\n}\n.i-notification-wrapper.i-notification-wrapper__bottom-right {\n  top: unset;\n  bottom: 24px;\n}\n.i-notification-wrapper.i-notification-wrapper__top-left {\n  right: unset;\n  left: 24px;\n}\n.i-notification-wrapper.i-notification-wrapper__bottom-left {\n  top: unset;\n  right: unset;\n  bottom: 24px;\n  left: 24px;\n}\n\n.i-notification-wrapper[class*=top] .i-notification:not(:last-of-type) {\n  margin-bottom: 16px;\n}\n\n.i-notification-wrapper[class*=bottom] .i-notification:not(:first-of-type) {\n  margin-top: 16px;\n}\n\n.i-notification-top-left-enter {\n  transform: translateX(-100%);\n  opacity: 0;\n}\n\n.i-notification-top-left-enter-active {\n  transform: translate(0);\n  opacity: 1;\n  transition: all 300ms ease-out;\n}\n\n.i-notification-top-left-exit {\n  opacity: 1;\n}\n\n.i-notification-top-left-exit-active {\n  height: 0 !important;\n  margin-bottom: 0 !important;\n  padding: 0 16px !important;\n  transform: translateY(-100%);\n  opacity: 0;\n  transition: all 300ms ease-out;\n}\n\n.i-notification-top-right-enter {\n  transform: translateX(100%);\n  opacity: 0;\n}\n\n.i-notification-top-right-enter-active {\n  transform: translate(0);\n  opacity: 1;\n  transition: all 300ms ease-out;\n}\n\n.i-notification-top-right-exit {\n  opacity: 1;\n}\n\n.i-notification-top-right-exit-active {\n  height: 0 !important;\n  margin-bottom: 0 !important;\n  padding: 0 16px !important;\n  transform: translateY(-100%);\n  opacity: 0;\n  transition: all 300ms ease-out;\n}\n\n.i-notification-bottom-right-enter {\n  transform: translateX(100%);\n  opacity: 0;\n}\n\n.i-notification-bottom-right-enter-active {\n  transform: translate(0);\n  opacity: 1;\n  transition: all 300ms ease-out;\n}\n\n.i-notification-bottom-right-exit {\n  opacity: 1;\n}\n\n.i-notification-bottom-right-exit-active {\n  height: 0 !important;\n  margin-top: 0 !important;\n  padding: 0 16px !important;\n  transform: translateY(100%);\n  opacity: 0;\n  transition: all 300ms ease-out;\n}\n\n.i-notification-bottom-left-enter {\n  transform: translateX(-100%);\n  opacity: 0;\n}\n\n.i-notification-bottom-left-enter-active {\n  transform: translate(0);\n  opacity: 1;\n  transition: all 300ms ease-out;\n}\n\n.i-notification-bottom-left-exit {\n  opacity: 1;\n}\n\n.i-notification-bottom-left-exit-active {\n  height: 0 !important;\n  margin-top: 0 !important;\n  padding: 0 16px !important;\n  transform: translateY(100%);\n  opacity: 0;\n  transition: all 300ms ease-out;\n}";
styleInject(css_248z$E);

var _excluded$J = ["type", "content", "title", "closeable", "entered", "onClose"];

var Notification = function Notification(props) {
  var _props$type = props.type,
      type = _props$type === void 0 ? 'info' : _props$type,
      content = props.content,
      title = props.title,
      _props$closeable = props.closeable,
      closeable = _props$closeable === void 0 ? false : _props$closeable,
      _props$entered = props.entered,
      entered = _props$entered === void 0 ? false : _props$entered,
      onClose = props.onClose,
      restProps = _objectWithoutProperties(props, _excluded$J);

  var ntfRef = useRef(null);

  var _useState = useState(undefined),
      _useState2 = _slicedToArray(_useState, 2),
      ntfHeight = _useState2[0],
      setNtfHeight = _useState2[1];

  useEffect(function () {
    if (entered) {
      var _ntfRef$current$getBo = ntfRef.current.getBoundingClientRect(),
          height = _ntfRef$current$getBo.height;

      setNtfHeight(height);
    }
  }, [entered]);
  return /*#__PURE__*/React.createElement("div", _objectSpread2({
    className: "i-notification"
  }, restProps), /*#__PURE__*/React.createElement(Icon, {
    name: {
      info: 'TipInfo',
      success: 'TipCheckFill',
      warning: 'TipWarningFill',
      error: 'TipCloseFill'
    }[type],
    size: 20
  }), /*#__PURE__*/React.createElement("div", {
    className: classNames('i-notification__main', closeable && 'i-notification__main-closeable'),
    style: {
      height: ntfHeight
    },
    ref: ntfRef
  }, title && /*#__PURE__*/React.createElement("div", {
    className: "i-notification__title"
  }, title), /*#__PURE__*/React.createElement("div", {
    className: "i-notification__content"
  }, content)), closeable && /*#__PURE__*/React.createElement("div", {
    className: "i-notification__close",
    onClick: function onClick() {
      return onClose === null || onClose === void 0 ? void 0 : onClose();
    }
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "Close"
  })));
};

Notification.displayName = 'Notification';

var NotificationList = function NotificationList(props) {
  var listData = props.listData,
      _props$position = props.position,
      position = _props$position === void 0 ? 'top-right' : _props$position,
      _onClose = props.onClose;

  var _useState = useState([]),
      _useState2 = _slicedToArray(_useState, 2),
      enteredIds = _useState2[0],
      setEnteredIds = _useState2[1];

  var handleEntered = function handleEntered(id) {
    enteredIds.push(id);
    setEnteredIds(_toConsumableArray(enteredIds));
  };

  return /*#__PURE__*/React.createElement(TransitionGroup, null, listData.map(function (_ref, index) {
    var id = _ref.id,
        type = _ref.type,
        title = _ref.title,
        content = _ref.content,
        closeable = _ref.closeable;
    return /*#__PURE__*/React.createElement(Transition, {
      timeout: 300,
      in: true,
      animation: "notification-".concat(position),
      key: id,
      onEntered: function onEntered() {
        return handleEntered(id);
      }
    }, /*#__PURE__*/React.createElement(Notification, {
      type: type,
      title: title,
      content: content,
      closeable: closeable,
      entered: enteredIds.includes(id),
      onClose: function onClose() {
        return _onClose === null || _onClose === void 0 ? void 0 : _onClose(index, position);
      }
    }));
  }));
};

NotificationList.displayName = 'NotificationList';

var popupWrapper$2 = useContainer('i-popup-wrapper', document.body);
var notificationWrapper = useContainer('i-notification-container', popupWrapper$2);

var getWrapper$1 = function getWrapper(location) {
  return document.querySelector("#i-notification-wrapper__".concat(location));
};

var notificationList = {
  'top-left': [],
  'top-right': [],
  'bottom-left': [],
  'bottom-right': []
};

var handleClose = function handleClose(index, position) {
  notificationList[position].splice(index, 1);
  ReactDOM.render( /*#__PURE__*/React.createElement(NotificationList, {
    onClose: handleClose,
    position: position,
    listData: notificationList[position]
  }), getWrapper$1(position));
};

var createNotificationWrapper = function createNotificationWrapper(position) {
  var idName = "i-notification-wrapper__".concat(position);
  var container = useContainer(idName, notificationWrapper, "i-notification-wrapper ".concat(idName));
  ReactDOM.render( /*#__PURE__*/React.createElement(NotificationList, {
    onClose: handleClose,
    position: position,
    listData: notificationList[position]
  }), container);
};

createNotificationWrapper('top-left');
createNotificationWrapper('top-right');
createNotificationWrapper('bottom-left');
createNotificationWrapper('bottom-right');

var updateNotificationContainer = function updateNotificationContainer(config) {
  var _config$id = config.id,
      id = _config$id === void 0 ? 0 : _config$id,
      _config$position = config.position,
      position = _config$position === void 0 ? 'top-right' : _config$position,
      _config$duration = config.duration,
      duration = _config$duration === void 0 ? 3 : _config$duration;
  position.split('-')[0] === 'top' ? notificationList[position].push(config) : notificationList[position].unshift(config);
  var renderContainer = getWrapper$1(position); // 延迟消除

  if (duration > 0) {
    setTimeout(function () {
      notificationList[position].map(function (item, index) {
        if (item.id === id) {
          notificationList[position].splice(index, 1);
        }
      });
      ReactDOM.render( /*#__PURE__*/React.createElement(NotificationList, {
        onClose: handleClose,
        position: position,
        listData: notificationList[position]
      }), renderContainer);
    }, duration * 1000);
  } // 此刻更新


  ReactDOM.render( /*#__PURE__*/React.createElement(NotificationList, {
    onClose: handleClose,
    position: position,
    listData: notificationList[position]
  }), renderContainer);
};

var openNotification = function openNotification(type, NotificationConfig) {
  var _NotificationConfig$d, _NotificationConfig$p, _NotificationConfig$c;

  var duration = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 3;
  var position = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 'top-right';
  var closeable = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : false;
  var isConfigMode = _typeof(NotificationConfig) === 'object' && ! /*#__PURE__*/React.isValidElement(NotificationConfig);
  var mergeConfig = {
    id: Date.now(),
    type: type,
    title: isConfigMode ? NotificationConfig === null || NotificationConfig === void 0 ? void 0 : NotificationConfig.title : undefined,
    content: isConfigMode ? NotificationConfig === null || NotificationConfig === void 0 ? void 0 : NotificationConfig.content : NotificationConfig,
    duration: isConfigMode ? (_NotificationConfig$d = NotificationConfig === null || NotificationConfig === void 0 ? void 0 : NotificationConfig.duration) !== null && _NotificationConfig$d !== void 0 ? _NotificationConfig$d : 3 : duration,
    position: isConfigMode ? (_NotificationConfig$p = NotificationConfig.position) !== null && _NotificationConfig$p !== void 0 ? _NotificationConfig$p : 'top-right' : position,
    closeable: isConfigMode ? (_NotificationConfig$c = NotificationConfig === null || NotificationConfig === void 0 ? void 0 : NotificationConfig.closeable) !== null && _NotificationConfig$c !== void 0 ? _NotificationConfig$c : false : closeable
  };
  updateNotificationContainer(mergeConfig);
};

var clearNotification = function clearNotification(position) {
  var positionArr = ['top-left', 'top-right', 'bottom-left', 'bottom-right'];

  if (position) {
    notificationList[position] = [];
    ReactDOM.render( /*#__PURE__*/React.createElement(NotificationList, {
      onClose: handleClose,
      position: position,
      listData: []
    }), getWrapper$1(position));
  } else {
    positionArr.forEach(function (item) {
      notificationList[item] = [];
      ReactDOM.render( /*#__PURE__*/React.createElement(NotificationList, {
        onClose: handleClose,
        position: item,
        listData: []
      }), getWrapper$1(item));
    });
  }
};

Notification.info = function (NotificationConfig, duration, position, closeable) {
  return openNotification('info', NotificationConfig, duration, position, closeable);
};

Notification.success = function (NotificationConfig, duration, position, closeable) {
  return openNotification('success', NotificationConfig, duration, position, closeable);
};

Notification.warning = function (NotificationConfig, duration, position, closeable) {
  return openNotification('warning', NotificationConfig, duration, position, closeable);
};

Notification.error = function (NotificationConfig, duration, position, closeable) {
  return openNotification('error', NotificationConfig, duration, position, closeable);
};

Notification.clear = function (position) {
  return clearNotification(position);
};

Notification.displayName = 'Notification';

var css_248z$F = ".i-dialog-wrapper {\n  position: fixed;\n  top: 0;\n  left: 0;\n  z-index: 2500;\n  width: 100vw;\n  height: 100vh;\n  pointer-events: none;\n}\n\n.i-dialog__mask {\n  position: absolute;\n  top: 0;\n  left: 0;\n  z-index: 2500;\n  width: 100%;\n  height: 100%;\n  background: rgba(0, 0, 0, 0.6);\n  pointer-events: auto;\n}\n\n@-webkit-keyframes iDialogOpen {\n  0% {\n    transform: scale(0.2) translate(-50%, -50%);\n  }\n  100% {\n    transform: scale(1) translate(-50%, -50%);\n  }\n}\n\n@keyframes iDialogOpen {\n  0% {\n    transform: scale(0.2) translate(-50%, -50%);\n  }\n  100% {\n    transform: scale(1) translate(-50%, -50%);\n  }\n}\n.i-dialog {\n  position: absolute;\n  top: 50%;\n  left: 50%;\n  z-index: 2501;\n  box-sizing: border-box;\n  width: 520px;\n  max-height: 100%;\n  overflow: auto;\n  color: var(--i-font-2);\n  font-size: 14px;\n  background: var(--i-bg);\n  border: 1px solid var(--i-border);\n  border-radius: 6px;\n  box-shadow: var(--i-shadow);\n  -webkit-animation: iDialogOpen 0.2s ease-out forwards;\n          animation: iDialogOpen 0.2s ease-out forwards;\n  pointer-events: auto;\n}\n\n.i-dialog__close {\n  position: absolute;\n  top: 14px;\n  right: 14px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 24px;\n  height: 24px;\n  border-radius: 50%;\n  cursor: pointer;\n  transition: all 0.1s ease-out;\n}\n.i-dialog__close .i-icon {\n  margin: 0;\n}\n.i-dialog__close:hover {\n  background: var(--i-bg-hover);\n}\n\n.i-dialog__header,\n.i-dialog__body,\n.i-dialog__footer {\n  box-sizing: border-box;\n  padding: 16px;\n}\n\n.i-dialog__body {\n  overflow: overlay;\n  overflow: auto;\n}\n\n.i-dialog__header {\n  display: flex;\n  align-items: center;\n  font-weight: 700;\n  font-size: 16px;\n  word-break: break-word;\n}\n.i-dialog__header .i-icon {\n  margin-right: 8px;\n  font-size: 20px;\n}\n.i-dialog__header .icon-TipInfo {\n  color: var(--i-primary);\n}\n.i-dialog__header .icon-TipCheckFill {\n  color: var(--i-success);\n}\n.i-dialog__header .icon-TipWarningFill {\n  color: var(--i-warning);\n}\n.i-dialog__header .icon-TipCloseFill {\n  color: var(--i-error);\n}\n\n.i-dialog__footer {\n  width: 100%;\n  text-align: right;\n}\n.i-dialog__footer .i-button + .i-button {\n  margin-left: 10px;\n}";
styleInject(css_248z$F);

var _excluded$K = ["children", "className", "style", "visible", "closeOnEsc", "showMask", "width", "header", "footer", "onClose"];

var clickOpenTarget;
var mousePosition;

var getClickPosition = function getClickPosition(e) {
  clickOpenTarget = e.target;
  mousePosition = {
    x: e.clientX,
    y: e.clientY
  };
  setTimeout(function () {
    mousePosition = null;
  }, 100);
};

if (typeof window !== 'undefined' && window.document && window.document.documentElement) {
  document.documentElement.addEventListener('click', getClickPosition, true);
} // 创建对话框容器


var popupWrapper$3 = useContainer('i-popup-wrapper', document.body);
var dialogWrapper = useContainer('i-dialog-wrapper', popupWrapper$3);

var Dialog = function Dialog(props) {
  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      style = props.style,
      _props$visible = props.visible,
      visible = _props$visible === void 0 ? false : _props$visible,
      _props$closeOnEsc = props.closeOnEsc,
      closeOnEsc = _props$closeOnEsc === void 0 ? true : _props$closeOnEsc,
      _props$showMask = props.showMask,
      showMask = _props$showMask === void 0 ? true : _props$showMask,
      width = props.width,
      header = props.header,
      footer = props.footer,
      _props$onClose = props.onClose,
      onClose = _props$onClose === void 0 ? function () {} : _props$onClose,
      restProps = _objectWithoutProperties(props, _excluded$K);

  var handleKeyDown = function handleKeyDown(e) {
    if (e.key === 'Escape') {
      onClose === null || onClose === void 0 ? void 0 : onClose();
    }
  };

  var closeDialog = function closeDialog() {
    onClose === null || onClose === void 0 ? void 0 : onClose();
    closeOnEsc && document.removeEventListener('keydown', handleKeyDown);
  };

  var handleClick = function handleClick(e) {
    if (!useHasParent(e.target, dialogRef.current) && e.target !== clickOpenTarget) {
      closeDialog();
      document.removeEventListener('click', handleClick, true);
    }
  };

  var dialogRef = useRef(null); // 打开对话框时禁止背景滚动，对原 overflow 进行备份

  var bodyOverflow = useRef(document.body.style.overflow);
  useEffect(function () {
    if (visible) {
      // 打开对话框时禁止背景滚动
      document.body.style.overflow = 'hidden'; // 退出键功能

      closeOnEsc && document.addEventListener('keydown', handleKeyDown); // 展开动画出发点

      if (mousePosition && dialogRef.current) {
        dialogRef.current.style.transformOrigin = "".concat(mousePosition.x - dialogRef.current.offsetLeft, "px ").concat(mousePosition.y - dialogRef.current.offsetTop, "px");
      } // 无遮罩层时点击关闭功能


      !showMask && document.addEventListener('click', handleClick, true);
    } else {
      // 关闭对话框时恢复背景滚动
      document.body.style.overflow = bodyOverflow.current;
    }
  }, [visible]);
  var DialogNode = /*#__PURE__*/React.createElement(React.Fragment, null, showMask && /*#__PURE__*/React.createElement(Transition, {
    timeout: 200,
    in: visible,
    animation: 'fade-in',
    key: 'i-dialog__mask'
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-dialog__mask",
    onClick: closeDialog,
    onScroll: function onScroll() {
      return;
    }
  })), /*#__PURE__*/React.createElement(Transition, {
    timeout: 200,
    in: visible,
    animation: 'fade-in',
    key: 'i-dialog'
  }, /*#__PURE__*/React.createElement("div", _objectSpread2({
    ref: dialogRef,
    className: classNames('i-dialog', className),
    style: _objectSpread2(_objectSpread2({}, style || {}), {
      width: width
    })
  }, restProps), /*#__PURE__*/React.createElement("div", {
    className: "i-dialog__close",
    onClick: closeDialog
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "Close"
  })), /*#__PURE__*/React.createElement("div", {
    className: "i-dialog__header"
  }, header), /*#__PURE__*/React.createElement("div", {
    className: "i-dialog__body"
  }, children), /*#__PURE__*/React.createElement("div", {
    className: "i-dialog__footer"
  }, footer ? footer : /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Button, {
    variant: "outline",
    onClick: closeDialog
  }, "\u53D6\u6D88"), /*#__PURE__*/React.createElement(Button, null, "\u786E\u8BA4"))))));
  return /*#__PURE__*/ReactDOM.createPortal(DialogNode, dialogWrapper);
};

Dialog.displayName = 'Dialog';

var css_248z$G = ".i-drawer-wrapper {\n  position: fixed;\n  top: 0;\n  left: 0;\n  z-index: 2400;\n  width: 100vw;\n  height: 100vh;\n  pointer-events: none;\n}\n\n.i-drawer__mask {\n  position: absolute;\n  top: 0;\n  left: 0;\n  z-index: 2400;\n  width: 100%;\n  height: 100%;\n  background: rgba(0, 0, 0, 0.6);\n  pointer-events: auto;\n}\n\n.i-drawer {\n  position: absolute;\n  top: 0;\n  right: 0;\n  z-index: 2401;\n  display: flex;\n  flex-direction: column;\n  box-sizing: border-box;\n  width: 360px;\n  height: 100%;\n  overflow: auto;\n  color: var(--i-font-2);\n  font-size: 14px;\n  background: var(--i-bg);\n  border-left: 1px solid var(--i-border);\n  box-shadow: var(--i-shadow);\n  pointer-events: auto;\n}\n.i-drawer.i-drawer--placement-left {\n  right: unset;\n  left: 0;\n  border-left: unset;\n  border-right: 1px solid var(--i-border);\n}\n.i-drawer.i-drawer--placement-top {\n  width: 100%;\n  height: 300px;\n  border-left: unset;\n  border-bottom: 1px solid var(--i-border);\n}\n.i-drawer.i-drawer--placement-bottom {\n  top: unset;\n  bottom: 0;\n  width: 100%;\n  height: 300px;\n  border-left: unset;\n  border-top: 1px solid var(--i-border);\n}\n\n.i-drawer__close {\n  position: absolute;\n  top: 14px;\n  right: 14px;\n  display: flex;\n  align-items: center;\n  justify-content: center;\n  width: 24px;\n  height: 24px;\n  border-radius: 50%;\n  cursor: pointer;\n  transition: all 0.1s ease-out;\n}\n.i-drawer__close .i-icon {\n  margin: 0;\n}\n.i-drawer__close:hover {\n  background: var(--i-bg-hover);\n}\n\n.i-drawer__header,\n.i-drawer__body,\n.i-drawer__footer {\n  box-sizing: border-box;\n  padding: 16px;\n}\n\n.i-drawer__header {\n  display: flex;\n  align-items: center;\n  font-weight: 700;\n  font-size: 16px;\n  word-break: break-word;\n  border-bottom: 1px solid var(--i-border);\n}\n.i-drawer__header .i-icon {\n  margin-right: 8px;\n  font-size: 20px;\n}\n\n.i-drawer__body {\n  flex: 1;\n  overflow: auto;\n  overflow: overlay;\n}\n\n.i-drawer__footer {\n  width: 100%;\n  text-align: right;\n  border-top: 1px solid var(--i-border);\n}\n.i-drawer__footer .i-button + .i-button {\n  margin-left: 10px;\n}";
styleInject(css_248z$G);

var _excluded$L = ["children", "className", "style", "visible", "closeOnEsc", "showMask", "placement", "width", "height", "header", "footer", "onClose"];

var clickOpenTarget$1;

var getClickPosition$1 = function getClickPosition(e) {
  clickOpenTarget$1 = e.target;
};

if (typeof window !== 'undefined' && window.document && window.document.documentElement) {
  document.documentElement.addEventListener('click', getClickPosition$1, true);
} // 创建抽屉容器


var popupWrapper$4 = useContainer('i-popup-wrapper', document.body);
var drawerWrapper = useContainer('i-drawer-wrapper', popupWrapper$4);

var Drawer = function Drawer(props) {
  var _props$children = props.children,
      children = _props$children === void 0 ? '' : _props$children,
      className = props.className,
      style = props.style,
      _props$visible = props.visible,
      visible = _props$visible === void 0 ? false : _props$visible,
      _props$closeOnEsc = props.closeOnEsc,
      closeOnEsc = _props$closeOnEsc === void 0 ? true : _props$closeOnEsc,
      _props$showMask = props.showMask,
      showMask = _props$showMask === void 0 ? true : _props$showMask,
      _props$placement = props.placement,
      placement = _props$placement === void 0 ? 'right' : _props$placement,
      width = props.width,
      height = props.height,
      header = props.header,
      footer = props.footer,
      _props$onClose = props.onClose,
      onClose = _props$onClose === void 0 ? function () {} : _props$onClose,
      restProps = _objectWithoutProperties(props, _excluded$L);

  var handleKeyDown = function handleKeyDown(e) {
    if (e.key === 'Escape') {
      onClose === null || onClose === void 0 ? void 0 : onClose();
    }
  };

  var closeDrawer = function closeDrawer() {
    onClose === null || onClose === void 0 ? void 0 : onClose();
    closeOnEsc && document.removeEventListener('keydown', handleKeyDown);
  };

  var handleClick = function handleClick(e) {
    if (!useHasParent(e.target, drawerRef.current) && e.target !== clickOpenTarget$1) {
      closeDrawer();
      document.removeEventListener('click', handleClick, true);
    }
  };

  var drawerRef = useRef(null); // 打开抽屉时禁止背景滚动，对原 overflow 进行备份

  var bodyOverflow = useRef(document.body.style.overflow);
  useEffect(function () {
    if (visible) {
      // 打开抽屉时禁止背景滚动
      document.body.style.overflow = 'hidden'; // 退出键功能

      closeOnEsc && document.addEventListener('keydown', handleKeyDown); // 无遮罩层时点击关闭功能

      !showMask && document.addEventListener('click', handleClick, true);
    } else {
      // 关闭抽屉时恢复背景滚动
      document.body.style.overflow = bodyOverflow.current;
    }
  }, [visible]);
  var drawerNode = /*#__PURE__*/React.createElement(React.Fragment, null, showMask && /*#__PURE__*/React.createElement(Transition, {
    timeout: 200,
    in: visible,
    animation: 'fade-in',
    key: 'i-drawer__mask'
  }, /*#__PURE__*/React.createElement("div", {
    className: "i-drawer__mask",
    onClick: closeDrawer
  })), /*#__PURE__*/React.createElement(Transition, {
    timeout: 200,
    in: visible,
    animation: "slide-in-".concat(placement),
    key: 'i-drawer'
  }, /*#__PURE__*/React.createElement("div", _objectSpread2({
    ref: drawerRef,
    className: classNames('i-drawer', placement !== 'right' && "i-drawer--placement-".concat(placement), className),
    style: _objectSpread2(_objectSpread2({}, style || {}), {
      width: width,
      height: height
    })
  }, restProps), /*#__PURE__*/React.createElement("div", {
    className: "i-drawer__close",
    onClick: closeDrawer
  }, /*#__PURE__*/React.createElement(Icon, {
    name: "Close"
  })), /*#__PURE__*/React.createElement("div", {
    className: "i-drawer__header"
  }, header), /*#__PURE__*/React.createElement("div", {
    className: "i-drawer__body"
  }, children), footer !== false ? /*#__PURE__*/React.createElement("div", {
    className: "i-drawer__footer"
  }, footer ? footer : /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Button, {
    variant: "outline",
    onClick: closeDrawer
  }, "\u53D6\u6D88"), /*#__PURE__*/React.createElement(Button, null, "\u786E\u8BA4"))) : /*#__PURE__*/React.createElement(React.Fragment, null))));
  return /*#__PURE__*/ReactDOM.createPortal(drawerNode, drawerWrapper);
};

Drawer.displayName = 'Drawer';

export { Alert, Avatar, BackTop, Badge, Breadcrumb, Button, Carousel, Checkbox, Collapse, ColorPicker, DatePicker, Dialog, Divider, Drawer, Dropdown, Empty, Grid, Icon, IImage as Image, Input, Layout, Loading, Menu, Message, Notification, Pagination, Popup, Progress, Radio, Rate, Scrollbar, Select, Slider, Steps, Switch, Table, Tabs, Tag, Textarea, TimePicker, Upload };
